Class: Aws::CognitoIdentityProvider::Types::AccountTakeoverActionType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AccountTakeoverActionType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass AccountTakeoverActionType data as a hash:
{
notify: false, # required
event_action: "BLOCK", # required, accepts BLOCK, MFA_IF_CONFIGURED, MFA_REQUIRED, NO_ACTION
}
Account takeover action type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_action ⇒ String
The action to take in response to the account takeover action.
-
#notify ⇒ Boolean
Flag specifying whether to send a notification.
Instance Attribute Details
#event_action ⇒ String
The action to take in response to the account takeover action. Valid values are as follows:
-
`BLOCK` Choosing this action will block the request.
-
`MFA_IF_CONFIGURED` Present an MFA challenge if user has configured it, else allow the request.
-
`MFA_REQUIRED` Present an MFA challenge if user has configured it, else block the request.
-
`NO_ACTION` Allow the user to sign in.
70 71 72 73 74 75 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 70 class AccountTakeoverActionType < Struct.new( :notify, :event_action) SENSITIVE = [] include Aws::Structure end |
#notify ⇒ Boolean
Flag specifying whether to send a notification.
70 71 72 73 74 75 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 70 class AccountTakeoverActionType < Struct.new( :notify, :event_action) SENSITIVE = [] include Aws::Structure end |