Class: Aws::CognitoIdentityProvider::Types::AccountTakeoverRiskConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AccountTakeoverRiskConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass AccountTakeoverRiskConfigurationType data as a hash:
{
notify_configuration: {
from: "StringType",
reply_to: "StringType",
source_arn: "ArnType", # required
block_email: {
subject: "EmailNotificationSubjectType", # required
html_body: "EmailNotificationBodyType",
text_body: "EmailNotificationBodyType",
},
no_action_email: {
subject: "EmailNotificationSubjectType", # required
html_body: "EmailNotificationBodyType",
text_body: "EmailNotificationBodyType",
},
mfa_email: {
subject: "EmailNotificationSubjectType", # required
html_body: "EmailNotificationBodyType",
text_body: "EmailNotificationBodyType",
},
},
actions: { # required
low_action: {
notify: false, # required
event_action: "BLOCK", # required, accepts BLOCK, MFA_IF_CONFIGURED, MFA_REQUIRED, NO_ACTION
},
medium_action: {
notify: false, # required
event_action: "BLOCK", # required, accepts BLOCK, MFA_IF_CONFIGURED, MFA_REQUIRED, NO_ACTION
},
high_action: {
notify: false, # required
event_action: "BLOCK", # required, accepts BLOCK, MFA_IF_CONFIGURED, MFA_REQUIRED, NO_ACTION
},
},
}
Configuration for mitigation actions and notification for different levels of risk detected for a potential account takeover.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Types::AccountTakeoverActionsType
Account takeover risk configuration actions.
-
#notify_configuration ⇒ Types::NotifyConfigurationType
The notify configuration used to construct email notifications.
Instance Attribute Details
#actions ⇒ Types::AccountTakeoverActionsType
Account takeover risk configuration actions.
172 173 174 175 176 177 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 172 class AccountTakeoverRiskConfigurationType < Struct.new( :notify_configuration, :actions) SENSITIVE = [] include Aws::Structure end |
#notify_configuration ⇒ Types::NotifyConfigurationType
The notify configuration used to construct email notifications.
172 173 174 175 176 177 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 172 class AccountTakeoverRiskConfigurationType < Struct.new( :notify_configuration, :actions) SENSITIVE = [] include Aws::Structure end |