Class: Aws::CognitoIdentityProvider::Types::AddCustomAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AddCustomAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass AddCustomAttributesRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
custom_attributes: [ # required
{
name: "CustomAttributeNameType",
attribute_data_type: "String", # accepts String, Number, DateTime, Boolean
developer_only_attribute: false,
mutable: false,
required: false,
number_attribute_constraints: {
min_value: "StringType",
max_value: "StringType",
},
string_attribute_constraints: {
min_length: "StringType",
max_length: "StringType",
},
},
],
}
Represents the request to add custom attributes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_attributes ⇒ Array<Types::SchemaAttributeType>
An array of custom attributes, such as Mutable and Name.
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to add custom attributes.
Instance Attribute Details
#custom_attributes ⇒ Array<Types::SchemaAttributeType>
An array of custom attributes, such as Mutable and Name.
216 217 218 219 220 221 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 216 class AddCustomAttributesRequest < Struct.new( :user_pool_id, :custom_attributes) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to add custom attributes.
216 217 218 219 220 221 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 216 class AddCustomAttributesRequest < Struct.new( :user_pool_id, :custom_attributes) SENSITIVE = [] include Aws::Structure end |