Class: Aws::CognitoIdentityProvider::Types::AdminAddUserToGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminAddUserToGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#group_name ⇒ String
The name of the group that you want to add your user to.
-
#user_pool_id ⇒ String
The user pool ID for the user pool.
-
#username ⇒ String
The username of the user that you want to query or modify.
Instance Attribute Details
#group_name ⇒ String
The name of the group that you want to add your user to.
205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 205 class AdminAddUserToGroupRequest < Struct.new( :user_pool_id, :username, :group_name) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool.
205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 205 class AdminAddUserToGroupRequest < Struct.new( :user_pool_id, :username, :group_name) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.
205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 205 class AdminAddUserToGroupRequest < Struct.new( :user_pool_id, :username, :group_name) SENSITIVE = [:username] include Aws::Structure end |