Class: Aws::CognitoIdentityProvider::Types::AdminConfirmSignUpRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminConfirmSignUpRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass AdminConfirmSignUpRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
username: "UsernameType", # required
client_metadata: {
"StringType" => "StringType",
},
}
Represents the request to confirm user registration.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.
-
#user_pool_id ⇒ String
The user pool ID for which you want to confirm user registration.
-
#username ⇒ String
The user name for which you want to confirm user registration.
Instance Attribute Details
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.
If your user pool configuration includes triggers, the AdminConfirmSignUp API action invokes the Lambda function that is specified for the *post confirmation* trigger. When Amazon Cognito invokes this function, it passes a JSON payload, which the function receives as input. In this payload, the `clientMetadata` attribute provides the data that you assigned to the ClientMetadata parameter in your AdminConfirmSignUp request. In your function code in Lambda, you can process the ClientMetadata value to enhance your workflow for your specific needs.
For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.
<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won't do the following:
* Store the ClientMetadata value. This data is available only to
Lambda triggers that are assigned to a user pool to support custom
workflows. If your user pool configuration doesn't include
triggers, the ClientMetadata parameter serves no purpose.
-
Validate the ClientMetadata value.
-
Encrypt the ClientMetadata value. Don't use Amazon Cognito to provide sensitive information.
</note>
321 322 323 324 325 326 327 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 321 class AdminConfirmSignUpRequest < Struct.new( :user_pool_id, :username, :client_metadata) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for which you want to confirm user registration.
321 322 323 324 325 326 327 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 321 class AdminConfirmSignUpRequest < Struct.new( :user_pool_id, :username, :client_metadata) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The user name for which you want to confirm user registration.
321 322 323 324 325 326 327 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 321 class AdminConfirmSignUpRequest < Struct.new( :user_pool_id, :username, :client_metadata) SENSITIVE = [:username] include Aws::Structure end |