Class: Aws::CognitoIdentityProvider::Types::AdminCreateUserConfigType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass AdminCreateUserConfigType data as a hash:

{
  allow_admin_create_user_only: false,
  unused_account_validity_days: 1,
  invite_message_template: {
    sms_message: "SmsVerificationMessageType",
    email_message: "EmailVerificationMessageType",
    email_subject: "EmailVerificationSubjectType",
  },
}

The configuration for creating a new user profile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_admin_create_user_onlyBoolean

Set to `True` if only the administrator is allowed to create user profiles. Set to `False` if users can sign themselves up via an app.

Returns:

  • (Boolean)


384
385
386
387
388
389
390
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 384

class AdminCreateUserConfigType < Struct.new(
  :allow_admin_create_user_only,
  :unused_account_validity_days,
  :invite_message_template)
  SENSITIVE = []
  include Aws::Structure
end

#invite_message_templateTypes::MessageTemplateType



384
385
386
387
388
389
390
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 384

class AdminCreateUserConfigType < Struct.new(
  :allow_admin_create_user_only,
  :unused_account_validity_days,
  :invite_message_template)
  SENSITIVE = []
  include Aws::Structure
end

#unused_account_validity_daysInteger

The user account expiration limit, in days, after which the account is no longer usable. To reset the account after that time limit, you must call `AdminCreateUser` again, specifying `“RESEND”` for the `MessageAction` parameter. The default value for this parameter is 7.

<note markdown=“1”> If you set a value for `TemporaryPasswordValidityDays` in `PasswordPolicy`, that value will be used, and `UnusedAccountValidityDays` will be no longer be an available parameter for that user pool.

</note>

Returns:

  • (Integer)


384
385
386
387
388
389
390
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 384

class AdminCreateUserConfigType < Struct.new(
  :allow_admin_create_user_only,
  :unused_account_validity_days,
  :invite_message_template)
  SENSITIVE = []
  include Aws::Structure
end