Class: Aws::CognitoIdentityProvider::Types::AdminDeleteSoftwareTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminDeleteSoftwareTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#user_pool_id ⇒ String
The ID of the user pool where you want to delete the user's software token.
-
#username ⇒ String
The name of the user that you want to query or modify.
Instance Attribute Details
#user_pool_id ⇒ String
The ID of the user pool where you want to delete the user's software token.
611 612 613 614 615 616 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 611 class AdminDeleteSoftwareTokenRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The name of the user that you want to query or modify. The value of
this parameter is typically your user's username, but it can be any
of their alias attributes. If username isn't an alias attribute
in your user pool, this value must be the sub of a local user or
the username of a user from a third-party IdP.
611 612 613 614 615 616 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 611 class AdminDeleteSoftwareTokenRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |