Class: Aws::CognitoIdentityProvider::Types::AdminDeleteUserAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminDeleteUserAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to delete user attributes as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#user_attribute_names ⇒ Array<String>
An array of strings representing the user attribute names you want to delete.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to delete user attributes.
-
#username ⇒ String
The name of the user that you want to query or modify.
Instance Attribute Details
#user_attribute_names ⇒ Array<String>
An array of strings representing the user attribute names you want to delete.
For custom attributes, you must prepend the custom: prefix to the
attribute name.
646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 646 class AdminDeleteUserAttributesRequest < Struct.new( :user_pool_id, :username, :user_attribute_names) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to delete user attributes.
646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 646 class AdminDeleteUserAttributesRequest < Struct.new( :user_pool_id, :username, :user_attribute_names) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The name of the user that you want to query or modify. The value of
this parameter is typically your user's username, but it can be any
of their alias attributes. If username isn't an alias attribute
in your user pool, this value must be the sub of a local user or
the username of a user from a third-party IdP.
646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 646 class AdminDeleteUserAttributesRequest < Struct.new( :user_pool_id, :username, :user_attribute_names) SENSITIVE = [:username] include Aws::Structure end |