Class: Aws::CognitoIdentityProvider::Types::AdminDisableUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminDisableUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to disable the user as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to disable the user.
-
#username ⇒ String
The username of the user that you want to query or modify.
Instance Attribute Details
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to disable the user.
671 672 673 674 675 676 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 671 class AdminDisableUserRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.
671 672 673 674 675 676 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 671 class AdminDisableUserRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |