Class: Aws::CognitoIdentityProvider::Types::AdminEnableUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminEnableUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request that enables the user as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to enable the user.
-
#username ⇒ String
The user name of the user you want to enable.
Instance Attribute Details
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to enable the user.
570 571 572 573 574 575 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 570 class AdminEnableUserRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The user name of the user you want to enable.
570 571 572 573 574 575 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 570 class AdminEnableUserRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |