Class: Aws::CognitoIdentityProvider::Types::AdminForgetDeviceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminForgetDeviceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Sends the forgot device request, as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#device_key ⇒ String
The key ID of the device that you want to delete.
-
#user_pool_id ⇒ String
The ID of the user pool where the device owner is a user.
-
#username ⇒ String
The name of the user that you want to query or modify.
Instance Attribute Details
#device_key ⇒ String
The key ID of the device that you want to delete.
787 788 789 790 791 792 793 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 787 class AdminForgetDeviceRequest < Struct.new( :user_pool_id, :username, :device_key) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where the device owner is a user.
787 788 789 790 791 792 793 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 787 class AdminForgetDeviceRequest < Struct.new( :user_pool_id, :username, :device_key) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The name of the user that you want to query or modify. The value of
this parameter is typically your user's username, but it can be any
of their alias attributes. If username isn't an alias attribute
in your user pool, this value must be the sub of a local user or
the username of a user from a third-party IdP.
787 788 789 790 791 792 793 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 787 class AdminForgetDeviceRequest < Struct.new( :user_pool_id, :username, :device_key) SENSITIVE = [:username] include Aws::Structure end |