Class: Aws::CognitoIdentityProvider::Types::AdminGetDeviceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminGetDeviceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to get the device, as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#device_key ⇒ String
The device key.
-
#user_pool_id ⇒ String
The user pool ID.
-
#username ⇒ String
The username of the user that you want to query or modify.
Instance Attribute Details
#device_key ⇒ String
The device key.
764 765 766 767 768 769 770 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 764 class AdminGetDeviceRequest < Struct.new( :device_key, :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
764 765 766 767 768 769 770 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 764 class AdminGetDeviceRequest < Struct.new( :device_key, :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.
764 765 766 767 768 769 770 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 764 class AdminGetDeviceRequest < Struct.new( :device_key, :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |