Class: Aws::CognitoIdentityProvider::Types::AdminGetUserAuthFactorsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#user_pool_idString

The ID of the user pool where you want to get information about the user's authentication factors.

Returns:

  • (String)


853
854
855
856
857
858
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 853

class AdminGetUserAuthFactorsRequest < Struct.new(
  :user_pool_id,
  :username)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If username isn't an alias attribute in your user pool, this value must be the sub of a local user or the username of a user from a third-party IdP.

Returns:

  • (String)


853
854
855
856
857
858
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 853

class AdminGetUserAuthFactorsRequest < Struct.new(
  :user_pool_id,
  :username)
  SENSITIVE = [:username]
  include Aws::Structure
end