Class: Aws::CognitoIdentityProvider::Types::AdminGetUserAuthFactorsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#configured_user_auth_factorsArray<String>

The authentication types that are available to the user with USER_AUTH sign-in, for example ["PASSWORD", "WEB_AUTHN"].

PASSWORD can only be used as a first authentication factor. SOFTWARE_TOKEN can only be used as an MFA factor. EMAIL_OTP, SMS_OTP, and WEB_AUTHN can be used as either a first authentication factor or an MFA factor. WEB_AUTHN is available as an MFA factor only when passkey MFA is enabled at the user pool level.

Returns:

  • (Array<String>)


864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 864

class AdminGetUserAuthFactorsResponse < Struct.new(
  :username,
  :preferred_mfa_setting,
  :user_mfa_setting_list,
  :configured_user_auth_factors)
  SENSITIVE = [:username]
  include Aws::Structure
end

#preferred_mfa_settingString

The challenge method that Amazon Cognito returns to the user in response to sign-in requests. Users can prefer SMS message, email message, or TOTP MFA.

Returns:

  • (String)


864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 864

class AdminGetUserAuthFactorsResponse < Struct.new(
  :username,
  :preferred_mfa_setting,
  :user_mfa_setting_list,
  :configured_user_auth_factors)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_mfa_setting_listArray<String>

The MFA options that are activated for the user. The possible values in this list are SMS_MFA, EMAIL_OTP, and SOFTWARE_TOKEN_MFA.

Returns:

  • (Array<String>)


864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 864

class AdminGetUserAuthFactorsResponse < Struct.new(
  :username,
  :preferred_mfa_setting,
  :user_mfa_setting_list,
  :configured_user_auth_factors)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The name of the user who is eligible for the authentication factors in the response.

Returns:

  • (String)


864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 864

class AdminGetUserAuthFactorsResponse < Struct.new(
  :username,
  :preferred_mfa_setting,
  :user_mfa_setting_list,
  :configured_user_auth_factors)
  SENSITIVE = [:username]
  include Aws::Structure
end