Class: Aws::CognitoIdentityProvider::Types::AdminInitiateAuthRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass AdminInitiateAuthRequest data as a hash:

{
  user_pool_id: "UserPoolIdType", # required
  client_id: "ClientIdType", # required
  auth_flow: "USER_SRP_AUTH", # required, accepts USER_SRP_AUTH, REFRESH_TOKEN_AUTH, REFRESH_TOKEN, CUSTOM_AUTH, ADMIN_NO_SRP_AUTH, USER_PASSWORD_AUTH, ADMIN_USER_PASSWORD_AUTH
  auth_parameters: {
    "StringType" => "StringType",
  },
  client_metadata: {
    "StringType" => "StringType",
  },
  analytics_metadata: {
    analytics_endpoint_id: "StringType",
  },
  context_data: {
    ip_address: "StringType", # required
    server_name: "StringType", # required
    server_path: "StringType", # required
    http_headers: [ # required
      {
        header_name: "StringType",
        header_value: "StringType",
      },
    ],
    encoded_data: "StringType",
  },
}

Initiates the authorization request, as an administrator.

Constant Summary collapse

SENSITIVE =
[:client_id, :auth_parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_metadataTypes::AnalyticsMetadataType

The analytics metadata for collecting Amazon Pinpoint metrics for `AdminInitiateAuth` calls.



1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1137

class AdminInitiateAuthRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :auth_flow,
  :auth_parameters,
  :client_metadata,
  :analytics_metadata,
  :context_data)
  SENSITIVE = [:client_id, :auth_parameters]
  include Aws::Structure
end

#auth_flowString

The authentication flow for this call to run. The API action will depend on this value. For example:

  • `REFRESH_TOKEN_AUTH` will take in a valid refresh token and return new tokens.

  • `USER_SRP_AUTH` will take in `USERNAME` and `SRP_A` and return the Secure Remote Password (SRP) protocol variables to be used for next challenge execution.

  • `ADMIN_USER_PASSWORD_AUTH` will take in `USERNAME` and `PASSWORD` and return the next challenge or tokens.

Valid values include:

  • `USER_SRP_AUTH`: Authentication flow for the Secure Remote Password (SRP) protocol.

  • `REFRESH_TOKEN_AUTH`/`REFRESH_TOKEN`: Authentication flow for refreshing the access token and ID token by supplying a valid refresh token.

  • `CUSTOM_AUTH`: Custom authentication flow.

  • `ADMIN_NO_SRP_AUTH`: Non-SRP authentication flow; you can pass in the USERNAME and PASSWORD directly if the flow is enabled for calling the app client.

  • `ADMIN_USER_PASSWORD_AUTH`: Admin-based user password authentication. This replaces the `ADMIN_NO_SRP_AUTH` authentication flow. In this flow, Amazon Cognito receives the password in the request instead of using the SRP process to verify passwords.

Returns:

  • (String)


1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1137

class AdminInitiateAuthRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :auth_flow,
  :auth_parameters,
  :client_metadata,
  :analytics_metadata,
  :context_data)
  SENSITIVE = [:client_id, :auth_parameters]
  include Aws::Structure
end

#auth_parametersHash<String,String>

The authentication parameters. These are inputs corresponding to the `AuthFlow` that you're invoking. The required values depend on the value of `AuthFlow`:

  • For `USER_SRP_AUTH`: `USERNAME` (required), `SRP_A` (required), `SECRET_HASH` (required if the app client is configured with a client secret), `DEVICE_KEY`.

  • For `REFRESH_TOKEN_AUTH/REFRESH_TOKEN`: `REFRESH_TOKEN` (required), `SECRET_HASH` (required if the app client is configured with a client secret), `DEVICE_KEY`.

  • For `ADMIN_NO_SRP_AUTH`: `USERNAME` (required), `SECRET_HASH` (if app client is configured with client secret), `PASSWORD` (required), `DEVICE_KEY`.

  • For `CUSTOM_AUTH`: `USERNAME` (required), `SECRET_HASH` (if app client is configured with client secret), `DEVICE_KEY`. To start the authentication flow with password verification, include `ChallengeName: SRP_A` and `SRP_A: (The SRP_A Value)`.

Returns:

  • (Hash<String,String>)


1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1137

class AdminInitiateAuthRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :auth_flow,
  :auth_parameters,
  :client_metadata,
  :analytics_metadata,
  :context_data)
  SENSITIVE = [:client_id, :auth_parameters]
  include Aws::Structure
end

#client_idString

The app client ID.

Returns:

  • (String)


1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1137

class AdminInitiateAuthRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :auth_flow,
  :auth_parameters,
  :client_metadata,
  :analytics_metadata,
  :context_data)
  SENSITIVE = [:client_id, :auth_parameters]
  include Aws::Structure
end

#client_metadataHash<String,String>

A map of custom key-value pairs that you can provide as input for certain custom workflows that this action triggers.

You create custom workflows by assigning Lambda functions to user pool triggers. When you use the AdminInitiateAuth API action, Amazon Cognito invokes the Lambda functions that are specified for various triggers. The ClientMetadata value is passed as input to the functions for only the following triggers:

  • Pre signup

  • Pre authentication

  • User migration

When Amazon Cognito invokes the functions for these triggers, it passes a JSON payload, which the function receives as input. This payload contains a `validationData` attribute, which provides the data that you assigned to the ClientMetadata parameter in your AdminInitiateAuth request. In your function code in Lambda, you can process the `validationData` value to enhance your workflow for your specific needs.

When you use the AdminInitiateAuth API action, Amazon Cognito also invokes the functions for the following triggers, but it doesn't provide the ClientMetadata value as input:

  • Post authentication

  • Custom message

  • Pre token generation

  • Create auth challenge

  • Define auth challenge

  • Verify auth challenge

For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.

<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won't do the following:

* Store the ClientMetadata value. This data is available only to
 Lambda triggers that are assigned to a user pool to support custom
 workflows. If your user pool configuration doesn't include
 triggers, the ClientMetadata parameter serves no purpose.
  • Validate the ClientMetadata value.

  • Encrypt the ClientMetadata value. Don't use Amazon Cognito to provide sensitive information.

</note>

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools-working-with-aws-lambda-triggers.html

Returns:

  • (Hash<String,String>)


1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1137

class AdminInitiateAuthRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :auth_flow,
  :auth_parameters,
  :client_metadata,
  :analytics_metadata,
  :context_data)
  SENSITIVE = [:client_id, :auth_parameters]
  include Aws::Structure
end

#context_dataTypes::ContextDataType

Contextual data such as the user's device fingerprint, IP address, or location used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.



1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1137

class AdminInitiateAuthRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :auth_flow,
  :auth_parameters,
  :client_metadata,
  :analytics_metadata,
  :context_data)
  SENSITIVE = [:client_id, :auth_parameters]
  include Aws::Structure
end

#user_pool_idString

The ID of the Amazon Cognito user pool.

Returns:

  • (String)


1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1137

class AdminInitiateAuthRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :auth_flow,
  :auth_parameters,
  :client_metadata,
  :analytics_metadata,
  :context_data)
  SENSITIVE = [:client_id, :auth_parameters]
  include Aws::Structure
end