Class: Aws::CognitoIdentityProvider::Types::AdminListDevicesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminListDevicesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to list devices, as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of devices that you want Amazon Cognito to return in the response.
-
#pagination_token ⇒ String
This API operation returns a limited number of results.
-
#user_pool_id ⇒ String
The ID of the user pool where the device owner is a user.
-
#username ⇒ String
The name of the user that you want to query or modify.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of devices that you want Amazon Cognito to return in the response.
1484 1485 1486 1487 1488 1489 1490 1491 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1484 class AdminListDevicesRequest < Struct.new( :user_pool_id, :username, :limit, :pagination_token) SENSITIVE = [:username] include Aws::Structure end |
#pagination_token ⇒ String
This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.
1484 1485 1486 1487 1488 1489 1490 1491 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1484 class AdminListDevicesRequest < Struct.new( :user_pool_id, :username, :limit, :pagination_token) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where the device owner is a user.
1484 1485 1486 1487 1488 1489 1490 1491 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1484 class AdminListDevicesRequest < Struct.new( :user_pool_id, :username, :limit, :pagination_token) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The name of the user that you want to query or modify. The value of
this parameter is typically your user's username, but it can be any
of their alias attributes. If username isn't an alias attribute
in your user pool, this value must be the sub of a local user or
the username of a user from a third-party IdP.
1484 1485 1486 1487 1488 1489 1490 1491 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1484 class AdminListDevicesRequest < Struct.new( :user_pool_id, :username, :limit, :pagination_token) SENSITIVE = [:username] include Aws::Structure end |