Class: Aws::CognitoIdentityProvider::Types::AdminListDevicesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Lists the device's response, as an administrator.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#devicesArray<Types::DeviceType>

An array of devices and their information. Each entry that's returned includes device information, last-accessed and created dates, and the device key.

Returns:



1511
1512
1513
1514
1515
1516
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1511

class AdminListDevicesResponse < Struct.new(
  :devices,
  :pagination_token)
  SENSITIVE = []
  include Aws::Structure
end

#pagination_tokenString

The identifier that Amazon Cognito returned with the previous request to this operation. When you include a pagination token in your request, Amazon Cognito returns the next set of items in the list. By use of this token, you can paginate through the full list of items.

Returns:

  • (String)


1511
1512
1513
1514
1515
1516
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1511

class AdminListDevicesResponse < Struct.new(
  :devices,
  :pagination_token)
  SENSITIVE = []
  include Aws::Structure
end