Class: Aws::CognitoIdentityProvider::Types::AdminResetUserPasswordRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the request to reset a user’s password as an administrator.

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#client_metadataHash<String,String>

A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers.

When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a ‘clientMetadata` attribute that provides the data that you assigned to the ClientMetadata parameter in your request. In your function code, you can process the `clientMetadata` value to enhance your workflow for your specific needs.

To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see [ Connecting API actions to Lambda triggers] in the *Amazon Cognito Developer Guide*.

<note markdown=“1”> When you use the ‘ClientMetadata` parameter, note that Amazon Cognito won’t do the following:

* Store the `ClientMetadata` value. This data is available only to
 Lambda triggers that are assigned to a user pool to support custom
 workflows. If your user pool configuration doesn't include
 triggers, the `ClientMetadata` parameter serves no purpose.
  • Validate the ‘ClientMetadata` value.

  • Encrypt the ‘ClientMetadata` value. Don’t send sensitive information in this parameter.

</note>

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-working-with-lambda-triggers.html#lambda-triggers-by-event

Returns:

  • (Hash<String,String>)


1638
1639
1640
1641
1642
1643
1644
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1638

class AdminResetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :client_metadata)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool where you want to reset the user’s password.

Returns:

  • (String)


1638
1639
1640
1641
1642
1643
1644
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1638

class AdminResetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :client_metadata)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The name of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.

Returns:

  • (String)


1638
1639
1640
1641
1642
1643
1644
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1638

class AdminResetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :client_metadata)
  SENSITIVE = [:username]
  include Aws::Structure
end