Class: Aws::CognitoIdentityProvider::Types::AdminRespondToAuthChallengeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminRespondToAuthChallengeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Responds to the authentication challenge, as an administrator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_result ⇒ Types::AuthenticationResultType
The result returned by the server in response to the authentication request.
-
#challenge_name ⇒ String
The name of the challenge.
-
#challenge_parameters ⇒ Hash<String,String>
The challenge parameters.
-
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service.
Instance Attribute Details
#authentication_result ⇒ Types::AuthenticationResultType
The result returned by the server in response to the authentication request.
1855 1856 1857 1858 1859 1860 1861 1862 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1855 class AdminRespondToAuthChallengeResponse < Struct.new( :challenge_name, :session, :challenge_parameters, :authentication_result) SENSITIVE = [] include Aws::Structure end |
#challenge_name ⇒ String
The name of the challenge. For more information, see [AdminInitiateAuth].
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminInitiateAuth.html
1855 1856 1857 1858 1859 1860 1861 1862 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1855 class AdminRespondToAuthChallengeResponse < Struct.new( :challenge_name, :session, :challenge_parameters, :authentication_result) SENSITIVE = [] include Aws::Structure end |
#challenge_parameters ⇒ Hash<String,String>
The challenge parameters. For more information, see [AdminInitiateAuth].
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminInitiateAuth.html
1855 1856 1857 1858 1859 1860 1861 1862 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1855 class AdminRespondToAuthChallengeResponse < Struct.new( :challenge_name, :session, :challenge_parameters, :authentication_result) SENSITIVE = [] include Aws::Structure end |
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service. If the caller must pass another challenge, they return a session with other challenge parameters. This session should be passed as it is to the next `RespondToAuthChallenge` API call.
1855 1856 1857 1858 1859 1860 1861 1862 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1855 class AdminRespondToAuthChallengeResponse < Struct.new( :challenge_name, :session, :challenge_parameters, :authentication_result) SENSITIVE = [] include Aws::Structure end |