Class: Aws::CognitoIdentityProvider::Types::AdminSetUserMFAPreferenceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminSetUserMFAPreferenceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#email_mfa_settings ⇒ Types::EmailMfaSettingsType
User preferences for email message MFA.
-
#sms_mfa_settings ⇒ Types::SMSMfaSettingsType
User preferences for SMS message MFA.
-
#software_token_mfa_settings ⇒ Types::SoftwareTokenMfaSettingsType
User preferences for time-based one-time password (TOTP) MFA.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to set a user's MFA preferences.
-
#username ⇒ String
The name of the user that you want to query or modify.
-
#web_authn_mfa_settings ⇒ Types::WebAuthnMfaSettingsType
User preferences for passkey MFA.
Instance Attribute Details
#email_mfa_settings ⇒ Types::EmailMfaSettingsType
User preferences for email message MFA. Activates or deactivates email MFA and sets it as the preferred MFA method when multiple methods are available. To activate this setting, your user pool must be in the Essentials tier or higher.
2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2246 class AdminSetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :username, :user_pool_id) SENSITIVE = [:username] include Aws::Structure end |
#sms_mfa_settings ⇒ Types::SMSMfaSettingsType
User preferences for SMS message MFA. Activates or deactivates SMS MFA and sets it as the preferred MFA method when multiple methods are available.
2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2246 class AdminSetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :username, :user_pool_id) SENSITIVE = [:username] include Aws::Structure end |
#software_token_mfa_settings ⇒ Types::SoftwareTokenMfaSettingsType
User preferences for time-based one-time password (TOTP) MFA. Activates or deactivates TOTP MFA and sets it as the preferred MFA method when multiple methods are available.
2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2246 class AdminSetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :username, :user_pool_id) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to set a user's MFA preferences.
2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2246 class AdminSetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :username, :user_pool_id) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The name of the user that you want to query or modify. The value of
this parameter is typically your user's username, but it can be any
of their alias attributes. If username isn't an alias attribute
in your user pool, this value must be the sub of a local user or
the username of a user from a third-party IdP.
2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2246 class AdminSetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :username, :user_pool_id) SENSITIVE = [:username] include Aws::Structure end |
#web_authn_mfa_settings ⇒ Types::WebAuthnMfaSettingsType
User preferences for passkey MFA. Activates or deactivates passkey
MFA for the user. When activated, passkey authentication requires
user verification, and passkey sign-in is available when MFA is
required. To activate this setting, the FactorConfiguration of
your user pool WebAuthnConfiguration must be
MULTI_FACTOR_WITH_USER_VERIFICATION. To activate this setting,
your user pool must be in the Essentials tier or higher.
2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2246 class AdminSetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :username, :user_pool_id) SENSITIVE = [:username] include Aws::Structure end |