Class: Aws::CognitoIdentityProvider::Types::AdminSetUserPasswordRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:username, :password]

Instance Attribute Summary collapse

Instance Attribute Details

#passwordString

The new temporary or permanent password that you want to set for the user. You can’t remove the password for a user who already has a password so that they can only sign in with passwordless methods. In this scenario, you must create a new user without a password.

Returns:

  • (String)


2212
2213
2214
2215
2216
2217
2218
2219
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2212

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end

#permanentBoolean

Set to ‘true` to set a password that the user can immediately sign in with. Set to `false` to set a temporary password that the user must change on their next sign-in.

Returns:

  • (Boolean)


2212
2213
2214
2215
2216
2217
2218
2219
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2212

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool where you want to set the user’s password.

Returns:

  • (String)


2212
2213
2214
2215
2216
2217
2218
2219
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2212

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end

#usernameString

The name of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.

Returns:

  • (String)


2212
2213
2214
2215
2216
2217
2218
2219
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2212

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end