Class: Aws::CognitoIdentityProvider::Types::AdminUpdateAuthEventFeedbackRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminUpdateAuthEventFeedbackRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#event_id ⇒ String
The ID of the threat protection authentication event that you want to update.
-
#feedback_value ⇒ String
Your feedback to the authentication event.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to submit authentication-event feedback.
-
#username ⇒ String
The name of the user that you want to query or modify.
Instance Attribute Details
#event_id ⇒ String
The ID of the threat protection authentication event that you want to update.
2308 2309 2310 2311 2312 2313 2314 2315 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2308 class AdminUpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_value) SENSITIVE = [:username] include Aws::Structure end |
#feedback_value ⇒ String
Your feedback to the authentication event. When you provide a ‘FeedbackValue` value of `valid`, you tell Amazon Cognito that you trust a user session where Amazon Cognito has evaluated some level of risk. When you provide a `FeedbackValue` value of `invalid`, you tell Amazon Cognito that you don’t trust a user session, or you don’t believe that Amazon Cognito evaluated a high-enough risk level.
2308 2309 2310 2311 2312 2313 2314 2315 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2308 class AdminUpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_value) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to submit authentication-event feedback.
2308 2309 2310 2311 2312 2313 2314 2315 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2308 class AdminUpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_value) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The name of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.
2308 2309 2310 2311 2312 2313 2314 2315 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2308 class AdminUpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_value) SENSITIVE = [:username] include Aws::Structure end |