Class: Aws::CognitoIdentityProvider::Types::AdminUpdateDeviceStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The request to update the device status, as an administrator.

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#device_keyString

The unique identifier, or device key, of the device that you want to update the status for.

Returns:

  • (String)


2431
2432
2433
2434
2435
2436
2437
2438
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2431

class AdminUpdateDeviceStatusRequest < Struct.new(
  :user_pool_id,
  :username,
  :device_key,
  :device_remembered_status)
  SENSITIVE = [:username]
  include Aws::Structure
end

#device_remembered_statusString

To enable device authentication with the specified device, set to remembered.To disable, set to not_remembered.

Returns:

  • (String)


2431
2432
2433
2434
2435
2436
2437
2438
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2431

class AdminUpdateDeviceStatusRequest < Struct.new(
  :user_pool_id,
  :username,
  :device_key,
  :device_remembered_status)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool where you want to change a user's device status.

Returns:

  • (String)


2431
2432
2433
2434
2435
2436
2437
2438
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2431

class AdminUpdateDeviceStatusRequest < Struct.new(
  :user_pool_id,
  :username,
  :device_key,
  :device_remembered_status)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If username isn't an alias attribute in your user pool, this value must be the sub of a local user or the username of a user from a third-party IdP.

Returns:

  • (String)


2431
2432
2433
2434
2435
2436
2437
2438
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2431

class AdminUpdateDeviceStatusRequest < Struct.new(
  :user_pool_id,
  :username,
  :device_key,
  :device_remembered_status)
  SENSITIVE = [:username]
  include Aws::Structure
end