Class: Aws::CognitoIdentityProvider::Types::AliasExistsException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

This exception is thrown when a user tries to confirm the account with an email address or phone number that has already been supplied as an alias from a different account. This exception indicates that an account with this email address or phone already exists in a user pool that you've configured to use email address or phone number as a sign-in alias.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The message sent to the user when an alias exists.

Returns:

  • (String)


2239
2240
2241
2242
2243
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2239

class AliasExistsException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end