Class: Aws::CognitoIdentityProvider::Types::AnalyticsConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AnalyticsConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The settings for Amazon Pinpoint analytics configuration. With an analytics configuration, your application can collect user-activity metrics for user notifications with a Amazon Pinpoint campaign.
Amazon Pinpoint isn’t available in all Amazon Web Services Regions. For a list of available Regions, see [Amazon Cognito and Amazon Pinpoint Region availability].
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon Pinpoint project that you want to connect to your user pool app client.
-
#application_id ⇒ String
Your Amazon Pinpoint project ID.
-
#external_id ⇒ String
The [external ID] of the role that Amazon Cognito assumes to send analytics data to Amazon Pinpoint.
-
#role_arn ⇒ String
The ARN of an Identity and Access Management role that has the permissions required for Amazon Cognito to publish events to Amazon Pinpoint analytics.
-
#user_data_shared ⇒ Boolean
If
UserDataSharedistrue, Amazon Cognito includes user data in the events that it publishes to Amazon Pinpoint analytics.
Instance Attribute Details
#application_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon Pinpoint project that you want to connect to your user pool app client. Amazon Cognito publishes events to the Amazon Pinpoint project that ApplicationArn declares. You can also configure your application to pass an endpoint ID in the AnalyticsMetadata parameter of sign-in operations. The endpoint ID is information about the destination for push notifications
2558 2559 2560 2561 2562 2563 2564 2565 2566 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2558 class AnalyticsConfigurationType < Struct.new( :application_id, :application_arn, :role_arn, :external_id, :user_data_shared) SENSITIVE = [] include Aws::Structure end |
#application_id ⇒ String
Your Amazon Pinpoint project ID.
2558 2559 2560 2561 2562 2563 2564 2565 2566 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2558 class AnalyticsConfigurationType < Struct.new( :application_id, :application_arn, :role_arn, :external_id, :user_data_shared) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The [external ID] of the role that Amazon Cognito assumes to send analytics data to Amazon Pinpoint.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html
2558 2559 2560 2561 2562 2563 2564 2565 2566 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2558 class AnalyticsConfigurationType < Struct.new( :application_id, :application_arn, :role_arn, :external_id, :user_data_shared) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of an Identity and Access Management role that has the permissions required for Amazon Cognito to publish events to Amazon Pinpoint analytics.
2558 2559 2560 2561 2562 2563 2564 2565 2566 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2558 class AnalyticsConfigurationType < Struct.new( :application_id, :application_arn, :role_arn, :external_id, :user_data_shared) SENSITIVE = [] include Aws::Structure end |
#user_data_shared ⇒ Boolean
If UserDataShared is true, Amazon Cognito includes user data in the events that it publishes to Amazon Pinpoint analytics.
2558 2559 2560 2561 2562 2563 2564 2565 2566 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2558 class AnalyticsConfigurationType < Struct.new( :application_id, :application_arn, :role_arn, :external_id, :user_data_shared) SENSITIVE = [] include Aws::Structure end |