Class: Aws::CognitoIdentityProvider::Types::AssetType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AssetType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
An image file from a managed login branding style in a user pool.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
The image file, in Base64-encoded binary.
-
#category ⇒ String
The category that the image corresponds to in your managed login configuration.
-
#color_mode ⇒ String
The display-mode target of the asset: light, dark, or browser-adaptive.
-
#extension ⇒ String
The file type of the image file.
-
#resource_id ⇒ String
The ID of the asset.
Instance Attribute Details
#bytes ⇒ String
The image file, in Base64-encoded binary.
2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2701 class AssetType < Struct.new( :category, :color_mode, :extension, :bytes, :resource_id) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
The category that the image corresponds to in your managed login configuration. Managed login has asset categories for different types of logos, backgrounds, and icons.
2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2701 class AssetType < Struct.new( :category, :color_mode, :extension, :bytes, :resource_id) SENSITIVE = [] include Aws::Structure end |
#color_mode ⇒ String
The display-mode target of the asset: light, dark, or browser-adaptive. For example, Amazon Cognito displays a dark-mode image only when the browser or application is in dark mode, but displays a browser-adaptive file in all contexts.
2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2701 class AssetType < Struct.new( :category, :color_mode, :extension, :bytes, :resource_id) SENSITIVE = [] include Aws::Structure end |