Class: Aws::CognitoIdentityProvider::Types::AssociateSoftwareTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AssociateSoftwareTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose software token you want to generate.
-
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose software token you want to generate.
1926 1927 1928 1929 1930 1931 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1926 class AssociateSoftwareTokenRequest < Struct.new( :access_token, :session) SENSITIVE = [:access_token] include Aws::Structure end |
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service. This allows authentication of the user as part of the MFA setup process.
1926 1927 1928 1929 1930 1931 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1926 class AssociateSoftwareTokenRequest < Struct.new( :access_token, :session) SENSITIVE = [:access_token] include Aws::Structure end |