Class: Aws::CognitoIdentityProvider::Types::AssociateSoftwareTokenResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:secret_code]

Instance Attribute Summary collapse

Instance Attribute Details

#secret_codeString

A unique generated shared secret code that is used in the time-based one-time password (TOTP) algorithm to generate a one-time code.

Returns:

  • (String)


2313
2314
2315
2316
2317
2318
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2313

class AssociateSoftwareTokenResponse < Struct.new(
  :secret_code,
  :session)
  SENSITIVE = [:secret_code]
  include Aws::Structure
end

#sessionString

The session that should be passed both ways in challenge-response calls to the service. This allows authentication of the user as part of the MFA setup process.

Returns:

  • (String)


2313
2314
2315
2316
2317
2318
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2313

class AssociateSoftwareTokenResponse < Struct.new(
  :secret_code,
  :session)
  SENSITIVE = [:secret_code]
  include Aws::Structure
end