Class: Aws::CognitoIdentityProvider::Types::AuthEventType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

One authentication event that Amazon Cognito logged in a user pool with advanced security features active. Contains user and device metadata and a risk assessment from your user pool.

This data type is a request parameter of [AdminListUserAuthEvents].

[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminListUserAuthEvents.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#challenge_responsesArray<Types::ChallengeResponseType>

A list of the challenges that the user was requested to answer, for example ‘Password`, and the result, for example `Success`.

Returns:



2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2530

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date and time when the item was created. Amazon Cognito returns this timestamp in UNIX epoch time format. Your SDK might render the output in a human-readable format like ISO 8601 or a Java ‘Date` object.

Returns:

  • (Time)


2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2530

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_context_dataTypes::EventContextDataType

The user context data captured at the time of an event request. This value provides additional information about the client from which event the request is received.



2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2530

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_feedbackTypes::EventFeedbackType

The [UpdateAuthEventFeedback] or

AdminUpdateAuthEventFeedback][2

feedback that you or your user

provided in response to the event. A value of ‘Valid` indicates that you disagreed with the level of risk that your user pool assigned, and evaluated a session to be valid, or likely safe. A value of `Invalid` indicates that you agreed with the user pool risk level and evaluated a session to be invalid, or likely malicious.

[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateAuthEventFeedback.html [2]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminUpdateAuthEventFeedback.html



2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2530

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_idString

The event ID.

Returns:

  • (String)


2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2530

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_responseString

The event response.

Returns:

  • (String)


2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2530

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_riskTypes::EventRiskType

The threat evaluation from your user pool about an event. Contains information about whether your user pool detected compromised credentials, whether the event triggered an automated response, and the level of risk.



2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2530

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_typeString

The type of authentication event.

Returns:

  • (String)


2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2530

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end