Class: Aws::CognitoIdentityProvider::Types::ChangePasswordRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass ChangePasswordRequest data as a hash:

{
  previous_password: "PasswordType", # required
  proposed_password: "PasswordType", # required
  access_token: "TokenModelType", # required
}

Represents the request to change a user password.

Constant Summary collapse

SENSITIVE =
[:previous_password, :proposed_password, :access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A valid access token that Amazon Cognito issued to the user whose password you want to change.

Returns:

  • (String)


2552
2553
2554
2555
2556
2557
2558
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2552

class ChangePasswordRequest < Struct.new(
  :previous_password,
  :proposed_password,
  :access_token)
  SENSITIVE = [:previous_password, :proposed_password, :access_token]
  include Aws::Structure
end

#previous_passwordString

The old password.

Returns:

  • (String)


2552
2553
2554
2555
2556
2557
2558
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2552

class ChangePasswordRequest < Struct.new(
  :previous_password,
  :proposed_password,
  :access_token)
  SENSITIVE = [:previous_password, :proposed_password, :access_token]
  include Aws::Structure
end

#proposed_passwordString

The new password.

Returns:

  • (String)


2552
2553
2554
2555
2556
2557
2558
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2552

class ChangePasswordRequest < Struct.new(
  :previous_password,
  :proposed_password,
  :access_token)
  SENSITIVE = [:previous_password, :proposed_password, :access_token]
  include Aws::Structure
end