Class: Aws::CognitoIdentityProvider::Types::ConfirmDeviceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The confirm-device response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#user_confirmation_necessaryBoolean

When true, your user must confirm that they want to remember the device. Prompt the user for an answer.

When false, immediately sets the device as remembered and eligible for device authentication.

You can configure your user pool to always remember devices, in which case this response is false, or to allow users to opt in, in which case this response is true. Configure this option under Device tracking in the Sign-in menu of your user pool.

Returns:

  • (Boolean)


3367
3368
3369
3370
3371
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3367

class ConfirmDeviceResponse < Struct.new(
  :user_confirmation_necessary)
  SENSITIVE = []
  include Aws::Structure
end