Class: Aws::CognitoIdentityProvider::Types::ConfirmSignUpRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the request to confirm registration of a user.

Constant Summary collapse

SENSITIVE =
[:client_id, :secret_hash, :username]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_metadataTypes::AnalyticsMetadataType

The Amazon Pinpoint analytics metadata for collecting metrics for ‘ConfirmSignUp` calls.



2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2418

class ConfirmSignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :confirmation_code,
  :force_alias_creation,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username]
  include Aws::Structure
end

#client_idString

The ID of the app client associated with the user pool.

Returns:

  • (String)


2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2418

class ConfirmSignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :confirmation_code,
  :force_alias_creation,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username]
  include Aws::Structure
end

#client_metadataHash<String,String>

A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.

You create custom workflows by assigning Lambda functions to user pool triggers. When you use the ConfirmSignUp API action, Amazon Cognito invokes the function that is assigned to the *post confirmation* trigger. When Amazon Cognito invokes this function, it passes a JSON payload, which the function receives as input. This payload contains a ‘clientMetadata` attribute, which provides the data that you assigned to the ClientMetadata parameter in your ConfirmSignUp request. In your function code in Lambda, you can process the `clientMetadata` value to enhance your workflow for your specific needs.

For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.

<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won’t do the following:

* Store the ClientMetadata value. This data is available only to
 Lambda triggers that are assigned to a user pool to support custom
 workflows. If your user pool configuration doesn't include
 triggers, the ClientMetadata parameter serves no purpose.
  • Validate the ClientMetadata value.

  • Encrypt the ClientMetadata value. Don’t use Amazon Cognito to provide sensitive information.

</note>

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools-working-with-aws-lambda-triggers.html

Returns:

  • (Hash<String,String>)


2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2418

class ConfirmSignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :confirmation_code,
  :force_alias_creation,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username]
  include Aws::Structure
end

#confirmation_codeString

The confirmation code sent by a user’s request to confirm registration.

Returns:

  • (String)


2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2418

class ConfirmSignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :confirmation_code,
  :force_alias_creation,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username]
  include Aws::Structure
end

#force_alias_creationBoolean

Boolean to be specified to force user confirmation irrespective of existing alias. By default set to ‘False`. If this parameter is set to `True` and the phone number/email used for sign up confirmation already exists as an alias with a different user, the API call will migrate the alias from the previous user to the newly created user being confirmed. If set to `False`, the API will throw an AliasExistsException error.

Returns:

  • (Boolean)


2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2418

class ConfirmSignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :confirmation_code,
  :force_alias_creation,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username]
  include Aws::Structure
end

#secret_hashString

A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message.

Returns:

  • (String)


2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2418

class ConfirmSignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :confirmation_code,
  :force_alias_creation,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username]
  include Aws::Structure
end

#user_context_dataTypes::UserContextDataType

Contextual data about your user session, such as the device fingerprint, IP address, or location. Amazon Cognito advanced security evaluates the risk of an authentication event based on the context that your app generates and passes to Amazon Cognito when it makes API requests.



2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2418

class ConfirmSignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :confirmation_code,
  :force_alias_creation,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username]
  include Aws::Structure
end

#usernameString

The user name of the user whose registration you want to confirm.

Returns:

  • (String)


2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2418

class ConfirmSignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :confirmation_code,
  :force_alias_creation,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username]
  include Aws::Structure
end