Class: Aws::CognitoIdentityProvider::Types::ConfirmSignUpResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the response from the server for the registration confirmation.

Constant Summary collapse

SENSITIVE =
[:session]

Instance Attribute Summary collapse

Instance Attribute Details

#sessionString

You can automatically sign users in with the one-time password that they provided in a successful ‘ConfirmSignUp` request. To do this, pass the `Session` parameter from the `ConfirmSignUp` response in the `Session` parameter of an [InitiateAuth] or

AdminInitiateAuth][2

request.

[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_InitiateAuth.html [2]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminInitiateAuth.html

Returns:

  • (String)


3276
3277
3278
3279
3280
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3276

class ConfirmSignUpResponse < Struct.new(
  :session)
  SENSITIVE = [:session]
  include Aws::Structure
end