Class: Aws::CognitoIdentityProvider::Types::ContextDataType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ContextDataType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Contextual user data used for evaluating the risk of an authentication event by user pool threat protection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encoded_data ⇒ String
Encoded device-fingerprint details that your app collected with the Amazon Cognito context data collection library.
-
#http_headers ⇒ Array<Types::HttpHeader>
The HTTP headers from your user's authentication request.
-
#ip_address ⇒ String
The source IP address of your user's device.
-
#server_name ⇒ String
The name of your application's service endpoint.
-
#server_path ⇒ String
The path of your application's service endpoint.
Instance Attribute Details
#encoded_data ⇒ String
Encoded device-fingerprint details that your app collected with the Amazon Cognito context data collection library. For more information, see Adding user device and session data to API requests.
3674 3675 3676 3677 3678 3679 3680 3681 3682 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3674 class ContextDataType < Struct.new( :ip_address, :server_name, :server_path, :http_headers, :encoded_data) SENSITIVE = [] include Aws::Structure end |
#http_headers ⇒ Array<Types::HttpHeader>
The HTTP headers from your user's authentication request.
3674 3675 3676 3677 3678 3679 3680 3681 3682 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3674 class ContextDataType < Struct.new( :ip_address, :server_name, :server_path, :http_headers, :encoded_data) SENSITIVE = [] include Aws::Structure end |
#ip_address ⇒ String
The source IP address of your user's device.
3674 3675 3676 3677 3678 3679 3680 3681 3682 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3674 class ContextDataType < Struct.new( :ip_address, :server_name, :server_path, :http_headers, :encoded_data) SENSITIVE = [] include Aws::Structure end |
#server_name ⇒ String
The name of your application's service endpoint.
3674 3675 3676 3677 3678 3679 3680 3681 3682 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3674 class ContextDataType < Struct.new( :ip_address, :server_name, :server_path, :http_headers, :encoded_data) SENSITIVE = [] include Aws::Structure end |
#server_path ⇒ String
The path of your application's service endpoint.
3674 3675 3676 3677 3678 3679 3680 3681 3682 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3674 class ContextDataType < Struct.new( :ip_address, :server_name, :server_path, :http_headers, :encoded_data) SENSITIVE = [] include Aws::Structure end |