Class: Aws::CognitoIdentityProvider::Types::CreateGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the group that you’re creating.
-
#group_name ⇒ String
A name for the group.
-
#precedence ⇒ Integer
A non-negative integer value that specifies the precedence of this group relative to the other groups that a user can belong to in the user pool.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) for the IAM role that you want to associate with the group.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to create a user group.
Instance Attribute Details
#description ⇒ String
A description of the group that you’re creating.
3631 3632 3633 3634 3635 3636 3637 3638 3639 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3631 class CreateGroupRequest < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
A name for the group. This name must be unique in your user pool.
3631 3632 3633 3634 3635 3636 3637 3638 3639 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3631 class CreateGroupRequest < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence) SENSITIVE = [] include Aws::Structure end |
#precedence ⇒ Integer
A non-negative integer value that specifies the precedence of this group relative to the other groups that a user can belong to in the user pool. Zero is the highest precedence value. Groups with lower Precedence values take precedence over groups with higher or null Precedence values. If a user belongs to two or more groups, it is the group with the lowest precedence value whose role ARN is given in the user’s tokens for the cognito:roles and cognito:preferred_role claims.
Two groups can have the same Precedence value. If this happens, neither group takes precedence over the other. If two groups with the same Precedence have the same role ARN, that role is used in the cognito:preferred_role claim in tokens for users in each group. If the two groups have different role ARNs, the cognito:preferred_role claim isn’t set in users’ tokens.
The default Precedence value is null. The maximum Precedence value is ‘2^31-1`.
3631 3632 3633 3634 3635 3636 3637 3638 3639 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3631 class CreateGroupRequest < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) for the IAM role that you want to associate with the group. A group role primarily declares a preferred role for the credentials that you get from an identity pool. Amazon Cognito ID tokens have a cognito:preferred_role claim that presents the highest-precedence group that a user belongs to. Both ID and access tokens also contain a cognito:groups claim that list all the groups that a user is a member of.
3631 3632 3633 3634 3635 3636 3637 3638 3639 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3631 class CreateGroupRequest < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to create a user group.
3631 3632 3633 3634 3635 3636 3637 3638 3639 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3631 class CreateGroupRequest < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence) SENSITIVE = [] include Aws::Structure end |