Class: Aws::CognitoIdentityProvider::Types::CreateIdentityProviderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_mappingHash<String,String>

A mapping of IdP attributes to standard and custom user pool attributes.

Returns:

  • (Hash<String,String>)


2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2859

class CreateIdentityProviderRequest < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#idp_identifiersArray<String>

A list of IdP identifiers.

Returns:

  • (Array<String>)


2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2859

class CreateIdentityProviderRequest < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#provider_detailsHash<String,String>

The IdP details. The following list describes the provider detail keys for each IdP type.

  • For Google and Login with Amazon:

    • client_id

    • client_secret

    • authorize_scopes

  • For Facebook:

    • client_id

    • client_secret

    • authorize_scopes

    • api_version

  • For Sign in with Apple:

    • client_id

    • team_id

    • key_id

    • private_key

    • authorize_scopes

  • For OpenID Connect (OIDC) providers:

    • client_id

    • client_secret

    • attributes_request_method

    • oidc_issuer

    • authorize_scopes

    • The following keys are only present if Amazon Cognito didn’t discover them at the ‘oidc_issuer` URL.

      • authorize_url

      • token_url

      • attributes_url

      • jwks_uri

    • Amazon Cognito sets the value of the following keys automatically. They are read-only.

      • attributes_url_add_attributes

      ^

  • For SAML providers:

    • MetadataFile or MetadataURL

    • IDPSignout optional

Returns:

  • (Hash<String,String>)


2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2859

class CreateIdentityProviderRequest < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#provider_nameString

The IdP name.

Returns:

  • (String)


2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2859

class CreateIdentityProviderRequest < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#provider_typeString

The IdP type.

Returns:

  • (String)


2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2859

class CreateIdentityProviderRequest < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The user pool ID.

Returns:

  • (String)


2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2859

class CreateIdentityProviderRequest < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers)
  SENSITIVE = []
  include Aws::Structure
end