Class: Aws::CognitoIdentityProvider::Types::CreateResourceServerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateResourceServerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
A unique resource server identifier for the resource server.
-
#name ⇒ String
A friendly name for the resource server.
-
#scopes ⇒ Array<Types::ResourceServerScopeType>
A list of scopes.
-
#user_pool_id ⇒ String
The user pool ID for the user pool.
Instance Attribute Details
#identifier ⇒ String
A unique resource server identifier for the resource server. This could be an HTTPS endpoint where the resource server is located, such as `my-weather-api.example.com`.
2679 2680 2681 2682 2683 2684 2685 2686 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2679 class CreateResourceServerRequest < Struct.new( :user_pool_id, :identifier, :name, :scopes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A friendly name for the resource server.
2679 2680 2681 2682 2683 2684 2685 2686 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2679 class CreateResourceServerRequest < Struct.new( :user_pool_id, :identifier, :name, :scopes) SENSITIVE = [] include Aws::Structure end |
#scopes ⇒ Array<Types::ResourceServerScopeType>
A list of scopes. Each scope is a key-value map with the keys `name` and `description`.
2679 2680 2681 2682 2683 2684 2685 2686 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2679 class CreateResourceServerRequest < Struct.new( :user_pool_id, :identifier, :name, :scopes) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool.
2679 2680 2681 2682 2683 2684 2685 2686 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2679 class CreateResourceServerRequest < Struct.new( :user_pool_id, :identifier, :name, :scopes) SENSITIVE = [] include Aws::Structure end |