Class: Aws::CognitoIdentityProvider::Types::CreateTermsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateTermsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:client_id]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The ID of the app client where you want to create terms documents.
-
#enforcement ⇒ String
This parameter is reserved for future use and currently accepts only one value.
-
#links ⇒ Hash<String,String>
A map of URLs to languages.
-
#terms_name ⇒ String
A friendly name for the document that you want to create in the current request.
-
#terms_source ⇒ String
This parameter is reserved for future use and currently accepts only one value.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to create terms documents.
Instance Attribute Details
#client_id ⇒ String
The ID of the app client where you want to create terms documents. Must be an app client in the requested user pool.
4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4076 class CreateTermsRequest < Struct.new( :user_pool_id, :client_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [:client_id] include Aws::Structure end |
#enforcement ⇒ String
This parameter is reserved for future use and currently accepts only one value.
4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4076 class CreateTermsRequest < Struct.new( :user_pool_id, :client_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [:client_id] include Aws::Structure end |
#links ⇒ Hash<String,String>
A map of URLs to languages. For each localized language that will
view the requested TermsName, assign a URL. A selection of
cognito:default displays for all languages that don't have a
language-specific URL.
For example, "cognito:default": "https://terms.example.com", "cognito:spanish": "https://terms.example.com/es".
4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4076 class CreateTermsRequest < Struct.new( :user_pool_id, :client_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [:client_id] include Aws::Structure end |
#terms_name ⇒ String
A friendly name for the document that you want to create in the
current request. Must begin with terms-of-use or privacy-policy
as identification of the document type. Provide URLs for both
terms-of-use and privacy-policy in separate requests.
4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4076 class CreateTermsRequest < Struct.new( :user_pool_id, :client_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [:client_id] include Aws::Structure end |
#terms_source ⇒ String
This parameter is reserved for future use and currently accepts only one value.
4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4076 class CreateTermsRequest < Struct.new( :user_pool_id, :client_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [:client_id] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to create terms documents.
4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4076 class CreateTermsRequest < Struct.new( :user_pool_id, :client_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [:client_id] include Aws::Structure end |