Class: Aws::CognitoIdentityProvider::Types::CreateUserImportJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the request to create the user import job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_watch_logs_role_arnString

You must specify an IAM role that has permission to log import-job results to Amazon CloudWatch Logs. This parameter is the ARN of that role.

Returns:

  • (String)


4064
4065
4066
4067
4068
4069
4070
4071
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4064

class CreateUserImportJobRequest < Struct.new(
  :job_name,
  :user_pool_id,
  :cloud_watch_logs_role_arn,
  :password_hashing_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

A friendly name for the user import job.

Returns:

  • (String)


4064
4065
4066
4067
4068
4069
4070
4071
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4064

class CreateUserImportJobRequest < Struct.new(
  :job_name,
  :user_pool_id,
  :cloud_watch_logs_role_arn,
  :password_hashing_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#password_hashing_algorithmString

The password hashing algorithm used to generate the hashes in the CSV file for this import job.

Valid values: BCRYPT | SCRYPT | ARGON2ID | PBKDF2_SHA256

Returns:

  • (String)


4064
4065
4066
4067
4068
4069
4070
4071
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4064

class CreateUserImportJobRequest < Struct.new(
  :job_name,
  :user_pool_id,
  :cloud_watch_logs_role_arn,
  :password_hashing_algorithm)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool that you want to import users into.

Returns:

  • (String)


4064
4065
4066
4067
4068
4069
4070
4071
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4064

class CreateUserImportJobRequest < Struct.new(
  :job_name,
  :user_pool_id,
  :cloud_watch_logs_role_arn,
  :password_hashing_algorithm)
  SENSITIVE = []
  include Aws::Structure
end