Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_front_domainString

The Amazon CloudFront endpoint that you use as the target of the alias that you set up with your Domain Name Service (DNS) provider. Amazon Cognito returns this value if you set a custom domain with ‘CustomDomainConfig`. If you set an Amazon Cognito prefix domain, this operation returns a blank response.

Returns:

  • (String)


4193
4194
4195
4196
4197
4198
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4193

class CreateUserPoolDomainResponse < Struct.new(
  :managed_login_version,
  :cloud_front_domain)
  SENSITIVE = []
  include Aws::Structure
end

#managed_login_versionInteger

The version of managed login branding applied your domain. A value of ‘1` indicates hosted UI (classic) branding and a version of `2` indicates managed login branding.

Returns:

  • (Integer)


4193
4194
4195
4196
4197
4198
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4193

class CreateUserPoolDomainResponse < Struct.new(
  :managed_login_version,
  :cloud_front_domain)
  SENSITIVE = []
  include Aws::Structure
end