Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolReplicaRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateUserPoolReplicaRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#region_name ⇒ String
The Amazon Web Services Region where you want to create the replica user pool.
-
#user_pool_id ⇒ String
The ID of the user pool to replicate.
-
#user_pool_tags ⇒ Hash<String,String>
A map of tags to assign to the replica user pool.
Instance Attribute Details
#region_name ⇒ String
The Amazon Web Services Region where you want to create the replica user pool.
4636 4637 4638 4639 4640 4641 4642 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4636 class CreateUserPoolReplicaRequest < Struct.new( :user_pool_id, :region_name, :user_pool_tags) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool to replicate.
4636 4637 4638 4639 4640 4641 4642 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4636 class CreateUserPoolReplicaRequest < Struct.new( :user_pool_id, :region_name, :user_pool_tags) SENSITIVE = [] include Aws::Structure end |
#user_pool_tags ⇒ Hash<String,String>
A map of tags to assign to the replica user pool. Each tag consists of a key and an optional value, both of which you define. You can maintain tags independently on replica user pools.
4636 4637 4638 4639 4640 4641 4642 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4636 class CreateUserPoolReplicaRequest < Struct.new( :user_pool_id, :region_name, :user_pool_tags) SENSITIVE = [] include Aws::Structure end |