Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolReplicaResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateUserPoolReplicaResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#user_pool_replica ⇒ Types::UserPoolReplicaType
Information about the created user pool replica, including its status and role.
Instance Attribute Details
#user_pool_replica ⇒ Types::UserPoolReplicaType
Information about the created user pool replica, including its status and role.
4651 4652 4653 4654 4655 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4651 class CreateUserPoolReplicaResponse < Struct.new( :user_pool_replica) SENSITIVE = [] include Aws::Structure end |