Class: Aws::CognitoIdentityProvider::Types::CustomEmailLambdaVersionConfigType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CustomEmailLambdaVersionConfigType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass CustomEmailLambdaVersionConfigType data as a hash:
{
lambda_version: "V1_0", # required, accepts V1_0
lambda_arn: "ArnType", # required
}
A custom email sender Lambda configuration type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lambda_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function that Amazon Cognito activates to send email notifications to users.
-
#lambda_version ⇒ String
Signature of the “request” attribute in the “event” information Amazon Cognito passes to your custom email Lambda function.
Instance Attribute Details
#lambda_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function that Amazon Cognito activates to send email notifications to users.
3999 4000 4001 4002 4003 4004 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3999 class CustomEmailLambdaVersionConfigType < Struct.new( :lambda_version, :lambda_arn) SENSITIVE = [] include Aws::Structure end |
#lambda_version ⇒ String
Signature of the “request” attribute in the “event” information Amazon Cognito passes to your custom email Lambda function. The only supported value is `V1_0`.
3999 4000 4001 4002 4003 4004 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3999 class CustomEmailLambdaVersionConfigType < Struct.new( :lambda_version, :lambda_arn) SENSITIVE = [] include Aws::Structure end |