Class: Aws::CognitoIdentityProvider::Types::DeleteResourceServerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DeleteResourceServerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass DeleteResourceServerRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
identifier: "ResourceServerIdentifierType", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
The identifier for the resource server.
-
#user_pool_id ⇒ String
The user pool ID for the user pool that hosts the resource server.
Instance Attribute Details
#identifier ⇒ String
The identifier for the resource server.
4078 4079 4080 4081 4082 4083 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4078 class DeleteResourceServerRequest < Struct.new( :user_pool_id, :identifier) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool that hosts the resource server.
4078 4079 4080 4081 4082 4083 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4078 class DeleteResourceServerRequest < Struct.new( :user_pool_id, :identifier) SENSITIVE = [] include Aws::Structure end |