Class: Aws::CognitoIdentityProvider::Types::DeleteUserAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DeleteUserAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to delete user attributes.
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the currently signed-in user.
-
#user_attribute_names ⇒ Array<String>
An array of strings representing the user attribute names you want to delete.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for ‘aws.cognito.signin.user.admin`.
5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5065 class DeleteUserAttributesRequest < Struct.new( :user_attribute_names, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |
#user_attribute_names ⇒ Array<String>
An array of strings representing the user attribute names you want to delete.
For custom attributes, you must prepend the ‘custom:` prefix to the attribute name, for example `custom:department`.
5065 5066 5067 5068 5069 5070 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5065 class DeleteUserAttributesRequest < Struct.new( :user_attribute_names, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |