Class: Aws::CognitoIdentityProvider::Types::DeleteUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DeleteUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass DeleteUserRequest data as a hash:
{
access_token: "TokenModelType", # required
}
Represents the request to delete a user.
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose user profile you want to delete.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose user profile you want to delete.
4403 4404 4405 4406 4407 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4403 class DeleteUserRequest < Struct.new( :access_token) SENSITIVE = [:access_token] include Aws::Structure end |