Class: Aws::CognitoIdentityProvider::Types::DescribeRiskConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DescribeRiskConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:client_id]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The ID of the app client with the risk configuration that you want to inspect.
-
#user_pool_id ⇒ String
The ID of the user pool with the risk configuration that you want to inspect.
Instance Attribute Details
#client_id ⇒ String
The ID of the app client with the risk configuration that you want to inspect. You can apply default risk configuration at the user pool level and further customize it from user pool defaults at the app-client level. Specify ‘ClientId` to inspect client-level configuration, or `UserPoolId` to inspect pool-level configuration.
5365 5366 5367 5368 5369 5370 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5365 class DescribeRiskConfigurationRequest < Struct.new( :user_pool_id, :client_id) SENSITIVE = [:client_id] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool with the risk configuration that you want to inspect. You can apply default risk configuration at the user pool level and further customize it from user pool defaults at the app-client level. Specify ‘ClientId` to inspect client-level configuration, or `UserPoolId` to inspect pool-level configuration.
5365 5366 5367 5368 5369 5370 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5365 class DescribeRiskConfigurationRequest < Struct.new( :user_pool_id, :client_id) SENSITIVE = [:client_id] include Aws::Structure end |