Class: Aws::CognitoIdentityProvider::Types::DescribeUserPoolClientRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DescribeUserPoolClientRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to describe a user pool client.
Constant Summary collapse
- SENSITIVE =
[:client_id]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The app client ID of the app associated with the user pool.
-
#user_pool_id ⇒ String
The user pool ID for the user pool you want to describe.
Instance Attribute Details
#client_id ⇒ String
The app client ID of the app associated with the user pool.
3822 3823 3824 3825 3826 3827 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3822 class DescribeUserPoolClientRequest < Struct.new( :user_pool_id, :client_id) SENSITIVE = [:client_id] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool you want to describe.
3822 3823 3824 3825 3826 3827 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3822 class DescribeUserPoolClientRequest < Struct.new( :user_pool_id, :client_id) SENSITIVE = [:client_id] include Aws::Structure end |