Class: Aws::CognitoIdentityProvider::Types::EnableSoftwareTokenMFAException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::EnableSoftwareTokenMFAException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
This exception is thrown when there is a code mismatch and the service fails to configure the software token TOTP multi-factor authentication (MFA).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
4952 4953 4954 4955 4956 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4952 class EnableSoftwareTokenMFAException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |