Class: Aws::CognitoIdentityProvider::Types::ForgetDeviceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ForgetDeviceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass ForgetDeviceRequest data as a hash:
{
access_token: "TokenModelType",
device_key: "DeviceKeyType", # required
}
Represents the request to forget the device.
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose registered device you want to forget.
-
#device_key ⇒ String
The device key.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose registered device you want to forget.
5077 5078 5079 5080 5081 5082 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5077 class ForgetDeviceRequest < Struct.new( :access_token, :device_key) SENSITIVE = [:access_token] include Aws::Structure end |
#device_key ⇒ String
The device key.
5077 5078 5079 5080 5081 5082 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5077 class ForgetDeviceRequest < Struct.new( :access_token, :device_key) SENSITIVE = [:access_token] include Aws::Structure end |