Class: Aws::CognitoIdentityProvider::Types::GetCSVHeaderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass GetCSVHeaderRequest data as a hash:

{
  user_pool_id: "UserPoolIdType", # required
}

Represents the request to get the header information of the CSV file for the user import job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#user_pool_idString

The user pool ID for the user pool that the users are to be imported into.

Returns:

  • (String)


5297
5298
5299
5300
5301
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5297

class GetCSVHeaderRequest < Struct.new(
  :user_pool_id)
  SENSITIVE = []
  include Aws::Structure
end