Class: Aws::CognitoIdentityProvider::Types::GetClientTokenResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::GetClientTokenResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_authentication_result ⇒ Types::ClientAuthenticationResultType
The access token that Amazon Cognito issues for the app client, and its metadata.
Instance Attribute Details
#client_authentication_result ⇒ Types::ClientAuthenticationResultType
The access token that Amazon Cognito issues for the app client, and its metadata.
6804 6805 6806 6807 6808 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6804 class GetClientTokenResponse < Struct.new( :client_authentication_result) SENSITIVE = [] include Aws::Structure end |