Class: Aws::CognitoIdentityProvider::Types::GetTokensFromRefreshTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::GetTokensFromRefreshTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:refresh_token, :client_id, :client_secret]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The app client that issued the refresh token to the user who wants to request new tokens.
-
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.
-
#client_secret ⇒ String
The client secret of the requested app client, if the client has a secret.
-
#device_key ⇒ String
When you enable device remembering, Amazon Cognito issues a device key that you can use for device authentication that bypasses multi-factor authentication (MFA).
-
#refresh_token ⇒ String
A valid refresh token that can authorize the request for new tokens.
Instance Attribute Details
#client_id ⇒ String
The app client that issued the refresh token to the user who wants to request new tokens.
6518 6519 6520 6521 6522 6523 6524 6525 6526 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6518 class GetTokensFromRefreshTokenRequest < Struct.new( :refresh_token, :client_id, :client_secret, :device_key, :client_metadata) SENSITIVE = [:refresh_token, :client_id, :client_secret] include Aws::Structure end |
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers.
When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a ‘clientMetadata` attribute that provides the data that you assigned to the ClientMetadata parameter in your request. In your function code, you can process the `clientMetadata` value to enhance your workflow for your specific needs.
To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see [ Connecting API actions to Lambda triggers] in the *Amazon Cognito Developer Guide*.
<note markdown=“1”> When you use the ‘ClientMetadata` parameter, note that Amazon Cognito won’t do the following:
* Store the `ClientMetadata` value. This data is available only to
Lambda triggers that are assigned to a user pool to support custom
workflows. If your user pool configuration doesn't include
triggers, the `ClientMetadata` parameter serves no purpose.
-
Validate the ‘ClientMetadata` value.
-
Encrypt the ‘ClientMetadata` value. Don’t send sensitive information in this parameter.
</note>
6518 6519 6520 6521 6522 6523 6524 6525 6526 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6518 class GetTokensFromRefreshTokenRequest < Struct.new( :refresh_token, :client_id, :client_secret, :device_key, :client_metadata) SENSITIVE = [:refresh_token, :client_id, :client_secret] include Aws::Structure end |
#client_secret ⇒ String
The client secret of the requested app client, if the client has a secret.
6518 6519 6520 6521 6522 6523 6524 6525 6526 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6518 class GetTokensFromRefreshTokenRequest < Struct.new( :refresh_token, :client_id, :client_secret, :device_key, :client_metadata) SENSITIVE = [:refresh_token, :client_id, :client_secret] include Aws::Structure end |
#device_key ⇒ String
When you enable device remembering, Amazon Cognito issues a device key that you can use for device authentication that bypasses multi-factor authentication (MFA). To implement ‘GetTokensFromRefreshToken` in a user pool with device remembering, you must capture the device key from the initial authentication request. If your application doesn’t provide the key of a registered device, Amazon Cognito issues a new one. You must provide the confirmed device key in this request if device remembering is enabled in your user pool.
For more information about device remembering, see [Working with devices].
[1]: docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-device-tracking.html
6518 6519 6520 6521 6522 6523 6524 6525 6526 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6518 class GetTokensFromRefreshTokenRequest < Struct.new( :refresh_token, :client_id, :client_secret, :device_key, :client_metadata) SENSITIVE = [:refresh_token, :client_id, :client_secret] include Aws::Structure end |
#refresh_token ⇒ String
A valid refresh token that can authorize the request for new tokens. When refresh token rotation is active in the requested app client, this token is invalidated after the request is complete and after an optional grace period.
6518 6519 6520 6521 6522 6523 6524 6525 6526 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6518 class GetTokensFromRefreshTokenRequest < Struct.new( :refresh_token, :client_id, :client_secret, :device_key, :client_metadata) SENSITIVE = [:refresh_token, :client_id, :client_secret] include Aws::Structure end |