Class: Aws::CognitoIdentityProvider::Types::GetUserAttributeVerificationCodeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the request to get user attribute verification.

Constant Summary collapse

SENSITIVE =
[:access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for ‘aws.cognito.signin.user.admin`.

Returns:

  • (String)


6624
6625
6626
6627
6628
6629
6630
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6624

class GetUserAttributeVerificationCodeRequest < Struct.new(
  :access_token,
  :attribute_name,
  :client_metadata)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#attribute_nameString

The name of the attribute that the user wants to verify, for example ‘email`.

Returns:

  • (String)


6624
6625
6626
6627
6628
6629
6630
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6624

class GetUserAttributeVerificationCodeRequest < Struct.new(
  :access_token,
  :attribute_name,
  :client_metadata)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#client_metadataHash<String,String>

A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers.

When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a ‘clientMetadata` attribute that provides the data that you assigned to the ClientMetadata parameter in your request. In your function code, you can process the `clientMetadata` value to enhance your workflow for your specific needs.

To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see [ Connecting API actions to Lambda triggers] in the *Amazon Cognito Developer Guide*.

<note markdown=“1”> When you use the ‘ClientMetadata` parameter, note that Amazon Cognito won’t do the following:

* Store the `ClientMetadata` value. This data is available only to
 Lambda triggers that are assigned to a user pool to support custom
 workflows. If your user pool configuration doesn't include
 triggers, the `ClientMetadata` parameter serves no purpose.
  • Validate the ‘ClientMetadata` value.

  • Encrypt the ‘ClientMetadata` value. Don’t send sensitive information in this parameter.

</note>

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-working-with-lambda-triggers.html#lambda-triggers-by-event

Returns:

  • (Hash<String,String>)


6624
6625
6626
6627
6628
6629
6630
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6624

class GetUserAttributeVerificationCodeRequest < Struct.new(
  :access_token,
  :attribute_name,
  :client_metadata)
  SENSITIVE = [:access_token]
  include Aws::Structure
end