Class: Aws::CognitoIdentityProvider::Types::GetUserAuthFactorsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A valid access token that Amazon Cognito issued to the user whose authentication factors you want to view.

Returns:

  • (String)


6104
6105
6106
6107
6108
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6104

class GetUserAuthFactorsRequest < Struct.new(
  :access_token)
  SENSITIVE = [:access_token]
  include Aws::Structure
end