Class: Aws::CognitoIdentityProvider::Types::GetUserAuthFactorsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::GetUserAuthFactorsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#configured_user_auth_factors ⇒ Array<String>
The authentication types that are available to the user with
USER_AUTHsign-in, for example["PASSWORD", "WEB_AUTHN"]. -
#preferred_mfa_setting ⇒ String
The challenge method that Amazon Cognito returns to the user in response to sign-in requests.
-
#user_mfa_setting_list ⇒ Array<String>
The MFA options that are activated for the user.
-
#username ⇒ String
The name of the user who is eligible for the authentication factors in the response.
Instance Attribute Details
#configured_user_auth_factors ⇒ Array<String>
The authentication types that are available to the user with
USER_AUTH sign-in, for example ["PASSWORD", "WEB_AUTHN"].
6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6865 class GetUserAuthFactorsResponse < Struct.new( :username, :preferred_mfa_setting, :user_mfa_setting_list, :configured_user_auth_factors) SENSITIVE = [:username] include Aws::Structure end |
#preferred_mfa_setting ⇒ String
The challenge method that Amazon Cognito returns to the user in response to sign-in requests. Users can prefer SMS message, email message, or TOTP MFA.
6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6865 class GetUserAuthFactorsResponse < Struct.new( :username, :preferred_mfa_setting, :user_mfa_setting_list, :configured_user_auth_factors) SENSITIVE = [:username] include Aws::Structure end |
#user_mfa_setting_list ⇒ Array<String>
The MFA options that are activated for the user. The possible values
in this list are SMS_MFA, EMAIL_OTP, and SOFTWARE_TOKEN_MFA.
6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6865 class GetUserAuthFactorsResponse < Struct.new( :username, :preferred_mfa_setting, :user_mfa_setting_list, :configured_user_auth_factors) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The name of the user who is eligible for the authentication factors in the response.
6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6865 class GetUserAuthFactorsResponse < Struct.new( :username, :preferred_mfa_setting, :user_mfa_setting_list, :configured_user_auth_factors) SENSITIVE = [:username] include Aws::Structure end |