Class: Aws::CognitoIdentityProvider::Types::GetUserPoolMfaConfigResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::GetUserPoolMfaConfigResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mfa_configuration ⇒ String
The multi-factor (MFA) configuration.
-
#sms_mfa_configuration ⇒ Types::SmsMfaConfigType
The SMS text message multi-factor (MFA) configuration.
-
#software_token_mfa_configuration ⇒ Types::SoftwareTokenMfaConfigType
The software token multi-factor (MFA) configuration.
Instance Attribute Details
#mfa_configuration ⇒ String
The multi-factor (MFA) configuration. Valid values include:
-
`OFF` MFA won't be used for any users.
-
`ON` MFA is required for all users to sign in.
-
`OPTIONAL` MFA will be required only for individual users who have an MFA factor activated.
5426 5427 5428 5429 5430 5431 5432 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5426 class GetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :mfa_configuration) SENSITIVE = [] include Aws::Structure end |
#sms_mfa_configuration ⇒ Types::SmsMfaConfigType
The SMS text message multi-factor (MFA) configuration.
5426 5427 5428 5429 5430 5431 5432 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5426 class GetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :mfa_configuration) SENSITIVE = [] include Aws::Structure end |
#software_token_mfa_configuration ⇒ Types::SoftwareTokenMfaConfigType
The software token multi-factor (MFA) configuration.
5426 5427 5428 5429 5430 5431 5432 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5426 class GetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :mfa_configuration) SENSITIVE = [] include Aws::Structure end |