Class: Aws::CognitoIdentityProvider::Types::GetUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass GetUserRequest data as a hash:

{
  access_token: "TokenModelType", # required
}

Represents the request to get information about the user.

Constant Summary collapse

SENSITIVE =
[:access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A non-expired access token for the user whose information you want to query.

Returns:

  • (String)


5625
5626
5627
5628
5629
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5625

class GetUserRequest < Struct.new(
  :access_token)
  SENSITIVE = [:access_token]
  include Aws::Structure
end