Class: Aws::CognitoIdentityProvider::Types::GlobalSignOutRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::GlobalSignOutRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass GlobalSignOutRequest data as a hash:
{
access_token: "TokenModelType", # required
}
Represents the request to sign out all devices.
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user who you want to sign out.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user who you want to sign out.
5768 5769 5770 5771 5772 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5768 class GlobalSignOutRequest < Struct.new( :access_token) SENSITIVE = [:access_token] include Aws::Structure end |