Class: Aws::CognitoIdentityProvider::Types::GroupExistsException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::GroupExistsException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
This exception is thrown when Amazon Cognito encounters a group that already exists in the user pool.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
4886 4887 4888 4889 4890 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4886 class GroupExistsException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |