Class: Aws::CognitoIdentityProvider::Types::GroupType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::GroupType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The group type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date the group was created.
-
#description ⇒ String
A string containing the description of the group.
-
#group_name ⇒ String
The name of the group.
-
#last_modified_date ⇒ Time
The date the group was last modified.
-
#precedence ⇒ Integer
A non-negative integer value that specifies the precedence of this group relative to the other groups that a user can belong to in the user pool.
-
#role_arn ⇒ String
The role Amazon Resource Name (ARN) for the group.
-
#user_pool_id ⇒ String
The user pool ID for the user pool.
Instance Attribute Details
#creation_date ⇒ Time
The date the group was created.
4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4801 class GroupType < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A string containing the description of the group.
4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4801 class GroupType < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the group.
4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4801 class GroupType < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date the group was last modified.
4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4801 class GroupType < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#precedence ⇒ Integer
A non-negative integer value that specifies the precedence of this group relative to the other groups that a user can belong to in the user pool. Zero is the highest precedence value. Groups with lower ‘Precedence` values take precedence over groups with higher ornull `Precedence` values. If a user belongs to two or more groups, it is the group with the lowest precedence value whose role ARN is given in the user’s tokens for the ‘cognito:roles` and `cognito:preferred_role` claims.
Two groups can have the same ‘Precedence` value. If this happens, neither group takes precedence over the other. If two groups with the same `Precedence` have the same role ARN, that role is used in the `cognito:preferred_role` claim in tokens for users in each group. If the two groups have different role ARNs, the `cognito:preferred_role` claim isn’t set in users’ tokens.
The default ‘Precedence` value is null.
4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4801 class GroupType < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The role Amazon Resource Name (ARN) for the group.
4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4801 class GroupType < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool.
4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4801 class GroupType < Struct.new( :group_name, :user_pool_id, :description, :role_arn, :precedence, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |