Class: Aws::CognitoIdentityProvider::Types::InboundFederationLambdaType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The properties of an inbound federation Lambda trigger.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lambda_arnString

The Amazon Resource Name (ARN) of the function that you want to assign to your Lambda trigger.

Returns:

  • (String)


7162
7163
7164
7165
7166
7167
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7162

class InboundFederationLambdaType < Struct.new(
  :lambda_version,
  :lambda_arn)
  SENSITIVE = []
  include Aws::Structure
end

#lambda_versionString

The user pool trigger version of the request that Amazon Cognito sends to your Lambda function. Higher-numbered versions add fields that support new features.

You must use a ‘LambdaVersion` of `V1_0` with an inbound federation function.

Returns:

  • (String)


7162
7163
7164
7165
7166
7167
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7162

class InboundFederationLambdaType < Struct.new(
  :lambda_version,
  :lambda_arn)
  SENSITIVE = []
  include Aws::Structure
end