Class: Aws::CognitoIdentityProvider::Types::InvalidParameterException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

This exception is thrown when the Amazon Cognito service encounters an invalid parameter.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The message returned when the Amazon Cognito service throws an invalid parameter exception.

Returns:

  • (String)


6307
6308
6309
6310
6311
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6307

class InvalidParameterException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end