Class: Aws::CognitoIdentityProvider::Types::IssuerConfigurationType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Specifies the issuer configuration for a user pool. Contains settings that determine how tokens are issued and validated.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The type of issuer configuration. Determines the token issuing behavior for the user pool.

ORIGINAL

: The original issuer configuration for user pools. The issuer URL is hosted in the user pool’s region and provides OIDC endpoints specific to that region.

Original issuers have the format of
`https://cognito-idp.[region].amazonaws.com/[userPoolId]`

UPDATED

: Recommended for all user pools, including for multi-Region replication. Updated issuers host the same JWKS content in multiple regions, resulting in improved resilience and efficiency.

Updated issuers have the format of
`https://issuer-cognito-idp.[region].amazonaws.com/[userPoolId]`,
where region is the primary Amazon Web Services Region of your
user pool.

Returns:

  • (String)


7905
7906
7907
7908
7909
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7905

class IssuerConfigurationType < Struct.new(
  :type)
  SENSITIVE = []
  include Aws::Structure
end