Class: Aws::CognitoIdentityProvider::Types::KeyConfigurationType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Specifies the key configuration for a user pool. Contains settings for encryption keys used to secure user pool data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#key_typeString

The type of encryption key used for the user pool.

AWS_OWNED_KEY

: A key owned by Amazon Web Services in Key Management Service.

CUSTOMER_MANAGED_KEY

: A key managed by the customer in Key Management Service. You must

use a multi-region key to enable multi-region replication for a
user pool.

Returns:

  • (String)


7893
7894
7895
7896
7897
7898
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7893

class KeyConfigurationType < Struct.new(
  :key_type,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the KMS key used for encryption. If not specified, Amazon Web Services managed keys are used.

Returns:

  • (String)


7893
7894
7895
7896
7897
7898
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7893

class KeyConfigurationType < Struct.new(
  :key_type,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end