Class: Aws::CognitoIdentityProvider::Types::LambdaConfigType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

A collection of user pool Lambda triggers. Amazon Cognito invokes triggers at several possible stages of user pool operations. Triggers can modify the outcome of the operations that invoked them.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_auth_challengeString

The configuration of a create auth challenge Lambda trigger, one of three triggers in the sequence of the custom authentication challenge triggers.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#custom_email_senderTypes::CustomEmailLambdaVersionConfigType

The configuration of a custom email sender Lambda trigger. This trigger routes all email notifications from a user pool to a Lambda function that delivers the message using custom logic.



8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#custom_messageString

A custom message Lambda trigger. This trigger is an opportunity to customize all SMS and email messages from your user pool. When a custom message trigger is active, your user pool routes all messages to a Lambda function that returns a runtime-customized message subject and body for your user pool to deliver to a user.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#custom_sms_senderTypes::CustomSMSLambdaVersionConfigType

The configuration of a custom SMS sender Lambda trigger. This trigger routes all SMS notifications from a user pool to a Lambda function that delivers the message using custom logic.



8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#define_auth_challengeString

The configuration of a define auth challenge Lambda trigger, one of three triggers in the sequence of the custom authentication challenge triggers.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#inbound_federationTypes::InboundFederationLambdaType

The configuration of an inbound federation Lambda trigger. This trigger can transform federated user attributes during the authentication with external identity providers.



8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The ARN of an KMS key. Amazon Cognito uses the key to encrypt codes and temporary passwords sent to custom sender Lambda triggers.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#post_authenticationString

The configuration of a post authentication Lambda trigger in a user pool. This trigger can take custom actions after a user signs in.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#post_confirmationString

The configuration of a post confirmation Lambda trigger in a user pool. This trigger can take custom actions after a user confirms their user account and their email address or phone number.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#pre_authenticationString

The configuration of a pre authentication trigger in a user pool. This trigger can evaluate and modify user sign-in events.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#pre_sign_upString

The configuration of a pre sign-up Lambda trigger in a user pool. This trigger evaluates new users and can bypass confirmation, link a federated user profile, or block sign-up requests.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#pre_token_generationString

The legacy configuration of a pre token generation Lambda trigger in a user pool.

Set this parameter for legacy purposes. If you also set an ARN in PreTokenGenerationConfig, its value must be identical to PreTokenGeneration. For new instances of pre token generation triggers, set the LambdaArn of PreTokenGenerationConfig.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#pre_token_generation_configTypes::PreTokenGenerationVersionConfigType

The detailed configuration of a pre token generation Lambda trigger in a user pool. If you also set an ARN in PreTokenGeneration, its value must be identical to PreTokenGenerationConfig.



8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#user_migrationString

The configuration of a migrate user Lambda trigger in a user pool. This trigger can create user profiles when users sign in or attempt to reset their password with credentials that don't exist yet.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end

#verify_auth_challenge_responseString

The configuration of a verify auth challenge Lambda trigger, one of three triggers in the sequence of the custom authentication challenge triggers.

Returns:

  • (String)


8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
8311
8312
8313
8314
8315
8316
8317
8318
8319
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8301

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id,
  :inbound_federation)
  SENSITIVE = []
  include Aws::Structure
end