Class: Aws::CognitoIdentityProvider::Types::LimitExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::LimitExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
This exception is thrown when a user exceeds the limit for a requested Amazon Web Services resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The message returned when Amazon Cognito throws a limit exceeded exception.
Instance Attribute Details
#message ⇒ String
The message returned when Amazon Cognito throws a limit exceeded exception.
8258 8259 8260 8261 8262 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8258 class LimitExceededException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |