Class: Aws::CognitoIdentityProvider::Types::LimitType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The limit definition and current limit values for a provisioned limit.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#free_limit_valueInteger

The default (free) limit value, in requests per second (RPS). This is the rate included at no additional cost.

Returns:

  • (Integer)


8283
8284
8285
8286
8287
8288
8289
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8283

class LimitType < Struct.new(
  :limit_definition,
  :provisioned_limit_value,
  :free_limit_value)
  SENSITIVE = []
  include Aws::Structure
end

#limit_definitionTypes::LimitDefinitionType

The definition that identifies this limit, including the class and attributes.



8283
8284
8285
8286
8287
8288
8289
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8283

class LimitType < Struct.new(
  :limit_definition,
  :provisioned_limit_value,
  :free_limit_value)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_limit_valueInteger

The provisioned limit value, in requests per second (RPS). This is the rate that Amazon Cognito currently enforces for your account.

Returns:

  • (Integer)


8283
8284
8285
8286
8287
8288
8289
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8283

class LimitType < Struct.new(
  :limit_definition,
  :provisioned_limit_value,
  :free_limit_value)
  SENSITIVE = []
  include Aws::Structure
end