Class: Aws::CognitoIdentityProvider::Types::ListDevicesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the response to list devices.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#devicesArray<Types::DeviceType>

An array of devices and their details. Each entry that's returned includes device information, last-accessed and created dates, and the device key.

Returns:



8601
8602
8603
8604
8605
8606
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8601

class ListDevicesResponse < Struct.new(
  :devices,
  :pagination_token)
  SENSITIVE = []
  include Aws::Structure
end

#pagination_tokenString

The identifier that Amazon Cognito returned with the previous request to this operation. When you include a pagination token in your request, Amazon Cognito returns the next set of items in the list. By use of this token, you can paginate through the full list of items.

Returns:

  • (String)


8601
8602
8603
8604
8605
8606
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8601

class ListDevicesResponse < Struct.new(
  :devices,
  :pagination_token)
  SENSITIVE = []
  include Aws::Structure
end