Class: Aws::CognitoIdentityProvider::Types::ListGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ListGroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#groups ⇒ Array<Types::GroupType>
An array of groups and their details.
-
#next_token ⇒ String
The identifier that Amazon Cognito returned with the previous request to this operation.
Instance Attribute Details
#groups ⇒ Array<Types::GroupType>
An array of groups and their details. Each entry that's returned includes description, precedence, and IAM role values.
8652 8653 8654 8655 8656 8657 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8652 class ListGroupsResponse < Struct.new( :groups, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The identifier that Amazon Cognito returned with the previous request to this operation. When you include a pagination token in your request, Amazon Cognito returns the next set of items in the list. By use of this token, you can paginate through the full list of items.
8652 8653 8654 8655 8656 8657 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8652 class ListGroupsResponse < Struct.new( :groups, :next_token) SENSITIVE = [] include Aws::Structure end |