Class: Aws::CognitoIdentityProvider::Types::ListIdentityProvidersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The identifier that Amazon Cognito returned with the previous request to this operation. When you include a pagination token in your request, Amazon Cognito returns the next set of items in the list. By use of this token, you can paginate through the full list of items.



8704
8705
8706
8707
8708
8709
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8704

class ListIdentityProvidersResponse < Struct.new(
  :providers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#providersArray<Types::ProviderDescription>

An array of the IdPs in your user pool. For each, the response includes identifiers, the IdP name and type, and trust-relationship details like the issuer URL.



8704
8705
8706
8707
8708
8709
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8704

class ListIdentityProvidersResponse < Struct.new(
  :providers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end