Class: Aws::CognitoIdentityProvider::Types::ListResourceServersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The identifier that Amazon Cognito returned with the previous request to this operation. When you include a pagination token in your request, Amazon Cognito returns the next set of items in the list. By use of this token, you can paginate through the full list of items.



8756
8757
8758
8759
8760
8761
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8756

class ListResourceServersResponse < Struct.new(
  :resource_servers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_serversArray<Types::ResourceServerType>

An array of resource servers and the details of their configuration. For each, the response includes names, identifiers, and custom scopes.



8756
8757
8758
8759
8760
8761
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8756

class ListResourceServersResponse < Struct.new(
  :resource_servers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end