Class: Aws::CognitoIdentityProvider::Types::ListTermsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ListTermsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of terms documents that you want Amazon Cognito to return in the response.
-
#next_token ⇒ String
This API operation returns a limited number of results.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to list terms documents.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of terms documents that you want Amazon Cognito to return in the response.
8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8809 class ListTermsRequest < Struct.new( :user_pool_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.
8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8809 class ListTermsRequest < Struct.new( :user_pool_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to list terms documents.
8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8809 class ListTermsRequest < Struct.new( :user_pool_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |