Class: Aws::CognitoIdentityProvider::Types::ListUserPoolClientSecretsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The request to list client secrets for a user pool app client.

Constant Summary collapse

SENSITIVE =
[:client_id]

Instance Attribute Summary collapse

Instance Attribute Details

#client_idString

The ID of the app client whose secrets you want to list.

Returns:

  • (String)


8920
8921
8922
8923
8924
8925
8926
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8920

class ListUserPoolClientSecretsRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :next_token)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#next_tokenString

This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.

Returns:

  • (String)


8920
8921
8922
8923
8924
8925
8926
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8920

class ListUserPoolClientSecretsRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :next_token)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool that contains the app client.

Returns:

  • (String)


8920
8921
8922
8923
8924
8925
8926
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8920

class ListUserPoolClientSecretsRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :next_token)
  SENSITIVE = [:client_id]
  include Aws::Structure
end