Class: Aws::CognitoIdentityProvider::Types::ListUserPoolClientSecretsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The response containing the list of client secret metadata. This response does not include a NextToken field as all secrets are returned in a single response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_secretsArray<Types::ClientSecretDescriptorType>

A list of client secret descriptors containing the identifier and creation date for each secret. For security reasons, the response never reveals the actual secret value in ClientSecretValue.



8948
8949
8950
8951
8952
8953
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8948

class ListUserPoolClientSecretsResponse < Struct.new(
  :client_secrets,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The identifier that Amazon Cognito returned with the previous request to this operation. When you include a pagination token in your request, Amazon Cognito returns the next set of items in the list. By use of this token, you can paginate through the full list of items.



8948
8949
8950
8951
8952
8953
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8948

class ListUserPoolClientSecretsResponse < Struct.new(
  :client_secrets,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end