Class: Aws::CognitoIdentityProvider::Types::ListUserPoolReplicasResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A pagination token for retrieving the next page of results. If this value is null, there are no more results to retrieve.

Returns:

  • (String)


9041
9042
9043
9044
9045
9046
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9041

class ListUserPoolReplicasResponse < Struct.new(
  :user_pool_replicas,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_replicasArray<Types::UserPoolReplicaType>

A list of user pool replicas, including information about their status, role, and Region.

Returns:



9041
9042
9043
9044
9045
9046
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9041

class ListUserPoolReplicasResponse < Struct.new(
  :user_pool_replicas,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end