Class: Aws::CognitoIdentityProvider::Types::ListUserPoolsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the request to list user pools.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of user pools that you want Amazon Cognito to return in the response.

Returns:



9067
9068
9069
9070
9071
9072
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9067

class ListUserPoolsRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.

Returns:



9067
9068
9069
9070
9071
9072
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9067

class ListUserPoolsRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end