Class: Aws::CognitoIdentityProvider::Types::ListUsersInGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ListUsersInGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_name ⇒ String
The name of the group that you want to query for user membership.
-
#limit ⇒ Integer
The maximum number of groups that you want Amazon Cognito to return in the response.
-
#next_token ⇒ String
This API operation returns a limited number of results.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to view the membership of the requested group.
Instance Attribute Details
#group_name ⇒ String
The name of the group that you want to query for user membership.
9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9126 class ListUsersInGroupRequest < Struct.new( :user_pool_id, :group_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of groups that you want Amazon Cognito to return
in the response. In some SDK contexts, this operation might return
fewer items than you specify in the Limit parameter without having
reached the end of the full list. If the response contains a
PaginationToken, then there are more results.
9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9126 class ListUsersInGroupRequest < Struct.new( :user_pool_id, :group_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.
9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9126 class ListUsersInGroupRequest < Struct.new( :user_pool_id, :group_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to view the membership of the requested group.
9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9126 class ListUsersInGroupRequest < Struct.new( :user_pool_id, :group_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |