Class: Aws::CognitoIdentityProvider::Types::ListUsersInGroupResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The identifier that Amazon Cognito returned with the previous request to this operation. When you include a pagination token in your request, Amazon Cognito returns the next set of items in the list. By use of this token, you can paginate through the full list of items.

Returns:

  • (String)


9150
9151
9152
9153
9154
9155
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9150

class ListUsersInGroupResponse < Struct.new(
  :users,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#usersArray<Types::UserType>

An array of users who are members in the group, and their attributes.

Returns:



9150
9151
9152
9153
9154
9155
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9150

class ListUsersInGroupResponse < Struct.new(
  :users,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end