Class: Aws::CognitoIdentityProvider::Types::ListUsersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ListUsersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The response from the request to list users.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pagination_token ⇒ String
The identifier that Amazon Cognito returned with the previous request to this operation.
-
#users ⇒ Array<Types::UserType>
An array of user pool users who match your query, and their attributes.
Instance Attribute Details
#pagination_token ⇒ String
The identifier that Amazon Cognito returned with the previous request to this operation. When you include a pagination token in your request, Amazon Cognito returns the next set of items in the list. By use of this token, you can paginate through the full list of items.
9299 9300 9301 9302 9303 9304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9299 class ListUsersResponse < Struct.new( :users, :pagination_token) SENSITIVE = [] include Aws::Structure end |
#users ⇒ Array<Types::UserType>
An array of user pool users who match your query, and their attributes. Between different requests, you might observe variations in the sequence that users in this response object are sorted into. The sort order of users isn't guaranteed to follow a single pattern, but the paginated list from a single chain of requests won't return duplicates.
9299 9300 9301 9302 9303 9304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9299 class ListUsersResponse < Struct.new( :users, :pagination_token) SENSITIVE = [] include Aws::Structure end |