Class: Aws::CognitoIdentityProvider::Types::ListWebAuthnCredentialsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.

Returns:

  • (String)


9329
9330
9331
9332
9333
9334
9335
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9329

class ListWebAuthnCredentialsRequest < Struct.new(
  :access_token,
  :next_token,
  :max_results)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#max_resultsInteger

The maximum number of the user's passkey credentials that you want to return.

Returns:

  • (Integer)


9329
9330
9331
9332
9333
9334
9335
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9329

class ListWebAuthnCredentialsRequest < Struct.new(
  :access_token,
  :next_token,
  :max_results)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#next_tokenString

This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.

Returns:

  • (String)


9329
9330
9331
9332
9333
9334
9335
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9329

class ListWebAuthnCredentialsRequest < Struct.new(
  :access_token,
  :next_token,
  :max_results)
  SENSITIVE = [:access_token]
  include Aws::Structure
end