Class: Aws::CognitoIdentityProvider::Types::NotAuthorizedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::NotAuthorizedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
This exception is thrown when a user isn’t authorized.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The message returned when the Amazon Cognito service returns a not authorized exception.
Instance Attribute Details
#message ⇒ String
The message returned when the Amazon Cognito service returns a not authorized exception.
9175 9176 9177 9178 9179 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9175 class NotAuthorizedException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |