Class: Aws::CognitoIdentityProvider::Types::NotifyEmailType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The template for email messages that threat protection sends to a user when your threat protection automated response has a Notify action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#html_bodyString

The body of an email notification formatted in HTML. Choose an HtmlBody or a TextBody to send an HTML-formatted or plaintext message, respectively.

Returns:

  • (String)


9015
9016
9017
9018
9019
9020
9021
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9015

class NotifyEmailType < Struct.new(
  :subject,
  :html_body,
  :text_body)
  SENSITIVE = []
  include Aws::Structure
end

#subjectString

The subject of the threat protection email notification.

Returns:

  • (String)


9015
9016
9017
9018
9019
9020
9021
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9015

class NotifyEmailType < Struct.new(
  :subject,
  :html_body,
  :text_body)
  SENSITIVE = []
  include Aws::Structure
end

#text_bodyString

The body of an email notification formatted in plaintext. Choose an HtmlBody or a TextBody to send an HTML-formatted or plaintext message, respectively.

Returns:

  • (String)


9015
9016
9017
9018
9019
9020
9021
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9015

class NotifyEmailType < Struct.new(
  :subject,
  :html_body,
  :text_body)
  SENSITIVE = []
  include Aws::Structure
end