Class: Aws::CognitoIdentityProvider::Types::NumberAttributeConstraintsType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The minimum and maximum values of an attribute that is of the number data type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_valueString

The maximum value of an attribute that is of the number data type.

Returns:

  • (String)


6131
6132
6133
6134
6135
6136
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6131

class NumberAttributeConstraintsType < Struct.new(
  :min_value,
  :max_value)
  SENSITIVE = []
  include Aws::Structure
end

#min_valueString

The minimum value of an attribute that is of the number data type.

Returns:

  • (String)


6131
6132
6133
6134
6135
6136
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6131

class NumberAttributeConstraintsType < Struct.new(
  :min_value,
  :max_value)
  SENSITIVE = []
  include Aws::Structure
end