Class: Aws::CognitoIdentityProvider::Types::OperationNotEnabledException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::OperationNotEnabledException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
This exception is thrown when an operation is not available in the current region or for the current user pool configuration. This can occur when attempting to perform operations that are not supported in secondary replica regions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
9618 9619 9620 9621 9622 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9618 class OperationNotEnabledException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |