Class: Aws::CognitoIdentityProvider::Types::PasswordPolicyType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::PasswordPolicyType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The password policy settings for a user pool, including complexity, history, and length requirements.
This data type is a request and response parameter of
- CreateUserPool][1
-
and [UpdateUserPool], and a response parameter
of [DescribeUserPool].
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateUserPool.html [2]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateUserPool.html [3]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserPool.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#minimum_length ⇒ Integer
The minimum length of the password in the policy that you have set.
-
#password_history_size ⇒ Integer
The number of previous passwords that you want Amazon Cognito to restrict each user from reusing.
-
#require_lowercase ⇒ Boolean
The requirement in a password policy that users must include at least one lowercase letter in their password.
-
#require_numbers ⇒ Boolean
The requirement in a password policy that users must include at least one number in their password.
-
#require_symbols ⇒ Boolean
The requirement in a password policy that users must include at least one symbol in their password.
-
#require_uppercase ⇒ Boolean
The requirement in a password policy that users must include at least one uppercase letter in their password.
-
#temporary_password_validity_days ⇒ Integer
The number of days a temporary password is valid in the password policy.
Instance Attribute Details
#minimum_length ⇒ Integer
The minimum length of the password in the policy that you have set. This value can’t be less than 6.
8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8406 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :password_history_size, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#password_history_size ⇒ Integer
The number of previous passwords that you want Amazon Cognito to restrict each user from reusing. Users can’t set a password that matches any of ‘n` previous passwords, where `n` is the value of `PasswordHistorySize`.
Password history isn’t enforced and isn’t displayed in
- DescribeUserPool][1
-
responses when you set this value to ‘0` or
don’t provide it. To activate this setting, [ advanced security features] must be active in your user pool.
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserPool.html [2]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pool-settings-advanced-security.html
8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8406 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :password_history_size, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#require_lowercase ⇒ Boolean
The requirement in a password policy that users must include at least one lowercase letter in their password.
8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8406 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :password_history_size, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#require_numbers ⇒ Boolean
The requirement in a password policy that users must include at least one number in their password.
8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8406 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :password_history_size, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#require_symbols ⇒ Boolean
The requirement in a password policy that users must include at least one symbol in their password.
8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8406 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :password_history_size, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#require_uppercase ⇒ Boolean
The requirement in a password policy that users must include at least one uppercase letter in their password.
8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8406 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :password_history_size, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#temporary_password_validity_days ⇒ Integer
The number of days a temporary password is valid in the password policy. If the user doesn’t sign in during this time, an administrator must reset their password. Defaults to ‘7`. If you submit a value of `0`, Amazon Cognito treats it as a null value and sets `TemporaryPasswordValidityDays` to its default value.
<note markdown=“1”> When you set ‘TemporaryPasswordValidityDays` for a user pool, you can no longer set a value for the legacy `UnusedAccountValidityDays` parameter in that user pool.
</note>
8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8406 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :password_history_size, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |