Class: Aws::CognitoIdentityProvider::Types::PreTokenGenerationVersionConfigType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::PreTokenGenerationVersionConfigType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The properties of a pre token generation Lambda trigger.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lambda_arn ⇒ String
The Amazon Resource Name (ARN) of the function that you want to assign to your Lambda trigger.
-
#lambda_version ⇒ String
The user pool trigger version of the request that Amazon Cognito sends to your Lambda function.
Instance Attribute Details
#lambda_arn ⇒ String
The Amazon Resource Name (ARN) of the function that you want to assign to your Lambda trigger.
This parameter and the PreTokenGeneration property of
LambdaConfig have the same value. For new instances of pre token
generation triggers, set LambdaArn.
9734 9735 9736 9737 9738 9739 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9734 class PreTokenGenerationVersionConfigType < Struct.new( :lambda_version, :lambda_arn) SENSITIVE = [] include Aws::Structure end |
#lambda_version ⇒ String
The user pool trigger version of the request that Amazon Cognito sends to your Lambda function. Higher-numbered versions add fields that support new features.
9734 9735 9736 9737 9738 9739 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9734 class PreTokenGenerationVersionConfigType < Struct.new( :lambda_version, :lambda_arn) SENSITIVE = [] include Aws::Structure end |