Class: Aws::CognitoIdentityProvider::Types::ProviderDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ProviderDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A container for IdP details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date the provider was added to the user pool.
-
#last_modified_date ⇒ Time
The date the provider was last modified.
-
#provider_name ⇒ String
The IdP name.
-
#provider_type ⇒ String
The IdP type.
Instance Attribute Details
#creation_date ⇒ Time
The date the provider was added to the user pool.
6240 6241 6242 6243 6244 6245 6246 6247 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6240 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date the provider was last modified.
6240 6241 6242 6243 6244 6245 6246 6247 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6240 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The IdP name.
6240 6241 6242 6243 6244 6245 6246 6247 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6240 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#provider_type ⇒ String
The IdP type.
6240 6241 6242 6243 6244 6245 6246 6247 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6240 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |