Class: Aws::CognitoIdentityProvider::Types::ProviderUserIdentifierType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The characteristics of a source or destination user for linking a federated user profile to a local user profile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#provider_attribute_nameString

The name of the provider attribute to link to, such as NameID.

Returns:

  • (String)


9579
9580
9581
9582
9583
9584
9585
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9579

class ProviderUserIdentifierType < Struct.new(
  :provider_name,
  :provider_attribute_name,
  :provider_attribute_value)
  SENSITIVE = []
  include Aws::Structure
end

#provider_attribute_valueString

The value of the provider attribute to link to, such as xxxxx_account.

Returns:

  • (String)


9579
9580
9581
9582
9583
9584
9585
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9579

class ProviderUserIdentifierType < Struct.new(
  :provider_name,
  :provider_attribute_name,
  :provider_attribute_value)
  SENSITIVE = []
  include Aws::Structure
end

#provider_nameString

The name of the provider, such as Facebook, Google, or Login with Amazon.

Returns:

  • (String)


9579
9580
9581
9582
9583
9584
9585
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9579

class ProviderUserIdentifierType < Struct.new(
  :provider_name,
  :provider_attribute_name,
  :provider_attribute_value)
  SENSITIVE = []
  include Aws::Structure
end