Class: Aws::CognitoIdentityProvider::Types::RecoveryOptionType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::RecoveryOptionType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass RecoveryOptionType data as a hash:
{
priority: 1, # required
name: "verified_email", # required, accepts verified_email, verified_phone_number, admin_only
}
A map containing a priority as a key, and recovery method name as a value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The recovery method for a user.
-
#priority ⇒ Integer
A positive integer specifying priority of a method with 1 being the highest priority.
Instance Attribute Details
#name ⇒ String
The recovery method for a user.
7585 7586 7587 7588 7589 7590 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7585 class RecoveryOptionType < Struct.new( :priority, :name) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
A positive integer specifying priority of a method with 1 being the highest priority.
7585 7586 7587 7588 7589 7590 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7585 class RecoveryOptionType < Struct.new( :priority, :name) SENSITIVE = [] include Aws::Structure end |