Class: Aws::CognitoIdentityProvider::Types::RefreshTokenRotationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::RefreshTokenRotationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The configuration of your app client for refresh token rotation. When enabled, your app client issues new ID, access, and refresh tokens when users renew their sessions with refresh tokens. When disabled, token refresh issues only ID and access tokens.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#feature ⇒ String
The state of refresh token rotation for the current app client.
-
#retry_grace_period_seconds ⇒ Integer
When you request a token refresh with
GetTokensFromRefreshToken, the original refresh token that you’re rotating out can remain valid for a period of time of up to 60 seconds.
Instance Attribute Details
#feature ⇒ String
The state of refresh token rotation for the current app client.
9306 9307 9308 9309 9310 9311 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9306 class RefreshTokenRotationType < Struct.new( :feature, :retry_grace_period_seconds) SENSITIVE = [] include Aws::Structure end |
#retry_grace_period_seconds ⇒ Integer
When you request a token refresh with GetTokensFromRefreshToken, the original refresh token that you’re rotating out can remain valid for a period of time of up to 60 seconds. This allows for client-side retries. When RetryGracePeriodSeconds is 0, the grace period is disabled and a successful request immediately invalidates the submitted refresh token.
9306 9307 9308 9309 9310 9311 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9306 class RefreshTokenRotationType < Struct.new( :feature, :retry_grace_period_seconds) SENSITIVE = [] include Aws::Structure end |