Class: Aws::CognitoIdentityProvider::Types::ResourceNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ResourceNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
This exception is thrown when the Amazon Cognito service can't find the requested resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The message returned when the Amazon Cognito service returns a resource not found exception.
Instance Attribute Details
#message ⇒ String
The message returned when the Amazon Cognito service returns a resource not found exception.
9780 9781 9782 9783 9784 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9780 class ResourceNotFoundException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |