Class: Aws::CognitoIdentityProvider::Types::RespondToAuthChallengeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::RespondToAuthChallengeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The request to respond to an authentication challenge.
Constant Summary collapse
- SENSITIVE =
[:client_id]
Instance Attribute Summary collapse
-
#analytics_metadata ⇒ Types::AnalyticsMetadataType
The Amazon Pinpoint analytics metadata that contributes to your metrics for ‘RespondToAuthChallenge` calls.
-
#challenge_name ⇒ String
The challenge name.
-
#challenge_responses ⇒ Hash<String,String>
The challenge responses.
-
#client_id ⇒ String
The app client ID.
-
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.
-
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service.
-
#user_context_data ⇒ Types::UserContextDataType
Contextual data about your user session, such as the device fingerprint, IP address, or location.
Instance Attribute Details
#analytics_metadata ⇒ Types::AnalyticsMetadataType
The Amazon Pinpoint analytics metadata that contributes to your metrics for ‘RespondToAuthChallenge` calls.
6588 6589 6590 6591 6592 6593 6594 6595 6596 6597 6598 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6588 class RespondToAuthChallengeRequest < Struct.new( :client_id, :challenge_name, :session, :challenge_responses, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id] include Aws::Structure end |
#challenge_name ⇒ String
The challenge name. For more information, see [InitiateAuth].
‘ADMIN_NO_SRP_AUTH` isn’t a valid value.
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_InitiateAuth.html
6588 6589 6590 6591 6592 6593 6594 6595 6596 6597 6598 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6588 class RespondToAuthChallengeRequest < Struct.new( :client_id, :challenge_name, :session, :challenge_responses, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id] include Aws::Structure end |
#challenge_responses ⇒ Hash<String,String>
The challenge responses. These are inputs corresponding to the value of ‘ChallengeName`, for example:
<note markdown=“1”> ‘SECRET_HASH` (if app client is configured with client secret) applies to all of the inputs that follow (including `SOFTWARE_TOKEN_MFA`).
</note>
-
‘SMS_MFA`: `SMS_MFA_CODE`, `USERNAME`.
-
‘PASSWORD_VERIFIER`: `PASSWORD_CLAIM_SIGNATURE`, `PASSWORD_CLAIM_SECRET_BLOCK`, `TIMESTAMP`, `USERNAME`.
<note markdown=“1”> ‘PASSWORD_VERIFIER` requires `DEVICE_KEY` when you sign in with a remembered device.
</note> -
‘NEW_PASSWORD_REQUIRED`: `NEW_PASSWORD`, `USERNAME`, `SECRET_HASH` (if app client is configured with client secret). To set any required attributes that Amazon Cognito returned as `requiredAttributes` in the `InitiateAuth` response, add a `userAttributes.attributename ` parameter. This parameter can also set values for writable attributes that aren’t required by your user pool.
<note markdown=“1”> In a ‘NEW_PASSWORD_REQUIRED` challenge response, you can’t modify a required attribute that already has a value. In ‘RespondToAuthChallenge`, set a value for any keys that Amazon Cognito returned in the `requiredAttributes` parameter, then use the `UpdateUserAttributes` API operation to modify the value of any additional attributes.
</note> -
‘SOFTWARE_TOKEN_MFA`: `USERNAME` and `SOFTWARE_TOKEN_MFA_CODE` are required attributes.
-
‘DEVICE_SRP_AUTH` requires `USERNAME`, `DEVICE_KEY`, `SRP_A` (and `SECRET_HASH`).
-
‘DEVICE_PASSWORD_VERIFIER` requires everything that `PASSWORD_VERIFIER` requires, plus `DEVICE_KEY`.
-
‘MFA_SETUP` requires `USERNAME`, plus you must use the session value returned by `VerifySoftwareToken` in the `Session` parameter.
6588 6589 6590 6591 6592 6593 6594 6595 6596 6597 6598 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6588 class RespondToAuthChallengeRequest < Struct.new( :client_id, :challenge_name, :session, :challenge_responses, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id] include Aws::Structure end |
#client_id ⇒ String
The app client ID.
6588 6589 6590 6591 6592 6593 6594 6595 6596 6597 6598 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6588 class RespondToAuthChallengeRequest < Struct.new( :client_id, :challenge_name, :session, :challenge_responses, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id] include Aws::Structure end |
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.
You create custom workflows by assigning Lambda functions to user pool triggers. When you use the RespondToAuthChallenge API action, Amazon Cognito invokes any functions that are assigned to the following triggers: *post authentication*, *pre token generation*, *define auth challenge*, *create auth challenge*, and *verify auth challenge*. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a ‘clientMetadata` attribute, which provides the data that you assigned to the ClientMetadata parameter in your RespondToAuthChallenge request. In your function code in Lambda, you can process the `clientMetadata` value to enhance your workflow for your specific needs.
For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.
<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won’t do the following:
* Store the ClientMetadata value. This data is available only to
Lambda triggers that are assigned to a user pool to support custom
workflows. If your user pool configuration doesn't include
triggers, the ClientMetadata parameter serves no purpose.
-
Validate the ClientMetadata value.
-
Encrypt the ClientMetadata value. Don’t use Amazon Cognito to provide sensitive information.
</note>
6588 6589 6590 6591 6592 6593 6594 6595 6596 6597 6598 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6588 class RespondToAuthChallengeRequest < Struct.new( :client_id, :challenge_name, :session, :challenge_responses, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id] include Aws::Structure end |
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service. If ‘InitiateAuth` or `RespondToAuthChallenge` API call determines that the caller must pass another challenge, they return a session with other challenge parameters. This session should be passed as it is to the next `RespondToAuthChallenge` API call.
6588 6589 6590 6591 6592 6593 6594 6595 6596 6597 6598 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6588 class RespondToAuthChallengeRequest < Struct.new( :client_id, :challenge_name, :session, :challenge_responses, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id] include Aws::Structure end |
#user_context_data ⇒ Types::UserContextDataType
Contextual data about your user session, such as the device fingerprint, IP address, or location. Amazon Cognito advanced security evaluates the risk of an authentication event based on the context that your app generates and passes to Amazon Cognito when it makes API requests.
6588 6589 6590 6591 6592 6593 6594 6595 6596 6597 6598 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6588 class RespondToAuthChallengeRequest < Struct.new( :client_id, :challenge_name, :session, :challenge_responses, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id] include Aws::Structure end |