Class: Aws::CognitoIdentityProvider::Types::RoutingType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::RoutingType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Specifies routing configuration for user pool domains. Contains failover settings for multi-region deployments.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failover ⇒ Types::FailoverType
The failover configuration that specifies the secondary region and health check settings.
Instance Attribute Details
#failover ⇒ Types::FailoverType
The failover configuration that specifies the secondary region and health check settings.
10351 10352 10353 10354 10355 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10351 class RoutingType < Struct.new( :failover) SENSITIVE = [] include Aws::Structure end |