Class: Aws::CognitoIdentityProvider::Types::SMSMfaSettingsType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SMSMfaSettingsType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A user’s preference for using SMS message multi-factor authentication (MFA). Turns SMS MFA on and off, and can set SMS as preferred when other MFA options are available. You can’t turn off SMS MFA for any of your users when MFA is required in your user pool; you can only set the type that your user prefers.
This data type is a request parameter of [SetUserMFAPreference] and [AdminSetUserMFAPreference].
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetUserMFAPreference.html [2]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminSetUserMFAPreference.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Specifies whether SMS message MFA is activated.
-
#preferred_mfa ⇒ Boolean
Specifies whether SMS is the preferred MFA method.
Instance Attribute Details
#enabled ⇒ Boolean
Specifies whether SMS message MFA is activated. If an MFA type is activated for a user, the user will be prompted for MFA during all sign-in attempts, unless device tracking is turned on and the device has been trusted.
9237 9238 9239 9240 9241 9242 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9237 class SMSMfaSettingsType < Struct.new( :enabled, :preferred_mfa) SENSITIVE = [] include Aws::Structure end |
#preferred_mfa ⇒ Boolean
Specifies whether SMS is the preferred MFA method. If true, your user pool prompts the specified user for a code delivered by SMS message after username-password sign-in succeeds.
9237 9238 9239 9240 9241 9242 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9237 class SMSMfaSettingsType < Struct.new( :enabled, :preferred_mfa) SENSITIVE = [] include Aws::Structure end |