Class: Aws::CognitoIdentityProvider::Types::SetLogDeliveryConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_configurationsArray<Types::LogConfigurationType>

A collection of all of the detailed activity logging configurations for a user pool.

Returns:



7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7128

class SetLogDeliveryConfigurationRequest < Struct.new(
  :user_pool_id,
  :log_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool where you want to configure detailed activity logging .

Returns:

  • (String)


7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7128

class SetLogDeliveryConfigurationRequest < Struct.new(
  :user_pool_id,
  :log_configurations)
  SENSITIVE = []
  include Aws::Structure
end