Class: Aws::CognitoIdentityProvider::Types::SetUICustomizationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:client_id]

Instance Attribute Summary collapse

Instance Attribute Details

#client_idString

The ID of the app client that you want to customize. To apply a default style to all app clients not configured with client-level branding, set this parameter value to ALL.



11110
11111
11112
11113
11114
11115
11116
11117
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11110

class SetUICustomizationRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :css,
  :image_file)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#cssString

A plaintext CSS file that contains the custom fields that you want to apply to your user pool or app client. To download a template, go to the Amazon Cognito console. Navigate to your user pool App clients tab, select Login pages, edit Hosted UI (classic) style, and select the link to CSS template.css.



11110
11111
11112
11113
11114
11115
11116
11117
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11110

class SetUICustomizationRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :css,
  :image_file)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#image_fileString

The image that you want to set as your login in the classic hosted UI, as a Base64-formatted binary object.



11110
11111
11112
11113
11114
11115
11116
11117
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11110

class SetUICustomizationRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :css,
  :image_file)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool where you want to apply branding to the classic hosted UI.



11110
11111
11112
11113
11114
11115
11116
11117
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11110

class SetUICustomizationRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :css,
  :image_file)
  SENSITIVE = [:client_id]
  include Aws::Structure
end