Class: Aws::CognitoIdentityProvider::Types::SetUserMFAPreferenceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SetUserMFAPreferenceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the currently signed-in user.
-
#email_mfa_settings ⇒ Types::EmailMfaSettingsType
User preferences for email message MFA.
-
#sms_mfa_settings ⇒ Types::SMSMfaSettingsType
User preferences for SMS message MFA.
-
#software_token_mfa_settings ⇒ Types::SoftwareTokenMfaSettingsType
User preferences for time-based one-time password (TOTP) MFA.
-
#web_authn_mfa_settings ⇒ Types::WebAuthnMfaSettingsType
User preferences for passkey MFA.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the currently
signed-in user. Must include a scope claim for
aws.cognito.signin.user.admin.
11014 11015 11016 11017 11018 11019 11020 11021 11022 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11014 class SetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |
#email_mfa_settings ⇒ Types::EmailMfaSettingsType
User preferences for email message MFA. Activates or deactivates email MFA and sets it as the preferred MFA method when multiple methods are available. To activate this setting, your user pool must be in the Essentials tier or higher.
11014 11015 11016 11017 11018 11019 11020 11021 11022 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11014 class SetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |
#sms_mfa_settings ⇒ Types::SMSMfaSettingsType
User preferences for SMS message MFA. Activates or deactivates SMS MFA and sets it as the preferred MFA method when multiple methods are available.
11014 11015 11016 11017 11018 11019 11020 11021 11022 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11014 class SetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |
#software_token_mfa_settings ⇒ Types::SoftwareTokenMfaSettingsType
User preferences for time-based one-time password (TOTP) MFA. Activates or deactivates TOTP MFA and sets it as the preferred MFA method when multiple methods are available. Users must register a TOTP authenticator before they set this as their preferred MFA method.
11014 11015 11016 11017 11018 11019 11020 11021 11022 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11014 class SetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |
#web_authn_mfa_settings ⇒ Types::WebAuthnMfaSettingsType
User preferences for passkey MFA. Activates or deactivates passkey
MFA for the user. When activated, passkey authentication requires
user verification, and passkey sign-in is available when MFA is
required. To activate this setting, the FactorConfiguration of
your user pool WebAuthnConfiguration must be
MULTI_FACTOR_WITH_USER_VERIFICATION. To activate this setting,
your user pool must be in the Essentials tier or higher.
11014 11015 11016 11017 11018 11019 11020 11021 11022 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11014 class SetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :email_mfa_settings, :web_authn_mfa_settings, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |