Class: Aws::CognitoIdentityProvider::Types::SetUserPoolMfaConfigResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SetUserPoolMfaConfigResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_mfa_configuration ⇒ Types::EmailMfaConfigType
Shows configuration for user pool email message MFA and sign-in with one-time passwords (OTPs).
-
#mfa_configuration ⇒ String
Displays multi-factor authentication (MFA) as on, off, or optional.
-
#sms_mfa_configuration ⇒ Types::SmsMfaConfigType
Shows user pool SMS message configuration for MFA and sign-in with SMS-message OTPs.
-
#software_token_mfa_configuration ⇒ Types::SoftwareTokenMfaConfigType
Shows user pool configuration for time-based one-time password (TOTP) MFA.
-
#web_authn_configuration ⇒ Types::WebAuthnConfigurationType
The configuration of your user pool for passkey, or WebAuthn, sign-in with authenticators like biometric and security-key devices.
Instance Attribute Details
#email_mfa_configuration ⇒ Types::EmailMfaConfigType
Shows configuration for user pool email message MFA and sign-in with one-time passwords (OTPs). Includes the subject and body of the email message template for sign-in and MFA messages. To activate this setting, your user pool must be in the [ Essentials tier] or higher.
[1]: docs.aws.amazon.com/cognito/latest/developerguide/feature-plans-features-essentials.html
10531 10532 10533 10534 10535 10536 10537 10538 10539 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10531 class SetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#mfa_configuration ⇒ String
Displays multi-factor authentication (MFA) as on, off, or optional. When ON, all users must set up MFA before they can sign in. When OPTIONAL, your application must make a client-side determination of whether a user wants to register an MFA device. For user pools with adaptive authentication with threat protection, choose OPTIONAL.
When MfaConfiguration is OPTIONAL, managed login doesn’t automatically prompt users to set up MFA. Amazon Cognito generates MFA prompts in API responses and in managed login for users who have chosen and configured a preferred MFA factor.
10531 10532 10533 10534 10535 10536 10537 10538 10539 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10531 class SetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#sms_mfa_configuration ⇒ Types::SmsMfaConfigType
Shows user pool SMS message configuration for MFA and sign-in with SMS-message OTPs. Includes the message template and the SMS message sending configuration for Amazon SNS.
10531 10532 10533 10534 10535 10536 10537 10538 10539 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10531 class SetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#software_token_mfa_configuration ⇒ Types::SoftwareTokenMfaConfigType
Shows user pool configuration for time-based one-time password (TOTP) MFA. Includes TOTP enabled or disabled state.
10531 10532 10533 10534 10535 10536 10537 10538 10539 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10531 class SetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#web_authn_configuration ⇒ Types::WebAuthnConfigurationType
The configuration of your user pool for passkey, or WebAuthn, sign-in with authenticators like biometric and security-key devices. Includes relying-party configuration and settings for user-verification requirements.
10531 10532 10533 10534 10535 10536 10537 10538 10539 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10531 class SetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |