Class: Aws::CognitoIdentityProvider::Types::SetUserSettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass SetUserSettingsRequest data as a hash:

{
  access_token: "TokenModelType", # required
  mfa_options: [ # required
    {
      delivery_medium: "SMS", # accepts SMS, EMAIL
      attribute_name: "AttributeNameType",
    },
  ],
}

Represents the request to set user settings.

Constant Summary collapse

SENSITIVE =
[:access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A valid access token that Amazon Cognito issued to the user whose user settings you want to configure.

Returns:

  • (String)


8393
8394
8395
8396
8397
8398
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8393

class SetUserSettingsRequest < Struct.new(
  :access_token,
  :mfa_options)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#mfa_optionsArray<Types::MFAOptionType>

You can use this parameter only to set an SMS configuration that uses SMS for delivery.

Returns:



8393
8394
8395
8396
8397
8398
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8393

class SetUserSettingsRequest < Struct.new(
  :access_token,
  :mfa_options)
  SENSITIVE = [:access_token]
  include Aws::Structure
end