Class: Aws::CognitoIdentityProvider::Types::SignUpRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the request to register a user.

Constant Summary collapse

SENSITIVE =
[:client_id, :secret_hash, :username, :password]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_metadataTypes::AnalyticsMetadataType

The Amazon Pinpoint analytics metadata that contributes to your metrics for ‘SignUp` calls.



7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7446

class SignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :password,
  :user_attributes,
  :validation_data,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username, :password]
  include Aws::Structure
end

#client_idString

The ID of the client associated with the user pool.

Returns:

  • (String)


7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7446

class SignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :password,
  :user_attributes,
  :validation_data,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username, :password]
  include Aws::Structure
end

#client_metadataHash<String,String>

A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.

You create custom workflows by assigning Lambda functions to user pool triggers. When you use the SignUp API action, Amazon Cognito invokes any functions that are assigned to the following triggers: *pre sign-up*, *custom message*, and *post confirmation*. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a ‘clientMetadata` attribute, which provides the data that you assigned to the ClientMetadata parameter in your SignUp request. In your function code in Lambda, you can process the `clientMetadata` value to enhance your workflow for your specific needs.

For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.

<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won’t do the following:

* Store the ClientMetadata value. This data is available only to
 Lambda triggers that are assigned to a user pool to support custom
 workflows. If your user pool configuration doesn't include
 triggers, the ClientMetadata parameter serves no purpose.
  • Validate the ClientMetadata value.

  • Encrypt the ClientMetadata value. Don’t use Amazon Cognito to provide sensitive information.

</note>

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools-working-with-aws-lambda-triggers.html

Returns:

  • (Hash<String,String>)


7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7446

class SignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :password,
  :user_attributes,
  :validation_data,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username, :password]
  include Aws::Structure
end

#passwordString

The password of the user you want to register.

Returns:

  • (String)


7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7446

class SignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :password,
  :user_attributes,
  :validation_data,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username, :password]
  include Aws::Structure
end

#secret_hashString

A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message.

Returns:

  • (String)


7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7446

class SignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :password,
  :user_attributes,
  :validation_data,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username, :password]
  include Aws::Structure
end

#user_attributesArray<Types::AttributeType>

An array of name-value pairs representing user attributes.

For custom attributes, you must prepend the ‘custom:` prefix to the attribute name.

Returns:



7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7446

class SignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :password,
  :user_attributes,
  :validation_data,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username, :password]
  include Aws::Structure
end

#user_context_dataTypes::UserContextDataType

Contextual data about your user session, such as the device fingerprint, IP address, or location. Amazon Cognito advanced security evaluates the risk of an authentication event based on the context that your app generates and passes to Amazon Cognito when it makes API requests.



7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7446

class SignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :password,
  :user_attributes,
  :validation_data,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username, :password]
  include Aws::Structure
end

#usernameString

The user name of the user you want to register.

Returns:

  • (String)


7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7446

class SignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :password,
  :user_attributes,
  :validation_data,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username, :password]
  include Aws::Structure
end

#validation_dataArray<Types::AttributeType>

The validation data in the request to register a user.

Returns:



7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7446

class SignUpRequest < Struct.new(
  :client_id,
  :secret_hash,
  :username,
  :password,
  :user_attributes,
  :validation_data,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id, :secret_hash, :username, :password]
  include Aws::Structure
end