Class: Aws::CognitoIdentityProvider::Types::SignUpResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The response from the server for a registration request.

Constant Summary collapse

SENSITIVE =
[:session]

Instance Attribute Summary collapse

Instance Attribute Details

#code_delivery_detailsTypes::CodeDeliveryDetailsType

The code delivery details returned by the server response to the user registration request.



9845
9846
9847
9848
9849
9850
9851
9852
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9845

class SignUpResponse < Struct.new(
  :user_confirmed,
  :code_delivery_details,
  :user_sub,
  :session)
  SENSITIVE = [:session]
  include Aws::Structure
end

#sessionString

A session Id that you can pass to ‘ConfirmSignUp` when you want to immediately sign in your user with the `USER_AUTH` flow after they complete sign-up.

Returns:

  • (String)


9845
9846
9847
9848
9849
9850
9851
9852
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9845

class SignUpResponse < Struct.new(
  :user_confirmed,
  :code_delivery_details,
  :user_sub,
  :session)
  SENSITIVE = [:session]
  include Aws::Structure
end

#user_confirmedBoolean

A response from the server indicating that a user registration has been confirmed.

Returns:

  • (Boolean)


9845
9846
9847
9848
9849
9850
9851
9852
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9845

class SignUpResponse < Struct.new(
  :user_confirmed,
  :code_delivery_details,
  :user_sub,
  :session)
  SENSITIVE = [:session]
  include Aws::Structure
end

#user_subString

The 128-bit ID of the authenticated user. This isn’t the same as ‘username`.

Returns:

  • (String)


9845
9846
9847
9848
9849
9850
9851
9852
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9845

class SignUpResponse < Struct.new(
  :user_confirmed,
  :code_delivery_details,
  :user_sub,
  :session)
  SENSITIVE = [:session]
  include Aws::Structure
end