Class: Aws::CognitoIdentityProvider::Types::SmsConfigurationType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

User pool configuration for delivery of SMS messages with Amazon Simple Notification Service. To send SMS messages with Amazon SNS in the Amazon Web Services Region that you want, the Amazon Cognito user pool uses an Identity and Access Management (IAM) role in your Amazon Web Services account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eums_smsTypes::EumsSmsConfigurationType

The configuration for sending SMS messages through Amazon Web Services End User Messaging SMS, as an alternative to Amazon SNS. In a user pool, provide either the Amazon SNS configuration (SnsCallerArn) or this configuration, but not both. In Amazon Web Services Regions where Amazon SNS is not available, this configuration is required.



11343
11344
11345
11346
11347
11348
11349
11350
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11343

class SmsConfigurationType < Struct.new(
  :sns_caller_arn,
  :external_id,
  :sns_region,
  :eums_sms)
  SENSITIVE = []
  include Aws::Structure
end

#external_idString

The external ID provides additional security for your IAM role. You can use an ExternalId with the IAM role that you use with Amazon SNS to send SMS messages for your user pool. If you provide an ExternalId, your Amazon Cognito user pool includes it in the request to assume your IAM role. You can configure the role trust policy to require that Amazon Cognito, and any principal, provide the ExternalID. If you use the Amazon Cognito Management Console to create a role for SMS multi-factor authentication (MFA), Amazon Cognito creates a role with the required permissions and a trust policy that demonstrates use of the ExternalId.

For more information about the ExternalId of a role, see How to use an external ID when granting access to your Amazon Web Services resources to a third party.

Returns:

  • (String)


11343
11344
11345
11346
11347
11348
11349
11350
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11343

class SmsConfigurationType < Struct.new(
  :sns_caller_arn,
  :external_id,
  :sns_region,
  :eums_sms)
  SENSITIVE = []
  include Aws::Structure
end

#sns_caller_arnString

The Amazon Resource Name (ARN) of the Amazon SNS caller. This is the ARN of the IAM role in your Amazon Web Services account that Amazon Cognito will use to send SMS messages. SMS messages are subject to a spending limit.

Returns:

  • (String)


11343
11344
11345
11346
11347
11348
11349
11350
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11343

class SmsConfigurationType < Struct.new(
  :sns_caller_arn,
  :external_id,
  :sns_region,
  :eums_sms)
  SENSITIVE = []
  include Aws::Structure
end

#sns_regionString

The Amazon Web Services Region to use with Amazon SNS integration. You can choose the same Region as your user pool, or a supported Legacy Amazon SNS alternate Region.

Amazon Cognito resources in the Asia Pacific (Seoul) Amazon Web Services Region must use your Amazon SNS configuration in the Asia Pacific (Tokyo) Region. For more information, see SMS message settings for Amazon Cognito user pools.

Returns:

  • (String)


11343
11344
11345
11346
11347
11348
11349
11350
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11343

class SmsConfigurationType < Struct.new(
  :sns_caller_arn,
  :external_id,
  :sns_region,
  :eums_sms)
  SENSITIVE = []
  include Aws::Structure
end