Class: Aws::CognitoIdentityProvider::Types::SmsMfaConfigType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SmsMfaConfigType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass SmsMfaConfigType data as a hash:
{
sms_authentication_message: "SmsVerificationMessageType",
sms_configuration: {
sns_caller_arn: "ArnType", # required
external_id: "StringType",
},
}
The SMS text message multi-factor authentication (MFA) configuration type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#sms_authentication_message ⇒ String
The SMS authentication message that will be sent to users with the code they must sign in.
-
#sms_configuration ⇒ Types::SmsConfigurationType
The SMS configuration.
Instance Attribute Details
#sms_authentication_message ⇒ String
The SMS authentication message that will be sent to users with the code they must sign in. The message must contain the ‘{####\}’ placeholder, which is replaced with the code. If the message isn't included, and default message will be used.
8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8468 class SmsMfaConfigType < Struct.new( :sms_authentication_message, :sms_configuration) SENSITIVE = [] include Aws::Structure end |
#sms_configuration ⇒ Types::SmsConfigurationType
The SMS configuration.
8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8468 class SmsMfaConfigType < Struct.new( :sms_authentication_message, :sms_configuration) SENSITIVE = [] include Aws::Structure end |