Class: Aws::CognitoIdentityProvider::Types::SoftwareTokenMfaSettingsType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SoftwareTokenMfaSettingsType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass SoftwareTokenMfaSettingsType data as a hash:
{
enabled: false,
preferred_mfa: false,
}
The type used for enabling software token MFA at the user level. If an MFA type is activated for a user, the user will be prompted for MFA during all sign-in attempts, unless device tracking is turned on and the device has been trusted. If you want MFA to be applied selectively based on the assessed risk level of sign-in attempts, deactivate MFA for users and turn on Adaptive Authentication for the user pool.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Specifies whether software token MFA is activated.
-
#preferred_mfa ⇒ Boolean
Specifies whether software token MFA is the preferred MFA method.
Instance Attribute Details
#enabled ⇒ Boolean
Specifies whether software token MFA is activated. If an MFA type is activated for a user, the user will be prompted for MFA during all sign-in attempts, unless device tracking is turned on and the device has been trusted.
8897 8898 8899 8900 8901 8902 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8897 class SoftwareTokenMfaSettingsType < Struct.new( :enabled, :preferred_mfa) SENSITIVE = [] include Aws::Structure end |
#preferred_mfa ⇒ Boolean
Specifies whether software token MFA is the preferred MFA method.
8897 8898 8899 8900 8901 8902 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8897 class SoftwareTokenMfaSettingsType < Struct.new( :enabled, :preferred_mfa) SENSITIVE = [] include Aws::Structure end |