Class: Aws::CognitoIdentityProvider::Types::StopUserImportJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the request to stop the user import job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_idString

The ID of a running user import job.

Returns:

  • (String)


11022
11023
11024
11025
11026
11027
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11022

class StopUserImportJobRequest < Struct.new(
  :user_pool_id,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool that you want to stop.

Returns:

  • (String)


11022
11023
11024
11025
11026
11027
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11022

class StopUserImportJobRequest < Struct.new(
  :user_pool_id,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end