Class: Aws::CognitoIdentityProvider::Types::TokenValidityUnitsType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The time units that, with IdTokenValidity, AccessTokenValidity, and RefreshTokenValidity, set and display the duration of ID, access, and refresh tokens for an app client. You can assign a separate token validity unit to each type of token.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A time unit for the value that you set in the AccessTokenValidity parameter. The default AccessTokenValidity time unit is hours. AccessTokenValidity duration can range from five minutes to one day.

Returns:

  • (String)


11630
11631
11632
11633
11634
11635
11636
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11630

class TokenValidityUnitsType < Struct.new(
  :access_token,
  :id_token,
  :refresh_token)
  SENSITIVE = []
  include Aws::Structure
end

#id_tokenString

A time unit for the value that you set in the IdTokenValidity parameter. The default IdTokenValidity time unit is hours. IdTokenValidity duration can range from five minutes to one day.

Returns:

  • (String)


11630
11631
11632
11633
11634
11635
11636
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11630

class TokenValidityUnitsType < Struct.new(
  :access_token,
  :id_token,
  :refresh_token)
  SENSITIVE = []
  include Aws::Structure
end

#refresh_tokenString

A time unit for the value that you set in the RefreshTokenValidity parameter. The default RefreshTokenValidity time unit is days. RefreshTokenValidity duration can range from 60 minutes to 10 years.

Returns:

  • (String)


11630
11631
11632
11633
11634
11635
11636
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11630

class TokenValidityUnitsType < Struct.new(
  :access_token,
  :id_token,
  :refresh_token)
  SENSITIVE = []
  include Aws::Structure
end