Class: Aws::CognitoIdentityProvider::Types::TooManyFailedAttemptsException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::TooManyFailedAttemptsException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
This exception is thrown when the user has made too many failed attempts for a given action, such as sign-in.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The message returned when Amazon Cognito returns a ‘TooManyFailedAttempts` exception.
Instance Attribute Details
#message ⇒ String
The message returned when Amazon Cognito returns a ‘TooManyFailedAttempts` exception.
7801 7802 7803 7804 7805 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7801 class TooManyFailedAttemptsException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |