Class: Aws::CognitoIdentityProvider::Types::TooManyRequestsException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

This exception is thrown when the user has made too many requests for a given operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The message returned when the Amazon Cognito service returns a too many requests exception.

Returns:

  • (String)


11664
11665
11666
11667
11668
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11664

class TooManyRequestsException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end