Class: Aws::CognitoIdentityProvider::Types::UpdateAuthEventFeedbackRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:username, :feedback_token]

Instance Attribute Summary collapse

Instance Attribute Details

#event_idString

The ID of the authentication event that you want to submit feedback for.

Returns:

  • (String)


12094
12095
12096
12097
12098
12099
12100
12101
12102
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12094

class UpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_token,
  :feedback_value)
  SENSITIVE = [:username, :feedback_token]
  include Aws::Structure
end

#feedback_tokenString

The feedback token, an encrypted object generated by Amazon Cognito and passed to your user in the notification email message from the event.

Returns:

  • (String)


12094
12095
12096
12097
12098
12099
12100
12101
12102
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12094

class UpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_token,
  :feedback_value)
  SENSITIVE = [:username, :feedback_token]
  include Aws::Structure
end

#feedback_valueString

Your feedback to the authentication event. When you provide a FeedbackValue value of valid, you tell Amazon Cognito that you trust a user session where Amazon Cognito has evaluated some level of risk. When you provide a FeedbackValue value of invalid, you tell Amazon Cognito that you don't trust a user session, or you don't believe that Amazon Cognito evaluated a high-enough risk level.

Returns:

  • (String)


12094
12095
12096
12097
12098
12099
12100
12101
12102
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12094

class UpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_token,
  :feedback_value)
  SENSITIVE = [:username, :feedback_token]
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool where you want to update auth event feedback.

Returns:

  • (String)


12094
12095
12096
12097
12098
12099
12100
12101
12102
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12094

class UpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_token,
  :feedback_value)
  SENSITIVE = [:username, :feedback_token]
  include Aws::Structure
end

#usernameString

The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If username isn't an alias attribute in your user pool, this value must be the sub of a local user or the username of a user from a third-party IdP.

Returns:

  • (String)


12094
12095
12096
12097
12098
12099
12100
12101
12102
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12094

class UpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_token,
  :feedback_value)
  SENSITIVE = [:username, :feedback_token]
  include Aws::Structure
end