Class: Aws::CognitoIdentityProvider::Types::UpdateGroupResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateGroupResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group ⇒ Types::GroupType
Contains the updated details of the group, including precedence, IAM role, and description.
Instance Attribute Details
#group ⇒ Types::GroupType
Contains the updated details of the group, including precedence, IAM role, and description.
12223 12224 12225 12226 12227 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12223 class UpdateGroupResponse < Struct.new( :group) SENSITIVE = [] include Aws::Structure end |