Class: Aws::CognitoIdentityProvider::Types::UpdateResourceServerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateResourceServerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass UpdateResourceServerRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
identifier: "ResourceServerIdentifierType", # required
name: "ResourceServerNameType", # required
scopes: [
{
scope_name: "ResourceServerScopeNameType", # required
scope_description: "ResourceServerScopeDescriptionType", # required
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
The identifier for the resource server.
-
#name ⇒ String
The name of the resource server.
-
#scopes ⇒ Array<Types::ResourceServerScopeType>
The scope values to be set for the resource server.
-
#user_pool_id ⇒ String
The user pool ID for the user pool.
Instance Attribute Details
#identifier ⇒ String
The identifier for the resource server.
9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9460 class UpdateResourceServerRequest < Struct.new( :user_pool_id, :identifier, :name, :scopes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the resource server.
9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9460 class UpdateResourceServerRequest < Struct.new( :user_pool_id, :identifier, :name, :scopes) SENSITIVE = [] include Aws::Structure end |
#scopes ⇒ Array<Types::ResourceServerScopeType>
The scope values to be set for the resource server.
9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9460 class UpdateResourceServerRequest < Struct.new( :user_pool_id, :identifier, :name, :scopes) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool.
9460 9461 9462 9463 9464 9465 9466 9467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9460 class UpdateResourceServerRequest < Struct.new( :user_pool_id, :identifier, :name, :scopes) SENSITIVE = [] include Aws::Structure end |