Class: Aws::CognitoIdentityProvider::Types::UpdateTermsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateTermsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enforcement ⇒ String
This parameter is reserved for future use and currently accepts only one value.
-
#links ⇒ Hash<String,String>
A map of URLs to languages.
-
#terms_id ⇒ String
The ID of the terms document that you want to update.
-
#terms_name ⇒ String
The new name that you want to apply to the requested terms documents.
-
#terms_source ⇒ String
This parameter is reserved for future use and currently accepts only one value.
-
#user_pool_id ⇒ String
The ID of the user pool that contains the terms that you want to update.
Instance Attribute Details
#enforcement ⇒ String
This parameter is reserved for future use and currently accepts only one value.
11925 11926 11927 11928 11929 11930 11931 11932 11933 11934 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11925 class UpdateTermsRequest < Struct.new( :terms_id, :user_pool_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [] include Aws::Structure end |
#links ⇒ Hash<String,String>
A map of URLs to languages. For each localized language that will view the requested ‘TermsName`, assign a URL. A selection of `cognito:default` displays for all languages that don’t have a language-specific URL.
For example, ‘“cognito:default”: “terms.example.com”, “cognito:spanish”: “terms.example.com/es”`.
11925 11926 11927 11928 11929 11930 11931 11932 11933 11934 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11925 class UpdateTermsRequest < Struct.new( :terms_id, :user_pool_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [] include Aws::Structure end |
#terms_id ⇒ String
The ID of the terms document that you want to update.
11925 11926 11927 11928 11929 11930 11931 11932 11933 11934 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11925 class UpdateTermsRequest < Struct.new( :terms_id, :user_pool_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [] include Aws::Structure end |
#terms_name ⇒ String
The new name that you want to apply to the requested terms documents.
11925 11926 11927 11928 11929 11930 11931 11932 11933 11934 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11925 class UpdateTermsRequest < Struct.new( :terms_id, :user_pool_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [] include Aws::Structure end |
#terms_source ⇒ String
This parameter is reserved for future use and currently accepts only one value.
11925 11926 11927 11928 11929 11930 11931 11932 11933 11934 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11925 class UpdateTermsRequest < Struct.new( :terms_id, :user_pool_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool that contains the terms that you want to update.
11925 11926 11927 11928 11929 11930 11931 11932 11933 11934 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11925 class UpdateTermsRequest < Struct.new( :terms_id, :user_pool_id, :terms_name, :terms_source, :enforcement, :links) SENSITIVE = [] include Aws::Structure end |