Class: Aws::CognitoIdentityProvider::Types::UpdateUserAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateUserAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to update user attributes.
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the currently signed-in user.
-
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.
-
#user_attributes ⇒ Array<Types::AttributeType>
An array of name-value pairs representing user attributes.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for ‘aws.cognito.signin.user.admin`.
12009 12010 12011 12012 12013 12014 12015 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12009 class UpdateUserAttributesRequest < Struct.new( :user_attributes, :access_token, :client_metadata) SENSITIVE = [:access_token] include Aws::Structure end |
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers.
When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a ‘clientMetadata` attribute that provides the data that you assigned to the ClientMetadata parameter in your request. In your function code, you can process the `clientMetadata` value to enhance your workflow for your specific needs.
To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see [ Connecting API actions to Lambda triggers] in the *Amazon Cognito Developer Guide*.
<note markdown=“1”> When you use the ‘ClientMetadata` parameter, note that Amazon Cognito won’t do the following:
* Store the `ClientMetadata` value. This data is available only to
Lambda triggers that are assigned to a user pool to support custom
workflows. If your user pool configuration doesn't include
triggers, the `ClientMetadata` parameter serves no purpose.
-
Validate the ‘ClientMetadata` value.
-
Encrypt the ‘ClientMetadata` value. Don’t send sensitive information in this parameter.
</note>
12009 12010 12011 12012 12013 12014 12015 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12009 class UpdateUserAttributesRequest < Struct.new( :user_attributes, :access_token, :client_metadata) SENSITIVE = [:access_token] include Aws::Structure end |
#user_attributes ⇒ Array<Types::AttributeType>
An array of name-value pairs representing user attributes.
For custom attributes, you must add a ‘custom:` prefix to the attribute name.
If you have set an attribute to require verification before Amazon Cognito updates its value, this request doesn’t immediately update the value of that attribute. After your user receives and responds to a verification message to verify the new value, Amazon Cognito updates the attribute value. Your user can sign in and receive messages with the original attribute value until they verify the new value.
12009 12010 12011 12012 12013 12014 12015 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12009 class UpdateUserAttributesRequest < Struct.new( :user_attributes, :access_token, :client_metadata) SENSITIVE = [:access_token] include Aws::Structure end |