Class: Aws::CognitoIdentityProvider::Types::UpdateUserAttributesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the response from the server for the request to update user attributes.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_delivery_details_listArray<Types::CodeDeliveryDetailsType>

When the attribute-update request includes an email address or phone number attribute, Amazon Cognito sends a message to users with a code that confirms ownership of the new value that they entered. The CodeDeliveryDetails object is information about the delivery destination for that link or code. This behavior happens in user pools configured to automatically verify changes to those attributes. For more information, see Verifying when users change their email or phone number.

Returns:



12707
12708
12709
12710
12711
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12707

class UpdateUserAttributesResponse < Struct.new(
  :code_delivery_details_list)
  SENSITIVE = []
  include Aws::Structure
end