Class: Aws::CognitoIdentityProvider::Types::UpdateUserPoolReplicaRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#region_nameString

The Amazon Web Services Region of the replica to update.

Returns:

  • (String)


13115
13116
13117
13118
13119
13120
13121
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13115

class UpdateUserPoolReplicaRequest < Struct.new(
  :user_pool_id,
  :region_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status to set for the replica. Valid values are ACTIVE and INACTIVE.

Returns:

  • (String)


13115
13116
13117
13118
13119
13120
13121
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13115

class UpdateUserPoolReplicaRequest < Struct.new(
  :user_pool_id,
  :region_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool that contains the replica to update.

Returns:

  • (String)


13115
13116
13117
13118
13119
13120
13121
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13115

class UpdateUserPoolReplicaRequest < Struct.new(
  :user_pool_id,
  :region_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end