Class: Aws::CognitoIdentityProvider::Types::UserContextDataType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UserContextDataType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Contextual data, such as the user's device fingerprint, IP address, or location, used for evaluating the risk of an unexpected event by Amazon Cognito threat protection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encoded_data ⇒ String
Encoded device-fingerprint details that your app collected with the Amazon Cognito context data collection library.
-
#ip_address ⇒ String
The source IP address of your user's device.
Instance Attribute Details
#encoded_data ⇒ String
Encoded device-fingerprint details that your app collected with the Amazon Cognito context data collection library. For more information, see Adding user device and session data to API requests.
13539 13540 13541 13542 13543 13544 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13539 class UserContextDataType < Struct.new( :ip_address, :encoded_data) SENSITIVE = [] include Aws::Structure end |
#ip_address ⇒ String
The source IP address of your user's device.
13539 13540 13541 13542 13543 13544 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13539 class UserContextDataType < Struct.new( :ip_address, :encoded_data) SENSITIVE = [] include Aws::Structure end |