Class: Aws::CognitoIdentityProvider::Types::UserPoolAddOnsType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Contains settings for activation of threat protection, including the operating mode and additional authentication types. To log user security information but take no action, set to AUDIT. To configure automatic security responses to potentially unwanted traffic to your user pool, set to ENFORCED.

For more information, see Adding advanced security to a user pool. To activate this setting, your user pool must be on the Plus tier.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#advanced_security_additional_flowsTypes::AdvancedSecurityAdditionalFlowsType

Threat protection configuration options for additional authentication types in your user pool, including custom authentication.



13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13662

class UserPoolAddOnsType < Struct.new(
  :advanced_security_mode,
  :advanced_security_additional_flows)
  SENSITIVE = []
  include Aws::Structure
end

#advanced_security_modeString

The operating mode of threat protection for standard authentication types in your user pool, including username-password and secure remote password (SRP) authentication.

Returns:

  • (String)


13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13662

class UserPoolAddOnsType < Struct.new(
  :advanced_security_mode,
  :advanced_security_additional_flows)
  SENSITIVE = []
  include Aws::Structure
end