Class: Aws::CognitoIdentityProvider::Types::UserPoolClientType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UserPoolClientType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The configuration of a user pool client.
Constant Summary collapse
- SENSITIVE =
[:client_id, :client_secret]
Instance Attribute Summary collapse
-
#access_token_validity ⇒ Integer
The access token time limit.
-
#allowed_o_auth_flows ⇒ Array<String>
The OAuth grant types that you want your app client to generate.
-
#allowed_o_auth_flows_user_pool_client ⇒ Boolean
Set to
trueto use OAuth 2.0 authorization server features in your app client. -
#allowed_o_auth_scopes ⇒ Array<String>
The OAuth 2.0 scopes that you want your app client to support.
-
#analytics_configuration ⇒ Types::AnalyticsConfigurationType
The user pool analytics configuration for collecting metrics and sending them to your Amazon Pinpoint campaign.
-
#auth_session_validity ⇒ Integer
Amazon Cognito creates a session token for each API request in an authentication flow.
-
#callback_urls ⇒ Array<String>
A list of allowed redirect (callback) URLs for the IdPs.
-
#client_id ⇒ String
The ID of the app client.
-
#client_name ⇒ String
The name of the app client.
-
#client_secret ⇒ String
The app client secret.
-
#creation_date ⇒ Time
The date and time when the item was created.
-
#default_redirect_uri ⇒ String
The default redirect URI.
-
#enable_propagate_additional_user_context_data ⇒ Boolean
When
EnablePropagateAdditionalUserContextDatais true, Amazon Cognito accepts anIpAddressvalue that you send in theUserContextDataparameter. -
#enable_token_revocation ⇒ Boolean
Indicates whether token revocation is activated for the user pool client.
-
#explicit_auth_flows ⇒ Array<String>
The [authentication flows] that you want your user pool client to support.
-
#id_token_validity ⇒ Integer
The ID token time limit.
-
#last_modified_date ⇒ Time
The date and time when the item was modified.
-
#logout_urls ⇒ Array<String>
A list of allowed logout URLs for the IdPs.
-
#prevent_user_existence_errors ⇒ String
When
ENABLED, suppresses messages that might indicate a valid user exists when someone attempts sign-in. -
#read_attributes ⇒ Array<String>
The list of user attributes that you want your app client to have read access to.
-
#refresh_token_rotation ⇒ Types::RefreshTokenRotationType
The configuration of your app client for refresh token rotation.
-
#refresh_token_validity ⇒ Integer
The refresh token time limit.
-
#supported_identity_providers ⇒ Array<String>
A list of provider names for the identity providers (IdPs) that are supported on this client.
-
#token_validity_units ⇒ Types::TokenValidityUnitsType
The time units that, with
IdTokenValidity,AccessTokenValidity, andRefreshTokenValidity, set and display the duration of ID, access, and refresh tokens for an app client. -
#user_pool_id ⇒ String
The ID of the user pool associated with the app client.
-
#write_attributes ⇒ Array<String>
The list of user attributes that you want your app client to have write access to.
Instance Attribute Details
#access_token_validity ⇒ Integer
The access token time limit. After this limit expires, your user can’t use their access token. To specify the time unit for AccessTokenValidity as seconds, minutes, hours, or days, set a TokenValidityUnits value in your API request.
For example, when you set AccessTokenValidity to 10 and TokenValidityUnits to hours, your user can authorize access with their access token for 10 hours.
The default time unit for AccessTokenValidity in an API request is hours. *Valid range* is displayed below in seconds.
If you don’t specify otherwise in the configuration of your app client, your access tokens are valid for one hour.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#allowed_o_auth_flows ⇒ Array<String>
The OAuth grant types that you want your app client to generate. To create an app client that generates client credentials grants, you must add client_credentials as the only allowed OAuth flow.
code
: Use a code grant flow, which provides an authorization code as the
response. This code can be exchanged for access tokens with the
`/oauth2/token` endpoint.
implicit
: Issue the access token (and, optionally, ID token, based on
scopes) directly to your user.
client_credentials
: Issue the access token from the /oauth2/token endpoint directly
to a non-person user using a combination of the client ID and
client secret.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#allowed_o_auth_flows_user_pool_client ⇒ Boolean
Set to true to use OAuth 2.0 authorization server features in your app client.
This parameter must have a value of true before you can configure the following features in your app client.
-
CallBackURLs: Callback URLs. -
LogoutURLs: Sign-out redirect URLs. -
AllowedOAuthScopes: OAuth 2.0 scopes. -
AllowedOAuthFlows: Support for authorization code, implicit, and client credentials OAuth 2.0 grants.
To use authorization server features, configure one of these features in the Amazon Cognito console or set AllowedOAuthFlowsUserPoolClient to true in a CreateUserPoolClient or UpdateUserPoolClient API request. If you don’t set a value for AllowedOAuthFlowsUserPoolClient in a request with the CLI or SDKs, it defaults to false. When false, only SDK-based API sign-in is permitted.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#allowed_o_auth_scopes ⇒ Array<String>
The OAuth 2.0 scopes that you want your app client to support. Can include standard OAuth scopes like phone, email, openid, and profile. Can also include the aws.cognito.signin.user.admin scope that authorizes user profile self-service operations and custom scopes from resource servers.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#analytics_configuration ⇒ Types::AnalyticsConfigurationType
The user pool analytics configuration for collecting metrics and sending them to your Amazon Pinpoint campaign.
<note markdown=“1”> In Amazon Web Services Regions where Amazon Pinpoint isn’t available, user pools only support sending events to Amazon Pinpoint projects in Amazon Web Services Region us-east-1. In Regions where Amazon Pinpoint is available, user pools support sending events to Amazon Pinpoint projects within that same Region.
</note>
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#auth_session_validity ⇒ Integer
Amazon Cognito creates a session token for each API request in an authentication flow. AuthSessionValidity is the duration, in minutes, of that session token. Your user pool native user must respond to each authentication challenge before the session expires.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#callback_urls ⇒ Array<String>
A list of allowed redirect (callback) URLs for the IdPs.
A redirect URI must:
-
Be an absolute URI.
-
Be registered with the authorization server.
-
Not include a fragment component.
See [OAuth 2.0 - Redirection Endpoint].
Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.
App callback URLs such as myapp://example are also supported.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#client_id ⇒ String
The ID of the app client.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#client_name ⇒ String
The name of the app client.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#client_secret ⇒ String
The app client secret.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#creation_date ⇒ Time
The date and time when the item was created. Amazon Cognito returns this timestamp in UNIX epoch time format. Your SDK might render the output in a human-readable format like ISO 8601 or a Java Date object.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#default_redirect_uri ⇒ String
The default redirect URI. Must be in the CallbackURLs list.
A redirect URI must:
-
Be an absolute URI.
-
Be registered with the authorization server.
-
Not include a fragment component.
See [OAuth 2.0 - Redirection Endpoint].
Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.
App callback URLs such as myapp://example are also supported.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#enable_propagate_additional_user_context_data ⇒ Boolean
When EnablePropagateAdditionalUserContextData is true, Amazon Cognito accepts an IpAddress value that you send in the UserContextData parameter. The UserContextData parameter sends information to Amazon Cognito threat protection for risk analysis. You can send UserContextData when you sign in Amazon Cognito native users with the InitiateAuth and RespondToAuthChallenge API operations.
When EnablePropagateAdditionalUserContextData is false, you can’t send your user’s source IP address to Amazon Cognito threat protection with unauthenticated API operations. EnablePropagateAdditionalUserContextData doesn’t affect whether you can send a source IP address in a ContextData parameter with the authenticated API operations AdminInitiateAuth and AdminRespondToAuthChallenge.
You can only activate EnablePropagateAdditionalUserContextData in an app client that has a client secret. For more information about propagation of user context data, see [Adding user device and session data to API requests].
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#enable_token_revocation ⇒ Boolean
Indicates whether token revocation is activated for the user pool client. When you create a new user pool client, token revocation is activated by default.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#explicit_auth_flows ⇒ Array<String>
The [authentication flows] that you want your user pool client to support. For each app client in your user pool, you can sign in your users with any combination of one or more flows, including with a user name and Secure Remote Password (SRP), a user name and password, or a custom authentication process that you define with Lambda functions.
<note markdown=“1”> If you don’t specify a value for ExplicitAuthFlows, your app client supports ALLOW_REFRESH_TOKEN_AUTH, ALLOW_USER_SRP_AUTH, and ALLOW_CUSTOM_AUTH.
</note>
The values for authentication flow options include the following.
-
ALLOW_USER_AUTH: Enable selection-based sign-in withUSER_AUTH. This setting covers username-password, secure remote password (SRP), passwordless, and passkey authentication. This authentiation flow can do username-password and SRP authentication without otherExplicitAuthFlowspermitting them. For example users can complete an SRP challenge throughUSER_AUTHwithout the flowUSER_SRP_AUTHbeing active for the app client. This flow doesn’t includeCUSTOM_AUTH.To activate this setting, your user pool must be in the [ Essentials tier] or higher.
-
ALLOW_ADMIN_USER_PASSWORD_AUTH: Enable admin based user password authentication flowADMIN_USER_PASSWORD_AUTH. This setting replaces theADMIN_NO_SRP_AUTHsetting. With this authentication flow, your app passes a user name and password to Amazon Cognito in the request, instead of using the Secure Remote Password (SRP) protocol to securely transmit the password. -
ALLOW_CUSTOM_AUTH: Enable Lambda trigger based authentication. -
ALLOW_USER_PASSWORD_AUTH: Enable user password-based authentication. In this flow, Amazon Cognito receives the password in the request instead of using the SRP protocol to verify passwords. -
ALLOW_USER_SRP_AUTH: Enable SRP-based authentication. -
ALLOW_REFRESH_TOKEN_AUTH: Enable authflow to refresh tokens.
In some environments, you will see the values ADMIN_NO_SRP_AUTH, CUSTOM_AUTH_FLOW_ONLY, or USER_PASSWORD_AUTH. You can’t assign these legacy ExplicitAuthFlows values to user pool clients at the same time as values that begin with ALLOW_, like ALLOW_USER_SRP_AUTH.
[1]: docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-authentication-flow-methods.html [2]: docs.aws.amazon.com/cognito/latest/developerguide/feature-plans-features-essentials.html
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#id_token_validity ⇒ Integer
The ID token time limit. After this limit expires, your user can’t use their ID token. To specify the time unit for IdTokenValidity as seconds, minutes, hours, or days, set a TokenValidityUnits value in your API request.
For example, when you set IdTokenValidity as 10 and TokenValidityUnits as hours, your user can authenticate their session with their ID token for 10 hours.
The default time unit for IdTokenValidity in an API request is hours. *Valid range* is displayed below in seconds.
If you don’t specify otherwise in the configuration of your app client, your ID tokens are valid for one hour.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#last_modified_date ⇒ Time
The date and time when the item was modified. Amazon Cognito returns this timestamp in UNIX epoch time format. Your SDK might render the output in a human-readable format like ISO 8601 or a Java Date object.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#logout_urls ⇒ Array<String>
A list of allowed logout URLs for the IdPs.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#prevent_user_existence_errors ⇒ String
When ENABLED, suppresses messages that might indicate a valid user exists when someone attempts sign-in. This parameters sets your preference for the errors and responses that you want Amazon Cognito APIs to return during authentication, account confirmation, and password recovery when the user doesn’t exist in the user pool. When set to ENABLED and the user doesn’t exist, authentication returns an error indicating either the username or password was incorrect. Account confirmation and password recovery return a response indicating a code was sent to a simulated destination. When set to LEGACY, those APIs return a UserNotFoundException exception if the user doesn’t exist in the user pool.
Defaults to LEGACY.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#read_attributes ⇒ Array<String>
The list of user attributes that you want your app client to have read access to. After your user authenticates in your app, their access token authorizes them to read their own attribute value for any attribute in this list.
When you don’t specify the ReadAttributes for your app client, your app can read the values of email_verified, phone_number_verified, and the standard attributes of your user pool. When your user pool app client has read access to these default attributes, ReadAttributes doesn’t return any information. Amazon Cognito only populates ReadAttributes in the API response if you have specified your own custom set of read attributes.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#refresh_token_rotation ⇒ Types::RefreshTokenRotationType
The configuration of your app client for refresh token rotation. When enabled, your app client issues new ID, access, and refresh tokens when users renew their sessions with refresh tokens. When disabled, token refresh issues only ID and access tokens.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#refresh_token_validity ⇒ Integer
The refresh token time limit. After this limit expires, your user can’t use their refresh token. To specify the time unit for RefreshTokenValidity as seconds, minutes, hours, or days, set a TokenValidityUnits value in your API request.
For example, when you set RefreshTokenValidity as 10 and TokenValidityUnits as days, your user can refresh their session and retrieve new access and ID tokens for 10 days.
The default time unit for RefreshTokenValidity in an API request is days. You can’t set RefreshTokenValidity to 0. If you do, Amazon Cognito overrides the value with the default value of 30 days. *Valid range* is displayed below in seconds.
If you don’t specify otherwise in the configuration of your app client, your refresh tokens are valid for 30 days.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#supported_identity_providers ⇒ Array<String>
A list of provider names for the identity providers (IdPs) that are supported on this client. The following are supported: COGNITO, Facebook, Google, SignInWithApple, and LoginWithAmazon. You can also specify the names that you configured for the SAML and OIDC IdPs in your user pool, for example MySAMLIdP or MyOIDCIdP.
This parameter sets the IdPs that [managed login] will display on the login page for your app client. The removal of COGNITO from this list doesn’t prevent authentication operations for local users with the user pools API in an Amazon Web Services SDK. The only way to prevent SDK-based authentication is to block access with a [WAF rule].
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-managed-login.html [2]: docs.aws.amazon.com/cognito/latest/developerguide/user-pool-waf.html
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#token_validity_units ⇒ Types::TokenValidityUnitsType
The time units that, with IdTokenValidity, AccessTokenValidity, and RefreshTokenValidity, set and display the duration of ID, access, and refresh tokens for an app client. You can assign a separate token validity unit to each type of token.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool associated with the app client.
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#write_attributes ⇒ Array<String>
The list of user attributes that you want your app client to have write access to. After your user authenticates in your app, their access token authorizes them to set or modify their own attribute value for any attribute in this list.
When you don’t specify the WriteAttributes for your app client, your app can write the values of the Standard attributes of your user pool. When your user pool has write access to these default attributes, WriteAttributes doesn’t return any information. Amazon Cognito only populates WriteAttributes in the API response if you have specified your own custom set of write attributes.
If your app client allows users to sign in through an IdP, this array must include all attributes that you have mapped to IdP attributes. Amazon Cognito updates mapped attributes when users sign in to your application through an IdP. If your app client does not have write access to a mapped attribute, Amazon Cognito throws an error when it tries to update the attribute. For more information, see [Specifying IdP Attribute Mappings for Your user pool].
13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 13319 13320 13321 13322 13323 13324 13325 13326 13327 13328 13329 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13300 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data, :auth_session_validity, :refresh_token_rotation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |