Class: Aws::CognitoIdentityProvider::Types::VerificationMessageTemplateType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::VerificationMessageTemplateType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The template for the verification message that your user pool delivers to users who set an email address or phone number attribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_email_option ⇒ String
The configuration of verification emails to contain a clickable link or a verification code.
-
#email_message ⇒ String
The template for email messages that Amazon Cognito sends to your users.
-
#email_message_by_link ⇒ String
The email message template for sending a confirmation link to the user.
-
#email_subject ⇒ String
The subject line for the email message template.
-
#email_subject_by_link ⇒ String
The subject line for the email message template for sending a confirmation link to the user.
-
#sms_message ⇒ String
The template for SMS messages that Amazon Cognito sends to your users.
Instance Attribute Details
#default_email_option ⇒ String
The configuration of verification emails to contain a clickable link or a verification code.
For link, your template body must contain link text in the format
{##Click here##}. "Click here" in the example is a customizable
string. For code, your template body must contain a code placeholder
in the format {####}.
14893 14894 14895 14896 14897 14898 14899 14900 14901 14902 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14893 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_message ⇒ String
The template for email messages that Amazon Cognito sends to your
users. You can set an EmailMessage template only if the value of
EmailSendingAccount is DEVELOPER. When your
EmailSendingAccount is DEVELOPER, your user pool sends email
messages with your own Amazon SES configuration.
14893 14894 14895 14896 14897 14898 14899 14900 14901 14902 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14893 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_message_by_link ⇒ String
The email message template for sending a confirmation link to the
user. You can set an EmailMessageByLink template only if the value
of EmailSendingAccount is DEVELOPER. When your
EmailSendingAccount is DEVELOPER, your user pool sends email
messages with your own Amazon SES configuration.
14893 14894 14895 14896 14897 14898 14899 14900 14901 14902 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14893 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_subject ⇒ String
The subject line for the email message template. You can set an
EmailSubject template only if the value of
EmailSendingAccount is DEVELOPER. When your
EmailSendingAccount is DEVELOPER, your user pool sends email
messages with your own Amazon SES configuration.
14893 14894 14895 14896 14897 14898 14899 14900 14901 14902 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14893 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_subject_by_link ⇒ String
The subject line for the email message template for sending a
confirmation link to the user. You can set an EmailSubjectByLink
template only if the value of EmailSendingAccount is
DEVELOPER. When your EmailSendingAccount is DEVELOPER, your
user pool sends email messages with your own Amazon SES
configuration.
14893 14894 14895 14896 14897 14898 14899 14900 14901 14902 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14893 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#sms_message ⇒ String
The template for SMS messages that Amazon Cognito sends to your users.
14893 14894 14895 14896 14897 14898 14899 14900 14901 14902 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14893 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |