Class: Aws::CognitoIdentityProvider::Types::VerifySoftwareTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::VerifySoftwareTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass VerifySoftwareTokenRequest data as a hash:
{
access_token: "TokenModelType",
session: "SessionType",
user_code: "SoftwareTokenMFAUserCodeType", # required
friendly_device_name: "StringType",
}
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose software token you want to verify.
-
#friendly_device_name ⇒ String
The friendly device name.
-
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service.
-
#user_code ⇒ String
The one- time password computed using the secret code returned by [AssociateSoftwareToken].
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose software token you want to verify.
11402 11403 11404 11405 11406 11407 11408 11409 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11402 class VerifySoftwareTokenRequest < Struct.new( :access_token, :session, :user_code, :friendly_device_name) SENSITIVE = [:access_token] include Aws::Structure end |
#friendly_device_name ⇒ String
The friendly device name.
11402 11403 11404 11405 11406 11407 11408 11409 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11402 class VerifySoftwareTokenRequest < Struct.new( :access_token, :session, :user_code, :friendly_device_name) SENSITIVE = [:access_token] include Aws::Structure end |
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service.
11402 11403 11404 11405 11406 11407 11408 11409 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11402 class VerifySoftwareTokenRequest < Struct.new( :access_token, :session, :user_code, :friendly_device_name) SENSITIVE = [:access_token] include Aws::Structure end |
#user_code ⇒ String
The one- time password computed using the secret code returned by [AssociateSoftwareToken].
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AssociateSoftwareToken.html
11402 11403 11404 11405 11406 11407 11408 11409 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11402 class VerifySoftwareTokenRequest < Struct.new( :access_token, :session, :user_code, :friendly_device_name) SENSITIVE = [:access_token] include Aws::Structure end |