Class: Aws::CognitoIdentityProvider::Types::VerifyUserAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass VerifyUserAttributeRequest data as a hash:

{
  access_token: "TokenModelType", # required
  attribute_name: "AttributeNameType", # required
  code: "ConfirmationCodeType", # required
}

Represents the request to verify user attributes.

Constant Summary collapse

SENSITIVE =
[:access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A valid access token that Amazon Cognito issued to the user whose user attributes you want to verify.

Returns:

  • (String)


11637
11638
11639
11640
11641
11642
11643
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11637

class VerifyUserAttributeRequest < Struct.new(
  :access_token,
  :attribute_name,
  :code)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#attribute_nameString

The attribute name in the request to verify user attributes.

Returns:

  • (String)


11637
11638
11639
11640
11641
11642
11643
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11637

class VerifyUserAttributeRequest < Struct.new(
  :access_token,
  :attribute_name,
  :code)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#codeString

The verification code in the request to verify user attributes.

Returns:

  • (String)


11637
11638
11639
11640
11641
11642
11643
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11637

class VerifyUserAttributeRequest < Struct.new(
  :access_token,
  :attribute_name,
  :code)
  SENSITIVE = [:access_token]
  include Aws::Structure
end