Class: Aws::CognitoIdentityProvider::Types::AdminDeleteUserAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the request to delete user attributes as an administrator.

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#user_attribute_namesArray<String>

An array of strings representing the user attribute names you want to delete.

For custom attributes, you must prepend the ‘custom:` prefix to the attribute name.

Returns:

  • (Array<String>)


461
462
463
464
465
466
467
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 461

class AdminDeleteUserAttributesRequest < Struct.new(
  :user_pool_id,
  :username,
  :user_attribute_names)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool where you want to delete user attributes.

Returns:

  • (String)


461
462
463
464
465
466
467
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 461

class AdminDeleteUserAttributesRequest < Struct.new(
  :user_pool_id,
  :username,
  :user_attribute_names)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The user name of the user from which you would like to delete attributes.

Returns:

  • (String)


461
462
463
464
465
466
467
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 461

class AdminDeleteUserAttributesRequest < Struct.new(
  :user_pool_id,
  :username,
  :user_attribute_names)
  SENSITIVE = [:username]
  include Aws::Structure
end