Class: Aws::CognitoIdentityProvider::Types::AdminDeleteUserAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass AdminDeleteUserAttributesRequest data as a hash:

{
  user_pool_id: "UserPoolIdType", # required
  username: "UsernameType", # required
  user_attribute_names: ["AttributeNameType"], # required
}

Represents the request to delete user attributes as an administrator.

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#user_attribute_namesArray<String>

An array of strings representing the user attribute names you want to delete.

For custom attributes, you must prepend the `custom:` prefix to the attribute name.

Returns:

  • (Array<String>)


631
632
633
634
635
636
637
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 631

class AdminDeleteUserAttributesRequest < Struct.new(
  :user_pool_id,
  :username,
  :user_attribute_names)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool where you want to delete user attributes.

Returns:

  • (String)


631
632
633
634
635
636
637
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 631

class AdminDeleteUserAttributesRequest < Struct.new(
  :user_pool_id,
  :username,
  :user_attribute_names)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The user name of the user from which you would like to delete attributes.

Returns:

  • (String)


631
632
633
634
635
636
637
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 631

class AdminDeleteUserAttributesRequest < Struct.new(
  :user_pool_id,
  :username,
  :user_attribute_names)
  SENSITIVE = [:username]
  include Aws::Structure
end