Class: Aws::CognitoIdentityProvider::Types::AdminDeleteUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminDeleteUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to delete a user as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to delete the user.
-
#username ⇒ String
The user name of the user you want to delete.
Instance Attribute Details
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to delete the user.
489 490 491 492 493 494 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 489 class AdminDeleteUserRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The user name of the user you want to delete.
489 490 491 492 493 494 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 489 class AdminDeleteUserRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |