Class: Aws::CognitoIdentityProvider::Types::AdminDisableUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the request to disable the user as an administrator.

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#user_pool_idString

The user pool ID for the user pool where you want to disable the user.

Returns:

  • (String)


543
544
545
546
547
548
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 543

class AdminDisableUserRequest < Struct.new(
  :user_pool_id,
  :username)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The user name of the user you want to disable.

Returns:

  • (String)


543
544
545
546
547
548
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 543

class AdminDisableUserRequest < Struct.new(
  :user_pool_id,
  :username)
  SENSITIVE = [:username]
  include Aws::Structure
end