Class: Aws::CognitoIdentityProvider::Types::AdminEnableUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Represents the request that enables the user as an administrator.

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#user_pool_idString

The user pool ID for the user pool where you want to enable the user.

Returns:

  • (String)


556
557
558
559
560
561
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 556

class AdminEnableUserRequest < Struct.new(
  :user_pool_id,
  :username)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The user name of the user you want to enable.

Returns:

  • (String)


556
557
558
559
560
561
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 556

class AdminEnableUserRequest < Struct.new(
  :user_pool_id,
  :username)
  SENSITIVE = [:username]
  include Aws::Structure
end