Class: Aws::CognitoIdentityProvider::Types::AdminEnableUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminEnableUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass AdminEnableUserRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
username: "UsernameType", # required
}
Represents the request that enables the user as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to enable the user.
-
#username ⇒ String
The user name of the user you want to enable.
Instance Attribute Details
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to enable the user.
764 765 766 767 768 769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 764 class AdminEnableUserRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The user name of the user you want to enable.
764 765 766 767 768 769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 764 class AdminEnableUserRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |