Class: Aws::CognitoIdentityProvider::Types::AdminForgetDeviceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Sends the forgot device request, as an administrator.

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#device_keyString

The key ID of the device that you want to delete.

Returns:

  • (String)


761
762
763
764
765
766
767
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 761

class AdminForgetDeviceRequest < Struct.new(
  :user_pool_id,
  :username,
  :device_key)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool where the device owner is a user.

Returns:

  • (String)


761
762
763
764
765
766
767
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 761

class AdminForgetDeviceRequest < Struct.new(
  :user_pool_id,
  :username,
  :device_key)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The name of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.

Returns:

  • (String)


761
762
763
764
765
766
767
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 761

class AdminForgetDeviceRequest < Struct.new(
  :user_pool_id,
  :username,
  :device_key)
  SENSITIVE = [:username]
  include Aws::Structure
end