Class: Aws::CognitoIdentityProvider::Types::AdminForgetDeviceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminForgetDeviceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Sends the forgot device request, as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#device_key ⇒ String
The device key.
-
#user_pool_id ⇒ String
The user pool ID.
-
#username ⇒ String
The username of the user that you want to query or modify.
Instance Attribute Details
#device_key ⇒ String
The device key.
736 737 738 739 740 741 742 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 736 class AdminForgetDeviceRequest < Struct.new( :user_pool_id, :username, :device_key) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
736 737 738 739 740 741 742 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 736 class AdminForgetDeviceRequest < Struct.new( :user_pool_id, :username, :device_key) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.
736 737 738 739 740 741 742 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 736 class AdminForgetDeviceRequest < Struct.new( :user_pool_id, :username, :device_key) SENSITIVE = [:username] include Aws::Structure end |