Class: Aws::CognitoIdentityProvider::Types::AdminGetUserAuthFactorsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminGetUserAuthFactorsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#user_pool_id ⇒ String
The ID of the user pool where you want to get information about the user's authentication factors.
-
#username ⇒ String
The name of the user that you want to query or modify.
Instance Attribute Details
#user_pool_id ⇒ String
The ID of the user pool where you want to get information about the user's authentication factors.
827 828 829 830 831 832 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 827 class AdminGetUserAuthFactorsRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The name of the user that you want to query or modify. The value of
this parameter is typically your user's username, but it can be any
of their alias attributes. If username isn't an alias attribute
in your user pool, this value must be the sub of a local user or
the username of a user from a third-party IdP.
827 828 829 830 831 832 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 827 class AdminGetUserAuthFactorsRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |