Class: Aws::CognitoIdentityProvider::Types::AdminGetUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminGetUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to get the specified user as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to get information about the user.
-
#username ⇒ String
The user name of the user you want to retrieve.
Instance Attribute Details
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to get information about the user.
646 647 648 649 650 651 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 646 class AdminGetUserRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The user name of the user you want to retrieve.
646 647 648 649 650 651 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 646 class AdminGetUserRequest < Struct.new( :user_pool_id, :username) SENSITIVE = [:username] include Aws::Structure end |