Class: Aws::CognitoIdentityProvider::Types::AdminGetUserResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminGetUserResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the response from the server from the request to get the specified user as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Indicates that the status is ‘enabled`.
-
#mfa_options ⇒ Array<Types::MFAOptionType>
*This response parameter is no longer supported.* It provides information only about SMS MFA configurations.
-
#preferred_mfa_setting ⇒ String
The user’s preferred MFA setting.
-
#user_attributes ⇒ Array<Types::AttributeType>
An array of name-value pairs representing user attributes.
-
#user_create_date ⇒ Time
The date the user was created.
-
#user_last_modified_date ⇒ Time
The date and time, in [ISO 8601] format, when the item was modified.
-
#user_mfa_setting_list ⇒ Array<String>
The MFA options that are activated for the user.
-
#user_status ⇒ String
The user status.
-
#username ⇒ String
The username of the user that you requested.
Instance Attribute Details
#enabled ⇒ Boolean
Indicates that the status is ‘enabled`.
731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 731 class AdminGetUserResponse < Struct.new( :username, :user_attributes, :user_create_date, :user_last_modified_date, :enabled, :user_status, :mfa_options, :preferred_mfa_setting, :user_mfa_setting_list) SENSITIVE = [:username] include Aws::Structure end |
#mfa_options ⇒ Array<Types::MFAOptionType>
*This response parameter is no longer supported.* It provides information only about SMS MFA configurations. It doesn’t provide information about time-based one-time password (TOTP) software token MFA configurations. To look up information about either type of MFA configuration, use UserMFASettingList instead.
731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 731 class AdminGetUserResponse < Struct.new( :username, :user_attributes, :user_create_date, :user_last_modified_date, :enabled, :user_status, :mfa_options, :preferred_mfa_setting, :user_mfa_setting_list) SENSITIVE = [:username] include Aws::Structure end |
#preferred_mfa_setting ⇒ String
The user’s preferred MFA setting.
731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 731 class AdminGetUserResponse < Struct.new( :username, :user_attributes, :user_create_date, :user_last_modified_date, :enabled, :user_status, :mfa_options, :preferred_mfa_setting, :user_mfa_setting_list) SENSITIVE = [:username] include Aws::Structure end |
#user_attributes ⇒ Array<Types::AttributeType>
An array of name-value pairs representing user attributes.
731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 731 class AdminGetUserResponse < Struct.new( :username, :user_attributes, :user_create_date, :user_last_modified_date, :enabled, :user_status, :mfa_options, :preferred_mfa_setting, :user_mfa_setting_list) SENSITIVE = [:username] include Aws::Structure end |
#user_create_date ⇒ Time
The date the user was created.
731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 731 class AdminGetUserResponse < Struct.new( :username, :user_attributes, :user_create_date, :user_last_modified_date, :enabled, :user_status, :mfa_options, :preferred_mfa_setting, :user_mfa_setting_list) SENSITIVE = [:username] include Aws::Structure end |
#user_last_modified_date ⇒ Time
The date and time, in [ISO 8601] format, when the item was modified.
731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 731 class AdminGetUserResponse < Struct.new( :username, :user_attributes, :user_create_date, :user_last_modified_date, :enabled, :user_status, :mfa_options, :preferred_mfa_setting, :user_mfa_setting_list) SENSITIVE = [:username] include Aws::Structure end |
#user_mfa_setting_list ⇒ Array<String>
The MFA options that are activated for the user. The possible values in this list are ‘SMS_MFA` and `SOFTWARE_TOKEN_MFA`.
731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 731 class AdminGetUserResponse < Struct.new( :username, :user_attributes, :user_create_date, :user_last_modified_date, :enabled, :user_status, :mfa_options, :preferred_mfa_setting, :user_mfa_setting_list) SENSITIVE = [:username] include Aws::Structure end |
#user_status ⇒ String
The user status. Can be one of the following:
-
UNCONFIRMED - User has been created but not confirmed.
-
CONFIRMED - User has been confirmed.
-
UNKNOWN - User status isn’t known.
-
RESET_REQUIRED - User is confirmed, but the user must request a code and reset their password before they can sign in.
-
FORCE_CHANGE_PASSWORD - The user is confirmed and the user can sign in using a temporary password, but on first sign-in, the user must change their password to a new value before doing anything else.
731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 731 class AdminGetUserResponse < Struct.new( :username, :user_attributes, :user_create_date, :user_last_modified_date, :enabled, :user_status, :mfa_options, :preferred_mfa_setting, :user_mfa_setting_list) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The username of the user that you requested.
731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 731 class AdminGetUserResponse < Struct.new( :username, :user_attributes, :user_create_date, :user_last_modified_date, :enabled, :user_status, :mfa_options, :preferred_mfa_setting, :user_mfa_setting_list) SENSITIVE = [:username] include Aws::Structure end |