Class: Aws::CognitoIdentityProvider::Types::AdminLinkProviderForUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass AdminLinkProviderForUserRequest data as a hash:

{
  user_pool_id: "StringType", # required
  destination_user: { # required
    provider_name: "ProviderNameType",
    provider_attribute_name: "StringType",
    provider_attribute_value: "StringType",
  },
  source_user: { # required
    provider_name: "ProviderNameType",
    provider_attribute_name: "StringType",
    provider_attribute_value: "StringType",
  },
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_userTypes::ProviderUserIdentifierType

The existing user in the user pool to be linked to the external identity provider user account. Can be a native (Username + Password) Amazon Cognito User Pools user or a federated user (for example, a SAML or Facebook user). If the user doesn't exist, an exception is thrown. This is the user that is returned when the new user (with the linked identity provider attribute) signs in.

For a native username + password user, the `ProviderAttributeValue` for the `DestinationUser` should be the username in the user pool. For a federated user, it should be the provider-specific `user_id`.

The `ProviderAttributeName` of the `DestinationUser` is ignored.

The `ProviderName` should be set to `Cognito` for users in Cognito user pools.

All attributes in the DestinationUser profile must be mutable. If you have assigned the user any immutable custom attributes, the operation won't succeed.



1320
1321
1322
1323
1324
1325
1326
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1320

class AdminLinkProviderForUserRequest < Struct.new(
  :user_pool_id,
  :destination_user,
  :source_user)
  SENSITIVE = []
  include Aws::Structure
end

#source_userTypes::ProviderUserIdentifierType

An external identity provider account for a user who doesn't exist yet in the user pool. This user must be a federated user (for example, a SAML or Facebook user), not another native user.

If the `SourceUser` is using a federated social identity provider, such as Facebook, Google, or Login with Amazon, you must set the `ProviderAttributeName` to `Cognito_Subject`. For social identity providers, the `ProviderName` will be `Facebook`, `Google`, or `LoginWithAmazon`, and Amazon Cognito will automatically parse the Facebook, Google, and Login with Amazon tokens for `id`, `sub`, and `user_id`, respectively. The `ProviderAttributeValue` for the user must be the same value as the `id`, `sub`, or `user_id` value found in the social identity provider token.

For SAML, the `ProviderAttributeName` can be any value that matches a claim in the SAML assertion. If you want to link SAML users based on the subject of the SAML assertion, you should map the subject to a claim through the SAML identity provider and submit that claim name as the `ProviderAttributeName`. If you set `ProviderAttributeName` to `Cognito_Subject`, Amazon Cognito will automatically parse the default unique identifier found in the subject from the SAML token.



1320
1321
1322
1323
1324
1325
1326
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1320

class AdminLinkProviderForUserRequest < Struct.new(
  :user_pool_id,
  :destination_user,
  :source_user)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool.

Returns:

  • (String)


1320
1321
1322
1323
1324
1325
1326
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1320

class AdminLinkProviderForUserRequest < Struct.new(
  :user_pool_id,
  :destination_user,
  :source_user)
  SENSITIVE = []
  include Aws::Structure
end