Class: Aws::CognitoIdentityProvider::Types::AdminRemoveUserFromGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminRemoveUserFromGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#group_name ⇒ String
The name of the group that you want to remove the user from, for example
MyTestGroup. -
#user_pool_id ⇒ String
The ID of the user pool that contains the group and the user that you want to remove.
-
#username ⇒ String
The name of the user that you want to query or modify.
Instance Attribute Details
#group_name ⇒ String
The name of the group that you want to remove the user from, for
example MyTestGroup.
1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1659 class AdminRemoveUserFromGroupRequest < Struct.new( :user_pool_id, :username, :group_name) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool that contains the group and the user that you want to remove.
1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1659 class AdminRemoveUserFromGroupRequest < Struct.new( :user_pool_id, :username, :group_name) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The name of the user that you want to query or modify. The value of
this parameter is typically your user's username, but it can be any
of their alias attributes. If username isn't an alias attribute
in your user pool, this value must be the sub of a local user or
the username of a user from a third-party IdP.
1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1659 class AdminRemoveUserFromGroupRequest < Struct.new( :user_pool_id, :username, :group_name) SENSITIVE = [:username] include Aws::Structure end |