Class: Aws::CognitoIdentityProvider::Types::AdminRemoveUserFromGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#group_nameString

The name of the group that you want to remove the user from, for example MyTestGroup.

Returns:

  • (String)


1637
1638
1639
1640
1641
1642
1643
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1637

class AdminRemoveUserFromGroupRequest < Struct.new(
  :user_pool_id,
  :username,
  :group_name)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool that contains the group and the user that you want to remove.

Returns:

  • (String)


1637
1638
1639
1640
1641
1642
1643
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1637

class AdminRemoveUserFromGroupRequest < Struct.new(
  :user_pool_id,
  :username,
  :group_name)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If username isn't an alias attribute in your user pool, this value must be the sub of a local user or the username of a user from a third-party IdP.

Returns:

  • (String)


1637
1638
1639
1640
1641
1642
1643
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1637

class AdminRemoveUserFromGroupRequest < Struct.new(
  :user_pool_id,
  :username,
  :group_name)
  SENSITIVE = [:username]
  include Aws::Structure
end