Class: Aws::CognitoIdentityProvider::Types::AdminRemoveUserFromGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminRemoveUserFromGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#group_name ⇒ String
The group name.
-
#user_pool_id ⇒ String
The user pool ID for the user pool.
-
#username ⇒ String
The username of the user that you want to query or modify.
Instance Attribute Details
#group_name ⇒ String
The group name.
1498 1499 1500 1501 1502 1503 1504 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1498 class AdminRemoveUserFromGroupRequest < Struct.new( :user_pool_id, :username, :group_name) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool.
1498 1499 1500 1501 1502 1503 1504 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1498 class AdminRemoveUserFromGroupRequest < Struct.new( :user_pool_id, :username, :group_name) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.
1498 1499 1500 1501 1502 1503 1504 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1498 class AdminRemoveUserFromGroupRequest < Struct.new( :user_pool_id, :username, :group_name) SENSITIVE = [:username] include Aws::Structure end |