Class: Aws::CognitoIdentityProvider::Types::AdminResetUserPasswordRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminResetUserPasswordRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to reset a user’s password as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to reset the user’s password.
-
#username ⇒ String
The user name of the user whose password you want to reset.
Instance Attribute Details
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.
You create custom workflows by assigning Lambda functions to user pool triggers. When you use the AdminResetUserPassword API action, Amazon Cognito invokes the function that is assigned to the *custom message* trigger. When Amazon Cognito invokes this function, it passes a JSON payload, which the function receives as input. This payload contains a ‘clientMetadata` attribute, which provides the data that you assigned to the ClientMetadata parameter in your AdminResetUserPassword request. In your function code in Lambda, you can process the `clientMetadata` value to enhance your workflow for your specific needs.
For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.
<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won’t do the following:
* Store the ClientMetadata value. This data is available only to
Lambda triggers that are assigned to a user pool to support custom
workflows. If your user pool configuration doesn't include
triggers, the ClientMetadata parameter serves no purpose.
-
Validate the ClientMetadata value.
-
Encrypt the ClientMetadata value. Don’t use Amazon Cognito to provide sensitive information.
</note>
1319 1320 1321 1322 1323 1324 1325 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1319 class AdminResetUserPasswordRequest < Struct.new( :user_pool_id, :username, :client_metadata) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to reset the user’s password.
1319 1320 1321 1322 1323 1324 1325 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1319 class AdminResetUserPasswordRequest < Struct.new( :user_pool_id, :username, :client_metadata) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The user name of the user whose password you want to reset.
1319 1320 1321 1322 1323 1324 1325 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1319 class AdminResetUserPasswordRequest < Struct.new( :user_pool_id, :username, :client_metadata) SENSITIVE = [:username] include Aws::Structure end |