Class: Aws::CognitoIdentityProvider::Types::AdminRespondToAuthChallengeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass AdminRespondToAuthChallengeRequest data as a hash:

{
  user_pool_id: "UserPoolIdType", # required
  client_id: "ClientIdType", # required
  challenge_name: "SMS_MFA", # required, accepts SMS_MFA, SOFTWARE_TOKEN_MFA, SELECT_MFA_TYPE, MFA_SETUP, PASSWORD_VERIFIER, CUSTOM_CHALLENGE, DEVICE_SRP_AUTH, DEVICE_PASSWORD_VERIFIER, ADMIN_NO_SRP_AUTH, NEW_PASSWORD_REQUIRED
  challenge_responses: {
    "StringType" => "StringType",
  },
  session: "SessionType",
  analytics_metadata: {
    analytics_endpoint_id: "StringType",
  },
  context_data: {
    ip_address: "StringType", # required
    server_name: "StringType", # required
    server_path: "StringType", # required
    http_headers: [ # required
      {
        header_name: "StringType",
        header_value: "StringType",
      },
    ],
    encoded_data: "StringType",
  },
  client_metadata: {
    "StringType" => "StringType",
  },
}

The request to respond to the authentication challenge, as an administrator.

Constant Summary collapse

SENSITIVE =
[:client_id]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_metadataTypes::AnalyticsMetadataType

The analytics metadata for collecting Amazon Pinpoint metrics for `AdminRespondToAuthChallenge` calls.



1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1807

class AdminRespondToAuthChallengeRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :challenge_name,
  :challenge_responses,
  :session,
  :analytics_metadata,
  :context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#challenge_nameString

Returns:

  • (String)


1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1807

class AdminRespondToAuthChallengeRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :challenge_name,
  :challenge_responses,
  :session,
  :analytics_metadata,
  :context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#challenge_responsesHash<String,String>

The challenge responses. These are inputs corresponding to the value of `ChallengeName`, for example:

  • `SMS_MFA`: `SMS_MFA_CODE`, `USERNAME`, `SECRET_HASH` (if app client is configured with client secret).

  • `PASSWORD_VERIFIER`: `PASSWORD_CLAIM_SIGNATURE`, `PASSWORD_CLAIM_SECRET_BLOCK`, `TIMESTAMP`, `USERNAME`, `SECRET_HASH` (if app client is configured with client secret).

    <note markdown=“1”> `PASSWORD_VERIFIER` requires `DEVICE_KEY` when signing in with a remembered device.

    </note>
    
  • `ADMIN_NO_SRP_AUTH`: `PASSWORD`, `USERNAME`, `SECRET_HASH` (if app client is configured with client secret).

  • `NEW_PASSWORD_REQUIRED`: `NEW_PASSWORD`, `USERNAME`, `SECRET_HASH` (if app client is configured with client secret). To set any required attributes that Amazon Cognito returned as `requiredAttributes` in the `AdminInitiateAuth` response, add a `userAttributes.attributename ` parameter. This parameter can also set values for writable attributes that aren't required by your user pool.

    <note markdown=“1”> In a `NEW_PASSWORD_REQUIRED` challenge response, you can't modify a required attribute that already has a value. In `AdminRespondToAuthChallenge`, set a value for any keys that Amazon Cognito returned in the `requiredAttributes` parameter, then use the `AdminUpdateUserAttributes` API operation to modify the value of any additional attributes.

    </note>
    
  • `MFA_SETUP` requires `USERNAME`, plus you must use the session value returned by `VerifySoftwareToken` in the `Session` parameter.

The value of the `USERNAME` attribute must be the user's actual username, not an alias (such as an email address or phone number). To make this simpler, the `AdminInitiateAuth` response includes the actual username value in the `USERNAMEUSER_ID_FOR_SRP` attribute. This happens even if you specified an alias in your call to `AdminInitiateAuth`.

Returns:

  • (Hash<String,String>)


1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1807

class AdminRespondToAuthChallengeRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :challenge_name,
  :challenge_responses,
  :session,
  :analytics_metadata,
  :context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#client_idString

The app client ID.

Returns:

  • (String)


1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1807

class AdminRespondToAuthChallengeRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :challenge_name,
  :challenge_responses,
  :session,
  :analytics_metadata,
  :context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#client_metadataHash<String,String>

A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.

You create custom workflows by assigning Lambda functions to user pool triggers. When you use the AdminRespondToAuthChallenge API action, Amazon Cognito invokes any functions that you have assigned to the following triggers:

  • pre sign-up

  • custom message

  • post authentication

  • user migration

  • pre token generation

  • define auth challenge

  • create auth challenge

  • verify auth challenge response

When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a `clientMetadata` attribute that provides the data that you assigned to the ClientMetadata parameter in your AdminRespondToAuthChallenge request. In your function code in Lambda, you can process the `clientMetadata` value to enhance your workflow for your specific needs.

For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.

<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won't do the following:

* Store the ClientMetadata value. This data is available only to
 Lambda triggers that are assigned to a user pool to support custom
 workflows. If your user pool configuration doesn't include
 triggers, the ClientMetadata parameter serves no purpose.
  • Validate the ClientMetadata value.

  • Encrypt the ClientMetadata value. Don't use Amazon Cognito to provide sensitive information.

</note>

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools-working-with-aws-lambda-triggers.html

Returns:

  • (Hash<String,String>)


1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1807

class AdminRespondToAuthChallengeRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :challenge_name,
  :challenge_responses,
  :session,
  :analytics_metadata,
  :context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#context_dataTypes::ContextDataType

Contextual data about your user session, such as the device fingerprint, IP address, or location. Amazon Cognito advanced security evaluates the risk of an authentication event based on the context that your app generates and passes to Amazon Cognito when it makes API requests.



1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1807

class AdminRespondToAuthChallengeRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :challenge_name,
  :challenge_responses,
  :session,
  :analytics_metadata,
  :context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#sessionString

The session that should be passed both ways in challenge-response calls to the service. If an `InitiateAuth` or `RespondToAuthChallenge` API call determines that the caller must pass another challenge, it returns a session with other challenge parameters. This session should be passed as it is to the next `RespondToAuthChallenge` API call.

Returns:

  • (String)


1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1807

class AdminRespondToAuthChallengeRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :challenge_name,
  :challenge_responses,
  :session,
  :analytics_metadata,
  :context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#user_pool_idString

The ID of the Amazon Cognito user pool.

Returns:

  • (String)


1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1807

class AdminRespondToAuthChallengeRequest < Struct.new(
  :user_pool_id,
  :client_id,
  :challenge_name,
  :challenge_responses,
  :session,
  :analytics_metadata,
  :context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end