Class: Aws::CognitoIdentityProvider::Types::AdminSetUserPasswordRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:username, :password]

Instance Attribute Summary collapse

Instance Attribute Details

#passwordString

The password for the user.

Returns:

  • (String)


1952
1953
1954
1955
1956
1957
1958
1959
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1952

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end

#permanentBoolean

‘True` if the password is permanent, `False` if it is temporary.

Returns:

  • (Boolean)


1952
1953
1954
1955
1956
1957
1958
1959
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1952

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool where you want to set the user’s password.

Returns:

  • (String)


1952
1953
1954
1955
1956
1957
1958
1959
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1952

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end

#usernameString

The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.

Returns:

  • (String)


1952
1953
1954
1955
1956
1957
1958
1959
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1952

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end