Class: Aws::CognitoIdentityProvider::Types::AdminSetUserPasswordRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminSetUserPasswordRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username, :password]
Instance Attribute Summary collapse
-
#password ⇒ String
The password for the user.
-
#permanent ⇒ Boolean
‘True` if the password is permanent, `False` if it is temporary.
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to set the user’s password.
-
#username ⇒ String
The username of the user that you want to query or modify.
Instance Attribute Details
#password ⇒ String
The password for the user.
1952 1953 1954 1955 1956 1957 1958 1959 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1952 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |
#permanent ⇒ Boolean
‘True` if the password is permanent, `False` if it is temporary.
1952 1953 1954 1955 1956 1957 1958 1959 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1952 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to set the user’s password.
1952 1953 1954 1955 1956 1957 1958 1959 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1952 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |
#username ⇒ String
The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.
1952 1953 1954 1955 1956 1957 1958 1959 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1952 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |