Class: Aws::CognitoIdentityProvider::Types::AdminSetUserPasswordRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:username, :password]

Instance Attribute Summary collapse

Instance Attribute Details

#passwordString

The password for the user.

Returns:

  • (String)


1598
1599
1600
1601
1602
1603
1604
1605
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1598

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end

#permanentBoolean

‘True` if the password is permanent, `False` if it is temporary.

Returns:

  • (Boolean)


1598
1599
1600
1601
1602
1603
1604
1605
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1598

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool where you want to set the user’s password.

Returns:

  • (String)


1598
1599
1600
1601
1602
1603
1604
1605
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1598

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end

#usernameString

The user name of the user whose password you want to set.

Returns:

  • (String)


1598
1599
1600
1601
1602
1603
1604
1605
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1598

class AdminSetUserPasswordRequest < Struct.new(
  :user_pool_id,
  :username,
  :password,
  :permanent)
  SENSITIVE = [:username, :password]
  include Aws::Structure
end