Class: Aws::CognitoIdentityProvider::Types::AdminSetUserPasswordRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminSetUserPasswordRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username, :password]
Instance Attribute Summary collapse
-
#password ⇒ String
The password for the user.
-
#permanent ⇒ Boolean
‘True` if the password is permanent, `False` if it is temporary.
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to set the user’s password.
-
#username ⇒ String
The user name of the user whose password you want to set.
Instance Attribute Details
#password ⇒ String
The password for the user.
1598 1599 1600 1601 1602 1603 1604 1605 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1598 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |
#permanent ⇒ Boolean
‘True` if the password is permanent, `False` if it is temporary.
1598 1599 1600 1601 1602 1603 1604 1605 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1598 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to set the user’s password.
1598 1599 1600 1601 1602 1603 1604 1605 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1598 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |
#username ⇒ String
The user name of the user whose password you want to set.
1598 1599 1600 1601 1602 1603 1604 1605 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1598 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |