Class: Aws::CognitoIdentityProvider::Types::AdminSetUserPasswordRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminSetUserPasswordRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass AdminSetUserPasswordRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
username: "UsernameType", # required
password: "PasswordType", # required
permanent: false,
}
Constant Summary collapse
- SENSITIVE =
[:username, :password]
Instance Attribute Summary collapse
-
#password ⇒ String
The password for the user.
-
#permanent ⇒ Boolean
`True` if the password is permanent, `False` if it is temporary.
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to set the user's password.
-
#username ⇒ String
The user name of the user whose password you want to set.
Instance Attribute Details
#password ⇒ String
The password for the user.
1894 1895 1896 1897 1898 1899 1900 1901 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1894 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |
#permanent ⇒ Boolean
`True` if the password is permanent, `False` if it is temporary.
1894 1895 1896 1897 1898 1899 1900 1901 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1894 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to set the user's password.
1894 1895 1896 1897 1898 1899 1900 1901 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1894 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |
#username ⇒ String
The user name of the user whose password you want to set.
1894 1895 1896 1897 1898 1899 1900 1901 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1894 class AdminSetUserPasswordRequest < Struct.new( :user_pool_id, :username, :password, :permanent) SENSITIVE = [:username, :password] include Aws::Structure end |