Class: Aws::CognitoIdentityProvider::Types::AdminSetUserSettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass AdminSetUserSettingsRequest data as a hash:

{
  user_pool_id: "UserPoolIdType", # required
  username: "UsernameType", # required
  mfa_options: [ # required
    {
      delivery_medium: "SMS", # accepts SMS, EMAIL
      attribute_name: "AttributeNameType",
    },
  ],
}

You can use this parameter to set an MFA configuration that uses the SMS delivery medium.

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#mfa_optionsArray<Types::MFAOptionType>

You can use this parameter only to set an SMS configuration that uses SMS for delivery.

Returns:



1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1988

class AdminSetUserSettingsRequest < Struct.new(
  :user_pool_id,
  :username,
  :mfa_options)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool that contains the user whose options you're setting.

Returns:

  • (String)


1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1988

class AdminSetUserSettingsRequest < Struct.new(
  :user_pool_id,
  :username,
  :mfa_options)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The user name of the user whose options you're setting.

Returns:

  • (String)


1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1988

class AdminSetUserSettingsRequest < Struct.new(
  :user_pool_id,
  :username,
  :mfa_options)
  SENSITIVE = [:username]
  include Aws::Structure
end