Class: Aws::CognitoIdentityProvider::Types::AdminUpdateAuthEventFeedbackRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#event_idString

The authentication event ID.

Returns:

  • (String)


2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2031

class AdminUpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_value)
  SENSITIVE = [:username]
  include Aws::Structure
end

#feedback_valueString

The authentication event feedback value. When you provide a ‘FeedbackValue` value of `valid`, you tell Amazon Cognito that you trust a user session where Amazon Cognito has evaluated some level of risk. When you provide a `FeedbackValue` value of `invalid`, you tell Amazon Cognito that you don’t trust a user session, or you don’t believe that Amazon Cognito evaluated a high-enough risk level.

Returns:

  • (String)


2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2031

class AdminUpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_value)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_pool_idString

The user pool ID.

Returns:

  • (String)


2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2031

class AdminUpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_value)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.

Returns:

  • (String)


2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2031

class AdminUpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_value)
  SENSITIVE = [:username]
  include Aws::Structure
end