Class: Aws::CognitoIdentityProvider::Types::AdminUpdateDeviceStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminUpdateDeviceStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The request to update the device status, as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#device_key ⇒ String
The unique identifier, or device key, of the device that you want to update the status for.
-
#device_remembered_status ⇒ String
To enable device authentication with the specified device, set to ‘remembered`.To disable, set to `not_remembered`.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to change a user’s device status.
-
#username ⇒ String
The name of the user that you want to query or modify.
Instance Attribute Details
#device_key ⇒ String
The unique identifier, or device key, of the device that you want to update the status for.
2348 2349 2350 2351 2352 2353 2354 2355 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2348 class AdminUpdateDeviceStatusRequest < Struct.new( :user_pool_id, :username, :device_key, :device_remembered_status) SENSITIVE = [:username] include Aws::Structure end |
#device_remembered_status ⇒ String
To enable device authentication with the specified device, set to ‘remembered`.To disable, set to `not_remembered`.
2348 2349 2350 2351 2352 2353 2354 2355 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2348 class AdminUpdateDeviceStatusRequest < Struct.new( :user_pool_id, :username, :device_key, :device_remembered_status) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to change a user’s device status.
2348 2349 2350 2351 2352 2353 2354 2355 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2348 class AdminUpdateDeviceStatusRequest < Struct.new( :user_pool_id, :username, :device_key, :device_remembered_status) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The name of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.
2348 2349 2350 2351 2352 2353 2354 2355 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2348 class AdminUpdateDeviceStatusRequest < Struct.new( :user_pool_id, :username, :device_key, :device_remembered_status) SENSITIVE = [:username] include Aws::Structure end |