Class: Aws::CognitoIdentityProvider::Types::AdminUpdateDeviceStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AdminUpdateDeviceStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The request to update the device status, as an administrator.
Constant Summary collapse
- SENSITIVE =
[:username]
Instance Attribute Summary collapse
-
#device_key ⇒ String
The device key.
-
#device_remembered_status ⇒ String
The status indicating whether a device has been remembered or not.
-
#user_pool_id ⇒ String
The user pool ID.
-
#username ⇒ String
The username of the user that you want to query or modify.
Instance Attribute Details
#device_key ⇒ String
The device key.
2068 2069 2070 2071 2072 2073 2074 2075 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2068 class AdminUpdateDeviceStatusRequest < Struct.new( :user_pool_id, :username, :device_key, :device_remembered_status) SENSITIVE = [:username] include Aws::Structure end |
#device_remembered_status ⇒ String
The status indicating whether a device has been remembered or not.
2068 2069 2070 2071 2072 2073 2074 2075 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2068 class AdminUpdateDeviceStatusRequest < Struct.new( :user_pool_id, :username, :device_key, :device_remembered_status) SENSITIVE = [:username] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
2068 2069 2070 2071 2072 2073 2074 2075 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2068 class AdminUpdateDeviceStatusRequest < Struct.new( :user_pool_id, :username, :device_key, :device_remembered_status) SENSITIVE = [:username] include Aws::Structure end |
#username ⇒ String
The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.
2068 2069 2070 2071 2072 2073 2074 2075 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2068 class AdminUpdateDeviceStatusRequest < Struct.new( :user_pool_id, :username, :device_key, :device_remembered_status) SENSITIVE = [:username] include Aws::Structure end |