Class: Aws::CognitoIdentityProvider::Types::AdminUpdateUserAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass AdminUpdateUserAttributesRequest data as a hash:

{
  user_pool_id: "UserPoolIdType", # required
  username: "UsernameType", # required
  user_attributes: [ # required
    {
      name: "AttributeNameType", # required
      value: "AttributeValueType",
    },
  ],
  client_metadata: {
    "StringType" => "StringType",
  },
}

Represents the request to update the user's attributes as an administrator.

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#client_metadataHash<String,String>

A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.

You create custom workflows by assigning Lambda functions to user pool triggers. When you use the AdminUpdateUserAttributes API action, Amazon Cognito invokes the function that is assigned to the *custom message* trigger. When Amazon Cognito invokes this function, it passes a JSON payload, which the function receives as input. This payload contains a `clientMetadata` attribute, which provides the data that you assigned to the ClientMetadata parameter in your AdminUpdateUserAttributes request. In your function code in Lambda, you can process the `clientMetadata` value to enhance your workflow for your specific needs.

For more information, see [Customizing User Pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.

<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won't do the following:

* Store the ClientMetadata value. This data is available only to
 Lambda triggers that are assigned to a user pool to support custom
 workflows. If your user pool configuration doesn't include
 triggers, the ClientMetadata parameter serves no purpose.
  • Validate the ClientMetadata value.

  • Encrypt the ClientMetadata value. Don't use Amazon Cognito to provide sensitive information.

</note>

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools-working-with-aws-lambda-triggers.html

Returns:

  • (Hash<String,String>)


2119
2120
2121
2122
2123
2124
2125
2126
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2119

class AdminUpdateUserAttributesRequest < Struct.new(
  :user_pool_id,
  :username,
  :user_attributes,
  :client_metadata)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_attributesArray<Types::AttributeType>

An array of name-value pairs representing user attributes.

For custom attributes, you must prepend the `custom:` prefix to the attribute name.

Returns:



2119
2120
2121
2122
2123
2124
2125
2126
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2119

class AdminUpdateUserAttributesRequest < Struct.new(
  :user_pool_id,
  :username,
  :user_attributes,
  :client_metadata)
  SENSITIVE = [:username]
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool where you want to update user attributes.

Returns:

  • (String)


2119
2120
2121
2122
2123
2124
2125
2126
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2119

class AdminUpdateUserAttributesRequest < Struct.new(
  :user_pool_id,
  :username,
  :user_attributes,
  :client_metadata)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The user name of the user for whom you want to update user attributes.

Returns:

  • (String)


2119
2120
2121
2122
2123
2124
2125
2126
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2119

class AdminUpdateUserAttributesRequest < Struct.new(
  :user_pool_id,
  :username,
  :user_attributes,
  :client_metadata)
  SENSITIVE = [:username]
  include Aws::Structure
end