Class: Aws::CognitoIdentityProvider::Types::AdminUserGlobalSignOutRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The request to sign out of all devices, as an administrator.

Constant Summary collapse

SENSITIVE =
[:username]

Instance Attribute Summary collapse

Instance Attribute Details

#user_pool_idString

The user pool ID.

Returns:

  • (String)


2195
2196
2197
2198
2199
2200
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2195

class AdminUserGlobalSignOutRequest < Struct.new(
  :user_pool_id,
  :username)
  SENSITIVE = [:username]
  include Aws::Structure
end

#usernameString

The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.

Returns:

  • (String)


2195
2196
2197
2198
2199
2200
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2195

class AdminUserGlobalSignOutRequest < Struct.new(
  :user_pool_id,
  :username)
  SENSITIVE = [:username]
  include Aws::Structure
end