Class: Aws::CognitoIdentityProvider::Types::AliasExistsException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AliasExistsException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
This exception is thrown when a user tries to confirm the account with an email or phone number that has already been supplied as an alias from a different account. This exception tells user that an account with this email or phone already exists.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The message sent to the user when an alias exists.
Instance Attribute Details
#message ⇒ String
The message sent to the user when an alias exists.
2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2194 class AliasExistsException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |