Class: Aws::CognitoIdentityProvider::Types::AnalyticsConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AnalyticsConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass AnalyticsConfigurationType data as a hash:
{
application_id: "HexStringType",
application_arn: "ArnType",
role_arn: "ArnType",
external_id: "StringType",
user_data_shared: false,
}
The Amazon Pinpoint analytics configuration for collecting metrics for a user pool.
<note markdown=“1”> In Regions where Amazon Pinpointisn't available, user pools only support sending events to Amazon Pinpoint projects in us-east-1. In Regions where Amazon Pinpoint is available, user pools support sending events to Amazon Pinpoint projects within that same Region.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon Pinpoint project.
-
#application_id ⇒ String
The application ID for an Amazon Pinpoint application.
-
#external_id ⇒ String
The external ID.
-
#role_arn ⇒ String
The ARN of an Identity and Access Management role that authorizes Amazon Cognito to publish events to Amazon Pinpoint analytics.
-
#user_data_shared ⇒ Boolean
If `UserDataShared` is `true`, Amazon Cognito will include user data in the events it publishes to Amazon Pinpoint analytics.
Instance Attribute Details
#application_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon Pinpoint project. You can use the Amazon Pinpoint project to integrate with the chosen user pool Client. Amazon Cognito publishes events to the Amazon Pinpointproject declared by the app ARN.
2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2248 class AnalyticsConfigurationType < Struct.new( :application_id, :application_arn, :role_arn, :external_id, :user_data_shared) SENSITIVE = [] include Aws::Structure end |
#application_id ⇒ String
The application ID for an Amazon Pinpoint application.
2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2248 class AnalyticsConfigurationType < Struct.new( :application_id, :application_arn, :role_arn, :external_id, :user_data_shared) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The external ID.
2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2248 class AnalyticsConfigurationType < Struct.new( :application_id, :application_arn, :role_arn, :external_id, :user_data_shared) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of an Identity and Access Management role that authorizes Amazon Cognito to publish events to Amazon Pinpoint analytics.
2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2248 class AnalyticsConfigurationType < Struct.new( :application_id, :application_arn, :role_arn, :external_id, :user_data_shared) SENSITIVE = [] include Aws::Structure end |
#user_data_shared ⇒ Boolean
If `UserDataShared` is `true`, Amazon Cognito will include user data in the events it publishes to Amazon Pinpoint analytics.
2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2248 class AnalyticsConfigurationType < Struct.new( :application_id, :application_arn, :role_arn, :external_id, :user_data_shared) SENSITIVE = [] include Aws::Structure end |