Class: Aws::CognitoIdentityProvider::Types::AnalyticsMetadataType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AnalyticsMetadataType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
An Amazon Pinpoint analytics endpoint.
An endpoint uniquely identifies a mobile device, email address, or phone number that can receive messages from Amazon Pinpoint analytics. For more information about Amazon Web Services Regions that can contain Amazon Pinpoint resources for use with Amazon Cognito user pools, see [Using Amazon Pinpoint analytics with Amazon Cognito user pools].
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-pinpoint-integration.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analytics_endpoint_id ⇒ String
The endpoint ID.
Instance Attribute Details
#analytics_endpoint_id ⇒ String
The endpoint ID.
2072 2073 2074 2075 2076 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2072 class AnalyticsMetadataType < Struct.new( :analytics_endpoint_id) SENSITIVE = [] include Aws::Structure end |