Class: Aws::CognitoIdentityProvider::Types::AnalyticsMetadataType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass AnalyticsMetadataType data as a hash:

{
  analytics_endpoint_id: "StringType",
}

An Amazon Pinpoint analytics endpoint.

An endpoint uniquely identifies a mobile device, email address, or phone number that can receive messages from Amazon Pinpoint analytics. For more information about Amazon Web Services Regions that can contain Amazon Pinpoint resources for use with Amazon Cognito user pools, see [Using Amazon Pinpoint analytics with Amazon Cognito user pools].

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-pinpoint-integration.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_endpoint_idString

The endpoint ID.

Returns:

  • (String)


2329
2330
2331
2332
2333
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2329

class AnalyticsMetadataType < Struct.new(
  :analytics_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end