Class: Aws::CognitoIdentityProvider::Types::AnalyticsMetadataType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass AnalyticsMetadataType data as a hash:

{
  analytics_endpoint_id: "StringType",
}

An Amazon Pinpoint analytics endpoint.

An endpoint uniquely identifies a mobile device, email address, or phone number that can receive messages from Amazon Pinpoint analytics.

<note markdown=“1”> Amazon Cognito user pools only support sending events to Amazon Pinpoint projects in the US East (N. Virginia) us-east-1 Region, regardless of the Region where the user pool resides.

</note>

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_endpoint_idString

The endpoint ID.

Returns:

  • (String)


2282
2283
2284
2285
2286
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2282

class AnalyticsMetadataType < Struct.new(
  :analytics_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end