Class: Aws::CognitoIdentityProvider::Types::AnalyticsMetadataType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AnalyticsMetadataType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass AnalyticsMetadataType data as a hash:
{
analytics_endpoint_id: "StringType",
}
An Amazon Pinpoint analytics endpoint.
An endpoint uniquely identifies a mobile device, email address, or phone number that can receive messages from Amazon Pinpoint analytics.
<note markdown=“1”> Amazon Cognito User Pools only supports sending events to Amazon Pinpoint projects in the US East (N. Virginia) us-east-1 Region, regardless of the Region in which the user pool resides.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analytics_endpoint_id ⇒ String
The endpoint ID.
Instance Attribute Details
#analytics_endpoint_id ⇒ String
The endpoint ID.
2267 2268 2269 2270 2271 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2267 class AnalyticsMetadataType < Struct.new( :analytics_endpoint_id) SENSITIVE = [] include Aws::Structure end |