Class: Aws::CognitoIdentityProvider::Types::AssociateSoftwareTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AssociateSoftwareTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass AssociateSoftwareTokenRequest data as a hash:
{
access_token: "TokenModelType",
session: "SessionType",
}
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose software token you want to generate.
-
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose software token you want to generate.
2363 2364 2365 2366 2367 2368 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2363 class AssociateSoftwareTokenRequest < Struct.new( :access_token, :session) SENSITIVE = [:access_token] include Aws::Structure end |
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service. This allows authentication of the user as part of the MFA setup process.
2363 2364 2365 2366 2367 2368 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2363 class AssociateSoftwareTokenRequest < Struct.new( :access_token, :session) SENSITIVE = [:access_token] include Aws::Structure end |