Class: Aws::CognitoIdentityProvider::Types::AttributeType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The name and value of a user attribute.

Constant Summary collapse

SENSITIVE =
[:value]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the attribute, for example ‘email` or `custom:department`.

In some older user pools, the regex pattern for acceptable values of this parameter is ‘[pLpMpSpNpP]+`. Older pools will eventually be updated to use the new pattern. Affected user pools are those created before May 2024 in US East (N. Virginia), US East (Ohio), US West (N. California), US West (Oregon), Asia Pacific (Mumbai), Asia Pacific (Tokyo), Asia Pacific (Seoul), Asia Pacific (Singapore), Asia Pacific (Sydney), Canada (Central), Europe (Frankfurt), Europe (Ireland), Europe (London), Europe (Paris), Europe (Stockholm), Middle East (Bahrain), and South America (São Paulo).

Returns:

  • (String)


2718
2719
2720
2721
2722
2723
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2718

class AttributeType < Struct.new(
  :name,
  :value)
  SENSITIVE = [:value]
  include Aws::Structure
end

#valueString

The value of the attribute.

Returns:

  • (String)


2718
2719
2720
2721
2722
2723
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2718

class AttributeType < Struct.new(
  :name,
  :value)
  SENSITIVE = [:value]
  include Aws::Structure
end