Class: Aws::CognitoIdentityProvider::Types::AuthEventType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AuthEventType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The authentication event type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#challenge_responses ⇒ Array<Types::ChallengeResponseType>
The challenge responses.
-
#creation_date ⇒ Time
The creation date.
-
#event_context_data ⇒ Types::EventContextDataType
The user context data captured at the time of an event request.
-
#event_feedback ⇒ Types::EventFeedbackType
A flag specifying the user feedback captured at the time of an event request is good or bad.
-
#event_id ⇒ String
The event ID.
-
#event_response ⇒ String
The event response.
-
#event_risk ⇒ Types::EventRiskType
The event risk.
-
#event_type ⇒ String
The event type.
Instance Attribute Details
#challenge_responses ⇒ Array<Types::ChallengeResponseType>
The challenge responses.
1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1976 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The creation date
1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1976 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_context_data ⇒ Types::EventContextDataType
The user context data captured at the time of an event request. This value provides additional information about the client from which event the request is received.
1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1976 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_feedback ⇒ Types::EventFeedbackType
A flag specifying the user feedback captured at the time of an event request is good or bad.
1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1976 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_id ⇒ String
The event ID.
1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1976 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_response ⇒ String
The event response.
1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1976 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_risk ⇒ Types::EventRiskType
The event risk.
1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1976 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
The event type.
1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 1976 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |