Class: Aws::CognitoIdentityProvider::Types::AuthEventType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::AuthEventType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The authentication event type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#challenge_responses ⇒ Array<Types::ChallengeResponseType>
The challenge responses.
-
#creation_date ⇒ Time
The creation date.
-
#event_context_data ⇒ Types::EventContextDataType
The user context data captured at the time of an event request.
-
#event_feedback ⇒ Types::EventFeedbackType
A flag specifying the user feedback captured at the time of an event request is good or bad.
-
#event_id ⇒ String
The event ID.
-
#event_response ⇒ String
The event response.
-
#event_risk ⇒ Types::EventRiskType
The event risk.
-
#event_type ⇒ String
The event type.
Instance Attribute Details
#challenge_responses ⇒ Array<Types::ChallengeResponseType>
The challenge responses.
2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2456 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The creation date
2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2456 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_context_data ⇒ Types::EventContextDataType
The user context data captured at the time of an event request. This value provides additional information about the client from which event the request is received.
2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2456 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_feedback ⇒ Types::EventFeedbackType
A flag specifying the user feedback captured at the time of an event request is good or bad.
2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2456 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_id ⇒ String
The event ID.
2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2456 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_response ⇒ String
The event response.
2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2456 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_risk ⇒ Types::EventRiskType
The event risk.
2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2456 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
The event type.
2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2456 class AuthEventType < Struct.new( :event_id, :event_type, :creation_date, :event_response, :event_risk, :challenge_responses, :event_context_data, :event_feedback) SENSITIVE = [] include Aws::Structure end |