Class: Aws::CognitoIdentityProvider::Types::AuthEventType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The authentication event type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#challenge_responsesArray<Types::ChallengeResponseType>

The challenge responses.

Returns:



2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2449

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The creation date

Returns:

  • (Time)


2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2449

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_context_dataTypes::EventContextDataType

The user context data captured at the time of an event request. This value provides additional information about the client from which event the request is received.



2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2449

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_feedbackTypes::EventFeedbackType

A flag specifying the user feedback captured at the time of an event request is good or bad.



2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2449

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_idString

The event ID.

Returns:

  • (String)


2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2449

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_responseString

The event response.

Returns:

  • (String)


2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2449

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_riskTypes::EventRiskType

The event risk.



2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2449

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end

#event_typeString

The event type.

Returns:

  • (String)


2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2449

class AuthEventType < Struct.new(
  :event_id,
  :event_type,
  :creation_date,
  :event_response,
  :event_risk,
  :challenge_responses,
  :event_context_data,
  :event_feedback)
  SENSITIVE = []
  include Aws::Structure
end