Class: Aws::CognitoIdentityProvider::Types::ChangePasswordRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ChangePasswordRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass ChangePasswordRequest data as a hash:
{
previous_password: "PasswordType", # required
proposed_password: "PasswordType", # required
access_token: "TokenModelType", # required
}
Represents the request to change a user password.
Constant Summary collapse
- SENSITIVE =
[:previous_password, :proposed_password, :access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose password you want to change.
-
#previous_password ⇒ String
The old password.
-
#proposed_password ⇒ String
The new password.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose password you want to change.
2552 2553 2554 2555 2556 2557 2558 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2552 class ChangePasswordRequest < Struct.new( :previous_password, :proposed_password, :access_token) SENSITIVE = [:previous_password, :proposed_password, :access_token] include Aws::Structure end |
#previous_password ⇒ String
The old password.
2552 2553 2554 2555 2556 2557 2558 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2552 class ChangePasswordRequest < Struct.new( :previous_password, :proposed_password, :access_token) SENSITIVE = [:previous_password, :proposed_password, :access_token] include Aws::Structure end |
#proposed_password ⇒ String
The new password.
2552 2553 2554 2555 2556 2557 2558 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2552 class ChangePasswordRequest < Struct.new( :previous_password, :proposed_password, :access_token) SENSITIVE = [:previous_password, :proposed_password, :access_token] include Aws::Structure end |