Class: Aws::CognitoIdentityProvider::Types::ClientSecretDescriptorType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ClientSecretDescriptorType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Contains information about a client secret, including its unique identifier, value, and creation timestamp.
Constant Summary collapse
- SENSITIVE =
[:client_secret_value]
Instance Attribute Summary collapse
-
#client_secret_create_date ⇒ Time
The date and time when the client secret was created.
-
#client_secret_id ⇒ String
The unique identifier for the client secret.
-
#client_secret_value ⇒ String
The actual secret value.
Instance Attribute Details
#client_secret_create_date ⇒ Time
The date and time when the client secret was created.
3045 3046 3047 3048 3049 3050 3051 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3045 class ClientSecretDescriptorType < Struct.new( :client_secret_id, :client_secret_value, :client_secret_create_date) SENSITIVE = [:client_secret_value] include Aws::Structure end |
#client_secret_id ⇒ String
The unique identifier for the client secret. This identifier follows the format <client-id>–<epoch-create-time>.
3045 3046 3047 3048 3049 3050 3051 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3045 class ClientSecretDescriptorType < Struct.new( :client_secret_id, :client_secret_value, :client_secret_create_date) SENSITIVE = [:client_secret_value] include Aws::Structure end |
#client_secret_value ⇒ String
The actual secret value. This is only returned when creating a new secret and only if Amazon Cognito generated the secret. For custom secrets that you provide, this field is not included in the response.
3045 3046 3047 3048 3049 3050 3051 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3045 class ClientSecretDescriptorType < Struct.new( :client_secret_id, :client_secret_value, :client_secret_create_date) SENSITIVE = [:client_secret_value] include Aws::Structure end |