Class: Aws::CognitoIdentityProvider::Types::CloudWatchLogsConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CloudWatchLogsConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The CloudWatch logging destination of a user pool detailed activity logging configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_arn ⇒ String
The Amazon Resource Name (arn) of a CloudWatch Logs log group where your user pool sends logs.
Instance Attribute Details
#log_group_arn ⇒ String
The Amazon Resource Name (arn) of a CloudWatch Logs log group where your user pool sends logs. The log group must not be encrypted with Key Management Service and must be in the same Amazon Web Services account as your user pool.
2131 2132 2133 2134 2135 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2131 class CloudWatchLogsConfigurationType < Struct.new( :log_group_arn) SENSITIVE = [] include Aws::Structure end |