Class: Aws::CognitoIdentityProvider::Types::CompleteWebAuthnRegistrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CompleteWebAuthnRegistrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose passkey registration you want to verify.
-
#credential ⇒ Hash, ...
A [RegistrationResponseJSON] public-key credential response from the user’s passkey provider.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose passkey registration you want to verify.
2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2912 class CompleteWebAuthnRegistrationRequest < Struct.new( :access_token, :credential) SENSITIVE = [:access_token] include Aws::Structure end |
#credential ⇒ Hash, ...
A [RegistrationResponseJSON] public-key credential response from the user’s passkey provider.
[1]: www.w3.org/TR/webauthn-3/#dictdef-registrationresponsejson
2912 2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2912 class CompleteWebAuthnRegistrationRequest < Struct.new( :access_token, :credential) SENSITIVE = [:access_token] include Aws::Structure end |