Class: Aws::CognitoIdentityProvider::Types::ConfirmSignUpRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ConfirmSignUpRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass ConfirmSignUpRequest data as a hash:
{
client_id: "ClientIdType", # required
secret_hash: "SecretHashType",
username: "UsernameType", # required
confirmation_code: "ConfirmationCodeType", # required
force_alias_creation: false,
analytics_metadata: {
analytics_endpoint_id: "StringType",
},
user_context_data: {
encoded_data: "StringType",
},
client_metadata: {
"StringType" => "StringType",
},
}
Represents the request to confirm registration of a user.
Constant Summary collapse
- SENSITIVE =
[:client_id, :secret_hash, :username]
Instance Attribute Summary collapse
-
#analytics_metadata ⇒ Types::AnalyticsMetadataType
The Amazon Pinpoint analytics metadata for collecting metrics for `ConfirmSignUp` calls.
-
#client_id ⇒ String
The ID of the app client associated with the user pool.
-
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.
-
#confirmation_code ⇒ String
The confirmation code sent by a user's request to confirm registration.
-
#force_alias_creation ⇒ Boolean
Boolean to be specified to force user confirmation irrespective of existing alias.
-
#secret_hash ⇒ String
A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message.
-
#user_context_data ⇒ Types::UserContextDataType
Contextual data such as the user's device fingerprint, IP address, or location used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.
-
#username ⇒ String
The user name of the user whose registration you want to confirm.
Instance Attribute Details
#analytics_metadata ⇒ Types::AnalyticsMetadataType
The Amazon Pinpoint analytics metadata for collecting metrics for `ConfirmSignUp` calls.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2967 class ConfirmSignUpRequest < Struct.new( :client_id, :secret_hash, :username, :confirmation_code, :force_alias_creation, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id, :secret_hash, :username] include Aws::Structure end |
#client_id ⇒ String
The ID of the app client associated with the user pool.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2967 class ConfirmSignUpRequest < Struct.new( :client_id, :secret_hash, :username, :confirmation_code, :force_alias_creation, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id, :secret_hash, :username] include Aws::Structure end |
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.
You create custom workflows by assigning Lambda functions to user pool triggers. When you use the ConfirmSignUp API action, Amazon Cognito invokes the function that is assigned to the *post confirmation* trigger. When Amazon Cognito invokes this function, it passes a JSON payload, which the function receives as input. This payload contains a `clientMetadata` attribute, which provides the data that you assigned to the ClientMetadata parameter in your ConfirmSignUp request. In your function code in Lambda, you can process the `clientMetadata` value to enhance your workflow for your specific needs.
For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.
<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won't do the following:
* Store the ClientMetadata value. This data is available only to
Lambda triggers that are assigned to a user pool to support custom
workflows. If your user pool configuration doesn't include
triggers, the ClientMetadata parameter serves no purpose.
-
Validate the ClientMetadata value.
-
Encrypt the ClientMetadata value. Don't use Amazon Cognito to provide sensitive information.
</note>
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2967 class ConfirmSignUpRequest < Struct.new( :client_id, :secret_hash, :username, :confirmation_code, :force_alias_creation, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id, :secret_hash, :username] include Aws::Structure end |
#confirmation_code ⇒ String
The confirmation code sent by a user's request to confirm registration.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2967 class ConfirmSignUpRequest < Struct.new( :client_id, :secret_hash, :username, :confirmation_code, :force_alias_creation, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id, :secret_hash, :username] include Aws::Structure end |
#force_alias_creation ⇒ Boolean
Boolean to be specified to force user confirmation irrespective of existing alias. By default set to `False`. If this parameter is set to `True` and the phone number/email used for sign up confirmation already exists as an alias with a different user, the API call will migrate the alias from the previous user to the newly created user being confirmed. If set to `False`, the API will throw an *AliasExistsException* error.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2967 class ConfirmSignUpRequest < Struct.new( :client_id, :secret_hash, :username, :confirmation_code, :force_alias_creation, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id, :secret_hash, :username] include Aws::Structure end |
#secret_hash ⇒ String
A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2967 class ConfirmSignUpRequest < Struct.new( :client_id, :secret_hash, :username, :confirmation_code, :force_alias_creation, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id, :secret_hash, :username] include Aws::Structure end |
#user_context_data ⇒ Types::UserContextDataType
Contextual data such as the user's device fingerprint, IP address, or location used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2967 class ConfirmSignUpRequest < Struct.new( :client_id, :secret_hash, :username, :confirmation_code, :force_alias_creation, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id, :secret_hash, :username] include Aws::Structure end |
#username ⇒ String
The user name of the user whose registration you want to confirm.
2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2967 class ConfirmSignUpRequest < Struct.new( :client_id, :secret_hash, :username, :confirmation_code, :force_alias_creation, :analytics_metadata, :user_context_data, :client_metadata) SENSITIVE = [:client_id, :secret_hash, :username] include Aws::Structure end |