Class: Aws::CognitoIdentityProvider::Types::ContextDataType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ContextDataType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass ContextDataType data as a hash:
{
ip_address: "StringType", # required
server_name: "StringType", # required
server_path: "StringType", # required
http_headers: [ # required
{
header_name: "StringType",
header_value: "StringType",
},
],
encoded_data: "StringType",
}
Contextual user data type used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encoded_data ⇒ String
Encoded data containing device fingerprinting details collected using the Amazon Cognito context data collection library.
-
#http_headers ⇒ Array<Types::HttpHeader>
HttpHeaders received on your server in same order.
-
#ip_address ⇒ String
Source IP address of your user.
-
#server_name ⇒ String
Your server endpoint where this API is invoked.
-
#server_path ⇒ String
Your server path where this API is invoked.
Instance Attribute Details
#encoded_data ⇒ String
Encoded data containing device fingerprinting details collected using the Amazon Cognito context data collection library.
2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2975 class ContextDataType < Struct.new( :ip_address, :server_name, :server_path, :http_headers, :encoded_data) SENSITIVE = [] include Aws::Structure end |
#http_headers ⇒ Array<Types::HttpHeader>
HttpHeaders received on your server in same order.
2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2975 class ContextDataType < Struct.new( :ip_address, :server_name, :server_path, :http_headers, :encoded_data) SENSITIVE = [] include Aws::Structure end |
#ip_address ⇒ String
Source IP address of your user.
2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2975 class ContextDataType < Struct.new( :ip_address, :server_name, :server_path, :http_headers, :encoded_data) SENSITIVE = [] include Aws::Structure end |
#server_name ⇒ String
Your server endpoint where this API is invoked.
2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2975 class ContextDataType < Struct.new( :ip_address, :server_name, :server_path, :http_headers, :encoded_data) SENSITIVE = [] include Aws::Structure end |
#server_path ⇒ String
Your server path where this API is invoked.
2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2975 class ContextDataType < Struct.new( :ip_address, :server_name, :server_path, :http_headers, :encoded_data) SENSITIVE = [] include Aws::Structure end |