Class: Aws::CognitoIdentityProvider::Types::CreateGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass CreateGroupRequest data as a hash:

{
  group_name: "GroupNameType", # required
  user_pool_id: "UserPoolIdType", # required
  description: "DescriptionType",
  role_arn: "ArnType",
  precedence: 1,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A string containing the description of the group.

Returns:

  • (String)


3034
3035
3036
3037
3038
3039
3040
3041
3042
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3034

class CreateGroupRequest < Struct.new(
  :group_name,
  :user_pool_id,
  :description,
  :role_arn,
  :precedence)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the group. Must be unique.

Returns:

  • (String)


3034
3035
3036
3037
3038
3039
3040
3041
3042
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3034

class CreateGroupRequest < Struct.new(
  :group_name,
  :user_pool_id,
  :description,
  :role_arn,
  :precedence)
  SENSITIVE = []
  include Aws::Structure
end

#precedenceInteger

A non-negative integer value that specifies the precedence of this group relative to the other groups that a user can belong to in the user pool. Zero is the highest precedence value. Groups with lower `Precedence` values take precedence over groups with higher ornull `Precedence` values. If a user belongs to two or more groups, it is the group with the lowest precedence value whose role ARN is given in the user's tokens for the `cognito:roles` and `cognito:preferred_role` claims.

Two groups can have the same `Precedence` value. If this happens, neither group takes precedence over the other. If two groups with the same `Precedence` have the same role ARN, that role is used in the `cognito:preferred_role` claim in tokens for users in each group. If the two groups have different role ARNs, the `cognito:preferred_role` claim isn't set in users' tokens.

The default `Precedence` value is null.

Returns:

  • (Integer)


3034
3035
3036
3037
3038
3039
3040
3041
3042
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3034

class CreateGroupRequest < Struct.new(
  :group_name,
  :user_pool_id,
  :description,
  :role_arn,
  :precedence)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The role Amazon Resource Name (ARN) for the group.

Returns:

  • (String)


3034
3035
3036
3037
3038
3039
3040
3041
3042
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3034

class CreateGroupRequest < Struct.new(
  :group_name,
  :user_pool_id,
  :description,
  :role_arn,
  :precedence)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool.

Returns:

  • (String)


3034
3035
3036
3037
3038
3039
3040
3041
3042
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3034

class CreateGroupRequest < Struct.new(
  :group_name,
  :user_pool_id,
  :description,
  :role_arn,
  :precedence)
  SENSITIVE = []
  include Aws::Structure
end