Class: Aws::CognitoIdentityProvider::Types::CreateIdentityProviderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateIdentityProviderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_mapping ⇒ Hash<String,String>
A mapping of IdP attributes to standard and custom user pool attributes.
-
#idp_identifiers ⇒ Array<String>
A list of IdP identifiers.
-
#provider_details ⇒ Hash<String,String>
The IdP details.
-
#provider_name ⇒ String
The IdP name.
-
#provider_type ⇒ String
The IdP type.
-
#user_pool_id ⇒ String
The user pool ID.
Instance Attribute Details
#attribute_mapping ⇒ Hash<String,String>
A mapping of IdP attributes to standard and custom user pool attributes.
2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2635 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |
#idp_identifiers ⇒ Array<String>
A list of IdP identifiers.
2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2635 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |
#provider_details ⇒ Hash<String,String>
The IdP details. The following list describes the provider detail keys for each IdP type.
-
For Google and Login with Amazon:
-
client_id
-
client_secret
-
authorize_scopes
-
-
For Facebook:
-
client_id
-
client_secret
-
authorize_scopes
-
api_version
-
-
For Sign in with Apple:
-
client_id
-
team_id
-
key_id
-
private_key
-
authorize_scopes
-
-
For OpenID Connect (OIDC) providers:
-
client_id
-
client_secret
-
attributes_request_method
-
oidc_issuer
-
authorize_scopes
-
The following keys are only present if Amazon Cognito didn’t discover them at the ‘oidc_issuer` URL.
-
authorize_url
-
token_url
-
attributes_url
-
jwks_uri
-
-
Amazon Cognito sets the value of the following keys automatically. They are read-only.
-
attributes_url_add_attributes
^
-
-
-
For SAML providers:
-
MetadataFile or MetadataURL
-
IDPSignout optional
-
2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2635 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The IdP name.
2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2635 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |
#provider_type ⇒ String
The IdP type.
2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2635 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 2635 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |