Class: Aws::CognitoIdentityProvider::Types::CreateIdentityProviderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateIdentityProviderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass CreateIdentityProviderRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
provider_name: "ProviderNameTypeV1", # required
provider_type: "SAML", # required, accepts SAML, Facebook, Google, LoginWithAmazon, SignInWithApple, OIDC
provider_details: { # required
"StringType" => "StringType",
},
attribute_mapping: {
"AttributeMappingKeyType" => "StringType",
},
idp_identifiers: ["IdpIdentifierType"],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_mapping ⇒ Hash<String,String>
A mapping of identity provider attributes to standard and custom user pool attributes.
-
#idp_identifiers ⇒ Array<String>
A list of identity provider identifiers.
-
#provider_details ⇒ Hash<String,String>
The identity provider details.
-
#provider_name ⇒ String
The identity provider name.
-
#provider_type ⇒ String
The identity provider type.
-
#user_pool_id ⇒ String
The user pool ID.
Instance Attribute Details
#attribute_mapping ⇒ Hash<String,String>
A mapping of identity provider attributes to standard and custom user pool attributes.
3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3148 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |
#idp_identifiers ⇒ Array<String>
A list of identity provider identifiers.
3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3148 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |
#provider_details ⇒ Hash<String,String>
The identity provider details. The following list describes the provider detail keys for each identity provider type.
-
For Google and Login with Amazon:
-
client_id
-
client_secret
-
authorize_scopes
-
-
For Facebook:
-
client_id
-
client_secret
-
authorize_scopes
-
api_version
-
-
For Sign in with Apple:
-
client_id
-
team_id
-
key_id
-
private_key
-
authorize_scopes
-
-
For OpenID Connect (OIDC) providers:
-
client_id
-
client_secret
-
attributes_request_method
-
oidc_issuer
-
authorize_scopes
-
authorize_url *if not available from discovery URL specified by oidc_issuer key*
-
token_url *if not available from discovery URL specified by oidc_issuer key*
-
attributes_url *if not available from discovery URL specified by oidc_issuer key*
-
jwks_uri *if not available from discovery URL specified by oidc_issuer key*
-
attributes_url_add_attributes *a read-only property that is set automatically*
-
-
For SAML providers:
-
MetadataFile OR MetadataURL
-
IDPSignout (optional)
-
3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3148 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The identity provider name.
3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3148 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |
#provider_type ⇒ String
The identity provider type.
3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3148 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3148 class CreateIdentityProviderRequest < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers) SENSITIVE = [] include Aws::Structure end |