Class: Aws::CognitoIdentityProvider::Types::CreateUserImportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateUserImportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to create the user import job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_logs_role_arn ⇒ String
You must specify an IAM role that has permission to log import-job results to Amazon CloudWatch Logs.
-
#job_name ⇒ String
A friendly name for the user import job.
-
#password_hashing_algorithm ⇒ String
The password hashing algorithm used to generate the hashes in the CSV file for this import job.
-
#user_pool_id ⇒ String
The ID of the user pool that you want to import users into.
Instance Attribute Details
#cloud_watch_logs_role_arn ⇒ String
You must specify an IAM role that has permission to log import-job results to Amazon CloudWatch Logs. This parameter is the ARN of that role.
4064 4065 4066 4067 4068 4069 4070 4071 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4064 class CreateUserImportJobRequest < Struct.new( :job_name, :user_pool_id, :cloud_watch_logs_role_arn, :password_hashing_algorithm) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
A friendly name for the user import job.
4064 4065 4066 4067 4068 4069 4070 4071 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4064 class CreateUserImportJobRequest < Struct.new( :job_name, :user_pool_id, :cloud_watch_logs_role_arn, :password_hashing_algorithm) SENSITIVE = [] include Aws::Structure end |
#password_hashing_algorithm ⇒ String
The password hashing algorithm used to generate the hashes in the CSV file for this import job.
Valid values: BCRYPT | SCRYPT | ARGON2ID | PBKDF2_SHA256
4064 4065 4066 4067 4068 4069 4070 4071 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4064 class CreateUserImportJobRequest < Struct.new( :job_name, :user_pool_id, :cloud_watch_logs_role_arn, :password_hashing_algorithm) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool that you want to import users into.
4064 4065 4066 4067 4068 4069 4070 4071 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4064 class CreateUserImportJobRequest < Struct.new( :job_name, :user_pool_id, :cloud_watch_logs_role_arn, :password_hashing_algorithm) SENSITIVE = [] include Aws::Structure end |