Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolClientRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateUserPoolClientRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass CreateUserPoolClientRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
client_name: "ClientNameType", # required
generate_secret: false,
refresh_token_validity: 1,
access_token_validity: 1,
id_token_validity: 1,
token_validity_units: {
access_token: "seconds", # accepts seconds, minutes, hours, days
id_token: "seconds", # accepts seconds, minutes, hours, days
refresh_token: "seconds", # accepts seconds, minutes, hours, days
},
read_attributes: ["ClientPermissionType"],
write_attributes: ["ClientPermissionType"],
explicit_auth_flows: ["ADMIN_NO_SRP_AUTH"], # accepts ADMIN_NO_SRP_AUTH, CUSTOM_AUTH_FLOW_ONLY, USER_PASSWORD_AUTH, ALLOW_ADMIN_USER_PASSWORD_AUTH, ALLOW_CUSTOM_AUTH, ALLOW_USER_PASSWORD_AUTH, ALLOW_USER_SRP_AUTH, ALLOW_REFRESH_TOKEN_AUTH
supported_identity_providers: ["ProviderNameType"],
callback_urls: ["RedirectUrlType"],
logout_urls: ["RedirectUrlType"],
default_redirect_uri: "RedirectUrlType",
allowed_o_auth_flows: ["code"], # accepts code, implicit, client_credentials
allowed_o_auth_scopes: ["ScopeType"],
allowed_o_auth_flows_user_pool_client: false,
analytics_configuration: {
application_id: "HexStringType",
application_arn: "ArnType",
role_arn: "ArnType",
external_id: "StringType",
user_data_shared: false,
},
prevent_user_existence_errors: "LEGACY", # accepts LEGACY, ENABLED
enable_token_revocation: false,
enable_propagate_additional_user_context_data: false,
}
Represents the request to create a user pool client.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_token_validity ⇒ Integer
The access token time limit.
-
#allowed_o_auth_flows ⇒ Array<String>
The allowed OAuth flows.
-
#allowed_o_auth_flows_user_pool_client ⇒ Boolean
Set to true if the client is allowed to follow the OAuth protocol when interacting with Amazon Cognito user pools.
-
#allowed_o_auth_scopes ⇒ Array<String>
The allowed OAuth scopes.
-
#analytics_configuration ⇒ Types::AnalyticsConfigurationType
The user pool analytics configuration for collecting metrics and sending them to your Amazon Pinpoint campaign.
-
#callback_urls ⇒ Array<String>
A list of allowed redirect (callback) URLs for the IdPs.
-
#client_name ⇒ String
The client name for the user pool client you would like to create.
-
#default_redirect_uri ⇒ String
The default redirect URI.
-
#enable_propagate_additional_user_context_data ⇒ Boolean
Activates the propagation of additional user context data.
-
#enable_token_revocation ⇒ Boolean
Activates or deactivates token revocation.
-
#explicit_auth_flows ⇒ Array<String>
The authentication flows that are supported by the user pool clients.
-
#generate_secret ⇒ Boolean
Boolean to specify whether you want to generate a secret for the user pool client being created.
-
#id_token_validity ⇒ Integer
The ID token time limit.
-
#logout_urls ⇒ Array<String>
A list of allowed logout URLs for the IdPs.
-
#prevent_user_existence_errors ⇒ String
Errors and responses that you want Amazon Cognito APIs to return during authentication, account confirmation, and password recovery when the user doesn't exist in the user pool.
-
#read_attributes ⇒ Array<String>
The read attributes.
-
#refresh_token_validity ⇒ Integer
The refresh token time limit.
-
#supported_identity_providers ⇒ Array<String>
A list of provider names for the identity providers (IdPs) that are supported on this client.
-
#token_validity_units ⇒ Types::TokenValidityUnitsType
The units in which the validity times are represented.
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to create a user pool client.
-
#write_attributes ⇒ Array<String>
The user pool attributes that the app client can write to.
Instance Attribute Details
#access_token_validity ⇒ Integer
The access token time limit. After this limit expires, your user can't use their access token. To specify the time unit for `AccessTokenValidity` as `seconds`, `minutes`, `hours`, or `days`, set a `TokenValidityUnits` value in your API request.
For example, when you set `AccessTokenValidity` to `10` and `TokenValidityUnits` to `hours`, your user can authorize access with their access token for 10 hours.
The default time unit for `AccessTokenValidity` in an API request is hours. *Valid range* is displayed below in seconds.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#allowed_o_auth_flows ⇒ Array<String>
The allowed OAuth flows.
code
: Use a code grant flow, which provides an authorization code as the
response. This code can be exchanged for access tokens with the
`/oauth2/token` endpoint.
implicit
: Issue the access token (and, optionally, ID token, based on
scopes) directly to your user.
client_credentials
: Issue the access token from the `/oauth2/token` endpoint directly
to a non-person user using a combination of the client ID and
client secret.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#allowed_o_auth_flows_user_pool_client ⇒ Boolean
Set to true if the client is allowed to follow the OAuth protocol when interacting with Amazon Cognito user pools.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#allowed_o_auth_scopes ⇒ Array<String>
The allowed OAuth scopes. Possible values provided by OAuth are `phone`, `email`, `openid`, and `profile`. Possible values provided by Amazon Web Services are `aws.cognito.signin.user.admin`. Custom scopes created in Resource Servers are also supported.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#analytics_configuration ⇒ Types::AnalyticsConfigurationType
The user pool analytics configuration for collecting metrics and sending them to your Amazon Pinpoint campaign.
<note markdown=“1”> In Amazon Web Services Regions where Amazon Pinpoint isn't available, user pools only support sending events to Amazon Pinpoint projects in Amazon Web Services Region us-east-1. In Regions where Amazon Pinpoint is available, user pools support sending events to Amazon Pinpoint projects within that same Region.
</note>
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#callback_urls ⇒ Array<String>
A list of allowed redirect (callback) URLs for the IdPs.
A redirect URI must:
-
Be an absolute URI.
-
Be registered with the authorization server.
-
Not include a fragment component.
See [OAuth 2.0 - Redirection Endpoint].
Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.
App callback URLs such as myapp://example are also supported.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#client_name ⇒ String
The client name for the user pool client you would like to create.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#default_redirect_uri ⇒ String
The default redirect URI. Must be in the `CallbackURLs` list.
A redirect URI must:
-
Be an absolute URI.
-
Be registered with the authorization server.
-
Not include a fragment component.
See [OAuth 2.0 - Redirection Endpoint].
Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.
App callback URLs such as myapp://example are also supported.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#enable_propagate_additional_user_context_data ⇒ Boolean
Activates the propagation of additional user context data. For more information about propagation of user context data, see [ Adding advanced security to a user pool]. If you don’t include this parameter, you can't send device fingerprint information, including source IP address, to Amazon Cognito advanced security. You can only activate `EnablePropagateAdditionalUserContextData` in an app client that has a client secret.
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pool-settings-advanced-security.html
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#enable_token_revocation ⇒ Boolean
Activates or deactivates token revocation. For more information about revoking tokens, see [RevokeToken].
If you don't include this parameter, token revocation is automatically activated for the new user pool client.
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RevokeToken.html
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#explicit_auth_flows ⇒ Array<String>
The authentication flows that are supported by the user pool clients. Flow names without the `ALLOW_` prefix are no longer supported, in favor of new names with the `ALLOW_` prefix.
<note markdown=“1”> Values with `ALLOW_` prefix must be used only along with the `ALLOW_` prefix.
</note>
Valid values include:
ALLOW_ADMIN_USER_PASSWORD_AUTH
: Enable admin based user password authentication flow
`ADMIN_USER_PASSWORD_AUTH`. This setting replaces the
`ADMIN_NO_SRP_AUTH` setting. With this authentication flow, Amazon
Cognito receives the password in the request instead of using the
Secure Remote Password (SRP) protocol to verify passwords.
ALLOW_CUSTOM_AUTH
: Enable Lambda trigger based authentication.
ALLOW_USER_PASSWORD_AUTH
: Enable user password-based authentication. In this flow, Amazon
Cognito receives the password in the request instead of using the
SRP protocol to verify passwords.
ALLOW_USER_SRP_AUTH
: Enable SRP-based authentication.
ALLOW_REFRESH_TOKEN_AUTH
: Enable the authflow that refreshes tokens.
If you don't specify a value for `ExplicitAuthFlows`, your user client supports `ALLOW_USER_SRP_AUTH` and `ALLOW_CUSTOM_AUTH`.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#generate_secret ⇒ Boolean
Boolean to specify whether you want to generate a secret for the user pool client being created.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#id_token_validity ⇒ Integer
The ID token time limit. After this limit expires, your user can't use their ID token. To specify the time unit for `IdTokenValidity` as `seconds`, `minutes`, `hours`, or `days`, set a `TokenValidityUnits` value in your API request.
For example, when you set `IdTokenValidity` as `10` and `TokenValidityUnits` as `hours`, your user can authenticate their session with their ID token for 10 hours.
The default time unit for `AccessTokenValidity` in an API request is hours. *Valid range* is displayed below in seconds.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#logout_urls ⇒ Array<String>
A list of allowed logout URLs for the IdPs.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#prevent_user_existence_errors ⇒ String
Errors and responses that you want Amazon Cognito APIs to return during authentication, account confirmation, and password recovery when the user doesn't exist in the user pool. When set to `ENABLED` and the user doesn't exist, authentication returns an error indicating either the username or password was incorrect. Account confirmation and password recovery return a response indicating a code was sent to a simulated destination. When set to `LEGACY`, those APIs return a `UserNotFoundException` exception if the user doesn't exist in the user pool.
Valid values include:
-
`ENABLED` - This prevents user existence-related errors.
-
`LEGACY` - This represents the early behavior of Amazon Cognito where user existence related errors aren't prevented.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#read_attributes ⇒ Array<String>
The read attributes.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#refresh_token_validity ⇒ Integer
The refresh token time limit. After this limit expires, your user can't use their refresh token. To specify the time unit for `RefreshTokenValidity` as `seconds`, `minutes`, `hours`, or `days`, set a `TokenValidityUnits` value in your API request.
For example, when you set `RefreshTokenValidity` as `10` and `TokenValidityUnits` as `days`, your user can refresh their session and retrieve new access and ID tokens for 10 days.
The default time unit for `RefreshTokenValidity` in an API request is days. You can't set `RefreshTokenValidity` to 0. If you do, Amazon Cognito overrides the value with the default value of 30 days. *Valid range* is displayed below in seconds.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#supported_identity_providers ⇒ Array<String>
A list of provider names for the identity providers (IdPs) that are supported on this client. The following are supported: `COGNITO`, `Facebook`, `Google`, `SignInWithApple`, and `LoginWithAmazon`. You can also specify the names that you configured for the SAML and OIDC IdPs in your user pool, for example `MySAMLIdP` or `MyOIDCIdP`.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#token_validity_units ⇒ Types::TokenValidityUnitsType
The units in which the validity times are represented. The default unit for RefreshToken is days, and default for ID and access tokens are hours.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to create a user pool client.
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |
#write_attributes ⇒ Array<String>
The user pool attributes that the app client can write to.
If your app client allows users to sign in through an IdP, this array must include all attributes that you have mapped to IdP attributes. Amazon Cognito updates mapped attributes when users sign in to your application through an IdP. If your app client does not have write access to a mapped attribute, Amazon Cognito throws an error when it tries to update the attribute. For more information, see [Specifying IdP Attribute Mappings for Your user pool].
3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3683 class CreateUserPoolClientRequest < Struct.new( :user_pool_id, :client_name, :generate_secret, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation, :enable_propagate_additional_user_context_data) SENSITIVE = [] include Aws::Structure end |