Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain.
-
#domain ⇒ String
The domain string.
-
#managed_login_version ⇒ Integer
The version of managed login branding that you want to apply to your domain.
-
#routing ⇒ Types::RoutingType
The configuration of routing for requests to the domain for replicas of a replicated user pool.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to add a domain.
Instance Attribute Details
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain. Configures your domain with
an Certificate Manager certificate in the us-east-1 Region.
Provide this parameter only if you want to use a custom domain for your user pool. Otherwise, you can omit this parameter and use a prefix domain instead.
When you create a custom domain, the passkey RP ID defaults to the custom domain. If you had a prefix domain active, this will cause passkey integration for your prefix domain to stop working due to a mismatch in RP ID. To keep the prefix domain passkey integration working, you can explicitly set RP ID to the prefix domain.
4571 4572 4573 4574 4575 4576 4577 4578 4579 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4571 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config, :routing) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The domain string. For custom domains, this is the fully-qualified
domain name, such as auth.example.com. For prefix domains, this is
the prefix alone, such as myprefix. A prefix value of myprefix
for a user pool in the us-east-1 Region results in a domain of
myprefix.auth.us-east-1.amazoncognito.com.
4571 4572 4573 4574 4575 4576 4577 4578 4579 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4571 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config, :routing) SENSITIVE = [] include Aws::Structure end |
#managed_login_version ⇒ Integer
The version of managed login branding that you want to apply to your
domain. A value of 1 indicates hosted UI (classic) and a version
of 2 indicates managed login.
Managed login requires that your user pool be configured for any
feature plan other than Lite.
4571 4572 4573 4574 4575 4576 4577 4578 4579 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4571 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config, :routing) SENSITIVE = [] include Aws::Structure end |
#routing ⇒ Types::RoutingType
The configuration of routing for requests to the domain for replicas of a replicated user pool. The routing configuration is currently only supported for custom domains.
4571 4572 4573 4574 4575 4576 4577 4578 4579 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4571 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config, :routing) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to add a domain.
4571 4572 4573 4574 4575 4576 4577 4578 4579 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4571 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config, :routing) SENSITIVE = [] include Aws::Structure end |