Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application.
-
#domain ⇒ String
The domain string.
-
#managed_login_version ⇒ Integer
The version of managed login branding that you want to apply to your domain.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to add a domain.
Instance Attribute Details
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application.
Provide this parameter only if you want to use a custom domain for your user pool. Otherwise, you can exclude this parameter and use the Amazon Cognito hosted domain instead.
For more information about the hosted domain and custom domains, see [Configuring a User Pool Domain].
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-assign-domain.html
4168 4169 4170 4171 4172 4173 4174 4175 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4168 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The domain string. For custom domains, this is the fully-qualified domain name, such as ‘auth.example.com`. For Amazon Cognito prefix domains, this is the prefix alone, such as `auth`.
4168 4169 4170 4171 4172 4173 4174 4175 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4168 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#managed_login_version ⇒ Integer
The version of managed login branding that you want to apply to your domain. A value of ‘1` indicates hosted UI (classic) branding and a version of `2` indicates managed login branding.
Managed login requires that your user pool be configured for any
- feature plan][1
-
other than ‘Lite`.
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-sign-in-feature-plans.html
4168 4169 4170 4171 4172 4173 4174 4175 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4168 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to add a domain.
4168 4169 4170 4171 4172 4173 4174 4175 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4168 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |