Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_domain_configTypes::CustomDomainConfigType

The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application.

Provide this parameter only if you want to use a custom domain for your user pool. Otherwise, you can exclude this parameter and use the Amazon Cognito hosted domain instead.

For more information about the hosted domain and custom domains, see [Configuring a User Pool Domain].

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-assign-domain.html



3380
3381
3382
3383
3384
3385
3386
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3380

class CreateUserPoolDomainRequest < Struct.new(
  :domain,
  :user_pool_id,
  :custom_domain_config)
  SENSITIVE = []
  include Aws::Structure
end

#domainString

The domain string. For custom domains, this is the fully-qualified domain name, such as ‘auth.example.com`. For Amazon Cognito prefix domains, this is the prefix alone, such as `auth`.

Returns:

  • (String)


3380
3381
3382
3383
3384
3385
3386
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3380

class CreateUserPoolDomainRequest < Struct.new(
  :domain,
  :user_pool_id,
  :custom_domain_config)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The user pool ID.

Returns:

  • (String)


3380
3381
3382
3383
3384
3385
3386
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3380

class CreateUserPoolDomainRequest < Struct.new(
  :domain,
  :user_pool_id,
  :custom_domain_config)
  SENSITIVE = []
  include Aws::Structure
end