Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass CreateUserPoolDomainRequest data as a hash:
{
domain: "DomainType", # required
user_pool_id: "UserPoolIdType", # required
custom_domain_config: {
certificate_arn: "ArnType", # required
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application.
-
#domain ⇒ String
The domain string.
-
#user_pool_id ⇒ String
The user pool ID.
Instance Attribute Details
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application.
Provide this parameter only if you want to use a custom domain for your user pool. Otherwise, you can exclude this parameter and use the Amazon Cognito hosted domain instead.
For more information about the hosted domain and custom domains, see [Configuring a User Pool Domain].
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-assign-domain.html
3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3762 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The domain string. For custom domains, this is the fully-qualified domain name, such as `auth.example.com`. For Amazon Cognito prefix domains, this is the prefix alone, such as `auth`.
3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3762 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3762 class CreateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |