Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_front_domain ⇒ String
The Amazon CloudFront endpoint that you use as the target of the alias that you set up with your Domain Name Service (DNS) provider.
Instance Attribute Details
#cloud_front_domain ⇒ String
The Amazon CloudFront endpoint that you use as the target of the alias that you set up with your Domain Name Service (DNS) provider.
3777 3778 3779 3780 3781 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3777 class CreateUserPoolDomainResponse < Struct.new( :cloud_front_domain) SENSITIVE = [] include Aws::Structure end |