Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolDomainResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_front_domainString

The Amazon CloudFront endpoint that you use as the target of the alias that you set up with your Domain Name Service (DNS) provider.

Returns:

  • (String)


3643
3644
3645
3646
3647
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 3643

class CreateUserPoolDomainResponse < Struct.new(
  :cloud_front_domain)
  SENSITIVE = []
  include Aws::Structure
end