Class: Aws::CognitoIdentityProvider::Types::CreateUserPoolReplicaRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#region_nameString

The Amazon Web Services Region where you want to create the replica user pool.

Returns:

  • (String)


4628
4629
4630
4631
4632
4633
4634
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4628

class CreateUserPoolReplicaRequest < Struct.new(
  :user_pool_id,
  :region_name,
  :user_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool to replicate.

Returns:

  • (String)


4628
4629
4630
4631
4632
4633
4634
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4628

class CreateUserPoolReplicaRequest < Struct.new(
  :user_pool_id,
  :region_name,
  :user_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_tagsHash<String,String>

A map of tags to assign to the replica user pool. Each tag consists of a key and an optional value, both of which you define. You can maintain tags independently on replica user pools.

Returns:

  • (Hash<String,String>)


4628
4629
4630
4631
4632
4633
4634
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4628

class CreateUserPoolReplicaRequest < Struct.new(
  :user_pool_id,
  :region_name,
  :user_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end