Class: Aws::CognitoIdentityProvider::Types::CustomDomainConfigType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The configuration for a custom domain, including the SSL certificate and TLS security policy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_arnString

The Amazon Resource Name (ARN) of an Certificate Manager SSL certificate. You use this certificate for the subdomain of your custom domain.

Returns:

  • (String)


4980
4981
4982
4983
4984
4985
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4980

class CustomDomainConfigType < Struct.new(
  :certificate_arn,
  :security_policy)
  SENSITIVE = []
  include Aws::Structure
end

#security_policyString

The security policy for the custom domain. Defines the minimum TLS version and cipher suites that CloudFront uses when communicating with viewers (clients). Valid values are as follows:

  • ‘TLS_V1`: Supports TLS 1.0 and later. Provides the broadest client compatibility.

  • ‘TLS_V1_2_2021`: Supports TLS 1.2 and later with 2021 cipher suites. Recommended minimum for most use cases.

  • ‘TLS_V1_3_2025`: Supports TLS 1.3 and later with 2025 cipher suites. Provides the strongest security posture.

Returns:

  • (String)


4980
4981
4982
4983
4984
4985
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4980

class CustomDomainConfigType < Struct.new(
  :certificate_arn,
  :security_policy)
  SENSITIVE = []
  include Aws::Structure
end