Class: Aws::CognitoIdentityProvider::Types::CustomDomainConfigType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass CustomDomainConfigType data as a hash:

{
  certificate_arn: "ArnType", # required
}

The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_arnString

The Amazon Resource Name (ARN) of an Certificate Manager SSL certificate. You use this certificate for the subdomain of your custom domain.

Returns:

  • (String)


4164
4165
4166
4167
4168
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4164

class CustomDomainConfigType < Struct.new(
  :certificate_arn)
  SENSITIVE = []
  include Aws::Structure
end