Class: Aws::CognitoIdentityProvider::Types::DeleteUserAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass DeleteUserAttributesRequest data as a hash:

{
  user_attribute_names: ["AttributeNameType"], # required
  access_token: "TokenModelType", # required
}

Represents the request to delete user attributes.

Constant Summary collapse

SENSITIVE =
[:access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A valid access token that Amazon Cognito issued to the user whose attributes you want to delete.

Returns:

  • (String)


4330
4331
4332
4333
4334
4335
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4330

class DeleteUserAttributesRequest < Struct.new(
  :user_attribute_names,
  :access_token)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#user_attribute_namesArray<String>

An array of strings representing the user attribute names you want to delete.

For custom attributes, you must prependattach the `custom:` prefix to the front of the attribute name.

Returns:

  • (Array<String>)


4330
4331
4332
4333
4334
4335
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4330

class DeleteUserAttributesRequest < Struct.new(
  :user_attribute_names,
  :access_token)
  SENSITIVE = [:access_token]
  include Aws::Structure
end