Class: Aws::CognitoIdentityProvider::Types::DeleteUserAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DeleteUserAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass DeleteUserAttributesRequest data as a hash:
{
user_attribute_names: ["AttributeNameType"], # required
access_token: "TokenModelType", # required
}
Represents the request to delete user attributes.
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token used in the request to delete user attributes.
-
#user_attribute_names ⇒ Array<String>
An array of strings representing the user attribute names you want to delete.
Instance Attribute Details
#access_token ⇒ String
The access token used in the request to delete user attributes.
4109 4110 4111 4112 4113 4114 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4109 class DeleteUserAttributesRequest < Struct.new( :user_attribute_names, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |
#user_attribute_names ⇒ Array<String>
An array of strings representing the user attribute names you want to delete.
For custom attributes, you must prependattach the `custom:` prefix to the front of the attribute name.
4109 4110 4111 4112 4113 4114 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4109 class DeleteUserAttributesRequest < Struct.new( :user_attribute_names, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |