Class: Aws::CognitoIdentityProvider::Types::DeleteUserPoolReplicaRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DeleteUserPoolReplicaRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#region_name ⇒ String
The Amazon Web Services Region of the replica to delete.
-
#user_pool_id ⇒ String
The ID of the user pool that contains the replica to delete.
Instance Attribute Details
#region_name ⇒ String
The Amazon Web Services Region of the replica to delete.
5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5223 class DeleteUserPoolReplicaRequest < Struct.new( :user_pool_id, :region_name) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool that contains the replica to delete.
5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5223 class DeleteUserPoolReplicaRequest < Struct.new( :user_pool_id, :region_name) SENSITIVE = [] include Aws::Structure end |