Class: Aws::CognitoIdentityProvider::Types::DeleteWebAuthnCredentialRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A valid access token that Amazon Cognito issued to the user whose passkey you want to delete.

Returns:

  • (String)


4728
4729
4730
4731
4732
4733
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4728

class DeleteWebAuthnCredentialRequest < Struct.new(
  :access_token,
  :credential_id)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#credential_idString

The unique identifier of the passkey that you want to delete. Look up registered devices with [ ListWebAuthnCredentials].

[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListWebAuthnCredentials.html

Returns:

  • (String)


4728
4729
4730
4731
4732
4733
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4728

class DeleteWebAuthnCredentialRequest < Struct.new(
  :access_token,
  :credential_id)
  SENSITIVE = [:access_token]
  include Aws::Structure
end