Class: Aws::CognitoIdentityProvider::Types::DescribeRiskConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DescribeRiskConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:client_id]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The ID of the app client with the risk configuration that you want to inspect.
-
#user_pool_id ⇒ String
The ID of the user pool with the risk configuration that you want to inspect.
Instance Attribute Details
#client_id ⇒ String
The ID of the app client with the risk configuration that you want to inspect. You can apply default risk configuration at the user pool level and further customize it from user pool defaults at the app-client level. Specify ‘ClientId` to inspect client-level configuration, or `UserPoolId` to inspect pool-level configuration.
5350 5351 5352 5353 5354 5355 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5350 class DescribeRiskConfigurationRequest < Struct.new( :user_pool_id, :client_id) SENSITIVE = [:client_id] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool with the risk configuration that you want to inspect. You can apply default risk configuration at the user pool level and further customize it from user pool defaults at the app-client level. Specify ‘ClientId` to inspect client-level configuration, or `UserPoolId` to inspect pool-level configuration.
5350 5351 5352 5353 5354 5355 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5350 class DescribeRiskConfigurationRequest < Struct.new( :user_pool_id, :client_id) SENSITIVE = [:client_id] include Aws::Structure end |