Class: Aws::CognitoIdentityProvider::Types::DeviceConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DeviceConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass DeviceConfigurationType data as a hash:
{
challenge_required_on_new_device: false,
device_only_remembered_on_user_prompt: false,
}
The device-remembering configuration for a user pool. A null value indicates that you have deactivated device remembering in your user pool.
<note markdown=“1”> When you provide a value for any `DeviceConfiguration` field, you activate the Amazon Cognito device-remembering feature.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#challenge_required_on_new_device ⇒ Boolean
When true, device authentication can replace SMS and time-based one-time password (TOTP) factors for multi-factor authentication (MFA).
-
#device_only_remembered_on_user_prompt ⇒ Boolean
When true, Amazon Cognito doesn't remember newly-confirmed devices.
Instance Attribute Details
#challenge_required_on_new_device ⇒ Boolean
When true, device authentication can replace SMS and time-based one-time password (TOTP) factors for multi-factor authentication (MFA).
<note markdown=“1”> Regardless of the value of this field, users that sign in with new devices that have not been confirmed or remembered must provide a second factor if your user pool requires MFA.
</note>
4718 4719 4720 4721 4722 4723 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4718 class DeviceConfigurationType < Struct.new( :challenge_required_on_new_device, :device_only_remembered_on_user_prompt) SENSITIVE = [] include Aws::Structure end |
#device_only_remembered_on_user_prompt ⇒ Boolean
When true, Amazon Cognito doesn't remember newly-confirmed devices. Users who want to authenticate with their device can instead opt in to remembering their device. To collect a choice from your user, create an input prompt in your app and return the value that the user chooses in an [UpdateDeviceStatus] API request.
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateDeviceStatus.html
4718 4719 4720 4721 4722 4723 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4718 class DeviceConfigurationType < Struct.new( :challenge_required_on_new_device, :device_only_remembered_on_user_prompt) SENSITIVE = [] include Aws::Structure end |