Class: Aws::CognitoIdentityProvider::Types::DeviceConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DeviceConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass DeviceConfigurationType data as a hash:
{
challenge_required_on_new_device: false,
device_only_remembered_on_user_prompt: false,
}
The device tracking configuration for a user pool. A user pool with device tracking deactivated returns a null value.
<note markdown=“1”> When you provide values for any DeviceConfiguration field, you activate device tracking.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#challenge_required_on_new_device ⇒ Boolean
When true, device authentication can replace SMS and time-based one-time password (TOTP) factors for multi-factor authentication (MFA).
-
#device_only_remembered_on_user_prompt ⇒ Boolean
When true, users can opt in to remembering their device.
Instance Attribute Details
#challenge_required_on_new_device ⇒ Boolean
When true, device authentication can replace SMS and time-based one-time password (TOTP) factors for multi-factor authentication (MFA).
<note markdown=“1”> Users that sign in with devices that have not been confirmed or remembered will still have to provide a second factor, whether or not ChallengeRequiredOnNewDevice is true, when your user pool requires MFA.
</note>
4551 4552 4553 4554 4555 4556 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4551 class DeviceConfigurationType < Struct.new( :challenge_required_on_new_device, :device_only_remembered_on_user_prompt) SENSITIVE = [] include Aws::Structure end |
#device_only_remembered_on_user_prompt ⇒ Boolean
When true, users can opt in to remembering their device. Your app code must use callback functions to return the user's choice.
4551 4552 4553 4554 4555 4556 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4551 class DeviceConfigurationType < Struct.new( :challenge_required_on_new_device, :device_only_remembered_on_user_prompt) SENSITIVE = [] include Aws::Structure end |