Class: Aws::CognitoIdentityProvider::Types::DomainDescriptionType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DomainDescriptionType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A container for information about the user pool domain associated with the hosted UI and OAuth endpoints.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account that you created the user pool in.
-
#cloud_front_distribution ⇒ String
The Amazon CloudFront endpoint that hosts your custom domain.
-
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application.
-
#domain ⇒ String
The domain string.
-
#managed_login_version ⇒ Integer
The version of managed login branding that you want to apply to your domain.
-
#routing ⇒ Types::RoutingType
The routing configuration for the domain, including failover settings for multi-region deployments.
-
#s3_bucket ⇒ String
The Amazon S3 bucket where the static files for this domain are stored.
-
#status ⇒ String
The domain status.
-
#user_pool_id ⇒ String
The ID of the user pool that the domain is attached to.
-
#version ⇒ String
The app version.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account that you created the user pool in.
5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5861 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config, :managed_login_version, :routing) SENSITIVE = [] include Aws::Structure end |
#cloud_front_distribution ⇒ String
The Amazon CloudFront endpoint that hosts your custom domain.
5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5861 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config, :managed_login_version, :routing) SENSITIVE = [] include Aws::Structure end |
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application.
5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5861 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config, :managed_login_version, :routing) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The domain string. For custom domains, this is the fully-qualified
domain name, such as auth.example.com. For Amazon Cognito prefix
domains, this is the prefix alone, such as auth.
5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5861 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config, :managed_login_version, :routing) SENSITIVE = [] include Aws::Structure end |
#managed_login_version ⇒ Integer
The version of managed login branding that you want to apply to your
domain. A value of 1 indicates hosted UI (classic) branding and a
version of 2 indicates managed login branding.
Managed login requires that your user pool be configured for any
feature plan other than Lite.
5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5861 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config, :managed_login_version, :routing) SENSITIVE = [] include Aws::Structure end |
#routing ⇒ Types::RoutingType
The routing configuration for the domain, including failover
settings for multi-region deployments. Currently only Failover
configurations are allowed.
5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5861 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config, :managed_login_version, :routing) SENSITIVE = [] include Aws::Structure end |
#s3_bucket ⇒ String
The Amazon S3 bucket where the static files for this domain are stored.
5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5861 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config, :managed_login_version, :routing) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The domain status.
5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5861 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config, :managed_login_version, :routing) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool that the domain is attached to.
5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5861 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config, :managed_login_version, :routing) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The app version.
5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5861 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config, :managed_login_version, :routing) SENSITIVE = [] include Aws::Structure end |