Class: Aws::CognitoIdentityProvider::Types::DomainDescriptionType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::DomainDescriptionType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A container for information about a domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services ID for the user pool owner.
-
#cloud_front_distribution ⇒ String
The Amazon Resource Name (ARN) of the Amazon CloudFront distribution.
-
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application.
-
#domain ⇒ String
The domain string.
-
#s3_bucket ⇒ String
The Amazon S3 bucket where the static files for this domain are stored.
-
#status ⇒ String
The domain status.
-
#user_pool_id ⇒ String
The user pool ID.
-
#version ⇒ String
The app version.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services ID for the user pool owner.
4809 4810 4811 4812 4813 4814 4815 4816 4817 4818 4819 4820 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4809 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#cloud_front_distribution ⇒ String
The Amazon Resource Name (ARN) of the Amazon CloudFront distribution.
4809 4810 4811 4812 4813 4814 4815 4816 4817 4818 4819 4820 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4809 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application.
4809 4810 4811 4812 4813 4814 4815 4816 4817 4818 4819 4820 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4809 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The domain string. For custom domains, this is the fully-qualified domain name, such as `auth.example.com`. For Amazon Cognito prefix domains, this is the prefix alone, such as `auth`.
4809 4810 4811 4812 4813 4814 4815 4816 4817 4818 4819 4820 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4809 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#s3_bucket ⇒ String
The Amazon S3 bucket where the static files for this domain are stored.
4809 4810 4811 4812 4813 4814 4815 4816 4817 4818 4819 4820 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4809 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The domain status.
4809 4810 4811 4812 4813 4814 4815 4816 4817 4818 4819 4820 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4809 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
4809 4810 4811 4812 4813 4814 4815 4816 4817 4818 4819 4820 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4809 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The app version.
4809 4810 4811 4812 4813 4814 4815 4816 4817 4818 4819 4820 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 4809 class DomainDescriptionType < Struct.new( :user_pool_id, :aws_account_id, :domain, :s3_bucket, :cloud_front_distribution, :version, :status, :custom_domain_config) SENSITIVE = [] include Aws::Structure end |