Class: Aws::CognitoIdentityProvider::Types::EmailMfaSettingsType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::EmailMfaSettingsType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
User preferences for multi-factor authentication with email messages. Activates or deactivates email MFA and sets it as the preferred MFA method when multiple methods are available. To activate this setting, your user pool must be in the [ Essentials tier] or higher.
[1]: docs.aws.amazon.com/cognito/latest/developerguide/feature-plans-features-essentials.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Specifies whether email message MFA is active for a user.
-
#preferred_mfa ⇒ Boolean
Specifies whether email message MFA is the user’s preferred method.
Instance Attribute Details
#enabled ⇒ Boolean
Specifies whether email message MFA is active for a user. When the value of this parameter is ‘Enabled`, the user will be prompted for MFA during all sign-in attempts, unless device tracking is turned on and the device has been trusted.
5948 5949 5950 5951 5952 5953 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5948 class EmailMfaSettingsType < Struct.new( :enabled, :preferred_mfa) SENSITIVE = [] include Aws::Structure end |
#preferred_mfa ⇒ Boolean
Specifies whether email message MFA is the user’s preferred method.
5948 5949 5950 5951 5952 5953 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5948 class EmailMfaSettingsType < Struct.new( :enabled, :preferred_mfa) SENSITIVE = [] include Aws::Structure end |