Class: Aws::CognitoIdentityProvider::Types::EventRiskType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::EventRiskType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The risk evaluation by adaptive authentication, as displayed in an
AdminListUserAuthEvents response. Contains evaluations of
compromised-credentials detection and assessed risk level and action
taken by adaptive authentication.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compromised_credentials_detected ⇒ Boolean
Indicates whether compromised credentials were detected during an authentication event.
-
#risk_decision ⇒ String
The action taken by adaptive authentication.
-
#risk_level ⇒ String
The risk level that adaptive authentication assessed for the authentication event.
Instance Attribute Details
#compromised_credentials_detected ⇒ Boolean
Indicates whether compromised credentials were detected during an authentication event.
6177 6178 6179 6180 6181 6182 6183 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6177 class EventRiskType < Struct.new( :risk_decision, :risk_level, :compromised_credentials_detected) SENSITIVE = [] include Aws::Structure end |
#risk_decision ⇒ String
The action taken by adaptive authentication. If NoRisk, your user
pool took no action. If AccountTakeover, your user pool applied
the adaptive authentication automated response that you configured.
If Block, your user pool prevented the attempt.
6177 6178 6179 6180 6181 6182 6183 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6177 class EventRiskType < Struct.new( :risk_decision, :risk_level, :compromised_credentials_detected) SENSITIVE = [] include Aws::Structure end |
#risk_level ⇒ String
The risk level that adaptive authentication assessed for the authentication event.
6177 6178 6179 6180 6181 6182 6183 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6177 class EventRiskType < Struct.new( :risk_decision, :risk_level, :compromised_credentials_detected) SENSITIVE = [] include Aws::Structure end |