Class: Aws::CognitoIdentityProvider::Types::FailoverType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Specifies failover configuration for multi-region user pool domains. Contains settings for the secondary region and health check configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#primary_route_53_health_check_idString

The ID of the Amazon Web Services Route53 healthcheck that controls routing. If the healthcheck is healthy, traffic will be routed to the primary replica, and if the healthcheck is unhealthy, traffic will be routed to the secondary region.

Returns:

  • (String)


6200
6201
6202
6203
6204
6205
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6200

class FailoverType < Struct.new(
  :secondary_region,
  :primary_route_53_health_check_id)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_regionString

The secondary Amazon Web Services Region to use for failover when the primary region becomes unavailable.

Returns:

  • (String)


6200
6201
6202
6203
6204
6205
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6200

class FailoverType < Struct.new(
  :secondary_region,
  :primary_route_53_health_check_id)
  SENSITIVE = []
  include Aws::Structure
end