Class: Aws::CognitoIdentityProvider::Types::GetCSVHeaderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::GetCSVHeaderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass GetCSVHeaderRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
}
Represents the request to get the header information of the CSV file for the user import job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#user_pool_id ⇒ String
The user pool ID for the user pool that the users are to be imported into.
Instance Attribute Details
#user_pool_id ⇒ String
The user pool ID for the user pool that the users are to be imported into.
5085 5086 5087 5088 5089 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5085 class GetCSVHeaderRequest < Struct.new( :user_pool_id) SENSITIVE = [] include Aws::Structure end |