Class: Aws::CognitoIdentityProvider::Types::GetIdentityProviderByIdentifierRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idp_identifierString

The identifier that you assigned to your user pool. The identifier is an alternative name for an IdP that is distinct from the IdP name. For example, an IdP with a name of MyIdP might have an identifier of the email domain example.com.

Returns:

  • (String)


6639
6640
6641
6642
6643
6644
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6639

class GetIdentityProviderByIdentifierRequest < Struct.new(
  :user_pool_id,
  :idp_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The ID of the user pool where you want to get information about the IdP.

Returns:

  • (String)


6639
6640
6641
6642
6643
6644
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6639

class GetIdentityProviderByIdentifierRequest < Struct.new(
  :user_pool_id,
  :idp_identifier)
  SENSITIVE = []
  include Aws::Structure
end