Class: Aws::CognitoIdentityProvider::Types::GetIdentityProviderByIdentifierRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::GetIdentityProviderByIdentifierRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#idp_identifier ⇒ String
The identifier that you assigned to your user pool.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to get information about the IdP.
Instance Attribute Details
#idp_identifier ⇒ String
The identifier that you assigned to your user pool. The identifier is an alternative name for an IdP that is distinct from the IdP name. For example, an IdP with a name of ‘MyIdP` might have an identifier of the email domain `example.com`.
6505 6506 6507 6508 6509 6510 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6505 class GetIdentityProviderByIdentifierRequest < Struct.new( :user_pool_id, :idp_identifier) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to get information about the IdP.
6505 6506 6507 6508 6509 6510 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6505 class GetIdentityProviderByIdentifierRequest < Struct.new( :user_pool_id, :idp_identifier) SENSITIVE = [] include Aws::Structure end |