Class: Aws::CognitoIdentityProvider::Types::GetUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::GetUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass GetUserRequest data as a hash:
{
access_token: "TokenModelType", # required
}
Represents the request to get information about the user.
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token returned by the server response to get information about the user.
Instance Attribute Details
#access_token ⇒ String
The access token returned by the server response to get information about the user.
5495 5496 5497 5498 5499 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5495 class GetUserRequest < Struct.new( :access_token) SENSITIVE = [:access_token] include Aws::Structure end |