Class: Aws::CognitoIdentityProvider::Types::IdentityProviderType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::IdentityProviderType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A container for information about an identity provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_mapping ⇒ Hash<String,String>
A mapping of identity provider attributes to standard and custom user pool attributes.
-
#creation_date ⇒ Time
The date the identity provider was created.
-
#idp_identifiers ⇒ Array<String>
A list of identity provider identifiers.
-
#last_modified_date ⇒ Time
The date the identity provider was last modified.
-
#provider_details ⇒ Hash<String,String>
The identity provider details.
-
#provider_name ⇒ String
The identity provider name.
-
#provider_type ⇒ String
The identity provider type.
-
#user_pool_id ⇒ String
The user pool ID.
Instance Attribute Details
#attribute_mapping ⇒ Hash<String,String>
A mapping of identity provider attributes to standard and custom user pool attributes.
5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5774 class IdentityProviderType < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date the identity provider was created.
5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5774 class IdentityProviderType < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#idp_identifiers ⇒ Array<String>
A list of identity provider identifiers.
5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5774 class IdentityProviderType < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date the identity provider was last modified.
5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5774 class IdentityProviderType < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#provider_details ⇒ Hash<String,String>
The identity provider details. The following list describes the provider detail keys for each identity provider type.
-
For Google and Login with Amazon:
-
client_id
-
client_secret
-
authorize_scopes
-
-
For Facebook:
-
client_id
-
client_secret
-
authorize_scopes
-
api_version
-
-
For Sign in with Apple:
-
client_id
-
team_id
-
key_id
-
private_key
-
authorize_scopes
-
-
For OIDC providers:
-
client_id
-
client_secret
-
attributes_request_method
-
oidc_issuer
-
authorize_scopes
-
authorize_url *if not available from discovery URL specified by oidc_issuer key*
-
token_url *if not available from discovery URL specified by oidc_issuer key*
-
attributes_url *if not available from discovery URL specified by oidc_issuer key*
-
jwks_uri *if not available from discovery URL specified by oidc_issuer key*
-
attributes_url_add_attributes *a read-only property that is set automatically*
-
-
For SAML providers:
-
MetadataFile or MetadataURL
-
IDPSignOut optional
-
5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5774 class IdentityProviderType < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The identity provider name.
5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5774 class IdentityProviderType < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#provider_type ⇒ String
The identity provider type.
5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5774 class IdentityProviderType < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5774 class IdentityProviderType < Struct.new( :user_pool_id, :provider_name, :provider_type, :provider_details, :attribute_mapping, :idp_identifiers, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |