Class: Aws::CognitoIdentityProvider::Types::IdentityProviderType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

A container for information about an identity provider.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_mappingHash<String,String>

A mapping of identity provider attributes to standard and custom user pool attributes.

Returns:

  • (Hash<String,String>)


5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5729

class IdentityProviderType < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers,
  :last_modified_date,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date the identity provider was created.

Returns:

  • (Time)


5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5729

class IdentityProviderType < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers,
  :last_modified_date,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#idp_identifiersArray<String>

A list of identity provider identifiers.

Returns:

  • (Array<String>)


5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5729

class IdentityProviderType < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers,
  :last_modified_date,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The date the identity provider was last modified.

Returns:

  • (Time)


5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5729

class IdentityProviderType < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers,
  :last_modified_date,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#provider_detailsHash<String,String>

The identity provider details. The following list describes the provider detail keys for each identity provider type.

  • For Google and Login with Amazon:

    • client_id

    • client_secret

    • authorize_scopes

  • For Facebook:

    • client_id

    • client_secret

    • authorize_scopes

    • api_version

  • For Sign in with Apple:

    • client_id

    • team_id

    • key_id

    • private_key

    • authorize_scopes

  • For OIDC providers:

    • client_id

    • client_secret

    • attributes_request_method

    • oidc_issuer

    • authorize_scopes

    • authorize_url *if not available from discovery URL specified by oidc_issuer key*

    • token_url *if not available from discovery URL specified by oidc_issuer key*

    • attributes_url *if not available from discovery URL specified by oidc_issuer key*

    • jwks_uri *if not available from discovery URL specified by oidc_issuer key*

    • attributes_url_add_attributes *a read-only property that is set automatically*

  • For SAML providers:

    • MetadataFile or MetadataURL

    • IDPSignOut optional

Returns:

  • (Hash<String,String>)


5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5729

class IdentityProviderType < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers,
  :last_modified_date,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#provider_nameString

The identity provider name.

Returns:

  • (String)


5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5729

class IdentityProviderType < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers,
  :last_modified_date,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#provider_typeString

The identity provider type.

Returns:

  • (String)


5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5729

class IdentityProviderType < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers,
  :last_modified_date,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The user pool ID.

Returns:

  • (String)


5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5729

class IdentityProviderType < Struct.new(
  :user_pool_id,
  :provider_name,
  :provider_type,
  :provider_details,
  :attribute_mapping,
  :idp_identifiers,
  :last_modified_date,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end