Class: Aws::CognitoIdentityProvider::Types::InitiateAuthRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::InitiateAuthRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Initiates the authentication request.
Constant Summary collapse
- SENSITIVE =
[:auth_parameters, :client_id, :user_context_data, :session]
Instance Attribute Summary collapse
-
#analytics_metadata ⇒ Types::AnalyticsMetadataType
The Amazon Pinpoint analytics metadata that contributes to your metrics for ‘InitiateAuth` calls.
-
#auth_flow ⇒ String
The authentication flow that you want to initiate.
-
#auth_parameters ⇒ Hash<String,String>
The authentication parameters.
-
#client_id ⇒ String
The app client ID.
-
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for certain custom workflows that this action triggers.
-
#session ⇒ String
The optional session ID from a ‘ConfirmSignUp` API request.
-
#user_context_data ⇒ Types::UserContextDataType
Contextual data about your user session, such as the device fingerprint, IP address, or location.
Instance Attribute Details
#analytics_metadata ⇒ Types::AnalyticsMetadataType
The Amazon Pinpoint analytics metadata that contributes to your metrics for ‘InitiateAuth` calls.
6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6802 class InitiateAuthRequest < Struct.new( :auth_flow, :auth_parameters, :client_metadata, :client_id, :analytics_metadata, :user_context_data, :session) SENSITIVE = [:auth_parameters, :client_id, :user_context_data, :session] include Aws::Structure end |
#auth_flow ⇒ String
The authentication flow that you want to initiate. The ‘AuthParameters` that you must submit are linked to the flow that you submit. For example:
-
‘USER_AUTH`: Request a preferred authentication type or review available authentication types. From the offered authentication types, select one in a challenge response and then authenticate with that method in an additional challenge response.
-
‘REFRESH_TOKEN_AUTH`: Receive new ID and access tokens when you pass a `REFRESH_TOKEN` parameter with a valid refresh token as the value.
-
‘USER_SRP_AUTH`: Receive secure remote password (SRP) variables for the next challenge, `PASSWORD_VERIFIER`, when you pass `USERNAME` and `SRP_A` parameters.
-
‘USER_PASSWORD_AUTH`: Receive new tokens or the next challenge, for example `SOFTWARE_TOKEN_MFA`, when you pass `USERNAME` and `PASSWORD` parameters.
Valid values include the following:
USER_AUTH
: The entry point for sign-in with passwords, one-time passwords,
biometric devices, and security keys.
USER_SRP_AUTH
: Username-password authentication with the Secure Remote Password
(SRP) protocol. For more information, see [Use SRP password
verification in custom authentication flow][1].
REFRESH_TOKEN_AUTH and REFRESH_TOKEN
: Provide a valid refresh token and receive new ID and access
tokens. For more information, see [Using the refresh token][2].
CUSTOM_AUTH
: Custom authentication with Lambda triggers. For more information,
see [Custom authentication challenge Lambda triggers][3].
USER_PASSWORD_AUTH
: Username-password authentication with the password sent directly
in the request. For more information, see [Admin authentication
flow][4].
‘ADMIN_USER_PASSWORD_AUTH` is a flow type of [AdminInitiateAuth] and isn’t valid for InitiateAuth. ‘ADMIN_NO_SRP_AUTH` is a legacy server-side username-password flow and isn’t valid for InitiateAuth.
[1]: docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-authentication-flow.html#Using-SRP-password-verification-in-custom-authentication-flow [2]: docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-using-the-refresh-token.html [3]: docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-challenge.html [4]: docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-authentication-flow.html#Built-in-authentication-flow-and-challenges [5]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminInitiateAuth.html
6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6802 class InitiateAuthRequest < Struct.new( :auth_flow, :auth_parameters, :client_metadata, :client_id, :analytics_metadata, :user_context_data, :session) SENSITIVE = [:auth_parameters, :client_id, :user_context_data, :session] include Aws::Structure end |
#auth_parameters ⇒ Hash<String,String>
The authentication parameters. These are inputs corresponding to the ‘AuthFlow` that you’re invoking. The required values depend on the value of ‘AuthFlow`:
-
For ‘USER_AUTH`: `USERNAME` (required), `PREFERRED_CHALLENGE`. If you don’t provide a value for ‘PREFERRED_CHALLENGE`, Amazon Cognito responds with the `AvailableChallenges` parameter that specifies the available sign-in methods.
-
For ‘USER_SRP_AUTH`: `USERNAME` (required), `SRP_A` (required), `SECRET_HASH` (required if the app client is configured with a client secret), `DEVICE_KEY`.
-
For ‘USER_PASSWORD_AUTH`: `USERNAME` (required), `PASSWORD` (required), `SECRET_HASH` (required if the app client is configured with a client secret), `DEVICE_KEY`.
-
For ‘REFRESH_TOKEN_AUTH/REFRESH_TOKEN`: `REFRESH_TOKEN` (required), `SECRET_HASH` (required if the app client is configured with a client secret), `DEVICE_KEY`.
-
For ‘CUSTOM_AUTH`: `USERNAME` (required), `SECRET_HASH` (if app client is configured with client secret), `DEVICE_KEY`. To start the authentication flow with password verification, include `ChallengeName: SRP_A` and `SRP_A: (The SRP_A Value)`.
For more information about ‘SECRET_HASH`, see [Computing secret hash values]. For information about `DEVICE_KEY`, see [Working with user devices in your user pool].
[1]: docs.aws.amazon.com/cognito/latest/developerguide/signing-up-users-in-your-app.html#cognito-user-pools-computing-secret-hash [2]: docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-device-tracking.html
6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6802 class InitiateAuthRequest < Struct.new( :auth_flow, :auth_parameters, :client_metadata, :client_id, :analytics_metadata, :user_context_data, :session) SENSITIVE = [:auth_parameters, :client_id, :user_context_data, :session] include Aws::Structure end |
#client_id ⇒ String
The app client ID.
6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6802 class InitiateAuthRequest < Struct.new( :auth_flow, :auth_parameters, :client_metadata, :client_id, :analytics_metadata, :user_context_data, :session) SENSITIVE = [:auth_parameters, :client_id, :user_context_data, :session] include Aws::Structure end |
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for certain custom workflows that this action triggers.
You create custom workflows by assigning Lambda functions to user pool triggers. When you use the InitiateAuth API action, Amazon Cognito invokes the Lambda functions that are specified for various triggers. The ClientMetadata value is passed as input to the functions for only the following triggers:
-
Pre signup
-
Pre authentication
-
User migration
When Amazon Cognito invokes the functions for these triggers, it passes a JSON payload, which the function receives as input. This payload contains a ‘validationData` attribute, which provides the data that you assigned to the ClientMetadata parameter in your InitiateAuth request. In your function code in Lambda, you can process the `validationData` value to enhance your workflow for your specific needs.
When you use the InitiateAuth API action, Amazon Cognito also invokes the functions for the following triggers, but it doesn’t provide the ClientMetadata value as input:
-
Post authentication
-
Custom message
-
Pre token generation
-
Create auth challenge
-
Define auth challenge
-
Custom email sender
-
Custom SMS sender
For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.
<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won’t do the following:
* Store the ClientMetadata value. This data is available only to
Lambda triggers that are assigned to a user pool to support custom
workflows. If your user pool configuration doesn't include
triggers, the ClientMetadata parameter serves no purpose.
-
Validate the ClientMetadata value.
-
Encrypt the ClientMetadata value. Don’t use Amazon Cognito to provide sensitive information.
</note>
6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6802 class InitiateAuthRequest < Struct.new( :auth_flow, :auth_parameters, :client_metadata, :client_id, :analytics_metadata, :user_context_data, :session) SENSITIVE = [:auth_parameters, :client_id, :user_context_data, :session] include Aws::Structure end |
#session ⇒ String
The optional session ID from a ‘ConfirmSignUp` API request. You can sign in a user directly from the sign-up process with the `USER_AUTH` authentication flow.
6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6802 class InitiateAuthRequest < Struct.new( :auth_flow, :auth_parameters, :client_metadata, :client_id, :analytics_metadata, :user_context_data, :session) SENSITIVE = [:auth_parameters, :client_id, :user_context_data, :session] include Aws::Structure end |
#user_context_data ⇒ Types::UserContextDataType
Contextual data about your user session, such as the device fingerprint, IP address, or location. Amazon Cognito advanced security evaluates the risk of an authentication event based on the context that your app generates and passes to Amazon Cognito when it makes API requests.
6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6802 class InitiateAuthRequest < Struct.new( :auth_flow, :auth_parameters, :client_metadata, :client_id, :analytics_metadata, :user_context_data, :session) SENSITIVE = [:auth_parameters, :client_id, :user_context_data, :session] include Aws::Structure end |