Class: Aws::CognitoIdentityProvider::Types::InvalidEmailRoleAccessPolicyException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::InvalidEmailRoleAccessPolicyException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
This exception is thrown when Amazon Cognito isn’t allowed to use your email identity. HTTP status code: 400.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The message returned when you have an unverified email address or the identity policy isn’t set on an email address that Amazon Cognito can access.
Instance Attribute Details
#message ⇒ String
The message returned when you have an unverified email address or the identity policy isn’t set on an email address that Amazon Cognito can access.
5229 5230 5231 5232 5233 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5229 class InvalidEmailRoleAccessPolicyException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |