Class: Aws::CognitoIdentityProvider::Types::LambdaConfigType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Specifies the configuration for Lambda triggers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_auth_challengeString

Creates an authentication challenge.

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#custom_email_senderTypes::CustomEmailLambdaVersionConfigType

A custom email sender Lambda trigger.



5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#custom_messageString

A custom Message Lambda trigger.

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#custom_sms_senderTypes::CustomSMSLambdaVersionConfigType

A custom SMS sender Lambda trigger.



5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#define_auth_challengeString

Defines the authentication challenge.

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Resource Name (ARN) of an [KMS key](/kms/latest/developerguide/concepts.html#master_keys). Amazon Cognito uses the key to encrypt codes and temporary passwords sent to ‘CustomEmailSender` and `CustomSMSSender`.

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#post_authenticationString

A post-authentication Lambda trigger.

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#post_confirmationString

A post-confirmation Lambda trigger.

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#pre_authenticationString

A pre-authentication Lambda trigger.

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#pre_sign_upString

A pre-registration Lambda trigger.

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#pre_token_generationString

The Amazon Resource Name (ARN) of the function that you want to assign to your Lambda trigger.

Set this parameter for legacy purposes. If you also set an ARN in ‘PreTokenGenerationConfig`, its value must be identical to `PreTokenGeneration`. For new instances of pre token generation triggers, set the `LambdaArn` of `PreTokenGenerationConfig`.

You can set “

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#pre_token_generation_configTypes::PreTokenGenerationVersionConfigType

The detailed configuration of a pre token generation trigger. If you also set an ARN in ‘PreTokenGeneration`, its value must be identical to `PreTokenGenerationConfig`.



5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#user_migrationString

The user migration Lambda config type.

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#verify_auth_challenge_responseString

Verifies the authentication challenge response.

Returns:

  • (String)


5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918

class LambdaConfigType < Struct.new(
  :pre_sign_up,
  :custom_message,
  :post_confirmation,
  :pre_authentication,
  :post_authentication,
  :define_auth_challenge,
  :create_auth_challenge,
  :verify_auth_challenge_response,
  :pre_token_generation,
  :user_migration,
  :pre_token_generation_config,
  :custom_sms_sender,
  :custom_email_sender,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end