Class: Aws::CognitoIdentityProvider::Types::LambdaConfigType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::LambdaConfigType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Specifies the configuration for Lambda triggers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_auth_challenge ⇒ String
Creates an authentication challenge.
-
#custom_email_sender ⇒ Types::CustomEmailLambdaVersionConfigType
A custom email sender Lambda trigger.
-
#custom_message ⇒ String
A custom Message Lambda trigger.
-
#custom_sms_sender ⇒ Types::CustomSMSLambdaVersionConfigType
A custom SMS sender Lambda trigger.
-
#define_auth_challenge ⇒ String
Defines the authentication challenge.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of an [KMS key](/kms/latest/developerguide/concepts.html#master_keys).
-
#post_authentication ⇒ String
A post-authentication Lambda trigger.
-
#post_confirmation ⇒ String
A post-confirmation Lambda trigger.
-
#pre_authentication ⇒ String
A pre-authentication Lambda trigger.
-
#pre_sign_up ⇒ String
A pre-registration Lambda trigger.
-
#pre_token_generation ⇒ String
The Amazon Resource Name (ARN) of the function that you want to assign to your Lambda trigger.
-
#pre_token_generation_config ⇒ Types::PreTokenGenerationVersionConfigType
The detailed configuration of a pre token generation trigger.
-
#user_migration ⇒ String
The user migration Lambda config type.
-
#verify_auth_challenge_response ⇒ String
Verifies the authentication challenge response.
Instance Attribute Details
#create_auth_challenge ⇒ String
Creates an authentication challenge.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#custom_email_sender ⇒ Types::CustomEmailLambdaVersionConfigType
A custom email sender Lambda trigger.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#custom_message ⇒ String
A custom Message Lambda trigger.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#custom_sms_sender ⇒ Types::CustomSMSLambdaVersionConfigType
A custom SMS sender Lambda trigger.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#define_auth_challenge ⇒ String
Defines the authentication challenge.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of an [KMS key](/kms/latest/developerguide/concepts.html#master_keys). Amazon Cognito uses the key to encrypt codes and temporary passwords sent to ‘CustomEmailSender` and `CustomSMSSender`.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#post_authentication ⇒ String
A post-authentication Lambda trigger.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#post_confirmation ⇒ String
A post-confirmation Lambda trigger.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#pre_authentication ⇒ String
A pre-authentication Lambda trigger.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#pre_sign_up ⇒ String
A pre-registration Lambda trigger.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#pre_token_generation ⇒ String
The Amazon Resource Name (ARN) of the function that you want to assign to your Lambda trigger.
Set this parameter for legacy purposes. If you also set an ARN in ‘PreTokenGenerationConfig`, its value must be identical to `PreTokenGeneration`. For new instances of pre token generation triggers, set the `LambdaArn` of `PreTokenGenerationConfig`.
You can set “
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#pre_token_generation_config ⇒ Types::PreTokenGenerationVersionConfigType
The detailed configuration of a pre token generation trigger. If you also set an ARN in ‘PreTokenGeneration`, its value must be identical to `PreTokenGenerationConfig`.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#user_migration ⇒ String
The user migration Lambda config type.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#verify_auth_challenge_response ⇒ String
Verifies the authentication challenge response.
5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 5918 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :pre_token_generation_config, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |