Class: Aws::CognitoIdentityProvider::Types::LambdaConfigType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::LambdaConfigType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass LambdaConfigType data as a hash:
{
pre_sign_up: "ArnType",
custom_message: "ArnType",
post_confirmation: "ArnType",
pre_authentication: "ArnType",
post_authentication: "ArnType",
define_auth_challenge: "ArnType",
create_auth_challenge: "ArnType",
verify_auth_challenge_response: "ArnType",
pre_token_generation: "ArnType",
user_migration: "ArnType",
custom_sms_sender: {
lambda_version: "V1_0", # required, accepts V1_0
lambda_arn: "ArnType", # required
},
custom_email_sender: {
lambda_version: "V1_0", # required, accepts V1_0
lambda_arn: "ArnType", # required
},
kms_key_id: "ArnType",
}
Specifies the configuration for Lambda triggers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_auth_challenge ⇒ String
Creates an authentication challenge.
-
#custom_email_sender ⇒ Types::CustomEmailLambdaVersionConfigType
A custom email sender Lambda trigger.
-
#custom_message ⇒ String
A custom Message Lambda trigger.
-
#custom_sms_sender ⇒ Types::CustomSMSLambdaVersionConfigType
A custom SMS sender Lambda trigger.
-
#define_auth_challenge ⇒ String
Defines the authentication challenge.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of an [KMS key](/kms/latest/developerguide/concepts.html#master_keys).
-
#post_authentication ⇒ String
A post-authentication Lambda trigger.
-
#post_confirmation ⇒ String
A post-confirmation Lambda trigger.
-
#pre_authentication ⇒ String
A pre-authentication Lambda trigger.
-
#pre_sign_up ⇒ String
A pre-registration Lambda trigger.
-
#pre_token_generation ⇒ String
A Lambda trigger that is invoked before token generation.
-
#user_migration ⇒ String
The user migration Lambda config type.
-
#verify_auth_challenge_response ⇒ String
Verifies the authentication challenge response.
Instance Attribute Details
#create_auth_challenge ⇒ String
Creates an authentication challenge.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#custom_email_sender ⇒ Types::CustomEmailLambdaVersionConfigType
A custom email sender Lambda trigger.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#custom_message ⇒ String
A custom Message Lambda trigger.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#custom_sms_sender ⇒ Types::CustomSMSLambdaVersionConfigType
A custom SMS sender Lambda trigger.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#define_auth_challenge ⇒ String
Defines the authentication challenge.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of an [KMS key](/kms/latest/developerguide/concepts.html#master_keys). Amazon Cognito uses the key to encrypt codes and temporary passwords sent to `CustomEmailSender` and `CustomSMSSender`.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#post_authentication ⇒ String
A post-authentication Lambda trigger.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#post_confirmation ⇒ String
A post-confirmation Lambda trigger.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#pre_authentication ⇒ String
A pre-authentication Lambda trigger.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#pre_sign_up ⇒ String
A pre-registration Lambda trigger.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#pre_token_generation ⇒ String
A Lambda trigger that is invoked before token generation.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#user_migration ⇒ String
The user migration Lambda config type.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#verify_auth_challenge_response ⇒ String
Verifies the authentication challenge response.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6423 class LambdaConfigType < Struct.new( :pre_sign_up, :custom_message, :post_confirmation, :pre_authentication, :post_authentication, :define_auth_challenge, :create_auth_challenge, :verify_auth_challenge_response, :pre_token_generation, :user_migration, :custom_sms_sender, :custom_email_sender, :kms_key_id) SENSITIVE = [] include Aws::Structure end |