Class: Aws::CognitoIdentityProvider::Types::LimitType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::LimitType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The limit definition and current limit values for a provisioned limit.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#free_limit_value ⇒ Integer
The default (free) limit value, in requests per second (RPS).
-
#limit_definition ⇒ Types::LimitDefinitionType
The definition that identifies this limit, including the class and attributes.
-
#provisioned_limit_value ⇒ Integer
The provisioned limit value, in requests per second (RPS).
Instance Attribute Details
#free_limit_value ⇒ Integer
The default (free) limit value, in requests per second (RPS). This is the rate included at no additional cost.
8283 8284 8285 8286 8287 8288 8289 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8283 class LimitType < Struct.new( :limit_definition, :provisioned_limit_value, :free_limit_value) SENSITIVE = [] include Aws::Structure end |
#limit_definition ⇒ Types::LimitDefinitionType
The definition that identifies this limit, including the class and attributes.
8283 8284 8285 8286 8287 8288 8289 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8283 class LimitType < Struct.new( :limit_definition, :provisioned_limit_value, :free_limit_value) SENSITIVE = [] include Aws::Structure end |
#provisioned_limit_value ⇒ Integer
The provisioned limit value, in requests per second (RPS). This is the rate that Amazon Cognito currently enforces for your account.
8283 8284 8285 8286 8287 8288 8289 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8283 class LimitType < Struct.new( :limit_definition, :provisioned_limit_value, :free_limit_value) SENSITIVE = [] include Aws::Structure end |