Class: Aws::CognitoIdentityProvider::Types::ListUserPoolClientSecretsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ListUserPoolClientSecretsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The request to list client secrets for a user pool app client.
Constant Summary collapse
- SENSITIVE =
[:client_id]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The ID of the app client whose secrets you want to list.
-
#next_token ⇒ String
This API operation returns a limited number of results.
-
#user_pool_id ⇒ String
The ID of the user pool that contains the app client.
Instance Attribute Details
#client_id ⇒ String
The ID of the app client whose secrets you want to list.
8920 8921 8922 8923 8924 8925 8926 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8920 class ListUserPoolClientSecretsRequest < Struct.new( :user_pool_id, :client_id, :next_token) SENSITIVE = [:client_id] include Aws::Structure end |
#next_token ⇒ String
This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.
8920 8921 8922 8923 8924 8925 8926 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8920 class ListUserPoolClientSecretsRequest < Struct.new( :user_pool_id, :client_id, :next_token) SENSITIVE = [:client_id] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool that contains the app client.
8920 8921 8922 8923 8924 8925 8926 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8920 class ListUserPoolClientSecretsRequest < Struct.new( :user_pool_id, :client_id, :next_token) SENSITIVE = [:client_id] include Aws::Structure end |