Class: Aws::CognitoIdentityProvider::Types::ListUserPoolClientsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ListUserPoolClientsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Represents the request to list the user pool clients.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of app clients that you want Amazon Cognito to return in the response.
-
#next_token ⇒ String
This API operation returns a limited number of results.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to list user pool clients.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of app clients that you want Amazon Cognito to return in the response.
8978 8979 8980 8981 8982 8983 8984 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8978 class ListUserPoolClientsRequest < Struct.new( :user_pool_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.
8978 8979 8980 8981 8982 8983 8984 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8978 class ListUserPoolClientsRequest < Struct.new( :user_pool_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to list user pool clients.
8978 8979 8980 8981 8982 8983 8984 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8978 class ListUserPoolClientsRequest < Struct.new( :user_pool_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |