Class: Aws::CognitoIdentityProvider::Types::ListUserPoolReplicasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ListUserPoolReplicasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A pagination token for retrieving the next page of results.
-
#user_pool_id ⇒ String
The ID of the user pool for which to list replicas.
Instance Attribute Details
#next_token ⇒ String
A pagination token for retrieving the next page of results. If this parameter is omitted, the operation returns the first page of results.
9022 9023 9024 9025 9026 9027 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9022 class ListUserPoolReplicasRequest < Struct.new( :user_pool_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool for which to list replicas.
9022 9023 9024 9025 9026 9027 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9022 class ListUserPoolReplicasRequest < Struct.new( :user_pool_id, :next_token) SENSITIVE = [] include Aws::Structure end |