Class: Aws::CognitoIdentityProvider::Types::ListUserPoolReplicasResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ListUserPoolReplicasResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A pagination token for retrieving the next page of results.
-
#user_pool_replicas ⇒ Array<Types::UserPoolReplicaType>
A list of user pool replicas, including information about their status, role, and Region.
Instance Attribute Details
#next_token ⇒ String
A pagination token for retrieving the next page of results. If this value is null, there are no more results to retrieve.
9041 9042 9043 9044 9045 9046 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9041 class ListUserPoolReplicasResponse < Struct.new( :user_pool_replicas, :next_token) SENSITIVE = [] include Aws::Structure end |
#user_pool_replicas ⇒ Array<Types::UserPoolReplicaType>
A list of user pool replicas, including information about their status, role, and Region.
9041 9042 9043 9044 9045 9046 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9041 class ListUserPoolReplicasResponse < Struct.new( :user_pool_replicas, :next_token) SENSITIVE = [] include Aws::Structure end |