Class: Aws::CognitoIdentityProvider::Types::ListUsersInGroupResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ListUsersInGroupResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The identifier that Amazon Cognito returned with the previous request to this operation.
-
#users ⇒ Array<Types::UserType>
An array of users who are members in the group, and their attributes.
Instance Attribute Details
#next_token ⇒ String
The identifier that Amazon Cognito returned with the previous request to this operation. When you include a pagination token in your request, Amazon Cognito returns the next set of items in the list. By use of this token, you can paginate through the full list of items.
9150 9151 9152 9153 9154 9155 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9150 class ListUsersInGroupResponse < Struct.new( :users, :next_token) SENSITIVE = [] include Aws::Structure end |
#users ⇒ Array<Types::UserType>
An array of users who are members in the group, and their attributes.
9150 9151 9152 9153 9154 9155 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9150 class ListUsersInGroupResponse < Struct.new( :users, :next_token) SENSITIVE = [] include Aws::Structure end |