Class: Aws::CognitoIdentityProvider::Types::ListWebAuthnCredentialsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ListWebAuthnCredentialsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credentials ⇒ Array<Types::WebAuthnCredentialDescription>
A list of registered passkeys for a user.
-
#next_token ⇒ String
The identifier that Amazon Cognito returned with the previous request to this operation.
Instance Attribute Details
#credentials ⇒ Array<Types::WebAuthnCredentialDescription>
A list of registered passkeys for a user.
9351 9352 9353 9354 9355 9356 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9351 class ListWebAuthnCredentialsResponse < Struct.new( :credentials, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The identifier that Amazon Cognito returned with the previous request to this operation. When you include a pagination token in your request, Amazon Cognito returns the next set of items in the list. By use of this token, you can paginate through the full list of items.
9351 9352 9353 9354 9355 9356 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9351 class ListWebAuthnCredentialsResponse < Struct.new( :credentials, :next_token) SENSITIVE = [] include Aws::Structure end |