Class: Aws::CognitoIdentityProvider::Types::NotifyConfigurationType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The configuration for Amazon SES email messages that threat protection sends to a user when your adaptive authentication automated response has a Notify action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#block_emailTypes::NotifyEmailType

The template for the email message that your user pool sends when a detected risk event is blocked.



9238
9239
9240
9241
9242
9243
9244
9245
9246
9247
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9238

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#fromString

The email address that sends the email message. The address must be either individually verified with Amazon Simple Email Service, or from a domain that has been verified with Amazon SES.

Returns:

  • (String)


9238
9239
9240
9241
9242
9243
9244
9245
9246
9247
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9238

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#mfa_emailTypes::NotifyEmailType

The template for the email message that your user pool sends when MFA is challenged in response to a detected risk.



9238
9239
9240
9241
9242
9243
9244
9245
9246
9247
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9238

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#no_action_emailTypes::NotifyEmailType

The template for the email message that your user pool sends when no action is taken in response to a detected risk.



9238
9239
9240
9241
9242
9243
9244
9245
9246
9247
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9238

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#reply_toString

The reply-to email address of an email template. Can be an email address in the format ‘admin@example.com` or `Administrator <admin@example.com>`.

Returns:

  • (String)


9238
9239
9240
9241
9242
9243
9244
9245
9246
9247
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9238

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The Amazon Resource Name (ARN) of the identity that is associated with the sending authorization policy. This identity permits Amazon Cognito to send for the email address specified in the ‘From` parameter.

Returns:

  • (String)


9238
9239
9240
9241
9242
9243
9244
9245
9246
9247
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9238

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end