Class: Aws::CognitoIdentityProvider::Types::NotifyConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::NotifyConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The configuration for Amazon SES email messages that advanced security features sends to a user when your adaptive authentication automated response has a Notify action.
This data type is a request parameter of [SetRiskConfiguration] and a response parameter of [DescribeRiskConfiguration].
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetRiskConfiguration.html [2]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeRiskConfiguration.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#block_email ⇒ Types::NotifyEmailType
The template for the email message that your user pool sends when a detected risk event is blocked.
-
#from ⇒ String
The email address that sends the email message.
-
#mfa_email ⇒ Types::NotifyEmailType
The template for the email message that your user pool sends when MFA is challenged in response to a detected risk.
-
#no_action_email ⇒ Types::NotifyEmailType
The template for the email message that your user pool sends when no action is taken in response to a detected risk.
-
#reply_to ⇒ String
The reply-to email address of an email template.
-
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the identity that is associated with the sending authorization policy.
Instance Attribute Details
#block_email ⇒ Types::NotifyEmailType
The template for the email message that your user pool sends when a detected risk event is blocked.
8237 8238 8239 8240 8241 8242 8243 8244 8245 8246 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8237 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |
#from ⇒ String
The email address that sends the email message. The address must be either individually verified with Amazon Simple Email Service, or from a domain that has been verified with Amazon SES.
8237 8238 8239 8240 8241 8242 8243 8244 8245 8246 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8237 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |
#mfa_email ⇒ Types::NotifyEmailType
The template for the email message that your user pool sends when MFA is challenged in response to a detected risk.
8237 8238 8239 8240 8241 8242 8243 8244 8245 8246 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8237 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |
#no_action_email ⇒ Types::NotifyEmailType
The template for the email message that your user pool sends when no action is taken in response to a detected risk.
8237 8238 8239 8240 8241 8242 8243 8244 8245 8246 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8237 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |
#reply_to ⇒ String
The reply-to email address of an email template.
8237 8238 8239 8240 8241 8242 8243 8244 8245 8246 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8237 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the identity that is associated with the sending authorization policy. This identity permits Amazon Cognito to send for the email address specified in the ‘From` parameter.
8237 8238 8239 8240 8241 8242 8243 8244 8245 8246 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8237 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |