Class: Aws::CognitoIdentityProvider::Types::NotifyConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::NotifyConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The notify configuration type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#block_email ⇒ Types::NotifyEmailType
Email template used when a detected risk event is blocked.
-
#from ⇒ String
The email address that is sending the email.
-
#mfa_email ⇒ Types::NotifyEmailType
The multi-factor authentication (MFA) email template used when MFA is challenged as part of a detected risk.
-
#no_action_email ⇒ Types::NotifyEmailType
The email template used when a detected risk event is allowed.
-
#reply_to ⇒ String
The destination to which the receiver of an email should reply to.
-
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the identity that is associated with the sending authorization policy.
Instance Attribute Details
#block_email ⇒ Types::NotifyEmailType
Email template used when a detected risk event is blocked.
6565 6566 6567 6568 6569 6570 6571 6572 6573 6574 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6565 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |
#from ⇒ String
The email address that is sending the email. The address must be either individually verified with Amazon Simple Email Service, or from a domain that has been verified with Amazon SES.
6565 6566 6567 6568 6569 6570 6571 6572 6573 6574 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6565 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |
#mfa_email ⇒ Types::NotifyEmailType
The multi-factor authentication (MFA) email template used when MFA is challenged as part of a detected risk.
6565 6566 6567 6568 6569 6570 6571 6572 6573 6574 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6565 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |
#no_action_email ⇒ Types::NotifyEmailType
The email template used when a detected risk event is allowed.
6565 6566 6567 6568 6569 6570 6571 6572 6573 6574 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6565 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |
#reply_to ⇒ String
The destination to which the receiver of an email should reply to.
6565 6566 6567 6568 6569 6570 6571 6572 6573 6574 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6565 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the identity that is associated with the sending authorization policy. This identity permits Amazon Cognito to send for the email address specified in the ‘From` parameter.
6565 6566 6567 6568 6569 6570 6571 6572 6573 6574 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6565 class NotifyConfigurationType < Struct.new( :from, :reply_to, :source_arn, :block_email, :no_action_email, :mfa_email) SENSITIVE = [] include Aws::Structure end |