Class: Aws::CognitoIdentityProvider::Types::NotifyConfigurationType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The notify configuration type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#block_emailTypes::NotifyEmailType

Email template used when a detected risk event is blocked.



6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6083

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#fromString

The email address that is sending the email. The address must be either individually verified with Amazon Simple Email Service, or from a domain that has been verified with Amazon SES.

Returns:

  • (String)


6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6083

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#mfa_emailTypes::NotifyEmailType

The multi-factor authentication (MFA) email template used when MFA is challenged as part of a detected risk.



6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6083

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#no_action_emailTypes::NotifyEmailType

The email template used when a detected risk event is allowed.



6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6083

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#reply_toString

The destination to which the receiver of an email should reply to.

Returns:

  • (String)


6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6083

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The Amazon Resource Name (ARN) of the identity that is associated with the sending authorization policy. This identity permits Amazon Cognito to send for the email address specified in the ‘From` parameter.

Returns:

  • (String)


6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6083

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end