Class: Aws::CognitoIdentityProvider::Types::NotifyConfigurationType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass NotifyConfigurationType data as a hash:

{
  from: "StringType",
  reply_to: "StringType",
  source_arn: "ArnType", # required
  block_email: {
    subject: "EmailNotificationSubjectType", # required
    html_body: "EmailNotificationBodyType",
    text_body: "EmailNotificationBodyType",
  },
  no_action_email: {
    subject: "EmailNotificationSubjectType", # required
    html_body: "EmailNotificationBodyType",
    text_body: "EmailNotificationBodyType",
  },
  mfa_email: {
    subject: "EmailNotificationSubjectType", # required
    html_body: "EmailNotificationBodyType",
    text_body: "EmailNotificationBodyType",
  },
}

The notify configuration type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#block_emailTypes::NotifyEmailType

Email template used when a detected risk event is blocked.



7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7333

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#fromString

The email address that is sending the email. The address must be either individually verified with Amazon Simple Email Service, or from a domain that has been verified with Amazon SES.

Returns:

  • (String)


7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7333

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#mfa_emailTypes::NotifyEmailType

The multi-factor authentication (MFA) email template used when MFA is challenged as part of a detected risk.



7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7333

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#no_action_emailTypes::NotifyEmailType

The email template used when a detected risk event is allowed.



7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7333

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#reply_toString

The destination to which the receiver of an email should reply to.

Returns:

  • (String)


7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7333

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The Amazon Resource Name (ARN) of the identity that is associated with the sending authorization policy. This identity permits Amazon Cognito to send for the email address specified in the `From` parameter.

Returns:

  • (String)


7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7333

class NotifyConfigurationType < Struct.new(
  :from,
  :reply_to,
  :source_arn,
  :block_email,
  :no_action_email,
  :mfa_email)
  SENSITIVE = []
  include Aws::Structure
end