Class: Aws::CognitoIdentityProvider::Types::NumberAttributeConstraintsType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::NumberAttributeConstraintsType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass NumberAttributeConstraintsType data as a hash:
{
min_value: "StringType",
max_value: "StringType",
}
The minimum and maximum values of an attribute that is of the number data type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_value ⇒ String
The maximum value of an attribute that is of the number data type.
-
#min_value ⇒ String
The minimum value of an attribute that is of the number data type.
Instance Attribute Details
#max_value ⇒ String
The maximum value of an attribute that is of the number data type.
7374 7375 7376 7377 7378 7379 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7374 class NumberAttributeConstraintsType < Struct.new( :min_value, :max_value) SENSITIVE = [] include Aws::Structure end |
#min_value ⇒ String
The minimum value of an attribute that is of the number data type.
7374 7375 7376 7377 7378 7379 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7374 class NumberAttributeConstraintsType < Struct.new( :min_value, :max_value) SENSITIVE = [] include Aws::Structure end |