Class: Aws::CognitoIdentityProvider::Types::NumberAttributeConstraintsType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass NumberAttributeConstraintsType data as a hash:

{
  min_value: "StringType",
  max_value: "StringType",
}

The minimum and maximum values of an attribute that is of the number data type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_valueString

The maximum value of an attribute that is of the number data type.

Returns:

  • (String)


7337
7338
7339
7340
7341
7342
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7337

class NumberAttributeConstraintsType < Struct.new(
  :min_value,
  :max_value)
  SENSITIVE = []
  include Aws::Structure
end

#min_valueString

The minimum value of an attribute that is of the number data type.

Returns:

  • (String)


7337
7338
7339
7340
7341
7342
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7337

class NumberAttributeConstraintsType < Struct.new(
  :min_value,
  :max_value)
  SENSITIVE = []
  include Aws::Structure
end