Class: Aws::CognitoIdentityProvider::Types::OperationNotEnabledException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

This exception is thrown when an operation is not available in the current region or for the current user pool configuration. This can occur when attempting to perform operations that are not supported in secondary replica regions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


9501
9502
9503
9504
9505
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9501

class OperationNotEnabledException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end