Class: Aws::CognitoIdentityProvider::Types::OperationNotEnabledException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

This exception is thrown when an operation is not available in the current region or for the current user pool configuration. This can occur when attempting to perform operations that are not supported in secondary replica regions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


9310
9311
9312
9313
9314
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9310

class OperationNotEnabledException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end