Class: Aws::CognitoIdentityProvider::Types::OperationNotEnabledException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::OperationNotEnabledException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
This exception is thrown when an operation is not available in the current region or for the current user pool configuration. This can occur when attempting to perform operations that are not supported in secondary replica regions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
9293 9294 9295 9296 9297 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9293 class OperationNotEnabledException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |