Class: Aws::CognitoIdentityProvider::Types::PasswordPolicyType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The password policy type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#minimum_lengthInteger

The minimum length of the password in the policy that you have set. This value can’t be less than 6.

Returns:

  • (Integer)


6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6416

class PasswordPolicyType < Struct.new(
  :minimum_length,
  :require_uppercase,
  :require_lowercase,
  :require_numbers,
  :require_symbols,
  :temporary_password_validity_days)
  SENSITIVE = []
  include Aws::Structure
end

#require_lowercaseBoolean

In the password policy that you have set, refers to whether you have required users to use at least one lowercase letter in their password.

Returns:

  • (Boolean)


6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6416

class PasswordPolicyType < Struct.new(
  :minimum_length,
  :require_uppercase,
  :require_lowercase,
  :require_numbers,
  :require_symbols,
  :temporary_password_validity_days)
  SENSITIVE = []
  include Aws::Structure
end

#require_numbersBoolean

In the password policy that you have set, refers to whether you have required users to use at least one number in their password.

Returns:

  • (Boolean)


6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6416

class PasswordPolicyType < Struct.new(
  :minimum_length,
  :require_uppercase,
  :require_lowercase,
  :require_numbers,
  :require_symbols,
  :temporary_password_validity_days)
  SENSITIVE = []
  include Aws::Structure
end

#require_symbolsBoolean

In the password policy that you have set, refers to whether you have required users to use at least one symbol in their password.

Returns:

  • (Boolean)


6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6416

class PasswordPolicyType < Struct.new(
  :minimum_length,
  :require_uppercase,
  :require_lowercase,
  :require_numbers,
  :require_symbols,
  :temporary_password_validity_days)
  SENSITIVE = []
  include Aws::Structure
end

#require_uppercaseBoolean

In the password policy that you have set, refers to whether you have required users to use at least one uppercase letter in their password.

Returns:

  • (Boolean)


6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6416

class PasswordPolicyType < Struct.new(
  :minimum_length,
  :require_uppercase,
  :require_lowercase,
  :require_numbers,
  :require_symbols,
  :temporary_password_validity_days)
  SENSITIVE = []
  include Aws::Structure
end

#temporary_password_validity_daysInteger

The number of days a temporary password is valid in the password policy. If the user doesn’t sign in during this time, an administrator must reset their password.

<note markdown=“1”> When you set ‘TemporaryPasswordValidityDays` for a user pool, you can no longer set a value for the legacy `UnusedAccountValidityDays` parameter in that user pool.

</note>

Returns:

  • (Integer)


6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6416

class PasswordPolicyType < Struct.new(
  :minimum_length,
  :require_uppercase,
  :require_lowercase,
  :require_numbers,
  :require_symbols,
  :temporary_password_validity_days)
  SENSITIVE = []
  include Aws::Structure
end