Class: Aws::CognitoIdentityProvider::Types::PasswordPolicyType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::PasswordPolicyType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass PasswordPolicyType data as a hash:
{
minimum_length: 1,
require_uppercase: false,
require_lowercase: false,
require_numbers: false,
require_symbols: false,
temporary_password_validity_days: 1,
}
The password policy type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#minimum_length ⇒ Integer
The minimum length of the password in the policy that you have set.
-
#require_lowercase ⇒ Boolean
In the password policy that you have set, refers to whether you have required users to use at least one lowercase letter in their password.
-
#require_numbers ⇒ Boolean
In the password policy that you have set, refers to whether you have required users to use at least one number in their password.
-
#require_symbols ⇒ Boolean
In the password policy that you have set, refers to whether you have required users to use at least one symbol in their password.
-
#require_uppercase ⇒ Boolean
In the password policy that you have set, refers to whether you have required users to use at least one uppercase letter in their password.
-
#temporary_password_validity_days ⇒ Integer
The number of days a temporary password is valid in the password policy.
Instance Attribute Details
#minimum_length ⇒ Integer
The minimum length of the password in the policy that you have set. This value can't be less than 6.
7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7399 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#require_lowercase ⇒ Boolean
In the password policy that you have set, refers to whether you have required users to use at least one lowercase letter in their password.
7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7399 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#require_numbers ⇒ Boolean
In the password policy that you have set, refers to whether you have required users to use at least one number in their password.
7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7399 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#require_symbols ⇒ Boolean
In the password policy that you have set, refers to whether you have required users to use at least one symbol in their password.
7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7399 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#require_uppercase ⇒ Boolean
In the password policy that you have set, refers to whether you have required users to use at least one uppercase letter in their password.
7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7399 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |
#temporary_password_validity_days ⇒ Integer
The number of days a temporary password is valid in the password policy. If the user doesn't sign in during this time, an administrator must reset their password.
<note markdown=“1”> When you set `TemporaryPasswordValidityDays` for a user pool, you can no longer set a value for the legacy `UnusedAccountValidityDays` parameter in that user pool.
</note>
7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7399 class PasswordPolicyType < Struct.new( :minimum_length, :require_uppercase, :require_lowercase, :require_numbers, :require_symbols, :temporary_password_validity_days) SENSITIVE = [] include Aws::Structure end |