Class: Aws::CognitoIdentityProvider::Types::ProviderDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ProviderDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A container for IdP details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date the provider was added to the user pool.
-
#last_modified_date ⇒ Time
The date the provider was last modified.
-
#provider_name ⇒ String
The IdP name.
-
#provider_type ⇒ String
The IdP type.
Instance Attribute Details
#creation_date ⇒ Time
The date the provider was added to the user pool.
7418 7419 7420 7421 7422 7423 7424 7425 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7418 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date the provider was last modified.
7418 7419 7420 7421 7422 7423 7424 7425 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7418 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The IdP name.
7418 7419 7420 7421 7422 7423 7424 7425 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7418 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#provider_type ⇒ String
The IdP type.
7418 7419 7420 7421 7422 7423 7424 7425 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7418 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |