Class: Aws::CognitoIdentityProvider::Types::ProviderDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ProviderDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A container for identity provider details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date the provider was added to the user pool.
-
#last_modified_date ⇒ Time
The date the provider was last modified.
-
#provider_name ⇒ String
The identity provider name.
-
#provider_type ⇒ String
The identity provider type.
Instance Attribute Details
#creation_date ⇒ Time
The date the provider was added to the user pool.
7260 7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7260 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date the provider was last modified.
7260 7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7260 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The identity provider name.
7260 7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7260 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#provider_type ⇒ String
The identity provider type.
7260 7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7260 class ProviderDescription < Struct.new( :provider_name, :provider_type, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |