Class: Aws::CognitoIdentityProvider::Types::ProviderUserIdentifierType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ProviderUserIdentifierType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A container for information about an IdP for a user pool.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#provider_attribute_name ⇒ String
The name of the provider attribute to link to, such as ‘NameID`.
-
#provider_attribute_value ⇒ String
The value of the provider attribute to link to, such as ‘xxxxx_account`.
-
#provider_name ⇒ String
The name of the provider, such as Facebook, Google, or Login with Amazon.
Instance Attribute Details
#provider_attribute_name ⇒ String
The name of the provider attribute to link to, such as ‘NameID`.
6267 6268 6269 6270 6271 6272 6273 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6267 class ProviderUserIdentifierType < Struct.new( :provider_name, :provider_attribute_name, :provider_attribute_value) SENSITIVE = [] include Aws::Structure end |
#provider_attribute_value ⇒ String
The value of the provider attribute to link to, such as ‘xxxxx_account`.
6267 6268 6269 6270 6271 6272 6273 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6267 class ProviderUserIdentifierType < Struct.new( :provider_name, :provider_attribute_name, :provider_attribute_value) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the provider, such as Facebook, Google, or Login with Amazon.
6267 6268 6269 6270 6271 6272 6273 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 6267 class ProviderUserIdentifierType < Struct.new( :provider_name, :provider_attribute_name, :provider_attribute_value) SENSITIVE = [] include Aws::Structure end |