Class: Aws::CognitoIdentityProvider::Types::ProviderUserIdentifierType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::ProviderUserIdentifierType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass ProviderUserIdentifierType data as a hash:
{
provider_name: "ProviderNameType",
provider_attribute_name: "StringType",
provider_attribute_value: "StringType",
}
A container for information about an identity provider for a user pool.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#provider_attribute_name ⇒ String
The name of the provider attribute to link to, such as `NameID`.
-
#provider_attribute_value ⇒ String
The value of the provider attribute to link to, such as `xxxxx_account`.
-
#provider_name ⇒ String
The name of the provider, such as Facebook, Google, or Login with Amazon.
Instance Attribute Details
#provider_attribute_name ⇒ String
The name of the provider attribute to link to, such as `NameID`.
7250 7251 7252 7253 7254 7255 7256 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7250 class ProviderUserIdentifierType < Struct.new( :provider_name, :provider_attribute_name, :provider_attribute_value) SENSITIVE = [] include Aws::Structure end |
#provider_attribute_value ⇒ String
The value of the provider attribute to link to, such as `xxxxx_account`.
7250 7251 7252 7253 7254 7255 7256 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7250 class ProviderUserIdentifierType < Struct.new( :provider_name, :provider_attribute_name, :provider_attribute_value) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
The name of the provider, such as Facebook, Google, or Login with Amazon.
7250 7251 7252 7253 7254 7255 7256 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7250 class ProviderUserIdentifierType < Struct.new( :provider_name, :provider_attribute_name, :provider_attribute_value) SENSITIVE = [] include Aws::Structure end |