Class: Aws::CognitoIdentityProvider::Types::RespondToAuthChallengeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass RespondToAuthChallengeRequest data as a hash:

{
  client_id: "ClientIdType", # required
  challenge_name: "SMS_MFA", # required, accepts SMS_MFA, SOFTWARE_TOKEN_MFA, SELECT_MFA_TYPE, MFA_SETUP, PASSWORD_VERIFIER, CUSTOM_CHALLENGE, DEVICE_SRP_AUTH, DEVICE_PASSWORD_VERIFIER, ADMIN_NO_SRP_AUTH, NEW_PASSWORD_REQUIRED
  session: "SessionType",
  challenge_responses: {
    "StringType" => "StringType",
  },
  analytics_metadata: {
    analytics_endpoint_id: "StringType",
  },
  user_context_data: {
    encoded_data: "StringType",
  },
  client_metadata: {
    "StringType" => "StringType",
  },
}

The request to respond to an authentication challenge.

Constant Summary collapse

SENSITIVE =
[:client_id]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_metadataTypes::AnalyticsMetadataType

The Amazon Pinpoint analytics metadata for collecting metrics for `RespondToAuthChallenge` calls.



7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7655

class RespondToAuthChallengeRequest < Struct.new(
  :client_id,
  :challenge_name,
  :session,
  :challenge_responses,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#challenge_nameString

The challenge name. For more information, see [InitiateAuth].

`ADMIN_NO_SRP_AUTH` isn't a valid value.

[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_InitiateAuth.html

Returns:

  • (String)


7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7655

class RespondToAuthChallengeRequest < Struct.new(
  :client_id,
  :challenge_name,
  :session,
  :challenge_responses,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#challenge_responsesHash<String,String>

The challenge responses. These are inputs corresponding to the value of `ChallengeName`, for example:

<note markdown=“1”> `SECRET_HASH` (if app client is configured with client secret) applies to all of the inputs that follow (including `SOFTWARE_TOKEN_MFA`).

</note>
  • `SMS_MFA`: `SMS_MFA_CODE`, `USERNAME`.

  • `PASSWORD_VERIFIER`: `PASSWORD_CLAIM_SIGNATURE`, `PASSWORD_CLAIM_SECRET_BLOCK`, `TIMESTAMP`, `USERNAME`.

    <note markdown=“1”> `PASSWORD_VERIFIER` requires `DEVICE_KEY` when signing in with a remembered device.

    </note>
    
  • `NEW_PASSWORD_REQUIRED`: `NEW_PASSWORD`, any other required attributes, `USERNAME`.

  • `SOFTWARE_TOKEN_MFA`: `USERNAME` and `SOFTWARE_TOKEN_MFA_CODE` are required attributes.

  • `DEVICE_SRP_AUTH` requires `USERNAME`, `DEVICE_KEY`, `SRP_A` (and `SECRET_HASH`).

  • `DEVICE_PASSWORD_VERIFIER` requires everything that `PASSWORD_VERIFIER` requires, plus `DEVICE_KEY`.

  • `MFA_SETUP` requires `USERNAME`, plus you must use the session value returned by `VerifySoftwareToken` in the `Session` parameter.

Returns:

  • (Hash<String,String>)


7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7655

class RespondToAuthChallengeRequest < Struct.new(
  :client_id,
  :challenge_name,
  :session,
  :challenge_responses,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#client_idString

The app client ID.

Returns:

  • (String)


7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7655

class RespondToAuthChallengeRequest < Struct.new(
  :client_id,
  :challenge_name,
  :session,
  :challenge_responses,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#client_metadataHash<String,String>

A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.

You create custom workflows by assigning Lambda functions to user pool triggers. When you use the RespondToAuthChallenge API action, Amazon Cognito invokes any functions that are assigned to the following triggers: *post authentication*, *pre token generation*, *define auth challenge*, *create auth challenge*, and *verify auth challenge*. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a `clientMetadata` attribute, which provides the data that you assigned to the ClientMetadata parameter in your RespondToAuthChallenge request. In your function code in Lambda, you can process the `clientMetadata` value to enhance your workflow for your specific needs.

For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.

<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won't do the following:

* Store the ClientMetadata value. This data is available only to
 Lambda triggers that are assigned to a user pool to support custom
 workflows. If your user pool configuration doesn't include
 triggers, the ClientMetadata parameter serves no purpose.
  • Validate the ClientMetadata value.

  • Encrypt the ClientMetadata value. Don't use Amazon Cognito to provide sensitive information.

</note>

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools-working-with-aws-lambda-triggers.html

Returns:

  • (Hash<String,String>)


7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7655

class RespondToAuthChallengeRequest < Struct.new(
  :client_id,
  :challenge_name,
  :session,
  :challenge_responses,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#sessionString

The session that should be passed both ways in challenge-response calls to the service. If `InitiateAuth` or `RespondToAuthChallenge` API call determines that the caller must pass another challenge, they return a session with other challenge parameters. This session should be passed as it is to the next `RespondToAuthChallenge` API call.

Returns:

  • (String)


7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7655

class RespondToAuthChallengeRequest < Struct.new(
  :client_id,
  :challenge_name,
  :session,
  :challenge_responses,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end

#user_context_dataTypes::UserContextDataType

Contextual data such as the user's device fingerprint, IP address, or location used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.



7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 7655

class RespondToAuthChallengeRequest < Struct.new(
  :client_id,
  :challenge_name,
  :session,
  :challenge_responses,
  :analytics_metadata,
  :user_context_data,
  :client_metadata)
  SENSITIVE = [:client_id]
  include Aws::Structure
end