Class: Aws::CognitoIdentityProvider::Types::SetUICustomizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SetUICustomizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:client_id]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The ID of the app client that you want to customize.
-
#css ⇒ String
A plaintext CSS file that contains the custom fields that you want to apply to your user pool or app client.
-
#image_file ⇒ String
The image that you want to set as your login in the classic hosted UI, as a Base64-formatted binary object.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to apply branding to the classic hosted UI.
Instance Attribute Details
#client_id ⇒ String
The ID of the app client that you want to customize. To apply a
default style to all app clients not configured with client-level
branding, set this parameter value to ALL.
10968 10969 10970 10971 10972 10973 10974 10975 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10968 class SetUICustomizationRequest < Struct.new( :user_pool_id, :client_id, :css, :image_file) SENSITIVE = [:client_id] include Aws::Structure end |
#css ⇒ String
A plaintext CSS file that contains the custom fields that you want
to apply to your user pool or app client. To download a template, go
to the Amazon Cognito console. Navigate to your user pool App
clients tab, select Login pages, edit Hosted UI (classic)
style, and select the link to CSS template.css.
10968 10969 10970 10971 10972 10973 10974 10975 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10968 class SetUICustomizationRequest < Struct.new( :user_pool_id, :client_id, :css, :image_file) SENSITIVE = [:client_id] include Aws::Structure end |
#image_file ⇒ String
The image that you want to set as your login in the classic hosted UI, as a Base64-formatted binary object.
10968 10969 10970 10971 10972 10973 10974 10975 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10968 class SetUICustomizationRequest < Struct.new( :user_pool_id, :client_id, :css, :image_file) SENSITIVE = [:client_id] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to apply branding to the classic hosted UI.
10968 10969 10970 10971 10972 10973 10974 10975 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10968 class SetUICustomizationRequest < Struct.new( :user_pool_id, :client_id, :css, :image_file) SENSITIVE = [:client_id] include Aws::Structure end |