Class: Aws::CognitoIdentityProvider::Types::SetUserMFAPreferenceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for ‘aws.cognito.signin.user.admin`.

Returns:

  • (String)


10714
10715
10716
10717
10718
10719
10720
10721
10722
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10714

class SetUserMFAPreferenceRequest < Struct.new(
  :sms_mfa_settings,
  :software_token_mfa_settings,
  :email_mfa_settings,
  :web_authn_mfa_settings,
  :access_token)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#email_mfa_settingsTypes::EmailMfaSettingsType

User preferences for email message MFA. Activates or deactivates email MFA and sets it as the preferred MFA method when multiple methods are available. To activate this setting, your user pool must be in the [ Essentials tier] or higher.

[1]: docs.aws.amazon.com/cognito/latest/developerguide/feature-plans-features-essentials.html



10714
10715
10716
10717
10718
10719
10720
10721
10722
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10714

class SetUserMFAPreferenceRequest < Struct.new(
  :sms_mfa_settings,
  :software_token_mfa_settings,
  :email_mfa_settings,
  :web_authn_mfa_settings,
  :access_token)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#sms_mfa_settingsTypes::SMSMfaSettingsType

User preferences for SMS message MFA. Activates or deactivates SMS MFA and sets it as the preferred MFA method when multiple methods are available.



10714
10715
10716
10717
10718
10719
10720
10721
10722
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10714

class SetUserMFAPreferenceRequest < Struct.new(
  :sms_mfa_settings,
  :software_token_mfa_settings,
  :email_mfa_settings,
  :web_authn_mfa_settings,
  :access_token)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#software_token_mfa_settingsTypes::SoftwareTokenMfaSettingsType

User preferences for time-based one-time password (TOTP) MFA. Activates or deactivates TOTP MFA and sets it as the preferred MFA method when multiple methods are available. Users must register a TOTP authenticator before they set this as their preferred MFA method.



10714
10715
10716
10717
10718
10719
10720
10721
10722
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10714

class SetUserMFAPreferenceRequest < Struct.new(
  :sms_mfa_settings,
  :software_token_mfa_settings,
  :email_mfa_settings,
  :web_authn_mfa_settings,
  :access_token)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#web_authn_mfa_settingsTypes::WebAuthnMfaSettingsType

User preferences for passkey MFA. Activates or deactivates passkey MFA for the user. When activated, passkey authentication requires user verification, and passkey sign-in is available when MFA is required. To activate this setting, the ‘FactorConfiguration` of your user pool `WebAuthnConfiguration` must be `MULTI_FACTOR_WITH_USER_VERIFICATION`. To activate this setting, your user pool must be in the [ Essentials tier] or higher.

[1]: docs.aws.amazon.com/cognito/latest/developerguide/feature-plans-features-essentials.html



10714
10715
10716
10717
10718
10719
10720
10721
10722
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10714

class SetUserMFAPreferenceRequest < Struct.new(
  :sms_mfa_settings,
  :software_token_mfa_settings,
  :email_mfa_settings,
  :web_authn_mfa_settings,
  :access_token)
  SENSITIVE = [:access_token]
  include Aws::Structure
end