Class: Aws::CognitoIdentityProvider::Types::SetUserMFAPreferenceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SetUserMFAPreferenceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass SetUserMFAPreferenceRequest data as a hash:
{
sms_mfa_settings: {
enabled: false,
preferred_mfa: false,
},
software_token_mfa_settings: {
enabled: false,
preferred_mfa: false,
},
access_token: "TokenModelType", # required
}
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose MFA preference you want to set.
-
#sms_mfa_settings ⇒ Types::SMSMfaSettingsType
The SMS text message multi-factor authentication (MFA) settings.
-
#software_token_mfa_settings ⇒ Types::SoftwareTokenMfaSettingsType
The time-based one-time password software token MFA settings.
Instance Attribute Details
#access_token ⇒ String
A valid access token that Amazon Cognito issued to the user whose MFA preference you want to set.
8321 8322 8323 8324 8325 8326 8327 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8321 class SetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |
#sms_mfa_settings ⇒ Types::SMSMfaSettingsType
The SMS text message multi-factor authentication (MFA) settings.
8321 8322 8323 8324 8325 8326 8327 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8321 class SetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |
#software_token_mfa_settings ⇒ Types::SoftwareTokenMfaSettingsType
The time-based one-time password software token MFA settings.
8321 8322 8323 8324 8325 8326 8327 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8321 class SetUserMFAPreferenceRequest < Struct.new( :sms_mfa_settings, :software_token_mfa_settings, :access_token) SENSITIVE = [:access_token] include Aws::Structure end |