Class: Aws::CognitoIdentityProvider::Types::SetUserPoolMfaConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SetUserPoolMfaConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_mfa_configuration ⇒ Types::EmailMfaConfigType
Sets configuration for user pool email message MFA and sign-in with one-time passwords (OTPs).
-
#mfa_configuration ⇒ String
Sets multi-factor authentication (MFA) to be on, off, or optional.
-
#sms_mfa_configuration ⇒ Types::SmsMfaConfigType
Configures user pool SMS messages for MFA.
-
#software_token_mfa_configuration ⇒ Types::SoftwareTokenMfaConfigType
Configures a user pool for time-based one-time password (TOTP) MFA.
-
#user_pool_id ⇒ String
The user pool ID.
-
#web_authn_configuration ⇒ Types::WebAuthnConfigurationType
The configuration of your user pool for passkey, or WebAuthn, authentication and registration.
Instance Attribute Details
#email_mfa_configuration ⇒ Types::EmailMfaConfigType
Sets configuration for user pool email message MFA and sign-in with one-time passwords (OTPs). Includes the subject and body of the email message template for sign-in and MFA messages. To activate this setting, your user pool must be in the Essentials tier or higher.
11077 11078 11079 11080 11081 11082 11083 11084 11085 11086 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11077 class SetUserPoolMfaConfigRequest < Struct.new( :user_pool_id, :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#mfa_configuration ⇒ String
Sets multi-factor authentication (MFA) to be on, off, or optional.
When ON, all users must set up MFA before they can sign in. When
OPTIONAL, your application must make a client-side determination
of whether a user wants to register an MFA device. For user pools
with adaptive authentication with threat protection, choose
OPTIONAL.
When MfaConfiguration is OPTIONAL, managed login doesn't
automatically prompt users to set up MFA. Amazon Cognito generates
MFA prompts in API responses and in managed login for users who have
chosen and configured a preferred MFA factor.
11077 11078 11079 11080 11081 11082 11083 11084 11085 11086 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11077 class SetUserPoolMfaConfigRequest < Struct.new( :user_pool_id, :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#sms_mfa_configuration ⇒ Types::SmsMfaConfigType
Configures user pool SMS messages for MFA. Sets the message template and the SMS message sending configuration for Amazon SNS.
11077 11078 11079 11080 11081 11082 11083 11084 11085 11086 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11077 class SetUserPoolMfaConfigRequest < Struct.new( :user_pool_id, :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#software_token_mfa_configuration ⇒ Types::SoftwareTokenMfaConfigType
Configures a user pool for time-based one-time password (TOTP) MFA. Enables or disables TOTP.
11077 11078 11079 11080 11081 11082 11083 11084 11085 11086 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11077 class SetUserPoolMfaConfigRequest < Struct.new( :user_pool_id, :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
11077 11078 11079 11080 11081 11082 11083 11084 11085 11086 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11077 class SetUserPoolMfaConfigRequest < Struct.new( :user_pool_id, :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#web_authn_configuration ⇒ Types::WebAuthnConfigurationType
The configuration of your user pool for passkey, or WebAuthn, authentication and registration. Includes relying-party configuration, user-verification requirements, and whether passkeys can satisfy MFA requirements.
11077 11078 11079 11080 11081 11082 11083 11084 11085 11086 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11077 class SetUserPoolMfaConfigRequest < Struct.new( :user_pool_id, :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |