Class: Aws::CognitoIdentityProvider::Types::SetUserPoolMfaConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#email_mfa_configurationTypes::EmailMfaConfigType

Sets configuration for user pool email message MFA and sign-in with one-time passwords (OTPs). Includes the subject and body of the email message template for sign-in and MFA messages. To activate this setting, your user pool must be in the [ Essentials tier] or higher.

[1]: docs.aws.amazon.com/cognito/latest/developerguide/feature-plans-features-essentials.html



10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10760

class SetUserPoolMfaConfigRequest < Struct.new(
  :user_pool_id,
  :sms_mfa_configuration,
  :software_token_mfa_configuration,
  :email_mfa_configuration,
  :mfa_configuration,
  :web_authn_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#mfa_configurationString

Sets multi-factor authentication (MFA) to be on, off, or optional. When ‘ON`, all users must set up MFA before they can sign in. When `OPTIONAL`, your application must make a client-side determination of whether a user wants to register an MFA device. For user pools with adaptive authentication with threat protection, choose `OPTIONAL`.

When ‘MfaConfiguration` is `OPTIONAL`, managed login doesn’t automatically prompt users to set up MFA. Amazon Cognito generates MFA prompts in API responses and in managed login for users who have chosen and configured a preferred MFA factor.

Returns:

  • (String)


10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10760

class SetUserPoolMfaConfigRequest < Struct.new(
  :user_pool_id,
  :sms_mfa_configuration,
  :software_token_mfa_configuration,
  :email_mfa_configuration,
  :mfa_configuration,
  :web_authn_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sms_mfa_configurationTypes::SmsMfaConfigType

Configures user pool SMS messages for MFA. Sets the message template and the SMS message sending configuration for Amazon SNS.



10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10760

class SetUserPoolMfaConfigRequest < Struct.new(
  :user_pool_id,
  :sms_mfa_configuration,
  :software_token_mfa_configuration,
  :email_mfa_configuration,
  :mfa_configuration,
  :web_authn_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#software_token_mfa_configurationTypes::SoftwareTokenMfaConfigType

Configures a user pool for time-based one-time password (TOTP) MFA. Enables or disables TOTP.



10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10760

class SetUserPoolMfaConfigRequest < Struct.new(
  :user_pool_id,
  :sms_mfa_configuration,
  :software_token_mfa_configuration,
  :email_mfa_configuration,
  :mfa_configuration,
  :web_authn_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The user pool ID.

Returns:

  • (String)


10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10760

class SetUserPoolMfaConfigRequest < Struct.new(
  :user_pool_id,
  :sms_mfa_configuration,
  :software_token_mfa_configuration,
  :email_mfa_configuration,
  :mfa_configuration,
  :web_authn_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#web_authn_configurationTypes::WebAuthnConfigurationType

The configuration of your user pool for passkey, or WebAuthn, authentication and registration. Includes relying-party configuration, user-verification requirements, and whether passkeys can satisfy MFA requirements.



10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10760

class SetUserPoolMfaConfigRequest < Struct.new(
  :user_pool_id,
  :sms_mfa_configuration,
  :software_token_mfa_configuration,
  :email_mfa_configuration,
  :mfa_configuration,
  :web_authn_configuration)
  SENSITIVE = []
  include Aws::Structure
end