Class: Aws::CognitoIdentityProvider::Types::SetUserPoolMfaConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SetUserPoolMfaConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass SetUserPoolMfaConfigRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
sms_mfa_configuration: {
sms_authentication_message: "SmsVerificationMessageType",
sms_configuration: {
sns_caller_arn: "ArnType", # required
external_id: "StringType",
sns_region: "RegionCodeType",
},
},
software_token_mfa_configuration: {
enabled: false,
},
mfa_configuration: "OFF", # accepts OFF, ON, OPTIONAL
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mfa_configuration ⇒ String
The MFA configuration.
-
#sms_mfa_configuration ⇒ Types::SmsMfaConfigType
The SMS text message MFA configuration.
-
#software_token_mfa_configuration ⇒ Types::SoftwareTokenMfaConfigType
The software token MFA configuration.
-
#user_pool_id ⇒ String
The user pool ID.
Instance Attribute Details
#mfa_configuration ⇒ String
The MFA configuration. If you set the MfaConfiguration value to ‘ON’, only users who have set up an MFA factor can sign in. To learn more, see [Adding Multi-Factor Authentication (MFA) to a user pool](cognito/latest/developerguide/user-pool-settings-mfa.html). Valid values include:
-
`OFF` MFA won't be used for any users.
-
`ON` MFA is required for all users to sign in.
-
`OPTIONAL` MFA will be required only for individual users who have an MFA factor activated.
8421 8422 8423 8424 8425 8426 8427 8428 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8421 class SetUserPoolMfaConfigRequest < Struct.new( :user_pool_id, :sms_mfa_configuration, :software_token_mfa_configuration, :mfa_configuration) SENSITIVE = [] include Aws::Structure end |
#sms_mfa_configuration ⇒ Types::SmsMfaConfigType
The SMS text message MFA configuration.
8421 8422 8423 8424 8425 8426 8427 8428 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8421 class SetUserPoolMfaConfigRequest < Struct.new( :user_pool_id, :sms_mfa_configuration, :software_token_mfa_configuration, :mfa_configuration) SENSITIVE = [] include Aws::Structure end |
#software_token_mfa_configuration ⇒ Types::SoftwareTokenMfaConfigType
The software token MFA configuration.
8421 8422 8423 8424 8425 8426 8427 8428 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8421 class SetUserPoolMfaConfigRequest < Struct.new( :user_pool_id, :sms_mfa_configuration, :software_token_mfa_configuration, :mfa_configuration) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
8421 8422 8423 8424 8425 8426 8427 8428 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8421 class SetUserPoolMfaConfigRequest < Struct.new( :user_pool_id, :sms_mfa_configuration, :software_token_mfa_configuration, :mfa_configuration) SENSITIVE = [] include Aws::Structure end |