Class: Aws::CognitoIdentityProvider::Types::SetUserPoolMfaConfigResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SetUserPoolMfaConfigResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_mfa_configuration ⇒ Types::EmailMfaConfigType
Shows user pool email message configuration for MFA.
-
#mfa_configuration ⇒ String
The MFA configuration.
-
#sms_mfa_configuration ⇒ Types::SmsMfaConfigType
Shows user pool SMS message configuration for MFA.
-
#software_token_mfa_configuration ⇒ Types::SoftwareTokenMfaConfigType
Shows user pool configuration for time-based one-time password (TOTP) MFA.
-
#web_authn_configuration ⇒ Types::WebAuthnConfigurationType
The configuration of your user pool for passkey, or webauthN, biometric and security-key devices.
Instance Attribute Details
#email_mfa_configuration ⇒ Types::EmailMfaConfigType
Shows user pool email message configuration for MFA. Includes the subject and body of the email message template for MFA messages. To activate this setting, [ advanced security features] must be active in your user pool.
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pool-settings-advanced-security.html
9626 9627 9628 9629 9630 9631 9632 9633 9634 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9626 class SetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#mfa_configuration ⇒ String
The MFA configuration. Valid values include:
-
‘OFF` MFA won’t be used for any users.
-
‘ON` MFA is required for all users to sign in.
-
‘OPTIONAL` MFA will be required only for individual users who have an MFA factor enabled.
9626 9627 9628 9629 9630 9631 9632 9633 9634 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9626 class SetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#sms_mfa_configuration ⇒ Types::SmsMfaConfigType
Shows user pool SMS message configuration for MFA. Includes the message template and the SMS message sending configuration for Amazon SNS.
9626 9627 9628 9629 9630 9631 9632 9633 9634 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9626 class SetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#software_token_mfa_configuration ⇒ Types::SoftwareTokenMfaConfigType
Shows user pool configuration for time-based one-time password (TOTP) MFA. Includes TOTP enabled or disabled state.
9626 9627 9628 9629 9630 9631 9632 9633 9634 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9626 class SetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |
#web_authn_configuration ⇒ Types::WebAuthnConfigurationType
The configuration of your user pool for passkey, or webauthN, biometric and security-key devices.
9626 9627 9628 9629 9630 9631 9632 9633 9634 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9626 class SetUserPoolMfaConfigResponse < Struct.new( :sms_mfa_configuration, :software_token_mfa_configuration, :email_mfa_configuration, :mfa_configuration, :web_authn_configuration) SENSITIVE = [] include Aws::Structure end |