Class: Aws::CognitoIdentityProvider::Types::SmsConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::SmsConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass SmsConfigurationType data as a hash:
{
sns_caller_arn: "ArnType", # required
external_id: "StringType",
}
The SMS configuration type that includes the settings the Amazon Cognito User Pool must call for the Amazon Simple Notification Service service to send an SMS message from your Amazon Web Services account. The Amazon Cognito User Pool makes the request to the Amazon SNS Service by using an Identity and Access Management role that you provide for your Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#external_id ⇒ String
The external ID is a value that you should use to add security to your IAM role that is used to call Amazon SNS to send SMS messages for your user pool.
-
#sns_caller_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SNS caller.
Instance Attribute Details
#external_id ⇒ String
The external ID is a value that you should use to add security to your IAM role that is used to call Amazon SNS to send SMS messages for your user pool. If you provide an `ExternalId`, the Amazon Cognito User Pool will include it when attempting to assume your IAM role so that you can set your roles trust policy to require the `ExternalID`. If you use the Amazon Cognito Management Console to create a role for SMS multi-factor authentication (MFA), Amazon Cognito will create a role with the required permissions and a trust policy that demonstrates use of the `ExternalId`.
For more information about the `ExternalId` of a role, see [How to use an external ID when granting access to your Amazon Web Services resources to a third party]
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html
8434 8435 8436 8437 8438 8439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8434 class SmsConfigurationType < Struct.new( :sns_caller_arn, :external_id) SENSITIVE = [] include Aws::Structure end |
#sns_caller_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SNS caller. This is the ARN of the IAM role in your Amazon Web Services account that Amazon Cognito will use to send SMS messages. SMS messages are subject to a [spending limit].
[1]: docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-email-phone-verification.html
8434 8435 8436 8437 8438 8439 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8434 class SmsConfigurationType < Struct.new( :sns_caller_arn, :external_id) SENSITIVE = [] include Aws::Structure end |