Class: Aws::CognitoIdentityProvider::Types::StopUserImportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::StopUserImportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass StopUserImportJobRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
job_id: "UserImportJobIdType", # required
}
Represents the request to stop the user import job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The job ID for the user import job.
-
#user_pool_id ⇒ String
The user pool ID for the user pool that the users are being imported into.
Instance Attribute Details
#job_id ⇒ String
The job ID for the user import job.
8968 8969 8970 8971 8972 8973 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8968 class StopUserImportJobRequest < Struct.new( :user_pool_id, :job_id) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool that the users are being imported into.
8968 8969 8970 8971 8972 8973 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8968 class StopUserImportJobRequest < Struct.new( :user_pool_id, :job_id) SENSITIVE = [] include Aws::Structure end |