Class: Aws::CognitoIdentityProvider::Types::StopUserImportJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass StopUserImportJobRequest data as a hash:

{
  user_pool_id: "UserPoolIdType", # required
  job_id: "UserImportJobIdType", # required
}

Represents the request to stop the user import job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_idString

The job ID for the user import job.

Returns:

  • (String)


8864
8865
8866
8867
8868
8869
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8864

class StopUserImportJobRequest < Struct.new(
  :user_pool_id,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool that the users are being imported into.

Returns:

  • (String)


8864
8865
8866
8867
8868
8869
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8864

class StopUserImportJobRequest < Struct.new(
  :user_pool_id,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end