Class: Aws::CognitoIdentityProvider::Types::TermsExistsException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::TermsExistsException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Terms document names must be unique to the app client. This exception is thrown when you attempt to create terms documents with a duplicate ‘TermsName`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
11119 11120 11121 11122 11123 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11119 class TermsExistsException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |