Class: Aws::CognitoIdentityProvider::Types::TokenValidityUnitsType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::TokenValidityUnitsType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass TokenValidityUnitsType data as a hash:
{
access_token: "seconds", # accepts seconds, minutes, hours, days
id_token: "seconds", # accepts seconds, minutes, hours, days
refresh_token: "seconds", # accepts seconds, minutes, hours, days
}
The data type TokenValidityUnits specifies the time units you use when you set the duration of ID, access, and refresh tokens.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_token ⇒ String
A time unit of `seconds`, `minutes`, `hours`, or `days` for the value that you set in the `AccessTokenValidity` parameter.
-
#id_token ⇒ String
A time unit of `seconds`, `minutes`, `hours`, or `days` for the value that you set in the `IdTokenValidity` parameter.
-
#refresh_token ⇒ String
A time unit of `seconds`, `minutes`, `hours`, or `days` for the value that you set in the `RefreshTokenValidity` parameter.
Instance Attribute Details
#access_token ⇒ String
A time unit of `seconds`, `minutes`, `hours`, or `days` for the value that you set in the `AccessTokenValidity` parameter. The default `AccessTokenValidity` time unit is hours.
9017 9018 9019 9020 9021 9022 9023 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9017 class TokenValidityUnitsType < Struct.new( :access_token, :id_token, :refresh_token) SENSITIVE = [] include Aws::Structure end |
#id_token ⇒ String
A time unit of `seconds`, `minutes`, `hours`, or `days` for the value that you set in the `IdTokenValidity` parameter. The default `IdTokenValidity` time unit is hours.
9017 9018 9019 9020 9021 9022 9023 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9017 class TokenValidityUnitsType < Struct.new( :access_token, :id_token, :refresh_token) SENSITIVE = [] include Aws::Structure end |
#refresh_token ⇒ String
A time unit of `seconds`, `minutes`, `hours`, or `days` for the value that you set in the `RefreshTokenValidity` parameter. The default `RefreshTokenValidity` time unit is days.
9017 9018 9019 9020 9021 9022 9023 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9017 class TokenValidityUnitsType < Struct.new( :access_token, :id_token, :refresh_token) SENSITIVE = [] include Aws::Structure end |