Class: Aws::CognitoIdentityProvider::Types::UpdateAuthEventFeedbackRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateAuthEventFeedbackRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username, :feedback_token]
Instance Attribute Summary collapse
-
#event_id ⇒ String
The ID of the authentication event that you want to submit feedback for.
-
#feedback_token ⇒ String
The feedback token, an encrypted object generated by Amazon Cognito and passed to your user in the notification email message from the event.
-
#feedback_value ⇒ String
Your feedback to the authentication event.
-
#user_pool_id ⇒ String
The ID of the user pool where you want to update auth event feedback.
-
#username ⇒ String
The name of the user that you want to query or modify.
Instance Attribute Details
#event_id ⇒ String
The ID of the authentication event that you want to submit feedback for.
11762 11763 11764 11765 11766 11767 11768 11769 11770 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11762 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#feedback_token ⇒ String
The feedback token, an encrypted object generated by Amazon Cognito and passed to your user in the notification email message from the event.
11762 11763 11764 11765 11766 11767 11768 11769 11770 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11762 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#feedback_value ⇒ String
Your feedback to the authentication event. When you provide a ‘FeedbackValue` value of `valid`, you tell Amazon Cognito that you trust a user session where Amazon Cognito has evaluated some level of risk. When you provide a `FeedbackValue` value of `invalid`, you tell Amazon Cognito that you don’t trust a user session, or you don’t believe that Amazon Cognito evaluated a high-enough risk level.
11762 11763 11764 11765 11766 11767 11768 11769 11770 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11762 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool where you want to update auth event feedback.
11762 11763 11764 11765 11766 11767 11768 11769 11770 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11762 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#username ⇒ String
The name of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, this value must be the ‘sub` of a local user or the username of a user from a third-party IdP.
11762 11763 11764 11765 11766 11767 11768 11769 11770 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11762 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |