Class: Aws::CognitoIdentityProvider::Types::UpdateAuthEventFeedbackRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateAuthEventFeedbackRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username, :feedback_token]
Instance Attribute Summary collapse
-
#event_id ⇒ String
The event ID.
-
#feedback_token ⇒ String
The feedback token.
-
#feedback_value ⇒ String
The authentication event feedback value.
-
#user_pool_id ⇒ String
The user pool ID.
-
#username ⇒ String
The username of the user that you want to query or modify.
Instance Attribute Details
#event_id ⇒ String
The event ID.
8457 8458 8459 8460 8461 8462 8463 8464 8465 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8457 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#feedback_token ⇒ String
The feedback token.
8457 8458 8459 8460 8461 8462 8463 8464 8465 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8457 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#feedback_value ⇒ String
The authentication event feedback value. When you provide a ‘FeedbackValue` value of `valid`, you tell Amazon Cognito that you trust a user session where Amazon Cognito has evaluated some level of risk. When you provide a `FeedbackValue` value of `invalid`, you tell Amazon Cognito that you don’t trust a user session, or you don’t believe that Amazon Cognito evaluated a high-enough risk level.
8457 8458 8459 8460 8461 8462 8463 8464 8465 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8457 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
8457 8458 8459 8460 8461 8462 8463 8464 8465 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8457 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#username ⇒ String
The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, you can also use their ‘sub` in this request.
8457 8458 8459 8460 8461 8462 8463 8464 8465 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8457 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |