Class: Aws::CognitoIdentityProvider::Types::UpdateAuthEventFeedbackRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateAuthEventFeedbackRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username, :feedback_token]
Instance Attribute Summary collapse
-
#event_id ⇒ String
The event ID.
-
#feedback_token ⇒ String
The feedback token.
-
#feedback_value ⇒ String
The authentication event feedback value.
-
#user_pool_id ⇒ String
The user pool ID.
-
#username ⇒ String
The username of the user that you want to query or modify.
Instance Attribute Details
#event_id ⇒ String
The event ID.
8349 8350 8351 8352 8353 8354 8355 8356 8357 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8349 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#feedback_token ⇒ String
The feedback token.
8349 8350 8351 8352 8353 8354 8355 8356 8357 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8349 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#feedback_value ⇒ String
The authentication event feedback value. When you provide a ‘FeedbackValue` value of `valid`, you tell Amazon Cognito that you trust a user session where Amazon Cognito has evaluated some level of risk. When you provide a `FeedbackValue` value of `invalid`, you tell Amazon Cognito that you don’t trust a user session, or you don’t believe that Amazon Cognito evaluated a high-enough risk level.
8349 8350 8351 8352 8353 8354 8355 8356 8357 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8349 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID.
8349 8350 8351 8352 8353 8354 8355 8356 8357 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8349 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |
#username ⇒ String
The username of the user that you want to query or modify. The value of this parameter is typically your user’s username, but it can be any of their alias attributes. If ‘username` isn’t an alias attribute in your user pool, you can also use their ‘sub` in this request.
8349 8350 8351 8352 8353 8354 8355 8356 8357 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8349 class UpdateAuthEventFeedbackRequest < Struct.new( :user_pool_id, :username, :event_id, :feedback_token, :feedback_value) SENSITIVE = [:username, :feedback_token] include Aws::Structure end |