Class: Aws::CognitoIdentityProvider::Types::UpdateAuthEventFeedbackRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:username, :feedback_token]

Instance Attribute Summary collapse

Instance Attribute Details

#event_idString

The event ID.

Returns:

  • (String)


8014
8015
8016
8017
8018
8019
8020
8021
8022
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8014

class UpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_token,
  :feedback_value)
  SENSITIVE = [:username, :feedback_token]
  include Aws::Structure
end

#feedback_tokenString

The feedback token.

Returns:

  • (String)


8014
8015
8016
8017
8018
8019
8020
8021
8022
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8014

class UpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_token,
  :feedback_value)
  SENSITIVE = [:username, :feedback_token]
  include Aws::Structure
end

#feedback_valueString

The authentication event feedback value. When you provide a ‘FeedbackValue` value of `valid`, you tell Amazon Cognito that you trust a user session where Amazon Cognito has evaluated some level of risk. When you provide a `FeedbackValue` value of `invalid`, you tell Amazon Cognito that you don’t trust a user session, or you don’t believe that Amazon Cognito evaluated a high-enough risk level.

Returns:

  • (String)


8014
8015
8016
8017
8018
8019
8020
8021
8022
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8014

class UpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_token,
  :feedback_value)
  SENSITIVE = [:username, :feedback_token]
  include Aws::Structure
end

#user_pool_idString

The user pool ID.

Returns:

  • (String)


8014
8015
8016
8017
8018
8019
8020
8021
8022
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8014

class UpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_token,
  :feedback_value)
  SENSITIVE = [:username, :feedback_token]
  include Aws::Structure
end

#usernameString

The user pool username.

Returns:

  • (String)


8014
8015
8016
8017
8018
8019
8020
8021
8022
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8014

class UpdateAuthEventFeedbackRequest < Struct.new(
  :user_pool_id,
  :username,
  :event_id,
  :feedback_token,
  :feedback_value)
  SENSITIVE = [:username, :feedback_token]
  include Aws::Structure
end