Class: Aws::CognitoIdentityProvider::Types::UpdateUserAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateUserAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass UpdateUserAttributesRequest data as a hash:
{
user_attributes: [ # required
{
name: "AttributeNameType", # required
value: "AttributeValueType",
},
],
access_token: "TokenModelType", # required
client_metadata: {
"StringType" => "StringType",
},
}
Represents the request to update user attributes.
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token for the request to update user attributes.
-
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action initiates.
-
#user_attributes ⇒ Array<Types::AttributeType>
An array of name-value pairs representing user attributes.
Instance Attribute Details
#access_token ⇒ String
The access token for the request to update user attributes.
9324 9325 9326 9327 9328 9329 9330 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9324 class UpdateUserAttributesRequest < Struct.new( :user_attributes, :access_token, :client_metadata) SENSITIVE = [:access_token] include Aws::Structure end |
#client_metadata ⇒ Hash<String,String>
A map of custom key-value pairs that you can provide as input for any custom workflows that this action initiates.
You create custom workflows by assigning Lambda functions to user pool triggers. When you use the UpdateUserAttributes API action, Amazon Cognito invokes the function that is assigned to the *custom message* trigger. When Amazon Cognito invokes this function, it passes a JSON payload, which the function receives as input. This payload contains a `clientMetadata` attribute, which provides the data that you assigned to the ClientMetadata parameter in your UpdateUserAttributes request. In your function code in Lambda, you can process the `clientMetadata` value to enhance your workflow for your specific needs.
For more information, see [ Customizing user pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.
<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won't do the following:
* Store the ClientMetadata value. This data is available only to
Lambda triggers that are assigned to a user pool to support custom
workflows. If your user pool configuration doesn't include
triggers, the ClientMetadata parameter serves no purpose.
-
Validate the ClientMetadata value.
-
Encrypt the ClientMetadata value. Don't use Amazon Cognito to provide sensitive information.
</note>
9324 9325 9326 9327 9328 9329 9330 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9324 class UpdateUserAttributesRequest < Struct.new( :user_attributes, :access_token, :client_metadata) SENSITIVE = [:access_token] include Aws::Structure end |
#user_attributes ⇒ Array<Types::AttributeType>
An array of name-value pairs representing user attributes.
For custom attributes, you must prepend the `custom:` prefix to the attribute name.
9324 9325 9326 9327 9328 9329 9330 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9324 class UpdateUserAttributesRequest < Struct.new( :user_attributes, :access_token, :client_metadata) SENSITIVE = [:access_token] include Aws::Structure end |