Class: Aws::CognitoIdentityProvider::Types::UpdateUserAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass UpdateUserAttributesRequest data as a hash:

{
  user_attributes: [ # required
    {
      name: "AttributeNameType", # required
      value: "AttributeValueType",
    },
  ],
  access_token: "TokenModelType", # required
  client_metadata: {
    "StringType" => "StringType",
  },
}

Represents the request to update user attributes.

Constant Summary collapse

SENSITIVE =
[:access_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tokenString

The access token for the request to update user attributes.

Returns:

  • (String)


9252
9253
9254
9255
9256
9257
9258
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9252

class UpdateUserAttributesRequest < Struct.new(
  :user_attributes,
  :access_token,
  :client_metadata)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#client_metadataHash<String,String>

A map of custom key-value pairs that you can provide as input for any custom workflows that this action initiates.

You create custom workflows by assigning Lambda functions to user pool triggers. When you use the UpdateUserAttributes API action, Amazon Cognito invokes the function that is assigned to the *custom message* trigger. When Amazon Cognito invokes this function, it passes a JSON payload, which the function receives as input. This payload contains a `clientMetadata` attribute, which provides the data that you assigned to the ClientMetadata parameter in your UpdateUserAttributes request. In your function code in Lambda, you can process the `clientMetadata` value to enhance your workflow for your specific needs.

For more information, see [Customizing User Pool Workflows with Lambda Triggers] in the *Amazon Cognito Developer Guide*.

<note markdown=“1”> When you use the ClientMetadata parameter, remember that Amazon Cognito won't do the following:

* Store the ClientMetadata value. This data is available only to
 Lambda triggers that are assigned to a user pool to support custom
 workflows. If your user pool configuration doesn't include
 triggers, the ClientMetadata parameter serves no purpose.
  • Validate the ClientMetadata value.

  • Encrypt the ClientMetadata value. Don't use Amazon Cognito to provide sensitive information.

</note>

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools-working-with-aws-lambda-triggers.html

Returns:

  • (Hash<String,String>)


9252
9253
9254
9255
9256
9257
9258
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9252

class UpdateUserAttributesRequest < Struct.new(
  :user_attributes,
  :access_token,
  :client_metadata)
  SENSITIVE = [:access_token]
  include Aws::Structure
end

#user_attributesArray<Types::AttributeType>

An array of name-value pairs representing user attributes.

For custom attributes, you must prepend the `custom:` prefix to the attribute name.

Returns:



9252
9253
9254
9255
9256
9257
9258
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9252

class UpdateUserAttributesRequest < Struct.new(
  :user_attributes,
  :access_token,
  :client_metadata)
  SENSITIVE = [:access_token]
  include Aws::Structure
end