Class: Aws::CognitoIdentityProvider::Types::UpdateUserPoolClientRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateUserPoolClientRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass UpdateUserPoolClientRequest data as a hash:
{
user_pool_id: "UserPoolIdType", # required
client_id: "ClientIdType", # required
client_name: "ClientNameType",
refresh_token_validity: 1,
access_token_validity: 1,
id_token_validity: 1,
token_validity_units: {
access_token: "seconds", # accepts seconds, minutes, hours, days
id_token: "seconds", # accepts seconds, minutes, hours, days
refresh_token: "seconds", # accepts seconds, minutes, hours, days
},
read_attributes: ["ClientPermissionType"],
write_attributes: ["ClientPermissionType"],
explicit_auth_flows: ["ADMIN_NO_SRP_AUTH"], # accepts ADMIN_NO_SRP_AUTH, CUSTOM_AUTH_FLOW_ONLY, USER_PASSWORD_AUTH, ALLOW_ADMIN_USER_PASSWORD_AUTH, ALLOW_CUSTOM_AUTH, ALLOW_USER_PASSWORD_AUTH, ALLOW_USER_SRP_AUTH, ALLOW_REFRESH_TOKEN_AUTH
supported_identity_providers: ["ProviderNameType"],
callback_urls: ["RedirectUrlType"],
logout_urls: ["RedirectUrlType"],
default_redirect_uri: "RedirectUrlType",
allowed_o_auth_flows: ["code"], # accepts code, implicit, client_credentials
allowed_o_auth_scopes: ["ScopeType"],
allowed_o_auth_flows_user_pool_client: false,
analytics_configuration: {
application_id: "HexStringType",
application_arn: "ArnType",
role_arn: "ArnType",
external_id: "StringType",
user_data_shared: false,
},
prevent_user_existence_errors: "LEGACY", # accepts LEGACY, ENABLED
enable_token_revocation: false,
}
Represents the request to update the user pool client.
Constant Summary collapse
- SENSITIVE =
[:client_id]
Instance Attribute Summary collapse
-
#access_token_validity ⇒ Integer
The time limit after which the access token is no longer valid and can't be used.
-
#allowed_o_auth_flows ⇒ Array<String>
The allowed OAuth flows.
-
#allowed_o_auth_flows_user_pool_client ⇒ Boolean
Set to true if the client is allowed to follow the OAuth protocol when interacting with Amazon Cognito user pools.
-
#allowed_o_auth_scopes ⇒ Array<String>
The allowed OAuth scopes.
-
#analytics_configuration ⇒ Types::AnalyticsConfigurationType
The Amazon Pinpoint analytics configuration for collecting metrics for this user pool.
-
#callback_urls ⇒ Array<String>
A list of allowed redirect (callback) URLs for the identity providers.
-
#client_id ⇒ String
The ID of the client associated with the user pool.
-
#client_name ⇒ String
The client name from the update user pool client request.
-
#default_redirect_uri ⇒ String
The default redirect URI.
-
#enable_token_revocation ⇒ Boolean
Activates or deactivates token revocation.
-
#explicit_auth_flows ⇒ Array<String>
The authentication flows that are supported by the user pool clients.
-
#id_token_validity ⇒ Integer
The time limit after which the ID token is no longer valid and can't be used.
-
#logout_urls ⇒ Array<String>
A list of allowed logout URLs for the identity providers.
-
#prevent_user_existence_errors ⇒ String
Errors and responses that you want Amazon Cognito APIs to return during authentication, account confirmation, and password recovery when the user doesn't exist in the user pool.
-
#read_attributes ⇒ Array<String>
The read-only attributes of the user pool.
-
#refresh_token_validity ⇒ Integer
The time limit, in days, after which the refresh token is no longer valid and can't be used.
-
#supported_identity_providers ⇒ Array<String>
A list of provider names for the identity providers that are supported on this client.
-
#token_validity_units ⇒ Types::TokenValidityUnitsType
The units in which the validity times are represented.
-
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to update the user pool client.
-
#write_attributes ⇒ Array<String>
The writeable attributes of the user pool.
Instance Attribute Details
#access_token_validity ⇒ Integer
The time limit after which the access token is no longer valid and can't be used.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#allowed_o_auth_flows ⇒ Array<String>
The allowed OAuth flows.
Set to `code` to initiate a code grant flow, which provides an authorization code as the response. This code can be exchanged for access tokens with the token endpoint.
Set to `implicit` to specify that the client should get the access token (and, optionally, ID token, based on scopes) directly.
Set to `client_credentials` to specify that the client should get the access token (and, optionally, ID token, based on scopes) from the token endpoint using a combination of client and client_secret.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#allowed_o_auth_flows_user_pool_client ⇒ Boolean
Set to true if the client is allowed to follow the OAuth protocol when interacting with Amazon Cognito user pools.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#allowed_o_auth_scopes ⇒ Array<String>
The allowed OAuth scopes. Possible values provided by OAuth are: `phone`, `email`, `openid`, and `profile`. Possible values provided by Amazon Web Services are: `aws.cognito.signin.user.admin`. Custom scopes created in Resource Servers are also supported.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#analytics_configuration ⇒ Types::AnalyticsConfigurationType
The Amazon Pinpoint analytics configuration for collecting metrics for this user pool.
<note markdown=“1”> In Amazon Web Services Regions where Amazon Pinpoint isn't available, user pools only support sending events to Amazon Pinpoint projects in us-east-1. In Regions where Amazon Pinpoint is available, user pools support sending events to Amazon Pinpoint projects within that same Region.
</note>
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#callback_urls ⇒ Array<String>
A list of allowed redirect (callback) URLs for the identity providers.
A redirect URI must:
-
Be an absolute URI.
-
Be registered with the authorization server.
-
Not include a fragment component.
See [OAuth 2.0 - Redirection Endpoint].
Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.
App callback URLs such as `myapp://example` are also supported.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#client_id ⇒ String
The ID of the client associated with the user pool.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#client_name ⇒ String
The client name from the update user pool client request.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#default_redirect_uri ⇒ String
The default redirect URI. Must be in the `CallbackURLs` list.
A redirect URI must:
-
Be an absolute URI.
-
Be registered with the authorization server.
-
Not include a fragment component.
See [OAuth 2.0 - Redirection Endpoint].
Amazon Cognito requires HTTPS over HTTP except for `localhost` for testing purposes only.
App callback URLs such as `myapp://example` are also supported.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#enable_token_revocation ⇒ Boolean
Activates or deactivates token revocation. For more information about revoking tokens, see [RevokeToken].
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RevokeToken.html
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#explicit_auth_flows ⇒ Array<String>
The authentication flows that are supported by the user pool clients. Flow names without the `ALLOW_` prefix are no longer supported in favor of new names with the `ALLOW_` prefix. Note that values with `ALLOW_` prefix must be used only along with values with the `ALLOW_` prefix.
Valid values include:
-
`ALLOW_ADMIN_USER_PASSWORD_AUTH`: Enable admin based user password authentication flow `ADMIN_USER_PASSWORD_AUTH`. This setting replaces the `ADMIN_NO_SRP_AUTH` setting. With this authentication flow, Amazon Cognito receives the password in the request instead of using the Secure Remote Password (SRP) protocol to verify passwords.
-
`ALLOW_CUSTOM_AUTH`: Enable Lambda trigger based authentication.
-
`ALLOW_USER_PASSWORD_AUTH`: Enable user password-based authentication. In this flow, Amazon Cognito receives the password in the request instead of using the SRP protocol to verify passwords.
-
`ALLOW_USER_SRP_AUTH`: Enable SRP-based authentication.
-
`ALLOW_REFRESH_TOKEN_AUTH`: Enable authflow to refresh tokens.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#id_token_validity ⇒ Integer
The time limit after which the ID token is no longer valid and can't be used.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#logout_urls ⇒ Array<String>
A list of allowed logout URLs for the identity providers.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#prevent_user_existence_errors ⇒ String
Errors and responses that you want Amazon Cognito APIs to return during authentication, account confirmation, and password recovery when the user doesn't exist in the user pool. When set to `ENABLED` and the user doesn't exist, authentication returns an error indicating either the username or password was incorrect. Account confirmation and password recovery return a response indicating a code was sent to a simulated destination. When set to `LEGACY`, those APIs return a `UserNotFoundException` exception if the user doesn't exist in the user pool.
Valid values include:
-
`ENABLED` - This prevents user existence-related errors.
-
`LEGACY` - This represents the early behavior of Amazon Cognito where user existence related errors aren't prevented.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#read_attributes ⇒ Array<String>
The read-only attributes of the user pool.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#refresh_token_validity ⇒ Integer
The time limit, in days, after which the refresh token is no longer valid and can't be used.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#supported_identity_providers ⇒ Array<String>
A list of provider names for the identity providers that are supported on this client.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#token_validity_units ⇒ Types::TokenValidityUnitsType
The units in which the validity times are represented. Default for RefreshToken is days, and default for ID and access tokens is hours.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool where you want to update the user pool client.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |
#write_attributes ⇒ Array<String>
The writeable attributes of the user pool.
9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9581 class UpdateUserPoolClientRequest < Struct.new( :user_pool_id, :client_id, :client_name, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id] include Aws::Structure end |