Class: Aws::CognitoIdentityProvider::Types::UpdateUserPoolDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateUserPoolDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The UpdateUserPoolDomain request input.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain that hosts managed login for your application.
-
#domain ⇒ String
The name of the domain that you want to update.
-
#managed_login_version ⇒ Integer
A version number that indicates the state of managed login for your domain.
-
#routing ⇒ Types::RoutingType
The routing configuration for the user pool domain.
-
#user_pool_id ⇒ String
The ID of the user pool that is associated with the domain you’re updating.
Instance Attribute Details
#custom_domain_config ⇒ Types::CustomDomainConfigType
The configuration for a custom domain that hosts managed login for your application. In an ‘UpdateUserPoolDomain` request, this parameter specifies an SSL certificate for the managed login hosted webserver. The certificate must be an ACM ARN in `us-east-1`.
When you create a custom domain, the passkey RP ID defaults to the custom domain. If you had a prefix domain active, this will cause passkey integration for your prefix domain to stop working due to a mismatch in RP ID. To keep the prefix domain passkey integration working, you can explicitly set RP ID to the prefix domain.
12791 12792 12793 12794 12795 12796 12797 12798 12799 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12791 class UpdateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config, :routing) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The name of the domain that you want to update. For custom domains, this is the fully-qualified domain name, for example ‘auth.example.com`. For prefix domains, this is the prefix alone, such as `myprefix`.
12791 12792 12793 12794 12795 12796 12797 12798 12799 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12791 class UpdateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config, :routing) SENSITIVE = [] include Aws::Structure end |
#managed_login_version ⇒ Integer
A version number that indicates the state of managed login for your domain. Version ‘1` is hosted UI (classic). Version `2` is the newer managed login with the branding editor. For more information, see [Managed login].
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-managed-login.html
12791 12792 12793 12794 12795 12796 12797 12798 12799 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12791 class UpdateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config, :routing) SENSITIVE = [] include Aws::Structure end |
#routing ⇒ Types::RoutingType
The routing configuration for the user pool domain. Specifies failover settings for multi-region deployments.
12791 12792 12793 12794 12795 12796 12797 12798 12799 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12791 class UpdateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config, :routing) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool that is associated with the domain you’re updating.
12791 12792 12793 12794 12795 12796 12797 12798 12799 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12791 class UpdateUserPoolDomainRequest < Struct.new( :domain, :user_pool_id, :managed_login_version, :custom_domain_config, :routing) SENSITIVE = [] include Aws::Structure end |