Class: Aws::CognitoIdentityProvider::Types::UpdateUserPoolReplicaRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UpdateUserPoolReplicaRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#region_name ⇒ String
The Amazon Web Services Region of the replica to update.
-
#status ⇒ String
The status to set for the replica.
-
#user_pool_id ⇒ String
The ID of the user pool that contains the replica to update.
Instance Attribute Details
#region_name ⇒ String
The Amazon Web Services Region of the replica to update.
12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12853 class UpdateUserPoolReplicaRequest < Struct.new( :user_pool_id, :region_name, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status to set for the replica. Valid values are ACTIVE and INACTIVE.
12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12853 class UpdateUserPoolReplicaRequest < Struct.new( :user_pool_id, :region_name, :status) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The ID of the user pool that contains the replica to update.
12853 12854 12855 12856 12857 12858 12859 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 12853 class UpdateUserPoolReplicaRequest < Struct.new( :user_pool_id, :region_name, :status) SENSITIVE = [] include Aws::Structure end |