Class: Aws::CognitoIdentityProvider::Types::UserContextDataType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Contextual data, such as the user's device fingerprint, IP address, or location, used for evaluating the risk of an unexpected event by Amazon Cognito threat protection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encoded_dataString

Encoded device-fingerprint details that your app collected with the Amazon Cognito context data collection library. For more information, see Adding user device and session data to API requests.

Returns:

  • (String)


13312
13313
13314
13315
13316
13317
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13312

class UserContextDataType < Struct.new(
  :ip_address,
  :encoded_data)
  SENSITIVE = []
  include Aws::Structure
end

#ip_addressString

The source IP address of your user's device.

Returns:

  • (String)


13312
13313
13314
13315
13316
13317
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13312

class UserContextDataType < Struct.new(
  :ip_address,
  :encoded_data)
  SENSITIVE = []
  include Aws::Structure
end