Class: Aws::CognitoIdentityProvider::Types::UserContextDataType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UserContextDataType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Contextual data, such as the user’s device fingerprint, IP address, or location, used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.
This data type is a request parameter of public-client authentication operations like [InitiateAuth] and [RespondToAuthChallenge].
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_InitiateAuth.html [2]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RespondToAuthChallenge.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encoded_data ⇒ String
Encoded device-fingerprint details that your app collected with the Amazon Cognito context data collection library.
-
#ip_address ⇒ String
The source IP address of your user’s device.
Instance Attribute Details
#encoded_data ⇒ String
Encoded device-fingerprint details that your app collected with the Amazon Cognito context data collection library. For more information, see [Adding user device and session data to API requests].
11719 11720 11721 11722 11723 11724 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11719 class UserContextDataType < Struct.new( :ip_address, :encoded_data) SENSITIVE = [] include Aws::Structure end |
#ip_address ⇒ String
The source IP address of your user’s device.
11719 11720 11721 11722 11723 11724 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11719 class UserContextDataType < Struct.new( :ip_address, :encoded_data) SENSITIVE = [] include Aws::Structure end |