Class: Aws::CognitoIdentityProvider::Types::UserContextDataType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Contextual data, such as the user’s device fingerprint, IP address, or location, used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encoded_dataString

Encoded device-fingerprint details that your app collected with the Amazon Cognito context data collection library. For more information, see [Adding user device and session data to API requests].

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pool-settings-adaptive-authentication.html#user-pool-settings-adaptive-authentication-device-fingerprint

Returns:

  • (String)


8942
8943
8944
8945
8946
8947
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8942

class UserContextDataType < Struct.new(
  :ip_address,
  :encoded_data)
  SENSITIVE = []
  include Aws::Structure
end

#ip_addressString

The source IP address of your user’s device.

Returns:

  • (String)


8942
8943
8944
8945
8946
8947
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 8942

class UserContextDataType < Struct.new(
  :ip_address,
  :encoded_data)
  SENSITIVE = []
  include Aws::Structure
end