Class: Aws::CognitoIdentityProvider::Types::UserContextDataType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UserContextDataType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass UserContextDataType data as a hash:
{
encoded_data: "StringType",
}
Information that your app generates about a user's `AdminInitiateAuth` or `AdminRespondToAuthChallenge` session. Amazon Cognito advanced security features calculate risk levels for user sessions based on this context data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encoded_data ⇒ String
Contextual data, such as the user's device fingerprint, IP address, or location, used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.
Instance Attribute Details
#encoded_data ⇒ String
Contextual data, such as the user's device fingerprint, IP address, or location, used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.
10153 10154 10155 10156 10157 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10153 class UserContextDataType < Struct.new( :encoded_data) SENSITIVE = [] include Aws::Structure end |