Class: Aws::CognitoIdentityProvider::Types::UserContextDataType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Note:

When making an API call, you may pass UserContextDataType data as a hash:

{
  encoded_data: "StringType",
}

Contextual data, such as the user's device fingerprint, IP address, or location, used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encoded_dataString

Contextual data, such as the user's device fingerprint, IP address, or location, used for evaluating the risk of an unexpected event by Amazon Cognito advanced security.

Returns:

  • (String)


9846
9847
9848
9849
9850
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9846

class UserContextDataType < Struct.new(
  :encoded_data)
  SENSITIVE = []
  include Aws::Structure
end