Class: Aws::CognitoIdentityProvider::Types::UserImportJobType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UserImportJobType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
The user import job type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_logs_role_arn ⇒ String
The role Amazon Resource Name (ARN) for the Amazon CloudWatch Logging role for the user import job.
-
#completion_date ⇒ Time
The date when the user import job was completed.
-
#completion_message ⇒ String
The message returned when the user import job is completed.
-
#creation_date ⇒ Time
The date and time when the item was created.
-
#failed_users ⇒ Integer
The number of users that couldn’t be imported.
-
#imported_users ⇒ Integer
The number of users that were successfully imported.
-
#job_id ⇒ String
The job ID for the user import job.
-
#job_name ⇒ String
The job name for the user import job.
-
#pre_signed_url ⇒ String
The pre-signed URL to be used to upload the ‘.csv` file.
-
#skipped_users ⇒ Integer
The number of users that were skipped.
-
#start_date ⇒ Time
The date when the user import job was started.
-
#status ⇒ String
The status of the user import job.
-
#user_pool_id ⇒ String
The user pool ID for the user pool that the users are being imported into.
Instance Attribute Details
#cloud_watch_logs_role_arn ⇒ String
The role Amazon Resource Name (ARN) for the Amazon CloudWatch Logging role for the user import job. For more information, see “Creating the CloudWatch Logs IAM Role” in the Amazon Cognito Developer Guide.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#completion_date ⇒ Time
The date when the user import job was completed.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#completion_message ⇒ String
The message returned when the user import job is completed.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time when the item was created. Amazon Cognito returns this timestamp in UNIX epoch time format. Your SDK might render the output in a human-readable format like ISO 8601 or a Java ‘Date` object.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#failed_users ⇒ Integer
The number of users that couldn’t be imported.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#imported_users ⇒ Integer
The number of users that were successfully imported.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID for the user import job.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The job name for the user import job.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#pre_signed_url ⇒ String
The pre-signed URL to be used to upload the ‘.csv` file.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#skipped_users ⇒ Integer
The number of users that were skipped.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The date when the user import job was started.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the user import job. One of the following:
-
‘Created` - The job was created but not started.
-
‘Pending` - A transition state. You have started the job, but it has not begun importing users yet.
-
‘InProgress` - The job has started, and users are being imported.
-
‘Stopping` - You have stopped the job, but the job has not stopped importing users yet.
-
‘Stopped` - You have stopped the job, and the job has stopped importing users.
-
‘Succeeded` - The job has completed successfully.
-
‘Failed` - The job has stopped due to an error.
-
‘Expired` - You created a job, but did not start the job within 24-48 hours. All data associated with the job was deleted, and the job can’t be started.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool that the users are being imported into.
9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9753 class UserImportJobType < Struct.new( :job_name, :job_id, :user_pool_id, :pre_signed_url, :creation_date, :start_date, :completion_date, :status, :cloud_watch_logs_role_arn, :imported_users, :skipped_users, :failed_users, :completion_message) SENSITIVE = [] include Aws::Structure end |