Class: Aws::CognitoIdentityProvider::Types::UserImportJobType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The user import job type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_watch_logs_role_arnString

The role Amazon Resource Name (ARN) for the Amazon CloudWatch Logging role for the user import job. For more information, see “Creating the CloudWatch Logs IAM Role” in the Amazon Cognito Developer Guide.

Returns:

  • (String)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#completion_dateTime

The date when the user import job was completed.

Returns:

  • (Time)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#completion_messageString

The message returned when the user import job is completed.

Returns:

  • (String)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date the user import job was created.

Returns:

  • (Time)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#failed_usersInteger

The number of users that couldn't be imported.

Returns:

  • (Integer)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#imported_usersInteger

The number of users that were successfully imported.

Returns:

  • (Integer)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID for the user import job.

Returns:

  • (String)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The job name for the user import job.

Returns:

  • (String)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#pre_signed_urlString

The pre-signed URL to be used to upload the `.csv` file.

Returns:

  • (String)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#skipped_usersInteger

The number of users that were skipped.

Returns:

  • (Integer)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#start_dateTime

The date when the user import job was started.

Returns:

  • (Time)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the user import job. One of the following:

  • `Created` - The job was created but not started.

  • `Pending` - A transition state. You have started the job, but it has not begun importing users yet.

  • `InProgress` - The job has started, and users are being imported.

  • `Stopping` - You have stopped the job, but the job has not stopped importing users yet.

  • `Stopped` - You have stopped the job, and the job has stopped importing users.

  • `Succeeded` - The job has completed successfully.

  • `Failed` - The job has stopped due to an error.

  • `Expired` - You created a job, but did not start the job within 24-48 hours. All data associated with the job was deleted, and the job can't be started.

Returns:

  • (String)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool that the users are being imported into.

Returns:

  • (String)


10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10530

class UserImportJobType < Struct.new(
  :job_name,
  :job_id,
  :user_pool_id,
  :pre_signed_url,
  :creation_date,
  :start_date,
  :completion_date,
  :status,
  :cloud_watch_logs_role_arn,
  :imported_users,
  :skipped_users,
  :failed_users,
  :completion_message)
  SENSITIVE = []
  include Aws::Structure
end