Class: Aws::CognitoIdentityProvider::Types::UserPoolClientType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Contains information about a user pool client.

Constant Summary collapse

SENSITIVE =
[:client_id, :client_secret]

Instance Attribute Summary collapse

Instance Attribute Details

#access_token_validityInteger

The access token time limit. After this limit expires, your user can’t use their access token. To specify the time unit for ‘AccessTokenValidity` as `seconds`, `minutes`, `hours`, or `days`, set a `TokenValidityUnits` value in your API request.

For example, when you set ‘AccessTokenValidity` to `10` and `TokenValidityUnits` to `hours`, your user can authorize access with their access token for 10 hours.

The default time unit for ‘AccessTokenValidity` in an API request is hours. *Valid range* is displayed below in seconds.

If you don’t specify otherwise in the configuration of your app client, your access tokens are valid for one hour.

Returns:

  • (Integer)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#allowed_o_auth_flowsArray<String>

The allowed OAuth flows.

code

: Use a code grant flow, which provides an authorization code as the

response. This code can be exchanged for access tokens with the
`/oauth2/token` endpoint.

implicit

: Issue the access token (and, optionally, ID token, based on

scopes) directly to your user.

client_credentials

: Issue the access token from the ‘/oauth2/token` endpoint directly

to a non-person user using a combination of the client ID and
client secret.

Returns:

  • (Array<String>)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#allowed_o_auth_flows_user_pool_clientBoolean

Set to ‘true` to use OAuth 2.0 features in your user pool app client.

‘AllowedOAuthFlowsUserPoolClient` must be `true` before you can configure the following features in your app client.

  • ‘CallBackURLs`: Callback URLs.

  • ‘LogoutURLs`: Sign-out redirect URLs.

  • ‘AllowedOAuthScopes`: OAuth 2.0 scopes.

  • ‘AllowedOAuthFlows`: Support for authorization code, implicit, and client credentials OAuth 2.0 grants.

To use OAuth 2.0 features, configure one of these features in the Amazon Cognito console or set ‘AllowedOAuthFlowsUserPoolClient` to `true` in a `CreateUserPoolClient` or `UpdateUserPoolClient` API request. If you don’t set a value for ‘AllowedOAuthFlowsUserPoolClient` in a request with the CLI or SDKs, it defaults to `false`.

Returns:

  • (Boolean)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#allowed_o_auth_scopesArray<String>

The OAuth scopes that your app client supports. Possible values that OAuth provides are ‘phone`, `email`, `openid`, and `profile`. Possible values that Amazon Web Services provides are `aws.cognito.signin.user.admin`. Amazon Cognito also supports custom scopes that you create in Resource Servers.

Returns:

  • (Array<String>)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#analytics_configurationTypes::AnalyticsConfigurationType

The Amazon Pinpoint analytics configuration for the user pool client.

<note markdown=“1”> Amazon Cognito user pools only support sending events to Amazon Pinpoint projects in the US East (N. Virginia) us-east-1 Region, regardless of the Region where the user pool resides.

</note>


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#auth_session_validityInteger

Amazon Cognito creates a session token for each API request in an authentication flow. ‘AuthSessionValidity` is the duration, in minutes, of that session token. Your user pool native user must respond to each authentication challenge before the session expires.

Returns:

  • (Integer)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#callback_urlsArray<String>

A list of allowed redirect (callback) URLs for the IdPs.

A redirect URI must:

  • Be an absolute URI.

  • Be registered with the authorization server.

  • Not include a fragment component.

See [OAuth 2.0 - Redirection Endpoint].

Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.

App callback URLs such as myapp://example are also supported.

[1]: tools.ietf.org/html/rfc6749#section-3.1.2

Returns:

  • (Array<String>)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#client_idString

The ID of the client associated with the user pool.

Returns:

  • (String)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#client_nameString

The client name from the user pool request of the client type.

Returns:

  • (String)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#client_secretString

The client secret from the user pool request of the client type.

Returns:

  • (String)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#creation_dateTime

The date and time, in [ISO 8601] format, when the item was created.

[1]: www.iso.org/iso-8601-date-and-time-format.html

Returns:

  • (Time)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#default_redirect_uriString

The default redirect URI. Must be in the ‘CallbackURLs` list.

A redirect URI must:

  • Be an absolute URI.

  • Be registered with the authorization server.

  • Not include a fragment component.

See [OAuth 2.0 - Redirection Endpoint].

Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.

App callback URLs such as myapp://example are also supported.

[1]: tools.ietf.org/html/rfc6749#section-3.1.2

Returns:

  • (String)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#enable_propagate_additional_user_context_dataBoolean

When ‘EnablePropagateAdditionalUserContextData` is true, Amazon Cognito accepts an `IpAddress` value that you send in the `UserContextData` parameter. The `UserContextData` parameter sends information to Amazon Cognito advanced security for risk analysis. You can send `UserContextData` when you sign in Amazon Cognito native users with the `InitiateAuth` and `RespondToAuthChallenge` API operations.

When ‘EnablePropagateAdditionalUserContextData` is false, you can’t send your user’s source IP address to Amazon Cognito advanced security with unauthenticated API operations. ‘EnablePropagateAdditionalUserContextData` doesn’t affect whether you can send a source IP address in a ‘ContextData` parameter with the authenticated API operations `AdminInitiateAuth` and `AdminRespondToAuthChallenge`.

You can only activate ‘EnablePropagateAdditionalUserContextData` in an app client that has a client secret. For more information about propagation of user context data, see [Adding user device and session data to API requests].

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pool-settings-adaptive-authentication.html#user-pool-settings-adaptive-authentication-device-fingerprint

Returns:

  • (Boolean)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#enable_token_revocationBoolean

Indicates whether token revocation is activated for the user pool client. When you create a new user pool client, token revocation is activated by default. For more information about revoking tokens, see [RevokeToken].

[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RevokeToken.html

Returns:

  • (Boolean)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#explicit_auth_flowsArray<String>

The authentication flows that you want your user pool client to support. For each app client in your user pool, you can sign in your users with any combination of one or more flows, including with a user name and Secure Remote Password (SRP), a user name and password, or a custom authentication process that you define with Lambda functions.

<note markdown=“1”> If you don’t specify a value for ‘ExplicitAuthFlows`, your user client supports `ALLOW_REFRESH_TOKEN_AUTH`, `ALLOW_USER_SRP_AUTH`, and `ALLOW_CUSTOM_AUTH`.

</note>

Valid values include:

  • ‘ALLOW_ADMIN_USER_PASSWORD_AUTH`: Enable admin based user password authentication flow `ADMIN_USER_PASSWORD_AUTH`. This setting replaces the `ADMIN_NO_SRP_AUTH` setting. With this authentication flow, your app passes a user name and password to Amazon Cognito in the request, instead of using the Secure Remote Password (SRP) protocol to securely transmit the password.

  • ‘ALLOW_CUSTOM_AUTH`: Enable Lambda trigger based authentication.

  • ‘ALLOW_USER_PASSWORD_AUTH`: Enable user password-based authentication. In this flow, Amazon Cognito receives the password in the request instead of using the SRP protocol to verify passwords.

  • ‘ALLOW_USER_SRP_AUTH`: Enable SRP-based authentication.

  • ‘ALLOW_REFRESH_TOKEN_AUTH`: Enable authflow to refresh tokens.

In some environments, you will see the values ‘ADMIN_NO_SRP_AUTH`, `CUSTOM_AUTH_FLOW_ONLY`, or `USER_PASSWORD_AUTH`. You can’t assign these legacy ‘ExplicitAuthFlows` values to user pool clients at the same time as values that begin with `ALLOW_`, like `ALLOW_USER_SRP_AUTH`.

Returns:

  • (Array<String>)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#id_token_validityInteger

The ID token time limit. After this limit expires, your user can’t use their ID token. To specify the time unit for ‘IdTokenValidity` as `seconds`, `minutes`, `hours`, or `days`, set a `TokenValidityUnits` value in your API request.

For example, when you set ‘IdTokenValidity` as `10` and `TokenValidityUnits` as `hours`, your user can authenticate their session with their ID token for 10 hours.

The default time unit for ‘IdTokenValidity` in an API request is hours. *Valid range* is displayed below in seconds.

If you don’t specify otherwise in the configuration of your app client, your ID tokens are valid for one hour.

Returns:

  • (Integer)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#last_modified_dateTime

The date and time, in [ISO 8601] format, when the item was modified.

[1]: www.iso.org/iso-8601-date-and-time-format.html

Returns:

  • (Time)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#logout_urlsArray<String>

A list of allowed logout URLs for the IdPs.

Returns:

  • (Array<String>)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#prevent_user_existence_errorsString

Errors and responses that you want Amazon Cognito APIs to return during authentication, account confirmation, and password recovery when the user doesn’t exist in the user pool. When set to ‘ENABLED` and the user doesn’t exist, authentication returns an error indicating either the username or password was incorrect. Account confirmation and password recovery return a response indicating a code was sent to a simulated destination. When set to ‘LEGACY`, those APIs return a `UserNotFoundException` exception if the user doesn’t exist in the user pool.

Valid values include:

  • ‘ENABLED` - This prevents user existence-related errors.

  • ‘LEGACY` - This represents the old behavior of Amazon Cognito where user existence related errors aren’t prevented.

Returns:

  • (String)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#read_attributesArray<String>

The Read-only attributes.

Returns:

  • (Array<String>)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#refresh_token_validityInteger

The refresh token time limit. After this limit expires, your user can’t use their refresh token. To specify the time unit for ‘RefreshTokenValidity` as `seconds`, `minutes`, `hours`, or `days`, set a `TokenValidityUnits` value in your API request.

For example, when you set ‘RefreshTokenValidity` as `10` and `TokenValidityUnits` as `days`, your user can refresh their session and retrieve new access and ID tokens for 10 days.

The default time unit for ‘RefreshTokenValidity` in an API request is days. You can’t set ‘RefreshTokenValidity` to 0. If you do, Amazon Cognito overrides the value with the default value of 30 days. *Valid range* is displayed below in seconds.

If you don’t specify otherwise in the configuration of your app client, your refresh tokens are valid for 30 days.

Returns:

  • (Integer)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#supported_identity_providersArray<String>

A list of provider names for the IdPs that this client supports. The following are supported: ‘COGNITO`, `Facebook`, `Google`, `SignInWithApple`, `LoginWithAmazon`, and the names of your own SAML and OIDC providers.

Returns:

  • (Array<String>)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#token_validity_unitsTypes::TokenValidityUnitsType

The time units used to specify the token validity times of each token type: ID, access, and refresh.



9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool client.

Returns:

  • (String)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#write_attributesArray<String>

The writeable attributes.

Returns:

  • (Array<String>)


9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9481

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data,
  :auth_session_validity)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end