Class: Aws::CognitoIdentityProvider::Types::UserPoolClientType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Contains information about a user pool client.

Constant Summary collapse

SENSITIVE =
[:client_id, :client_secret]

Instance Attribute Summary collapse

Instance Attribute Details

#access_token_validityInteger

The access token time limit. After this limit expires, your user can't use their access token. To specify the time unit for `AccessTokenValidity` as `seconds`, `minutes`, `hours`, or `days`, set a `TokenValidityUnits` value in your API request.

For example, when you set `AccessTokenValidity` to `10` and `TokenValidityUnits` to `hours`, your user can authorize access with their access token for 10 hours.

The default time unit for `AccessTokenValidity` in an API request is hours. *Valid range* is displayed below in seconds.

Returns:

  • (Integer)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#allowed_o_auth_flowsArray<String>

The allowed OAuth flows.

code

: Use a code grant flow, which provides an authorization code as the

response. This code can be exchanged for access tokens with the
`/oauth2/token` endpoint.

implicit

: Issue the access token (and, optionally, ID token, based on

scopes) directly to your user.

client_credentials

: Issue the access token from the `/oauth2/token` endpoint directly

to a non-person user using a combination of the client ID and
client secret.

Returns:

  • (Array<String>)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#allowed_o_auth_flows_user_pool_clientBoolean

Set to true if the client is allowed to follow the OAuth protocol when interacting with Amazon Cognito user pools.

Returns:

  • (Boolean)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#allowed_o_auth_scopesArray<String>

The OAuth scopes that your app client supports. Possible values that OAuth provides are `phone`, `email`, `openid`, and `profile`. Possible values that Amazon Web Services provides are `aws.cognito.signin.user.admin`. Amazon Cognito also supports custom scopes that you create in Resource Servers.

Returns:

  • (Array<String>)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#analytics_configurationTypes::AnalyticsConfigurationType

The Amazon Pinpoint analytics configuration for the user pool client.

<note markdown=“1”> Amazon Cognito user pools only support sending events to Amazon Pinpoint projects in the US East (N. Virginia) us-east-1 Region, regardless of the Region where the user pool resides.

</note>


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#callback_urlsArray<String>

A list of allowed redirect (callback) URLs for the IdPs.

A redirect URI must:

  • Be an absolute URI.

  • Be registered with the authorization server.

  • Not include a fragment component.

See [OAuth 2.0 - Redirection Endpoint].

Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.

App callback URLs such as myapp://example are also supported.

[1]: tools.ietf.org/html/rfc6749#section-3.1.2

Returns:

  • (Array<String>)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#client_idString

The ID of the client associated with the user pool.

Returns:

  • (String)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#client_nameString

The client name from the user pool request of the client type.

Returns:

  • (String)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#client_secretString

The client secret from the user pool request of the client type.

Returns:

  • (String)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#creation_dateTime

The date the user pool client was created.

Returns:

  • (Time)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#default_redirect_uriString

The default redirect URI. Must be in the `CallbackURLs` list.

A redirect URI must:

  • Be an absolute URI.

  • Be registered with the authorization server.

  • Not include a fragment component.

See [OAuth 2.0 - Redirection Endpoint].

Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.

App callback URLs such as myapp://example are also supported.

[1]: tools.ietf.org/html/rfc6749#section-3.1.2

Returns:

  • (String)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#enable_propagate_additional_user_context_dataBoolean

When `EnablePropagateAdditionalUserContextData` is true, Amazon Cognito accepts an `IpAddress` value that you send in the `UserContextData` parameter. The `UserContextData` parameter sends information to Amazon Cognito advanced security for risk analysis. You can send `UserContextData` when you sign in Amazon Cognito native users with the `InitiateAuth` and `RespondToAuthChallenge` API operations.

When `EnablePropagateAdditionalUserContextData` is false, you can't send your user's source IP address to Amazon Cognito advanced security with unauthenticated API operations. `EnablePropagateAdditionalUserContextData` doesn't affect whether you can send a source IP address in a `ContextData` parameter with the authenticated API operations `AdminInitiateAuth` and `AdminRespondToAuthChallenge`.

You can only activate `EnablePropagateAdditionalUserContextData` in an app client that has a client secret. For more information about propagation of user context data, see [Adding user device and session data to API requests].

[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pool-settings-adaptive-authentication.html#user-pool-settings-adaptive-authentication-device-fingerprint

Returns:

  • (Boolean)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#enable_token_revocationBoolean

Indicates whether token revocation is activated for the user pool client. When you create a new user pool client, token revocation is activated by default. For more information about revoking tokens, see [RevokeToken].

[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RevokeToken.html

Returns:

  • (Boolean)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#explicit_auth_flowsArray<String>

The authentication flows that are supported by the user pool clients. Flow names without the `ALLOW_` prefix are no longer supported in favor of new names with the `ALLOW_` prefix. Note that values with `ALLOW_` prefix must be used only along with values including the `ALLOW_` prefix.

Valid values include:

  • `ALLOW_ADMIN_USER_PASSWORD_AUTH`: Enable admin based user password authentication flow `ADMIN_USER_PASSWORD_AUTH`. This setting replaces the `ADMIN_NO_SRP_AUTH` setting. With this authentication flow, Amazon Cognito receives the password in the request instead of using the Secure Remote Password (SRP) protocol to verify passwords.

  • `ALLOW_CUSTOM_AUTH`: Enable Lambda trigger based authentication.

  • `ALLOW_USER_PASSWORD_AUTH`: Enable user password-based authentication. In this flow, Amazon Cognito receives the password in the request instead of using the SRP protocol to verify passwords.

  • `ALLOW_USER_SRP_AUTH`: Enable SRP-based authentication.

  • `ALLOW_REFRESH_TOKEN_AUTH`: Enable authflow to refresh tokens.

Returns:

  • (Array<String>)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#id_token_validityInteger

The ID token time limit. After this limit expires, your user can't use their ID token. To specify the time unit for `IdTokenValidity` as `seconds`, `minutes`, `hours`, or `days`, set a `TokenValidityUnits` value in your API request.

For example, when you set `IdTokenValidity` as `10` and `TokenValidityUnits` as `hours`, your user can authenticate their session with their ID token for 10 hours.

The default time unit for `AccessTokenValidity` in an API request is hours. *Valid range* is displayed below in seconds.

Returns:

  • (Integer)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#last_modified_dateTime

The date the user pool client was last modified.

Returns:

  • (Time)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#logout_urlsArray<String>

A list of allowed logout URLs for the IdPs.

Returns:

  • (Array<String>)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#prevent_user_existence_errorsString

Errors and responses that you want Amazon Cognito APIs to return during authentication, account confirmation, and password recovery when the user doesn't exist in the user pool. When set to `ENABLED` and the user doesn't exist, authentication returns an error indicating either the username or password was incorrect. Account confirmation and password recovery return a response indicating a code was sent to a simulated destination. When set to `LEGACY`, those APIs return a `UserNotFoundException` exception if the user doesn't exist in the user pool.

Valid values include:

  • `ENABLED` - This prevents user existence-related errors.

  • `LEGACY` - This represents the old behavior of Amazon Cognito where user existence related errors aren't prevented.

Returns:

  • (String)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#read_attributesArray<String>

The Read-only attributes.

Returns:

  • (Array<String>)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#refresh_token_validityInteger

The refresh token time limit. After this limit expires, your user can't use their refresh token. To specify the time unit for `RefreshTokenValidity` as `seconds`, `minutes`, `hours`, or `days`, set a `TokenValidityUnits` value in your API request.

For example, when you set `RefreshTokenValidity` as `10` and `TokenValidityUnits` as `days`, your user can refresh their session and retrieve new access and ID tokens for 10 days.

The default time unit for `RefreshTokenValidity` in an API request is days. You can't set `RefreshTokenValidity` to 0. If you do, Amazon Cognito overrides the value with the default value of 30 days. *Valid range* is displayed below in seconds.

Returns:

  • (Integer)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#supported_identity_providersArray<String>

A list of provider names for the IdPs that this client supports. The following are supported: `COGNITO`, `Facebook`, `Google` `LoginWithAmazon`, and the names of your own SAML and OIDC providers.

Returns:

  • (Array<String>)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#token_validity_unitsTypes::TokenValidityUnitsType

The time units used to specify the token validity times of each token type: ID, access, and refresh.



10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool client.

Returns:

  • (String)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#write_attributesArray<String>

The writeable attributes.

Returns:

  • (Array<String>)


10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10752

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation,
  :enable_propagate_additional_user_context_data)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end