Class: Aws::CognitoIdentityProvider::Types::UserPoolClientType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Contains information about a user pool client.

Constant Summary collapse

SENSITIVE =
[:client_id, :client_secret]

Instance Attribute Summary collapse

Instance Attribute Details

#access_token_validityInteger

The time limit, specified by tokenValidityUnits, defaulting to hours, after which the access token is no longer valid and can't be used.

Returns:

  • (Integer)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#allowed_o_auth_flowsArray<String>

The allowed OAuth flows.

Set to `code` to initiate a code grant flow, which provides an authorization code as the response. This code can be exchanged for access tokens with the token endpoint.

Set to `implicit` to specify that the client should get the access token (and, optionally, ID token, based on scopes) directly.

Set to `client_credentials` to specify that the client should get the access token (and, optionally, ID token, based on scopes) from the token endpoint using a combination of client and client_secret.

Returns:

  • (Array<String>)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#allowed_o_auth_flows_user_pool_clientBoolean

Set to true if the client is allowed to follow the OAuth protocol when interacting with Amazon Cognito user pools.

Returns:

  • (Boolean)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#allowed_o_auth_scopesArray<String>

The allowed OAuth scopes. Possible values provided by OAuth are: `phone`, `email`, `openid`, and `profile`. Possible values provided by Amazon Web Services are: `aws.cognito.signin.user.admin`. Custom scopes created in Resource Servers are also supported.

Returns:

  • (Array<String>)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#analytics_configurationTypes::AnalyticsConfigurationType

The Amazon Pinpoint analytics configuration for the user pool client.

<note markdown=“1”> Amazon Cognito user pools only support sending events to Amazon Pinpoint projects in the US East (N. Virginia) us-east-1 Region, regardless of the Region where the user pool resides.

</note>


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#callback_urlsArray<String>

A list of allowed redirect (callback) URLs for the identity providers.

A redirect URI must:

  • Be an absolute URI.

  • Be registered with the authorization server.

  • Not include a fragment component.

See [OAuth 2.0 - Redirection Endpoint].

Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.

App callback URLs such as myapp://example are also supported.

[1]: tools.ietf.org/html/rfc6749#section-3.1.2

Returns:

  • (Array<String>)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#client_idString

The ID of the client associated with the user pool.

Returns:

  • (String)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#client_nameString

The client name from the user pool request of the client type.

Returns:

  • (String)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#client_secretString

The client secret from the user pool request of the client type.

Returns:

  • (String)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#creation_dateTime

The date the user pool client was created.

Returns:

  • (Time)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#default_redirect_uriString

The default redirect URI. Must be in the `CallbackURLs` list.

A redirect URI must:

  • Be an absolute URI.

  • Be registered with the authorization server.

  • Not include a fragment component.

See [OAuth 2.0 - Redirection Endpoint].

Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.

App callback URLs such as myapp://example are also supported.

[1]: tools.ietf.org/html/rfc6749#section-3.1.2

Returns:

  • (String)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#enable_token_revocationBoolean

Indicates whether token revocation is activated for the user pool client. When you create a new user pool client, token revocation is activated by default. For more information about revoking tokens, see [RevokeToken].

[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RevokeToken.html

Returns:

  • (Boolean)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#explicit_auth_flowsArray<String>

The authentication flows that are supported by the user pool clients. Flow names without the `ALLOW_` prefix are no longer supported in favor of new names with the `ALLOW_` prefix. Note that values with `ALLOW_` prefix must be used only along with values including the `ALLOW_` prefix.

Valid values include:

  • `ALLOW_ADMIN_USER_PASSWORD_AUTH`: Enable admin based user password authentication flow `ADMIN_USER_PASSWORD_AUTH`. This setting replaces the `ADMIN_NO_SRP_AUTH` setting. With this authentication flow, Amazon Cognito receives the password in the request instead of using the Secure Remote Password (SRP) protocol to verify passwords.

  • `ALLOW_CUSTOM_AUTH`: Enable Lambda trigger based authentication.

  • `ALLOW_USER_PASSWORD_AUTH`: Enable user password-based authentication. In this flow, Amazon Cognito receives the password in the request instead of using the SRP protocol to verify passwords.

  • `ALLOW_USER_SRP_AUTH`: Enable SRP-based authentication.

  • `ALLOW_REFRESH_TOKEN_AUTH`: Enable authflow to refresh tokens.

Returns:

  • (Array<String>)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#id_token_validityInteger

The time limit specified by tokenValidityUnits, defaulting to hours, after which the refresh token is no longer valid and can't be used.

Returns:

  • (Integer)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#last_modified_dateTime

The date the user pool client was last modified.

Returns:

  • (Time)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#logout_urlsArray<String>

A list of allowed logout URLs for the identity providers.

Returns:

  • (Array<String>)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#prevent_user_existence_errorsString

Errors and responses that you want Amazon Cognito APIs to return during authentication, account confirmation, and password recovery when the user doesn't exist in the user pool. When set to `ENABLED` and the user doesn't exist, authentication returns an error indicating either the username or password was incorrect. Account confirmation and password recovery return a response indicating a code was sent to a simulated destination. When set to `LEGACY`, those APIs return a `UserNotFoundException` exception if the user doesn't exist in the user pool.

Valid values include:

  • `ENABLED` - This prevents user existence-related errors.

  • `LEGACY` - This represents the old behavior of Cognito where user existence related errors aren't prevented.

Returns:

  • (String)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#read_attributesArray<String>

The Read-only attributes.

Returns:

  • (Array<String>)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#refresh_token_validityInteger

The time limit, in days, after which the refresh token is no longer valid and can't be used.

Returns:

  • (Integer)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#supported_identity_providersArray<String>

A list of provider names for the identity providers that are supported on this client.

Returns:

  • (Array<String>)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#token_validity_unitsTypes::TokenValidityUnitsType

The time units used to specify the token validity times of their respective token.



10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#user_pool_idString

The user pool ID for the user pool client.

Returns:

  • (String)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end

#write_attributesArray<String>

The writeable attributes.

Returns:

  • (Array<String>)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10359

class UserPoolClientType < Struct.new(
  :user_pool_id,
  :client_name,
  :client_id,
  :client_secret,
  :last_modified_date,
  :creation_date,
  :refresh_token_validity,
  :access_token_validity,
  :id_token_validity,
  :token_validity_units,
  :read_attributes,
  :write_attributes,
  :explicit_auth_flows,
  :supported_identity_providers,
  :callback_urls,
  :logout_urls,
  :default_redirect_uri,
  :allowed_o_auth_flows,
  :allowed_o_auth_scopes,
  :allowed_o_auth_flows_user_pool_client,
  :analytics_configuration,
  :prevent_user_existence_errors,
  :enable_token_revocation)
  SENSITIVE = [:client_id, :client_secret]
  include Aws::Structure
end