Class: Aws::CognitoIdentityProvider::Types::UserPoolClientType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UserPoolClientType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Contains information about a user pool client.
Constant Summary collapse
- SENSITIVE =
[:client_id, :client_secret]
Instance Attribute Summary collapse
-
#access_token_validity ⇒ Integer
The time limit, specified by tokenValidityUnits, defaulting to hours, after which the access token is no longer valid and can't be used.
-
#allowed_o_auth_flows ⇒ Array<String>
The allowed OAuth flows.
-
#allowed_o_auth_flows_user_pool_client ⇒ Boolean
Set to true if the client is allowed to follow the OAuth protocol when interacting with Amazon Cognito user pools.
-
#allowed_o_auth_scopes ⇒ Array<String>
The allowed OAuth scopes.
-
#analytics_configuration ⇒ Types::AnalyticsConfigurationType
The Amazon Pinpoint analytics configuration for the user pool client.
-
#callback_urls ⇒ Array<String>
A list of allowed redirect (callback) URLs for the identity providers.
-
#client_id ⇒ String
The ID of the client associated with the user pool.
-
#client_name ⇒ String
The client name from the user pool request of the client type.
-
#client_secret ⇒ String
The client secret from the user pool request of the client type.
-
#creation_date ⇒ Time
The date the user pool client was created.
-
#default_redirect_uri ⇒ String
The default redirect URI.
-
#enable_token_revocation ⇒ Boolean
Indicates whether token revocation is activated for the user pool client.
-
#explicit_auth_flows ⇒ Array<String>
The authentication flows that are supported by the user pool clients.
-
#id_token_validity ⇒ Integer
The time limit specified by tokenValidityUnits, defaulting to hours, after which the refresh token is no longer valid and can't be used.
-
#last_modified_date ⇒ Time
The date the user pool client was last modified.
-
#logout_urls ⇒ Array<String>
A list of allowed logout URLs for the identity providers.
-
#prevent_user_existence_errors ⇒ String
Errors and responses that you want Amazon Cognito APIs to return during authentication, account confirmation, and password recovery when the user doesn't exist in the user pool.
-
#read_attributes ⇒ Array<String>
The Read-only attributes.
-
#refresh_token_validity ⇒ Integer
The time limit, in days, after which the refresh token is no longer valid and can't be used.
-
#supported_identity_providers ⇒ Array<String>
A list of provider names for the identity providers that are supported on this client.
-
#token_validity_units ⇒ Types::TokenValidityUnitsType
The time units used to specify the token validity times of their respective token.
-
#user_pool_id ⇒ String
The user pool ID for the user pool client.
-
#write_attributes ⇒ Array<String>
The writeable attributes.
Instance Attribute Details
#access_token_validity ⇒ Integer
The time limit, specified by tokenValidityUnits, defaulting to hours, after which the access token is no longer valid and can't be used.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#allowed_o_auth_flows ⇒ Array<String>
The allowed OAuth flows.
Set to `code` to initiate a code grant flow, which provides an authorization code as the response. This code can be exchanged for access tokens with the token endpoint.
Set to `implicit` to specify that the client should get the access token (and, optionally, ID token, based on scopes) directly.
Set to `client_credentials` to specify that the client should get the access token (and, optionally, ID token, based on scopes) from the token endpoint using a combination of client and client_secret.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#allowed_o_auth_flows_user_pool_client ⇒ Boolean
Set to true if the client is allowed to follow the OAuth protocol when interacting with Amazon Cognito user pools.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#allowed_o_auth_scopes ⇒ Array<String>
The allowed OAuth scopes. Possible values provided by OAuth are: `phone`, `email`, `openid`, and `profile`. Possible values provided by Amazon Web Services are: `aws.cognito.signin.user.admin`. Custom scopes created in Resource Servers are also supported.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#analytics_configuration ⇒ Types::AnalyticsConfigurationType
The Amazon Pinpoint analytics configuration for the user pool client.
<note markdown=“1”> Amazon Cognito User Pools only supports sending events to Amazon Pinpoint projects in the US East (N. Virginia) us-east-1 Region, regardless of the Region in which the user pool resides.
</note>
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#callback_urls ⇒ Array<String>
A list of allowed redirect (callback) URLs for the identity providers.
A redirect URI must:
-
Be an absolute URI.
-
Be registered with the authorization server.
-
Not include a fragment component.
See [OAuth 2.0 - Redirection Endpoint].
Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.
App callback URLs such as myapp://example are also supported.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#client_id ⇒ String
The ID of the client associated with the user pool.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#client_name ⇒ String
The client name from the user pool request of the client type.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#client_secret ⇒ String
The client secret from the user pool request of the client type.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#creation_date ⇒ Time
The date the user pool client was created.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#default_redirect_uri ⇒ String
The default redirect URI. Must be in the `CallbackURLs` list.
A redirect URI must:
-
Be an absolute URI.
-
Be registered with the authorization server.
-
Not include a fragment component.
See [OAuth 2.0 - Redirection Endpoint].
Amazon Cognito requires HTTPS over HTTP except for localhost for testing purposes only.
App callback URLs such as myapp://example are also supported.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#enable_token_revocation ⇒ Boolean
Indicates whether token revocation is activated for the user pool client. When you create a new user pool client, token revocation is activated by default. For more information about revoking tokens, see [RevokeToken].
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RevokeToken.html
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#explicit_auth_flows ⇒ Array<String>
The authentication flows that are supported by the user pool clients. Flow names without the `ALLOW_` prefix are no longer supported in favor of new names with the `ALLOW_` prefix. Note that values with `ALLOW_` prefix must be used only along with values including the `ALLOW_` prefix.
Valid values include:
-
`ALLOW_ADMIN_USER_PASSWORD_AUTH`: Enable admin based user password authentication flow `ADMIN_USER_PASSWORD_AUTH`. This setting replaces the `ADMIN_NO_SRP_AUTH` setting. With this authentication flow, Amazon Cognito receives the password in the request instead of using the Secure Remote Password (SRP) protocol to verify passwords.
-
`ALLOW_CUSTOM_AUTH`: Enable Lambda trigger based authentication.
-
`ALLOW_USER_PASSWORD_AUTH`: Enable user password-based authentication. In this flow, Amazon Cognito receives the password in the request instead of using the SRP protocol to verify passwords.
-
`ALLOW_USER_SRP_AUTH`: Enable SRP-based authentication.
-
`ALLOW_REFRESH_TOKEN_AUTH`: Enable authflow to refresh tokens.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#id_token_validity ⇒ Integer
The time limit specified by tokenValidityUnits, defaulting to hours, after which the refresh token is no longer valid and can't be used.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#last_modified_date ⇒ Time
The date the user pool client was last modified.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#logout_urls ⇒ Array<String>
A list of allowed logout URLs for the identity providers.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#prevent_user_existence_errors ⇒ String
Errors and responses that you want Amazon Cognito APIs to return during authentication, account confirmation, and password recovery when the user doesn't exist in the user pool. When set to `ENABLED` and the user doesn't exist, authentication returns an error indicating either the username or password was incorrect. Account confirmation and password recovery return a response indicating a code was sent to a simulated destination. When set to `LEGACY`, those APIs return a `UserNotFoundException` exception if the user doesn't exist in the user pool.
Valid values include:
-
`ENABLED` - This prevents user existence-related errors.
-
`LEGACY` - This represents the old behavior of Cognito where user existence related errors aren't prevented.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#read_attributes ⇒ Array<String>
The Read-only attributes.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#refresh_token_validity ⇒ Integer
The time limit, in days, after which the refresh token is no longer valid and can't be used.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#supported_identity_providers ⇒ Array<String>
A list of provider names for the identity providers that are supported on this client.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#token_validity_units ⇒ Types::TokenValidityUnitsType
The time units used to specify the token validity times of their respective token.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#user_pool_id ⇒ String
The user pool ID for the user pool client.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |
#write_attributes ⇒ Array<String>
The writeable attributes.
10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 10290 10291 10292 10293 10294 10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10278 class UserPoolClientType < Struct.new( :user_pool_id, :client_name, :client_id, :client_secret, :last_modified_date, :creation_date, :refresh_token_validity, :access_token_validity, :id_token_validity, :token_validity_units, :read_attributes, :write_attributes, :explicit_auth_flows, :supported_identity_providers, :callback_urls, :logout_urls, :default_redirect_uri, :allowed_o_auth_flows, :allowed_o_auth_scopes, :allowed_o_auth_flows_user_pool_client, :analytics_configuration, :prevent_user_existence_errors, :enable_token_revocation) SENSITIVE = [:client_id, :client_secret] include Aws::Structure end |