Class: Aws::CognitoIdentityProvider::Types::UserPoolDescriptionType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

A short description of a user pool.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_dateTime

The date and time when the item was created. Amazon Cognito returns this timestamp in UNIX epoch time format. Your SDK might render the output in a human-readable format like ISO 8601 or a Java ‘Date` object.

Returns:

  • (Time)


13895
13896
13897
13898
13899
13900
13901
13902
13903
13904
13905
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895

class UserPoolDescriptionType < Struct.new(
  :id,
  :name,
  :lambda_config,
  :status,
  :last_modified_date,
  :creation_date,
  :replica_regions)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The user pool ID.

Returns:

  • (String)


13895
13896
13897
13898
13899
13900
13901
13902
13903
13904
13905
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895

class UserPoolDescriptionType < Struct.new(
  :id,
  :name,
  :lambda_config,
  :status,
  :last_modified_date,
  :creation_date,
  :replica_regions)
  SENSITIVE = []
  include Aws::Structure
end

#lambda_configTypes::LambdaConfigType

A collection of user pool Lambda triggers. Amazon Cognito invokes triggers at several possible stages of user pool operations. Triggers can modify the outcome of the operations that invoked them.



13895
13896
13897
13898
13899
13900
13901
13902
13903
13904
13905
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895

class UserPoolDescriptionType < Struct.new(
  :id,
  :name,
  :lambda_config,
  :status,
  :last_modified_date,
  :creation_date,
  :replica_regions)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The date and time when the item was modified. Amazon Cognito returns this timestamp in UNIX epoch time format. Your SDK might render the output in a human-readable format like ISO 8601 or a Java ‘Date` object.

Returns:

  • (Time)


13895
13896
13897
13898
13899
13900
13901
13902
13903
13904
13905
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895

class UserPoolDescriptionType < Struct.new(
  :id,
  :name,
  :lambda_config,
  :status,
  :last_modified_date,
  :creation_date,
  :replica_regions)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The user pool name.

Returns:

  • (String)


13895
13896
13897
13898
13899
13900
13901
13902
13903
13904
13905
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895

class UserPoolDescriptionType < Struct.new(
  :id,
  :name,
  :lambda_config,
  :status,
  :last_modified_date,
  :creation_date,
  :replica_regions)
  SENSITIVE = []
  include Aws::Structure
end

#replica_regionsArray<String>

A list of Amazon Web Services Regions where replicas of this user pool exist.

Returns:

  • (Array<String>)


13895
13896
13897
13898
13899
13900
13901
13902
13903
13904
13905
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895

class UserPoolDescriptionType < Struct.new(
  :id,
  :name,
  :lambda_config,
  :status,
  :last_modified_date,
  :creation_date,
  :replica_regions)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The user pool status.

Returns:

  • (String)


13895
13896
13897
13898
13899
13900
13901
13902
13903
13904
13905
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895

class UserPoolDescriptionType < Struct.new(
  :id,
  :name,
  :lambda_config,
  :status,
  :last_modified_date,
  :creation_date,
  :replica_regions)
  SENSITIVE = []
  include Aws::Structure
end