Class: Aws::CognitoIdentityProvider::Types::UserPoolDescriptionType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UserPoolDescriptionType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A short description of a user pool.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date and time when the item was created.
-
#id ⇒ String
The user pool ID.
-
#lambda_config ⇒ Types::LambdaConfigType
A collection of user pool Lambda triggers.
-
#last_modified_date ⇒ Time
The date and time when the item was modified.
-
#name ⇒ String
The user pool name.
-
#replica_regions ⇒ Array<String>
A list of Amazon Web Services Regions where replicas of this user pool exist.
-
#status ⇒ String
The user pool status.
Instance Attribute Details
#creation_date ⇒ Time
The date and time when the item was created. Amazon Cognito returns this timestamp in UNIX epoch time format. Your SDK might render the output in a human-readable format like ISO 8601 or a Java ‘Date` object.
13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date, :replica_regions) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The user pool ID.
13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date, :replica_regions) SENSITIVE = [] include Aws::Structure end |
#lambda_config ⇒ Types::LambdaConfigType
A collection of user pool Lambda triggers. Amazon Cognito invokes triggers at several possible stages of user pool operations. Triggers can modify the outcome of the operations that invoked them.
13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date, :replica_regions) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date and time when the item was modified. Amazon Cognito returns this timestamp in UNIX epoch time format. Your SDK might render the output in a human-readable format like ISO 8601 or a Java ‘Date` object.
13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date, :replica_regions) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The user pool name.
13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date, :replica_regions) SENSITIVE = [] include Aws::Structure end |
#replica_regions ⇒ Array<String>
A list of Amazon Web Services Regions where replicas of this user pool exist.
13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date, :replica_regions) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The user pool status.
13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13895 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date, :replica_regions) SENSITIVE = [] include Aws::Structure end |