Class: Aws::CognitoIdentityProvider::Types::UserPoolDescriptionType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UserPoolDescriptionType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A user pool description.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date the user pool description was created.
-
#id ⇒ String
The ID in a user pool description.
-
#lambda_config ⇒ Types::LambdaConfigType
The Lambda configuration information in a user pool description.
-
#last_modified_date ⇒ Time
The date the user pool description was last modified.
-
#name ⇒ String
The name in a user pool description.
-
#status ⇒ String
The user pool status in a user pool description.
Instance Attribute Details
#creation_date ⇒ Time
The date the user pool description was created.
10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10677 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID in a user pool description.
10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10677 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#lambda_config ⇒ Types::LambdaConfigType
The Lambda configuration information in a user pool description.
10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10677 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date the user pool description was last modified.
10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10677 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name in a user pool description.
10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10677 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The user pool status in a user pool description.
10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10677 class UserPoolDescriptionType < Struct.new( :id, :name, :lambda_config, :status, :last_modified_date, :creation_date) SENSITIVE = [] include Aws::Structure end |