Class: Aws::CognitoIdentityProvider::Types::UserPoolReplicaType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::UserPoolReplicaType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Contains information about a replica user pool, including Region, status, role, and ARN.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#region_name ⇒ String
The Amazon Web Services Region where the replica is located.
-
#role ⇒ String
The role of the user pool replica that determines which API operations are enabled.
-
#status ⇒ String
The current status of the replica.
-
#user_pool_arn ⇒ String
The Amazon Resource Name (ARN) of the replica user pool.
Instance Attribute Details
#region_name ⇒ String
The Amazon Web Services Region where the replica is located.
13981 13982 13983 13984 13985 13986 13987 13988 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13981 class UserPoolReplicaType < Struct.new( :region_name, :status, :role, :user_pool_arn) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role of the user pool replica that determines which API operations are enabled.
PRIMARY
: The primary replica supports all end user and administrator
operations.
SECONDARY
: The secondary replica supports a limited set of end user and
administrator operations. Generally, only administrator operations
that set configurations specific to the replica, and only end-user
operations that do not create or change attributes of a user are
supported.
13981 13982 13983 13984 13985 13986 13987 13988 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13981 class UserPoolReplicaType < Struct.new( :region_name, :status, :role, :user_pool_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the replica.
CREATING
: The replica is being created.
INACTIVE
: The replica has been created, but is not accepting requests for
end-users. Administrator configuration operations are supported.
ACTIVE
: The replica is available for both end-user and administrator
operations.
DELETING
: The replica is being deleted.
13981 13982 13983 13984 13985 13986 13987 13988 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13981 class UserPoolReplicaType < Struct.new( :region_name, :status, :role, :user_pool_arn) SENSITIVE = [] include Aws::Structure end |
#user_pool_arn ⇒ String
The Amazon Resource Name (ARN) of the replica user pool.
13981 13982 13983 13984 13985 13986 13987 13988 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 13981 class UserPoolReplicaType < Struct.new( :region_name, :status, :role, :user_pool_arn) SENSITIVE = [] include Aws::Structure end |