Class: Aws::CognitoIdentityProvider::Types::UsernameConfigurationType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

The username configuration type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#case_sensitiveBoolean

Specifies whether user name case sensitivity will be applied for all users in the user pool through Amazon Cognito APIs.

Valid values include:

True

: Enables case sensitivity for all username input. When this option

is set to `True`, users must sign in using the exact
capitalization of their given username, such as “UserName”. This
is the default value.

False

: Enables case insensitivity for all username input. For example,

when this option is set to `False`, users can sign in using either
"username" or "Username". This option also enables both
`preferred_username` and `email` alias to be case insensitive, in
addition to the `username` attribute.

Returns:

  • (Boolean)


9559
9560
9561
9562
9563
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 9559

class UsernameConfigurationType < Struct.new(
  :case_sensitive)
  SENSITIVE = []
  include Aws::Structure
end