Class: Aws::CognitoIdentityProvider::Types::VerificationMessageTemplateType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::VerificationMessageTemplateType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass VerificationMessageTemplateType data as a hash:
{
sms_message: "SmsVerificationMessageType",
email_message: "EmailVerificationMessageType",
email_subject: "EmailVerificationSubjectType",
email_message_by_link: "EmailVerificationMessageByLinkType",
email_subject_by_link: "EmailVerificationSubjectByLinkType",
default_email_option: "CONFIRM_WITH_LINK", # accepts CONFIRM_WITH_LINK, CONFIRM_WITH_CODE
}
The template for verification messages.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_email_option ⇒ String
The default email option.
-
#email_message ⇒ String
The template for email messages that Amazon Cognito sends to your users.
-
#email_message_by_link ⇒ String
The email message template for sending a confirmation link to the user.
-
#email_subject ⇒ String
The subject line for the email message template.
-
#email_subject_by_link ⇒ String
The subject line for the email message template for sending a confirmation link to the user.
-
#sms_message ⇒ String
The template for SMS messages that Amazon Cognito sends to your users.
Instance Attribute Details
#default_email_option ⇒ String
The default email option.
11160 11161 11162 11163 11164 11165 11166 11167 11168 11169 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11160 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_message ⇒ String
The template for email messages that Amazon Cognito sends to your users. You can set an `EmailMessage` template only if the value of [ EmailSendingAccount] is `DEVELOPER`. When your
- EmailSendingAccount][1
-
is `DEVELOPER`, your user pool sends email
messages with your own Amazon SES configuration.
11160 11161 11162 11163 11164 11165 11166 11167 11168 11169 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11160 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_message_by_link ⇒ String
The email message template for sending a confirmation link to the user. You can set an `EmailMessageByLink` template only if the value of [ EmailSendingAccount] is `DEVELOPER`. When your
- EmailSendingAccount][1
-
is `DEVELOPER`, your user pool sends email
messages with your own Amazon SES configuration.
11160 11161 11162 11163 11164 11165 11166 11167 11168 11169 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11160 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_subject ⇒ String
The subject line for the email message template. You can set an `EmailSubject` template only if the value of [ EmailSendingAccount] is `DEVELOPER`. When your
- EmailSendingAccount][1
-
is `DEVELOPER`, your user pool sends email
messages with your own Amazon SES configuration.
11160 11161 11162 11163 11164 11165 11166 11167 11168 11169 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11160 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_subject_by_link ⇒ String
The subject line for the email message template for sending a confirmation link to the user. You can set an `EmailSubjectByLink` template only if the value of [ EmailSendingAccount] is `DEVELOPER`. When your [EmailSendingAccount] is `DEVELOPER`, your user pool sends email messages with your own Amazon SES configuration.
11160 11161 11162 11163 11164 11165 11166 11167 11168 11169 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11160 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#sms_message ⇒ String
The template for SMS messages that Amazon Cognito sends to your users.
11160 11161 11162 11163 11164 11165 11166 11167 11168 11169 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11160 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |