Class: Aws::CognitoIdentityProvider::Types::VerificationMessageTemplateType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::VerificationMessageTemplateType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
When making an API call, you may pass VerificationMessageTemplateType data as a hash:
{
sms_message: "SmsVerificationMessageType",
email_message: "EmailVerificationMessageType",
email_subject: "EmailVerificationSubjectType",
email_message_by_link: "EmailVerificationMessageByLinkType",
email_subject_by_link: "EmailVerificationSubjectByLinkType",
default_email_option: "CONFIRM_WITH_LINK", # accepts CONFIRM_WITH_LINK, CONFIRM_WITH_CODE
}
The template for verification messages.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_email_option ⇒ String
The default email option.
-
#email_message ⇒ String
The email message template.
-
#email_message_by_link ⇒ String
The email message template for sending a confirmation link to the user.
-
#email_subject ⇒ String
The subject line for the email message template.
-
#email_subject_by_link ⇒ String
The subject line for the email message template for sending a confirmation link to the user.
-
#sms_message ⇒ String
The SMS message template.
Instance Attribute Details
#default_email_option ⇒ String
The default email option.
10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10880 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_message ⇒ String
The email message template. EmailMessage is allowed only if [ EmailSendingAccount] is DEVELOPER.
10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10880 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_message_by_link ⇒ String
The email message template for sending a confirmation link to the user. EmailMessageByLink is allowed only if [ EmailSendingAccount] is DEVELOPER.
10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10880 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_subject ⇒ String
The subject line for the email message template. EmailSubject is allowed only if [EmailSendingAccount] is DEVELOPER.
10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10880 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#email_subject_by_link ⇒ String
The subject line for the email message template for sending a confirmation link to the user. EmailSubjectByLink is allowed only [ EmailSendingAccount] is DEVELOPER.
10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10880 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |
#sms_message ⇒ String
The SMS message template.
10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10880 class VerificationMessageTemplateType < Struct.new( :sms_message, :email_message, :email_subject, :email_message_by_link, :email_subject_by_link, :default_email_option) SENSITIVE = [] include Aws::Structure end |