Class: Aws::CognitoIdentityProvider::Types::VerifySoftwareTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::VerifySoftwareTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Note:
When making an API call, you may pass VerifySoftwareTokenRequest data as a hash:
{
access_token: "TokenModelType",
session: "SessionType",
user_code: "SoftwareTokenMFAUserCodeType", # required
friendly_device_name: "StringType",
}
Constant Summary collapse
- SENSITIVE =
[:access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token.
-
#friendly_device_name ⇒ String
The friendly device name.
-
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service.
-
#user_code ⇒ String
The one- time password computed using the secret code returned by [AssociateSoftwareToken].
Instance Attribute Details
#access_token ⇒ String
The access token.
10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10831 class VerifySoftwareTokenRequest < Struct.new( :access_token, :session, :user_code, :friendly_device_name) SENSITIVE = [:access_token] include Aws::Structure end |
#friendly_device_name ⇒ String
The friendly device name.
10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10831 class VerifySoftwareTokenRequest < Struct.new( :access_token, :session, :user_code, :friendly_device_name) SENSITIVE = [:access_token] include Aws::Structure end |
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service.
10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10831 class VerifySoftwareTokenRequest < Struct.new( :access_token, :session, :user_code, :friendly_device_name) SENSITIVE = [:access_token] include Aws::Structure end |
#user_code ⇒ String
The one- time password computed using the secret code returned by [AssociateSoftwareToken].
[1]: docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AssociateSoftwareToken.html
10831 10832 10833 10834 10835 10836 10837 10838 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 10831 class VerifySoftwareTokenRequest < Struct.new( :access_token, :session, :user_code, :friendly_device_name) SENSITIVE = [:access_token] include Aws::Structure end |