Class: Aws::CognitoIdentityProvider::Types::VerifySoftwareTokenResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentityprovider/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:session]

Instance Attribute Summary collapse

Instance Attribute Details

#sessionString

This session ID satisfies an ‘MFA_SETUP` challenge. Supply the session ID in your challenge response.

Returns:

  • (String)


14579
14580
14581
14582
14583
14584
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14579

class VerifySoftwareTokenResponse < Struct.new(
  :status,
  :session)
  SENSITIVE = [:session]
  include Aws::Structure
end

#statusString

Amazon Cognito can accept or reject the code that you provide. This response parameter indicates the success of TOTP verification. Some reasons that this operation might return an error are clock skew on the user’s device and excessive retries.

Returns:

  • (String)


14579
14580
14581
14582
14583
14584
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14579

class VerifySoftwareTokenResponse < Struct.new(
  :status,
  :session)
  SENSITIVE = [:session]
  include Aws::Structure
end