Class: Aws::CognitoIdentityProvider::Types::VerifySoftwareTokenResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::VerifySoftwareTokenResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:session]
Instance Attribute Summary collapse
-
#session ⇒ String
This session ID satisfies an ‘MFA_SETUP` challenge.
-
#status ⇒ String
Amazon Cognito can accept or reject the code that you provide.
Instance Attribute Details
#session ⇒ String
This session ID satisfies an ‘MFA_SETUP` challenge. Supply the session ID in your challenge response.
14579 14580 14581 14582 14583 14584 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14579 class VerifySoftwareTokenResponse < Struct.new( :status, :session) SENSITIVE = [:session] include Aws::Structure end |
#status ⇒ String
Amazon Cognito can accept or reject the code that you provide. This response parameter indicates the success of TOTP verification. Some reasons that this operation might return an error are clock skew on the user’s device and excessive retries.
14579 14580 14581 14582 14583 14584 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14579 class VerifySoftwareTokenResponse < Struct.new( :status, :session) SENSITIVE = [:session] include Aws::Structure end |