Class: Aws::CognitoIdentityProvider::Types::VerifySoftwareTokenResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::VerifySoftwareTokenResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service.
-
#status ⇒ String
The status of the verify software token.
Instance Attribute Details
#session ⇒ String
The session that should be passed both ways in challenge-response calls to the service.
11604 11605 11606 11607 11608 11609 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11604 class VerifySoftwareTokenResponse < Struct.new( :status, :session) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the verify software token.
11604 11605 11606 11607 11608 11609 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 11604 class VerifySoftwareTokenResponse < Struct.new( :status, :session) SENSITIVE = [] include Aws::Structure end |