Class: Aws::CognitoIdentityProvider::Types::WebAuthnMfaSettingsType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CognitoIdentityProvider::Types::WebAuthnMfaSettingsType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cognitoidentityprovider/types.rb
Overview
A user’s preference for using passkey, or WebAuthn, multi-factor authentication (MFA). Turns passkey MFA on and off for the user. Unlike other MFA settings types, this type doesn’t include a ‘PreferredMfa` option because passkey MFA applies only when passkey is the first authentication factor.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Specifies whether passkey MFA is activated for a user.
Instance Attribute Details
#enabled ⇒ Boolean
Specifies whether passkey MFA is activated for a user. When activated, the user’s passkey authentication requires user verification, and passkey sign-in is available when MFA is required. The user must also have at least one other MFA method such as SMS, TOTP, or email activated to prevent account lockout.
14403 14404 14405 14406 14407 |
# File 'lib/aws-sdk-cognitoidentityprovider/types.rb', line 14403 class WebAuthnMfaSettingsType < Struct.new( :enabled) SENSITIVE = [] include Aws::Structure end |